# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: azure/azure_microsoft_compute.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#azure/azure_microsoft_compute.proto\x12#oak9.tython.azure.microsoft_compute\x1a\x13shared/shared.proto\"\xde\x04\n\x11Microsoft_Compute\x12P\n\x11\x61vailability_sets\x18\x01 \x03(\x0b\x32\x35.oak9.tython.azure.microsoft_compute.AvailabilitySets\x12\x63\n\x1b\x63\x61pacity_reservation_groups\x18\x02 \x03(\x0b\x32>.oak9.tython.azure.microsoft_compute.CapacityReservationGroups\x12\x44\n\x0bhost_groups\x18\x03 \x03(\x0b\x32/.oak9.tython.azure.microsoft_compute.HostGroups\x12;\n\x06images\x18\x04 \x03(\x0b\x32+.oak9.tython.azure.microsoft_compute.Images\x12\x61\n\x1aproximity_placement_groups\x18\x05 \x03(\x0b\x32=.oak9.tython.azure.microsoft_compute.ProximityPlacementGroups\x12_\n\x19restore_point_collections\x18\x06 \x03(\x0b\x32<.oak9.tython.azure.microsoft_compute.RestorePointCollections\x12K\n\x0fssh_public_keys\x18\x07 \x03(\x0b\x32\x32.oak9.tython.azure.microsoft_compute.SshPublicKeys\"\xf5\x01\n\rSshPublicKeys\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08location\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x12\n\npublic_key\x18\x04 \x01(\t\x12J\n\x04tags\x18\x05 \x03(\x0b\x32<.oak9.tython.azure.microsoft_compute.SshPublicKeys.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xaa\x02\n$RestorePointCollectionsRestorePoints\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12N\n\rexclude_disks\x18\x03 \x03(\x0b\x32\x37.oak9.tython.azure.microsoft_compute.ApiEntityReference\x12U\n\x14source_restore_point\x18\x04 \x01(\x0b\x32\x37.oak9.tython.azure.microsoft_compute.ApiEntityReference\x12\x14\n\x0ctime_created\x18\x05 \x01(\t\" \n\x12\x41piEntityReference\x12\n\n\x02id\x18\x01 \x01(\t\"\xcf\x03\n\x17RestorePointCollections\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08location\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12[\n\x06source\x18\x04 \x01(\x0b\x32K.oak9.tython.azure.microsoft_compute.RestorePointCollectionSourceProperties\x12T\n\x04tags\x18\x05 \x03(\x0b\x32\x46.oak9.tython.azure.microsoft_compute.RestorePointCollections.TagsEntry\x12{\n(restore_point_collections_restore_points\x18\x06 \x03(\x0b\x32I.oak9.tython.azure.microsoft_compute.RestorePointCollectionsRestorePoints\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"4\n&RestorePointCollectionSourceProperties\x12\n\n\x02id\x18\x01 \x01(\t\"\xf3\x02\n\x18ProximityPlacementGroups\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08location\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12R\n\x11\x63olocation_status\x18\x04 \x01(\x0b\x32\x37.oak9.tython.azure.microsoft_compute.InstanceViewStatus\x12&\n\x1eproximity_placement_group_type\x18\x05 \x01(\t\x12U\n\x04tags\x18\x06 \x03(\x0b\x32G.oak9.tython.azure.microsoft_compute.ProximityPlacementGroups.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"h\n\x12InstanceViewStatus\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\x12\x16\n\x0e\x64isplay_status\x18\x02 \x01(\t\x12\r\n\x05level\x18\x03 \x01(\t\x12\x0f\n\x07message\x18\x04 \x01(\t\x12\x0c\n\x04time\x18\x05 \x01(\t\"\xb4\x03\n\x06Images\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12P\n\x11\x65xtended_location\x18\x02 \x01(\x0b\x32\x35.oak9.tython.azure.microsoft_compute.ExtendedLocation\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x1a\n\x12hyper_v_generation\x18\x05 \x01(\t\x12\x1e\n\x16source_virtual_machine\x18\x06 \x01(\t\x12Q\n\x0fstorage_profile\x18\x07 \x01(\x0b\x32\x38.oak9.tython.azure.microsoft_compute.ImageStorageProfile\x12\x43\n\x04tags\x18\x08 \x03(\x0b\x32\x35.oak9.tython.azure.microsoft_compute.Images.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb8\x01\n\x13ImageStorageProfile\x12\x46\n\ndata_disks\x18\x01 \x03(\x0b\x32\x32.oak9.tython.azure.microsoft_compute.ImageDataDisk\x12\x41\n\x07os_disk\x18\x02 \x01(\x0b\x32\x30.oak9.tython.azure.microsoft_compute.ImageOSDisk\x12\x16\n\x0ezone_resilient\x18\x03 \x01(\x08\"\x8e\x02\n\x0bImageOSDisk\x12\x10\n\x08\x62lob_uri\x18\x01 \x01(\t\x12\x0f\n\x07\x63\x61\x63hing\x18\x02 \x01(\t\x12]\n\x13\x64isk_encryption_set\x18\x03 \x01(\x0b\x32@.oak9.tython.azure.microsoft_compute.DiskEncryptionSetParameters\x12\x14\n\x0c\x64isk_size_gb\x18\x04 \x01(\x05\x12\x14\n\x0cmanaged_disk\x18\x05 \x01(\t\x12\x10\n\x08os_state\x18\x06 \x01(\t\x12\x0f\n\x07os_type\x18\x07 \x01(\t\x12\x10\n\x08snapshot\x18\x08 \x01(\t\x12\x1c\n\x14storage_account_type\x18\t \x01(\t\"\xfa\x01\n\rImageDataDisk\x12\x10\n\x08\x62lob_uri\x18\x01 \x01(\t\x12\x0f\n\x07\x63\x61\x63hing\x18\x02 \x01(\t\x12]\n\x13\x64isk_encryption_set\x18\x03 \x01(\x0b\x32@.oak9.tython.azure.microsoft_compute.DiskEncryptionSetParameters\x12\x14\n\x0c\x64isk_size_gb\x18\x04 \x01(\x05\x12\x0b\n\x03lun\x18\x05 \x01(\x05\x12\x14\n\x0cmanaged_disk\x18\x06 \x01(\t\x12\x10\n\x08snapshot\x18\x07 \x01(\t\x12\x1c\n\x14storage_account_type\x18\x08 \x01(\t\")\n\x1b\x44iskEncryptionSetParameters\x12\n\n\x02id\x18\x01 \x01(\t\".\n\x10\x45xtendedLocation\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\"\xf2\x02\n\x0fHostGroupsHosts\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08location\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x1f\n\x17\x61uto_replace_on_failure\x18\x04 \x01(\x08\x12\x14\n\x0clicense_type\x18\x05 \x01(\t\x12\x1d\n\x15platform_fault_domain\x18\x06 \x01(\x05\x12\x35\n\x03sku\x18\x07 \x01(\x0b\x32(.oak9.tython.azure.microsoft_compute.Sku\x12L\n\x04tags\x18\x08 \x03(\x0b\x32>.oak9.tython.azure.microsoft_compute.HostGroupsHosts.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x85\x03\n\nHostGroups\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08location\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12#\n\x1bplatform_fault_domain_count\x18\x04 \x01(\x05\x12#\n\x1bsupport_automatic_placement\x18\x05 \x01(\x08\x12G\n\x04tags\x18\x06 \x03(\x0b\x32\x39.oak9.tython.azure.microsoft_compute.HostGroups.TagsEntry\x12\r\n\x05zones\x18\x07 \x03(\t\x12O\n\x11host_groups_hosts\x18\x08 \x03(\x0b\x32\x34.oak9.tython.azure.microsoft_compute.HostGroupsHosts\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xe7\x02\n-CapacityReservationGroupsCapacityReservations\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08location\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x35\n\x03sku\x18\x04 \x01(\x0b\x32(.oak9.tython.azure.microsoft_compute.Sku\x12j\n\x04tags\x18\x05 \x03(\x0b\x32\\.oak9.tython.azure.microsoft_compute.CapacityReservationGroupsCapacityReservations.TagsEntry\x12\r\n\x05zones\x18\x06 \x03(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x98\x03\n\x19\x43\x61pacityReservationGroups\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08location\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12V\n\x04tags\x18\x04 \x03(\x0b\x32H.oak9.tython.azure.microsoft_compute.CapacityReservationGroups.TagsEntry\x12\r\n\x05zones\x18\x05 \x03(\t\x12\x8d\x01\n1capacity_reservation_groups_capacity_reservations\x18\x06 \x03(\x0b\x32R.oak9.tython.azure.microsoft_compute.CapacityReservationGroupsCapacityReservations\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa6\x03\n\x10\x41vailabilitySets\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08location\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12#\n\x1bplatform_fault_domain_count\x18\x04 \x01(\x05\x12$\n\x1cplatform_update_domain_count\x18\x05 \x01(\x05\x12!\n\x19proximity_placement_group\x18\x06 \x01(\t\x12\x18\n\x10virtual_machines\x18\x07 \x03(\t\x12\x35\n\x03sku\x18\x08 \x01(\x0b\x32(.oak9.tython.azure.microsoft_compute.Sku\x12M\n\x04tags\x18\t \x03(\x0b\x32?.oak9.tython.azure.microsoft_compute.AvailabilitySets.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"3\n\x03Sku\x12\x10\n\x08\x63\x61pacity\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04tier\x18\x03 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'azure.azure_microsoft_compute_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SSHPUBLICKEYS_TAGSENTRY._options = None
  _SSHPUBLICKEYS_TAGSENTRY._serialized_options = b'8\001'
  _RESTOREPOINTCOLLECTIONS_TAGSENTRY._options = None
  _RESTOREPOINTCOLLECTIONS_TAGSENTRY._serialized_options = b'8\001'
  _PROXIMITYPLACEMENTGROUPS_TAGSENTRY._options = None
  _PROXIMITYPLACEMENTGROUPS_TAGSENTRY._serialized_options = b'8\001'
  _IMAGES_TAGSENTRY._options = None
  _IMAGES_TAGSENTRY._serialized_options = b'8\001'
  _HOSTGROUPSHOSTS_TAGSENTRY._options = None
  _HOSTGROUPSHOSTS_TAGSENTRY._serialized_options = b'8\001'
  _HOSTGROUPS_TAGSENTRY._options = None
  _HOSTGROUPS_TAGSENTRY._serialized_options = b'8\001'
  _CAPACITYRESERVATIONGROUPSCAPACITYRESERVATIONS_TAGSENTRY._options = None
  _CAPACITYRESERVATIONGROUPSCAPACITYRESERVATIONS_TAGSENTRY._serialized_options = b'8\001'
  _CAPACITYRESERVATIONGROUPS_TAGSENTRY._options = None
  _CAPACITYRESERVATIONGROUPS_TAGSENTRY._serialized_options = b'8\001'
  _AVAILABILITYSETS_TAGSENTRY._options = None
  _AVAILABILITYSETS_TAGSENTRY._serialized_options = b'8\001'
  _MICROSOFT_COMPUTE._serialized_start=98
  _MICROSOFT_COMPUTE._serialized_end=704
  _SSHPUBLICKEYS._serialized_start=707
  _SSHPUBLICKEYS._serialized_end=952
  _SSHPUBLICKEYS_TAGSENTRY._serialized_start=909
  _SSHPUBLICKEYS_TAGSENTRY._serialized_end=952
  _RESTOREPOINTCOLLECTIONSRESTOREPOINTS._serialized_start=955
  _RESTOREPOINTCOLLECTIONSRESTOREPOINTS._serialized_end=1253
  _APIENTITYREFERENCE._serialized_start=1255
  _APIENTITYREFERENCE._serialized_end=1287
  _RESTOREPOINTCOLLECTIONS._serialized_start=1290
  _RESTOREPOINTCOLLECTIONS._serialized_end=1753
  _RESTOREPOINTCOLLECTIONS_TAGSENTRY._serialized_start=909
  _RESTOREPOINTCOLLECTIONS_TAGSENTRY._serialized_end=952
  _RESTOREPOINTCOLLECTIONSOURCEPROPERTIES._serialized_start=1755
  _RESTOREPOINTCOLLECTIONSOURCEPROPERTIES._serialized_end=1807
  _PROXIMITYPLACEMENTGROUPS._serialized_start=1810
  _PROXIMITYPLACEMENTGROUPS._serialized_end=2181
  _PROXIMITYPLACEMENTGROUPS_TAGSENTRY._serialized_start=909
  _PROXIMITYPLACEMENTGROUPS_TAGSENTRY._serialized_end=952
  _INSTANCEVIEWSTATUS._serialized_start=2183
  _INSTANCEVIEWSTATUS._serialized_end=2287
  _IMAGES._serialized_start=2290
  _IMAGES._serialized_end=2726
  _IMAGES_TAGSENTRY._serialized_start=909
  _IMAGES_TAGSENTRY._serialized_end=952
  _IMAGESTORAGEPROFILE._serialized_start=2729
  _IMAGESTORAGEPROFILE._serialized_end=2913
  _IMAGEOSDISK._serialized_start=2916
  _IMAGEOSDISK._serialized_end=3186
  _IMAGEDATADISK._serialized_start=3189
  _IMAGEDATADISK._serialized_end=3439
  _DISKENCRYPTIONSETPARAMETERS._serialized_start=3441
  _DISKENCRYPTIONSETPARAMETERS._serialized_end=3482
  _EXTENDEDLOCATION._serialized_start=3484
  _EXTENDEDLOCATION._serialized_end=3530
  _HOSTGROUPSHOSTS._serialized_start=3533
  _HOSTGROUPSHOSTS._serialized_end=3903
  _HOSTGROUPSHOSTS_TAGSENTRY._serialized_start=909
  _HOSTGROUPSHOSTS_TAGSENTRY._serialized_end=952
  _HOSTGROUPS._serialized_start=3906
  _HOSTGROUPS._serialized_end=4295
  _HOSTGROUPS_TAGSENTRY._serialized_start=909
  _HOSTGROUPS_TAGSENTRY._serialized_end=952
  _CAPACITYRESERVATIONGROUPSCAPACITYRESERVATIONS._serialized_start=4298
  _CAPACITYRESERVATIONGROUPSCAPACITYRESERVATIONS._serialized_end=4657
  _CAPACITYRESERVATIONGROUPSCAPACITYRESERVATIONS_TAGSENTRY._serialized_start=909
  _CAPACITYRESERVATIONGROUPSCAPACITYRESERVATIONS_TAGSENTRY._serialized_end=952
  _CAPACITYRESERVATIONGROUPS._serialized_start=4660
  _CAPACITYRESERVATIONGROUPS._serialized_end=5068
  _CAPACITYRESERVATIONGROUPS_TAGSENTRY._serialized_start=909
  _CAPACITYRESERVATIONGROUPS_TAGSENTRY._serialized_end=952
  _AVAILABILITYSETS._serialized_start=5071
  _AVAILABILITYSETS._serialized_end=5493
  _AVAILABILITYSETS_TAGSENTRY._serialized_start=909
  _AVAILABILITYSETS_TAGSENTRY._serialized_end=952
  _SKU._serialized_start=5495
  _SKU._serialized_end=5546
# @@protoc_insertion_point(module_scope)
