# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_codedeploy.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18\x61ws/aws_codedeploy.proto\x12\x1aoak9.tython.aws.codedeploy\x1a\x13shared/shared.proto\"z\n\x0b\x41pplication\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x18\n\x10\x61pplication_name\x18\x02 \x01(\t\x12\x18\n\x10\x63ompute_platform\x18\x03 \x01(\t\"\xda\x01\n\nCodeDeploy\x12<\n\x0b\x61pplication\x18\x01 \x03(\x0b\x32\'.oak9.tython.aws.codedeploy.Application\x12G\n\x11\x64\x65ployment_config\x18\x02 \x03(\x0b\x32,.oak9.tython.aws.codedeploy.DeploymentConfig\x12\x45\n\x10\x64\x65ployment_group\x18\x03 \x03(\x0b\x32+.oak9.tython.aws.codedeploy.DeploymentGroup\"m\n#DeploymentConfigMinimumHealthyHosts\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\r\n\x05value\x18\x02 \x01(\x05\"\xcb\x01\n\x10\x44\x65ploymentConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1e\n\x16\x64\x65ployment_config_name\x18\x02 \x01(\t\x12^\n\x15minimum_healthy_hosts\x18\x03 \x01(\x0b\x32?.oak9.tython.aws.codedeploy.DeploymentConfigMinimumHealthyHosts\"]\n\x14\x44\x65ploymentGroupAlarm\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\"\xd2\x01\n!DeploymentGroupAlarmConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12@\n\x06\x61larms\x18\x02 \x03(\x0b\x32\x30.oak9.tython.aws.codedeploy.DeploymentGroupAlarm\x12\x0f\n\x07\x65nabled\x18\x03 \x01(\x08\x12!\n\x19ignore_poll_alarm_failure\x18\x04 \x01(\x08\"\x84\x01\n(DeploymentGroupAutoRollbackConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07\x65nabled\x18\x02 \x01(\x08\x12\x0e\n\x06\x65vents\x18\x03 \x03(\t\"\x7f\n\x1d\x44\x65ploymentGroupGitHubLocation\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\tcommit_id\x18\x02 \x01(\t\x12\x12\n\nrepository\x18\x03 \x01(\t\"\xa6\x01\n\x19\x44\x65ploymentGroupS3Location\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06\x62ucket\x18\x02 \x01(\t\x12\x13\n\x0b\x62undle_type\x18\x03 \x01(\t\x12\r\n\x05\x65_tag\x18\x04 \x01(\t\x12\x0b\n\x03key\x18\x05 \x01(\t\x12\x0f\n\x07version\x18\x06 \x01(\t\"\x92\x02\n\x1f\x44\x65ploymentGroupRevisionLocation\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12S\n\x10git_hub_location\x18\x02 \x01(\x0b\x32\x39.oak9.tython.aws.codedeploy.DeploymentGroupGitHubLocation\x12\x15\n\rrevision_type\x18\x03 \x01(\t\x12J\n\x0bs3_location\x18\x04 \x01(\x0b\x32\x35.oak9.tython.aws.codedeploy.DeploymentGroupS3Location\"\xe2\x01\n\x19\x44\x65ploymentGroupDeployment\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12(\n ignore_application_stop_failures\x18\x03 \x01(\x08\x12M\n\x08revision\x18\x04 \x01(\x0b\x32;.oak9.tython.aws.codedeploy.DeploymentGroupRevisionLocation\"\x8d\x01\n\x1e\x44\x65ploymentGroupDeploymentStyle\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x19\n\x11\x64\x65ployment_option\x18\x02 \x01(\t\x12\x17\n\x0f\x64\x65ployment_type\x18\x03 \x01(\t\"r\n\x1b\x44\x65ploymentGroupEC2TagFilter\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\"\xad\x01\n\"DeploymentGroupEC2TagSetListObject\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12N\n\rec2_tag_group\x18\x02 \x03(\x0b\x32\x37.oak9.tython.aws.codedeploy.DeploymentGroupEC2TagFilter\"\xad\x01\n\x18\x44\x65ploymentGroupEC2TagSet\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12X\n\x10\x65\x63\x32_tag_set_list\x18\x02 \x03(\x0b\x32>.oak9.tython.aws.codedeploy.DeploymentGroupEC2TagSetListObject\"_\n\x16\x44\x65ploymentGroupELBInfo\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\"g\n\x1e\x44\x65ploymentGroupTargetGroupInfo\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x81\x02\n\x1f\x44\x65ploymentGroupLoadBalancerInfo\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12I\n\relb_info_list\x18\x02 \x03(\x0b\x32\x32.oak9.tython.aws.codedeploy.DeploymentGroupELBInfo\x12Z\n\x16target_group_info_list\x18\x03 \x03(\x0b\x32:.oak9.tython.aws.codedeploy.DeploymentGroupTargetGroupInfo\"o\n\x18\x44\x65ploymentGroupTagFilter\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\"\xb9\x01\n)DeploymentGroupOnPremisesTagSetListObject\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12S\n\x15on_premises_tag_group\x18\x02 \x03(\x0b\x32\x34.oak9.tython.aws.codedeploy.DeploymentGroupTagFilter\"\xc3\x01\n\x1f\x44\x65ploymentGroupOnPremisesTagSet\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12g\n\x18on_premises_tag_set_list\x18\x02 \x03(\x0b\x32\x45.oak9.tython.aws.codedeploy.DeploymentGroupOnPremisesTagSetListObject\"\xa1\x01\n\x1c\x44\x65ploymentGroupTriggerConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0etrigger_events\x18\x02 \x03(\t\x12\x14\n\x0ctrigger_name\x18\x03 \x01(\t\x12\x1a\n\x12trigger_target_arn\x18\x04 \x01(\t\"\xcc\x08\n\x0f\x44\x65ploymentGroup\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12Z\n\x13\x61larm_configuration\x18\x02 \x01(\x0b\x32=.oak9.tython.aws.codedeploy.DeploymentGroupAlarmConfiguration\x12\x18\n\x10\x61pplication_name\x18\x03 \x01(\t\x12i\n\x1b\x61uto_rollback_configuration\x18\x04 \x01(\x0b\x32\x44.oak9.tython.aws.codedeploy.DeploymentGroupAutoRollbackConfiguration\x12\x1b\n\x13\x61uto_scaling_groups\x18\x05 \x03(\t\x12I\n\ndeployment\x18\x06 \x01(\x0b\x32\x35.oak9.tython.aws.codedeploy.DeploymentGroupDeployment\x12\x1e\n\x16\x64\x65ployment_config_name\x18\x07 \x01(\t\x12\x1d\n\x15\x64\x65ployment_group_name\x18\x08 \x01(\t\x12T\n\x10\x64\x65ployment_style\x18\t \x01(\x0b\x32:.oak9.tython.aws.codedeploy.DeploymentGroupDeploymentStyle\x12P\n\x0f\x65\x63\x32_tag_filters\x18\n \x03(\x0b\x32\x37.oak9.tython.aws.codedeploy.DeploymentGroupEC2TagFilter\x12I\n\x0b\x65\x63\x32_tag_set\x18\x0b \x01(\x0b\x32\x34.oak9.tython.aws.codedeploy.DeploymentGroupEC2TagSet\x12W\n\x12load_balancer_info\x18\x0c \x01(\x0b\x32;.oak9.tython.aws.codedeploy.DeploymentGroupLoadBalancerInfo\x12^\n on_premises_instance_tag_filters\x18\r \x03(\x0b\x32\x34.oak9.tython.aws.codedeploy.DeploymentGroupTagFilter\x12X\n\x13on_premises_tag_set\x18\x0e \x01(\x0b\x32;.oak9.tython.aws.codedeploy.DeploymentGroupOnPremisesTagSet\x12\x18\n\x10service_role_arn\x18\x0f \x01(\t\x12X\n\x16trigger_configurations\x18\x10 \x03(\x0b\x32\x38.oak9.tython.aws.codedeploy.DeploymentGroupTriggerConfigb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_codedeploy_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _APPLICATION._serialized_start=77
  _APPLICATION._serialized_end=199
  _CODEDEPLOY._serialized_start=202
  _CODEDEPLOY._serialized_end=420
  _DEPLOYMENTCONFIGMINIMUMHEALTHYHOSTS._serialized_start=422
  _DEPLOYMENTCONFIGMINIMUMHEALTHYHOSTS._serialized_end=531
  _DEPLOYMENTCONFIG._serialized_start=534
  _DEPLOYMENTCONFIG._serialized_end=737
  _DEPLOYMENTGROUPALARM._serialized_start=739
  _DEPLOYMENTGROUPALARM._serialized_end=832
  _DEPLOYMENTGROUPALARMCONFIGURATION._serialized_start=835
  _DEPLOYMENTGROUPALARMCONFIGURATION._serialized_end=1045
  _DEPLOYMENTGROUPAUTOROLLBACKCONFIGURATION._serialized_start=1048
  _DEPLOYMENTGROUPAUTOROLLBACKCONFIGURATION._serialized_end=1180
  _DEPLOYMENTGROUPGITHUBLOCATION._serialized_start=1182
  _DEPLOYMENTGROUPGITHUBLOCATION._serialized_end=1309
  _DEPLOYMENTGROUPS3LOCATION._serialized_start=1312
  _DEPLOYMENTGROUPS3LOCATION._serialized_end=1478
  _DEPLOYMENTGROUPREVISIONLOCATION._serialized_start=1481
  _DEPLOYMENTGROUPREVISIONLOCATION._serialized_end=1755
  _DEPLOYMENTGROUPDEPLOYMENT._serialized_start=1758
  _DEPLOYMENTGROUPDEPLOYMENT._serialized_end=1984
  _DEPLOYMENTGROUPDEPLOYMENTSTYLE._serialized_start=1987
  _DEPLOYMENTGROUPDEPLOYMENTSTYLE._serialized_end=2128
  _DEPLOYMENTGROUPEC2TAGFILTER._serialized_start=2130
  _DEPLOYMENTGROUPEC2TAGFILTER._serialized_end=2244
  _DEPLOYMENTGROUPEC2TAGSETLISTOBJECT._serialized_start=2247
  _DEPLOYMENTGROUPEC2TAGSETLISTOBJECT._serialized_end=2420
  _DEPLOYMENTGROUPEC2TAGSET._serialized_start=2423
  _DEPLOYMENTGROUPEC2TAGSET._serialized_end=2596
  _DEPLOYMENTGROUPELBINFO._serialized_start=2598
  _DEPLOYMENTGROUPELBINFO._serialized_end=2693
  _DEPLOYMENTGROUPTARGETGROUPINFO._serialized_start=2695
  _DEPLOYMENTGROUPTARGETGROUPINFO._serialized_end=2798
  _DEPLOYMENTGROUPLOADBALANCERINFO._serialized_start=2801
  _DEPLOYMENTGROUPLOADBALANCERINFO._serialized_end=3058
  _DEPLOYMENTGROUPTAGFILTER._serialized_start=3060
  _DEPLOYMENTGROUPTAGFILTER._serialized_end=3171
  _DEPLOYMENTGROUPONPREMISESTAGSETLISTOBJECT._serialized_start=3174
  _DEPLOYMENTGROUPONPREMISESTAGSETLISTOBJECT._serialized_end=3359
  _DEPLOYMENTGROUPONPREMISESTAGSET._serialized_start=3362
  _DEPLOYMENTGROUPONPREMISESTAGSET._serialized_end=3557
  _DEPLOYMENTGROUPTRIGGERCONFIG._serialized_start=3560
  _DEPLOYMENTGROUPTRIGGERCONFIG._serialized_end=3721
  _DEPLOYMENTGROUP._serialized_start=3724
  _DEPLOYMENTGROUP._serialized_end=4824
# @@protoc_insertion_point(module_scope)
