# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_servicecatalog.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x61ws/aws_servicecatalog.proto\x12\x1eoak9.tython.aws.servicecatalog\x1a\x13shared/shared.proto\"\x80\x01\n\x16\x41\x63\x63\x65ptedPortfolioShare\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x17\n\x0f\x61\x63\x63\x65pt_language\x18\x02 \x01(\t\x12\x14\n\x0cportfolio_id\x18\x03 \x01(\t\"\xe3\t\n\x0eServiceCatalog\x12X\n\x18\x61\x63\x63\x65pted_portfolio_share\x18\x01 \x03(\x0b\x32\x36.oak9.tython.aws.servicecatalog.AcceptedPortfolioShare\x12V\n\x17\x63loud_formation_product\x18\x02 \x03(\x0b\x32\x35.oak9.tython.aws.servicecatalog.CloudFormationProduct\x12m\n#cloud_formation_provisioned_product\x18\x03 \x03(\x0b\x32@.oak9.tython.aws.servicecatalog.CloudFormationProvisionedProduct\x12\x64\n\x1elaunch_notification_constraint\x18\x04 \x03(\x0b\x32<.oak9.tython.aws.servicecatalog.LaunchNotificationConstraint\x12T\n\x16launch_role_constraint\x18\x05 \x03(\x0b\x32\x34.oak9.tython.aws.servicecatalog.LaunchRoleConstraint\x12\\\n\x1alaunch_template_constraint\x18\x06 \x03(\x0b\x32\x38.oak9.tython.aws.servicecatalog.LaunchTemplateConstraint\x12<\n\tportfolio\x18\x07 \x03(\x0b\x32).oak9.tython.aws.servicecatalog.Portfolio\x12\x66\n\x1fportfolio_principal_association\x18\x08 \x03(\x0b\x32=.oak9.tython.aws.servicecatalog.PortfolioPrincipalAssociation\x12\x62\n\x1dportfolio_product_association\x18\t \x03(\x0b\x32;.oak9.tython.aws.servicecatalog.PortfolioProductAssociation\x12G\n\x0fportfolio_share\x18\n \x03(\x0b\x32..oak9.tython.aws.servicecatalog.PortfolioShare\x12\\\n\x1aresource_update_constraint\x18\x0b \x03(\x0b\x32\x38.oak9.tython.aws.servicecatalog.ResourceUpdateConstraint\x12P\n\x14stack_set_constraint\x18\x0c \x03(\x0b\x32\x32.oak9.tython.aws.servicecatalog.StackSetConstraint\x12=\n\ntag_option\x18\r \x03(\x0b\x32).oak9.tython.aws.servicecatalog.TagOption\x12T\n\x16tag_option_association\x18\x0e \x03(\x0b\x32\x34.oak9.tython.aws.servicecatalog.TagOptionAssociation\"\xd0\x02\n3CloudFormationProductProvisioningArtifactProperties\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12#\n\x1b\x64isable_template_validation\x18\x03 \x01(\x08\x12k\n\x04info\x18\x04 \x03(\x0b\x32].oak9.tython.aws.servicecatalog.CloudFormationProductProvisioningArtifactProperties.InfoEntry\x12\x0c\n\x04name\x18\x05 \x01(\t\x1a+\n\tInfoEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x9c\x04\n\x15\x43loudFormationProduct\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12&\n\x1ereplace_provisioning_artifacts\x18\x02 \x01(\x08\x12\r\n\x05owner\x18\x03 \x01(\t\x12\x1b\n\x13support_description\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12\x13\n\x0b\x64istributor\x18\x06 \x01(\t\x12\x15\n\rsupport_email\x18\x07 \x01(\t\x12\x17\n\x0f\x61\x63\x63\x65pt_language\x18\x08 \x01(\t\x12\x13\n\x0bsupport_url\x18\t \x01(\t\x12M\n\x04tags\x18\n \x03(\x0b\x32?.oak9.tython.aws.servicecatalog.CloudFormationProduct.TagsEntry\x12\x0c\n\x04name\x18\x0b \x01(\t\x12}\n provisioning_artifact_parameters\x18\x0c \x03(\x0b\x32S.oak9.tython.aws.servicecatalog.CloudFormationProductProvisioningArtifactProperties\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x8c\x01\n5CloudFormationProvisionedProductProvisioningParameter\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\"\xfd\x02\n7CloudFormationProvisionedProductProvisioningPreferences\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1a\n\x12stack_set_accounts\x18\x02 \x03(\t\x12)\n!stack_set_failure_tolerance_count\x18\x03 \x01(\x05\x12.\n&stack_set_failure_tolerance_percentage\x18\x04 \x01(\x05\x12\'\n\x1fstack_set_max_concurrency_count\x18\x05 \x01(\x05\x12,\n$stack_set_max_concurrency_percentage\x18\x06 \x01(\x05\x12 \n\x18stack_set_operation_type\x18\x07 \x01(\t\x12\x19\n\x11stack_set_regions\x18\x08 \x03(\t\"\xbf\x05\n CloudFormationProvisionedProduct\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x17\n\x0f\x61\x63\x63\x65pt_language\x18\x02 \x01(\t\x12\x19\n\x11notification_arns\x18\x03 \x03(\t\x12\x0f\n\x07path_id\x18\x04 \x01(\t\x12\x11\n\tpath_name\x18\x05 \x01(\t\x12\x12\n\nproduct_id\x18\x06 \x01(\t\x12\x14\n\x0cproduct_name\x18\x07 \x01(\t\x12 \n\x18provisioned_product_name\x18\x08 \x01(\t\x12 \n\x18provisioning_artifact_id\x18\t \x01(\t\x12\"\n\x1aprovisioning_artifact_name\x18\n \x01(\t\x12v\n\x17provisioning_parameters\x18\x0b \x03(\x0b\x32U.oak9.tython.aws.servicecatalog.CloudFormationProvisionedProductProvisioningParameter\x12y\n\x18provisioning_preferences\x18\x0c \x01(\x0b\x32W.oak9.tython.aws.servicecatalog.CloudFormationProvisionedProductProvisioningPreferences\x12X\n\x04tags\x18\r \x03(\x0b\x32J.oak9.tython.aws.servicecatalog.CloudFormationProvisionedProduct.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xca\x01\n\x1cLaunchNotificationConstraint\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x19\n\x11notification_arns\x18\x03 \x03(\t\x12\x17\n\x0f\x61\x63\x63\x65pt_language\x18\x04 \x01(\t\x12\x14\n\x0cportfolio_id\x18\x05 \x01(\t\x12\x12\n\nproduct_id\x18\x06 \x01(\t\"\xd2\x01\n\x14LaunchRoleConstraint\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x17\n\x0flocal_role_name\x18\x03 \x01(\t\x12\x17\n\x0f\x61\x63\x63\x65pt_language\x18\x04 \x01(\t\x12\x14\n\x0cportfolio_id\x18\x05 \x01(\t\x12\x12\n\nproduct_id\x18\x06 \x01(\t\x12\x10\n\x08role_arn\x18\x07 \x01(\t\"\xba\x01\n\x18LaunchTemplateConstraint\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x17\n\x0f\x61\x63\x63\x65pt_language\x18\x03 \x01(\t\x12\x14\n\x0cportfolio_id\x18\x04 \x01(\t\x12\x12\n\nproduct_id\x18\x05 \x01(\t\x12\r\n\x05rules\x18\x06 \x01(\t\"\x8f\x02\n\tPortfolio\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rprovider_name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x04 \x01(\t\x12\x17\n\x0f\x61\x63\x63\x65pt_language\x18\x05 \x01(\t\x12\x41\n\x04tags\x18\x06 \x03(\x0b\x32\x33.oak9.tython.aws.servicecatalog.Portfolio.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb6\x01\n\x1dPortfolioPrincipalAssociation\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rprincipal_arn\x18\x02 \x01(\t\x12\x17\n\x0f\x61\x63\x63\x65pt_language\x18\x03 \x01(\t\x12\x14\n\x0cportfolio_id\x18\x04 \x01(\t\x12\x16\n\x0eprincipal_type\x18\x05 \x01(\t\"\xb6\x01\n\x1bPortfolioProductAssociation\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1b\n\x13source_portfolio_id\x18\x02 \x01(\t\x12\x17\n\x0f\x61\x63\x63\x65pt_language\x18\x03 \x01(\t\x12\x14\n\x0cportfolio_id\x18\x04 \x01(\t\x12\x12\n\nproduct_id\x18\x05 \x01(\t\"\x8c\x01\n\x0ePortfolioShare\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\naccount_id\x18\x02 \x01(\t\x12\x17\n\x0f\x61\x63\x63\x65pt_language\x18\x03 \x01(\t\x12\x14\n\x0cportfolio_id\x18\x04 \x01(\t\"\xd6\x01\n\x18ResourceUpdateConstraint\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x17\n\x0f\x61\x63\x63\x65pt_language\x18\x03 \x01(\t\x12)\n!tag_update_on_provisioned_product\x18\x04 \x01(\t\x12\x14\n\x0cportfolio_id\x18\x05 \x01(\t\x12\x12\n\nproduct_id\x18\x06 \x01(\t\"\x9c\x02\n\x12StackSetConstraint\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x1e\n\x16stack_instance_control\x18\x03 \x01(\t\x12\x17\n\x0f\x61\x63\x63\x65pt_language\x18\x04 \x01(\t\x12\x14\n\x0cportfolio_id\x18\x05 \x01(\t\x12\x12\n\nproduct_id\x18\x06 \x01(\t\x12\x13\n\x0bregion_list\x18\x07 \x03(\t\x12\x12\n\nadmin_role\x18\x08 \x01(\t\x12\x14\n\x0c\x61\x63\x63ount_list\x18\t \x03(\t\x12\x16\n\x0e\x65xecution_role\x18\n \x01(\t\"p\n\tTagOption\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06\x61\x63tive\x18\x02 \x01(\x08\x12\r\n\x05value\x18\x03 \x01(\t\x12\x0b\n\x03key\x18\x04 \x01(\t\"{\n\x14TagOptionAssociation\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rtag_option_id\x18\x02 \x01(\t\x12\x13\n\x0bresource_id\x18\x03 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_servicecatalog_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CLOUDFORMATIONPRODUCTPROVISIONINGARTIFACTPROPERTIES_INFOENTRY._options = None
  _CLOUDFORMATIONPRODUCTPROVISIONINGARTIFACTPROPERTIES_INFOENTRY._serialized_options = b'8\001'
  _CLOUDFORMATIONPRODUCT_TAGSENTRY._options = None
  _CLOUDFORMATIONPRODUCT_TAGSENTRY._serialized_options = b'8\001'
  _CLOUDFORMATIONPROVISIONEDPRODUCT_TAGSENTRY._options = None
  _CLOUDFORMATIONPROVISIONEDPRODUCT_TAGSENTRY._serialized_options = b'8\001'
  _PORTFOLIO_TAGSENTRY._options = None
  _PORTFOLIO_TAGSENTRY._serialized_options = b'8\001'
  _ACCEPTEDPORTFOLIOSHARE._serialized_start=86
  _ACCEPTEDPORTFOLIOSHARE._serialized_end=214
  _SERVICECATALOG._serialized_start=217
  _SERVICECATALOG._serialized_end=1468
  _CLOUDFORMATIONPRODUCTPROVISIONINGARTIFACTPROPERTIES._serialized_start=1471
  _CLOUDFORMATIONPRODUCTPROVISIONINGARTIFACTPROPERTIES._serialized_end=1807
  _CLOUDFORMATIONPRODUCTPROVISIONINGARTIFACTPROPERTIES_INFOENTRY._serialized_start=1764
  _CLOUDFORMATIONPRODUCTPROVISIONINGARTIFACTPROPERTIES_INFOENTRY._serialized_end=1807
  _CLOUDFORMATIONPRODUCT._serialized_start=1810
  _CLOUDFORMATIONPRODUCT._serialized_end=2350
  _CLOUDFORMATIONPRODUCT_TAGSENTRY._serialized_start=2307
  _CLOUDFORMATIONPRODUCT_TAGSENTRY._serialized_end=2350
  _CLOUDFORMATIONPROVISIONEDPRODUCTPROVISIONINGPARAMETER._serialized_start=2353
  _CLOUDFORMATIONPROVISIONEDPRODUCTPROVISIONINGPARAMETER._serialized_end=2493
  _CLOUDFORMATIONPROVISIONEDPRODUCTPROVISIONINGPREFERENCES._serialized_start=2496
  _CLOUDFORMATIONPROVISIONEDPRODUCTPROVISIONINGPREFERENCES._serialized_end=2877
  _CLOUDFORMATIONPROVISIONEDPRODUCT._serialized_start=2880
  _CLOUDFORMATIONPROVISIONEDPRODUCT._serialized_end=3583
  _CLOUDFORMATIONPROVISIONEDPRODUCT_TAGSENTRY._serialized_start=2307
  _CLOUDFORMATIONPROVISIONEDPRODUCT_TAGSENTRY._serialized_end=2350
  _LAUNCHNOTIFICATIONCONSTRAINT._serialized_start=3586
  _LAUNCHNOTIFICATIONCONSTRAINT._serialized_end=3788
  _LAUNCHROLECONSTRAINT._serialized_start=3791
  _LAUNCHROLECONSTRAINT._serialized_end=4001
  _LAUNCHTEMPLATECONSTRAINT._serialized_start=4004
  _LAUNCHTEMPLATECONSTRAINT._serialized_end=4190
  _PORTFOLIO._serialized_start=4193
  _PORTFOLIO._serialized_end=4464
  _PORTFOLIO_TAGSENTRY._serialized_start=2307
  _PORTFOLIO_TAGSENTRY._serialized_end=2350
  _PORTFOLIOPRINCIPALASSOCIATION._serialized_start=4467
  _PORTFOLIOPRINCIPALASSOCIATION._serialized_end=4649
  _PORTFOLIOPRODUCTASSOCIATION._serialized_start=4652
  _PORTFOLIOPRODUCTASSOCIATION._serialized_end=4834
  _PORTFOLIOSHARE._serialized_start=4837
  _PORTFOLIOSHARE._serialized_end=4977
  _RESOURCEUPDATECONSTRAINT._serialized_start=4980
  _RESOURCEUPDATECONSTRAINT._serialized_end=5194
  _STACKSETCONSTRAINT._serialized_start=5197
  _STACKSETCONSTRAINT._serialized_end=5481
  _TAGOPTION._serialized_start=5483
  _TAGOPTION._serialized_end=5595
  _TAGOPTIONASSOCIATION._serialized_start=5597
  _TAGOPTIONASSOCIATION._serialized_end=5720
# @@protoc_insertion_point(module_scope)
