# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_alexa_ask.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17\x61ws/aws_alexa_ask.proto\x12\x19oak9.tython.aws.alexa_ask\x1a\x13shared/shared.proto\"\xa7\x01\n+Alexa_ASK_Skill_AuthenticationConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rrefresh_token\x18\x02 \x01(\t\x12\x15\n\rclient_secret\x18\x03 \x01(\t\x12\x11\n\tclient_id\x18\x04 \x01(\t\"\xdb\x01\n\x19\x41lexa_ASK_Skill_Overrides\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12T\n\x08manifest\x18\x02 \x03(\x0b\x32\x42.oak9.tython.aws.alexa_ask.Alexa_ASK_Skill_Overrides.ManifestEntry\x1a/\n\rManifestEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xf6\x01\n\x1c\x41lexa_ASK_Skill_SkillPackage\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0es3_bucket_role\x18\x02 \x01(\t\x12\x19\n\x11s3_object_version\x18\x03 \x01(\t\x12\x11\n\ts3_bucket\x18\x04 \x01(\t\x12\x0e\n\x06s3_key\x18\x05 \x01(\t\x12G\n\toverrides\x18\x06 \x01(\x0b\x32\x34.oak9.tython.aws.alexa_ask.Alexa_ASK_Skill_Overrides\"\x9b\x02\n\x0f\x41lexa_ASK_Skill\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12l\n\x1c\x61uthentication_configuration\x18\x02 \x01(\x0b\x32\x46.oak9.tython.aws.alexa_ask.Alexa_ASK_Skill_AuthenticationConfiguration\x12\x11\n\tvendor_id\x18\x03 \x01(\t\x12N\n\rskill_package\x18\x04 \x01(\x0b\x32\x37.oak9.tython.aws.alexa_ask.Alexa_ASK_Skill_SkillPackage\"T\n\tAlexa_ASK\x12G\n\x13\x61lexa__a_s_k__skill\x18\x01 \x03(\x0b\x32*.oak9.tython.aws.alexa_ask.Alexa_ASK_Skillb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_alexa_ask_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ALEXA_ASK_SKILL_OVERRIDES_MANIFESTENTRY._options = None
  _ALEXA_ASK_SKILL_OVERRIDES_MANIFESTENTRY._serialized_options = b'8\001'
  _ALEXA_ASK_SKILL_AUTHENTICATIONCONFIGURATION._serialized_start=76
  _ALEXA_ASK_SKILL_AUTHENTICATIONCONFIGURATION._serialized_end=243
  _ALEXA_ASK_SKILL_OVERRIDES._serialized_start=246
  _ALEXA_ASK_SKILL_OVERRIDES._serialized_end=465
  _ALEXA_ASK_SKILL_OVERRIDES_MANIFESTENTRY._serialized_start=418
  _ALEXA_ASK_SKILL_OVERRIDES_MANIFESTENTRY._serialized_end=465
  _ALEXA_ASK_SKILL_SKILLPACKAGE._serialized_start=468
  _ALEXA_ASK_SKILL_SKILLPACKAGE._serialized_end=714
  _ALEXA_ASK_SKILL._serialized_start=717
  _ALEXA_ASK_SKILL._serialized_end=1000
  _ALEXA_ASK._serialized_start=1002
  _ALEXA_ASK._serialized_end=1086
# @@protoc_insertion_point(module_scope)
