# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_storage.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15gcp/gcp_storage.proto\x12\x17oak9.tython.gcp.storage\x1a\x13shared/shared.proto\"f\n\x12StorageBucketXCors\x12\x17\n\x0fmax_age_seconds\x18\x01 \x01(\x01\x12\x0e\n\x06method\x18\x02 \x03(\t\x12\x0e\n\x06origin\x18\x03 \x03(\t\x12\x17\n\x0fresponse_header\x18\x04 \x03(\t\"8\n\x18StorageBucketXEncryption\x12\x1c\n\x14\x64\x65\x66\x61ult_kms_key_name\x18\x01 \x01(\t\"I\n\"StorageBucketXLifecycleRuleXAction\x12\x15\n\rstorage_class\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\"\xcb\x02\n%StorageBucketXLifecycleRuleXCondition\x12\x0b\n\x03\x61ge\x18\x01 \x01(\x01\x12\x16\n\x0e\x63reated_before\x18\x02 \x01(\t\x12\x1a\n\x12\x63ustom_time_before\x18\x03 \x01(\t\x12\x1e\n\x16\x64\x61ys_since_custom_time\x18\x04 \x01(\x01\x12\"\n\x1a\x64\x61ys_since_noncurrent_time\x18\x05 \x01(\x01\x12\x16\n\x0ematches_prefix\x18\x06 \x03(\t\x12\x1d\n\x15matches_storage_class\x18\x07 \x03(\t\x12\x16\n\x0ematches_suffix\x18\x08 \x03(\t\x12\x1e\n\x16noncurrent_time_before\x18\t \x01(\t\x12\x1a\n\x12num_newer_versions\x18\n \x01(\x01\x12\x12\n\nwith_state\x18\x0b \x01(\t\"\xbd\x01\n\x1bStorageBucketXLifecycleRule\x12K\n\x06\x61\x63tion\x18\x01 \x01(\x0b\x32;.oak9.tython.gcp.storage.StorageBucketXLifecycleRuleXAction\x12Q\n\tcondition\x18\x02 \x01(\x0b\x32>.oak9.tython.gcp.storage.StorageBucketXLifecycleRuleXCondition\"F\n\x15StorageBucketXLogging\x12\x12\n\nlog_bucket\x18\x01 \x01(\t\x12\x19\n\x11log_object_prefix\x18\x02 \x01(\t\"L\n\x1dStorageBucketXRetentionPolicy\x12\x11\n\tis_locked\x18\x01 \x01(\x08\x12\x18\n\x10retention_period\x18\x02 \x01(\x01\"F\n\x16StorageBucketXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0c\n\x04read\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"+\n\x18StorageBucketXVersioning\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\"I\n\x15StorageBucketXWebsite\x12\x18\n\x10main_page_suffix\x18\x01 \x01(\t\x12\x16\n\x0enot_found_page\x18\x02 \x01(\t\"\xd3\x07\n\rStorageBucket\x12 \n\x18\x64\x65\x66\x61ult_event_based_hold\x18\x01 \x01(\x08\x12\x15\n\rforce_destroy\x18\x02 \x01(\x08\x12\n\n\x02id\x18\x03 \x01(\t\x12\x42\n\x06labels\x18\x04 \x03(\x0b\x32\x32.oak9.tython.gcp.storage.StorageBucket.LabelsEntry\x12\x10\n\x08location\x18\x05 \x01(\t\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x0f\n\x07project\x18\x07 \x01(\t\x12\x16\n\x0erequester_pays\x18\x08 \x01(\x08\x12\x11\n\tself_link\x18\t \x01(\t\x12\x15\n\rstorage_class\x18\n \x01(\t\x12#\n\x1buniform_bucket_level_access\x18\x0b \x01(\x08\x12\x0b\n\x03url\x18\x0c \x01(\t\x12\x39\n\x04\x63ors\x18\r \x03(\x0b\x32+.oak9.tython.gcp.storage.StorageBucketXCors\x12\x45\n\nencryption\x18\x0e \x01(\x0b\x32\x31.oak9.tython.gcp.storage.StorageBucketXEncryption\x12L\n\x0elifecycle_rule\x18\x0f \x03(\x0b\x32\x34.oak9.tython.gcp.storage.StorageBucketXLifecycleRule\x12?\n\x07logging\x18\x10 \x01(\x0b\x32..oak9.tython.gcp.storage.StorageBucketXLogging\x12P\n\x10retention_policy\x18\x11 \x01(\x0b\x32\x36.oak9.tython.gcp.storage.StorageBucketXRetentionPolicy\x12\x41\n\x08timeouts\x18\x12 \x01(\x0b\x32/.oak9.tython.gcp.storage.StorageBucketXTimeouts\x12\x45\n\nversioning\x18\x13 \x01(\x0b\x32\x31.oak9.tython.gcp.storage.StorageBucketXVersioning\x12?\n\x07website\x18\x14 \x01(\x0b\x32..oak9.tython.gcp.storage.StorageBucketXWebsite\x12\x37\n\rresource_info\x18\x15 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"U\n#StorageBucketAccessControlXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xfe\x01\n\x1aStorageBucketAccessControl\x12\x0e\n\x06\x62ucket\x18\x01 \x01(\t\x12\x0e\n\x06\x64omain\x18\x02 \x01(\t\x12\r\n\x05\x65mail\x18\x03 \x01(\t\x12\x0e\n\x06\x65ntity\x18\x04 \x01(\t\x12\n\n\x02id\x18\x05 \x01(\t\x12\x0c\n\x04role\x18\x06 \x01(\t\x12N\n\x08timeouts\x18\x07 \x01(\x0b\x32<.oak9.tython.gcp.storage.StorageBucketAccessControlXTimeouts\x12\x37\n\rresource_info\x18\x08 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xa9\x01\n\x10StorageBucketAcl\x12\x0e\n\x06\x62ucket\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65\x66\x61ult_acl\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x16\n\x0epredefined_acl\x18\x04 \x01(\t\x12\x13\n\x0brole_entity\x18\x05 \x03(\t\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"[\n!StorageBucketIamBindingXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\xea\x01\n\x17StorageBucketIamBinding\x12\x0e\n\x06\x62ucket\x18\x01 \x01(\t\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0f\n\x07members\x18\x04 \x03(\t\x12\x0c\n\x04role\x18\x05 \x01(\t\x12M\n\tcondition\x18\x06 \x01(\x0b\x32:.oak9.tython.gcp.storage.StorageBucketIamBindingXCondition\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"Z\n StorageBucketIamMemberXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\xe7\x01\n\x16StorageBucketIamMember\x12\x0e\n\x06\x62ucket\x18\x01 \x01(\t\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0e\n\x06member\x18\x04 \x01(\t\x12\x0c\n\x04role\x18\x05 \x01(\t\x12L\n\tcondition\x18\x06 \x01(\x0b\x32\x39.oak9.tython.gcp.storage.StorageBucketIamMemberXCondition\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x90\x01\n\x16StorageBucketIamPolicy\x12\x0e\n\x06\x62ucket\x18\x01 \x01(\t\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x13\n\x0bpolicy_data\x18\x04 \x01(\t\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"^\n&StorageBucketObjectXCustomerEncryption\x12\x1c\n\x14\x65ncryption_algorithm\x18\x01 \x01(\t\x12\x16\n\x0e\x65ncryption_key\x18\x02 \x01(\t\"N\n\x1cStorageBucketObjectXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\x91\x06\n\x13StorageBucketObject\x12\x0e\n\x06\x62ucket\x18\x01 \x01(\t\x12\x15\n\rcache_control\x18\x02 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x03 \x01(\t\x12\x1b\n\x13\x63ontent_disposition\x18\x04 \x01(\t\x12\x18\n\x10\x63ontent_encoding\x18\x05 \x01(\t\x12\x18\n\x10\x63ontent_language\x18\x06 \x01(\t\x12\x14\n\x0c\x63ontent_type\x18\x07 \x01(\t\x12\x0e\n\x06\x63rc32c\x18\x08 \x01(\t\x12\x16\n\x0e\x64\x65tect_md5hash\x18\t \x01(\t\x12\x18\n\x10\x65vent_based_hold\x18\n \x01(\x08\x12\n\n\x02id\x18\x0b \x01(\t\x12\x14\n\x0ckms_key_name\x18\x0c \x01(\t\x12\x0f\n\x07md5hash\x18\r \x01(\t\x12\x12\n\nmedia_link\x18\x0e \x01(\t\x12L\n\x08metadata\x18\x0f \x03(\x0b\x32:.oak9.tython.gcp.storage.StorageBucketObject.MetadataEntry\x12\x0c\n\x04name\x18\x10 \x01(\t\x12\x13\n\x0boutput_name\x18\x11 \x01(\t\x12\x11\n\tself_link\x18\x12 \x01(\t\x12\x0e\n\x06source\x18\x13 \x01(\t\x12\x15\n\rstorage_class\x18\x14 \x01(\t\x12\x16\n\x0etemporary_hold\x18\x15 \x01(\x08\x12\\\n\x13\x63ustomer_encryption\x18\x16 \x01(\x0b\x32?.oak9.tython.gcp.storage.StorageBucketObjectXCustomerEncryption\x12G\n\x08timeouts\x18\x17 \x01(\x0b\x32\x35.oak9.tython.gcp.storage.StorageBucketObjectXTimeouts\x12\x37\n\rresource_info\x18\x18 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\\\n*StorageDefaultObjectAccessControlXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xda\x03\n!StorageDefaultObjectAccessControl\x12\x0e\n\x06\x62ucket\x18\x01 \x01(\t\x12\x0e\n\x06\x64omain\x18\x02 \x01(\t\x12\r\n\x05\x65mail\x18\x03 \x01(\t\x12\x0e\n\x06\x65ntity\x18\x04 \x01(\t\x12\x11\n\tentity_id\x18\x05 \x01(\t\x12\x12\n\ngeneration\x18\x06 \x01(\x01\x12\n\n\x02id\x18\x07 \x01(\t\x12\x0e\n\x06object\x18\x08 \x01(\t\x12\x61\n\x0cproject_team\x18\t \x03(\x0b\x32K.oak9.tython.gcp.storage.StorageDefaultObjectAccessControl.ProjectTeamEntry\x12\x0c\n\x04role\x18\n \x01(\t\x12U\n\x08timeouts\x18\x0b \x01(\x0b\x32\x43.oak9.tython.gcp.storage.StorageDefaultObjectAccessControlXTimeouts\x12\x37\n\rresource_info\x18\x0c \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a\x32\n\x10ProjectTeamEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x83\x01\n\x17StorageDefaultObjectAcl\x12\x0e\n\x06\x62ucket\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x13\n\x0brole_entity\x18\x03 \x03(\t\x12\x37\n\rresource_info\x18\x04 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"I\n\x17StorageHmacKeyXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xa2\x02\n\x0eStorageHmacKey\x12\x11\n\taccess_id\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0f\n\x07project\x18\x03 \x01(\t\x12\x0e\n\x06secret\x18\x04 \x01(\t\x12\x1d\n\x15service_account_email\x18\x05 \x01(\t\x12\r\n\x05state\x18\x06 \x01(\t\x12\x14\n\x0ctime_created\x18\x07 \x01(\t\x12\x0f\n\x07updated\x18\x08 \x01(\t\x12\x42\n\x08timeouts\x18\t \x01(\x0b\x32\x30.oak9.tython.gcp.storage.StorageHmacKeyXTimeouts\x12\x37\n\rresource_info\x18\n \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x86\x03\n\x13StorageNotification\x12\x0e\n\x06\x62ucket\x18\x01 \x01(\t\x12]\n\x11\x63ustom_attributes\x18\x02 \x03(\x0b\x32\x42.oak9.tython.gcp.storage.StorageNotification.CustomAttributesEntry\x12\x13\n\x0b\x65vent_types\x18\x03 \x03(\t\x12\n\n\x02id\x18\x04 \x01(\t\x12\x17\n\x0fnotification_id\x18\x05 \x01(\t\x12\x1a\n\x12object_name_prefix\x18\x06 \x01(\t\x12\x16\n\x0epayload_format\x18\x07 \x01(\t\x12\x11\n\tself_link\x18\x08 \x01(\t\x12\r\n\x05topic\x18\t \x01(\t\x12\x37\n\rresource_info\x18\n \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a\x37\n\x15\x43ustomAttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"U\n#StorageObjectAccessControlXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xc5\x03\n\x1aStorageObjectAccessControl\x12\x0e\n\x06\x62ucket\x18\x01 \x01(\t\x12\x0e\n\x06\x64omain\x18\x02 \x01(\t\x12\r\n\x05\x65mail\x18\x03 \x01(\t\x12\x0e\n\x06\x65ntity\x18\x04 \x01(\t\x12\x11\n\tentity_id\x18\x05 \x01(\t\x12\x12\n\ngeneration\x18\x06 \x01(\x01\x12\n\n\x02id\x18\x07 \x01(\t\x12\x0e\n\x06object\x18\x08 \x01(\t\x12Z\n\x0cproject_team\x18\t \x03(\x0b\x32\x44.oak9.tython.gcp.storage.StorageObjectAccessControl.ProjectTeamEntry\x12\x0c\n\x04role\x18\n \x01(\t\x12N\n\x08timeouts\x18\x0b \x01(\x0b\x32<.oak9.tython.gcp.storage.StorageObjectAccessControlXTimeouts\x12\x37\n\rresource_info\x18\x0c \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a\x32\n\x10ProjectTeamEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa4\x01\n\x10StorageObjectAcl\x12\x0e\n\x06\x62ucket\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0e\n\x06object\x18\x03 \x01(\t\x12\x16\n\x0epredefined_acl\x18\x04 \x01(\t\x12\x13\n\x0brole_entity\x18\x05 \x03(\t\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"W\n+StorageTransferJobXScheduleXScheduleEndDate\x12\x0b\n\x03\x64\x61y\x18\x01 \x01(\x01\x12\r\n\x05month\x18\x02 \x01(\x01\x12\x0c\n\x04year\x18\x03 \x01(\x01\"Y\n-StorageTransferJobXScheduleXScheduleStartDate\x12\x0b\n\x03\x64\x61y\x18\x01 \x01(\x01\x12\r\n\x05month\x18\x02 \x01(\x01\x12\x0c\n\x04year\x18\x03 \x01(\x01\"l\n*StorageTransferJobXScheduleXStartTimeOfDay\x12\r\n\x05hours\x18\x01 \x01(\x01\x12\x0f\n\x07minutes\x18\x02 \x01(\x01\x12\r\n\x05nanos\x18\x03 \x01(\x01\x12\x0f\n\x07seconds\x18\x04 \x01(\x01\"\xdc\x02\n\x1bStorageTransferJobXSchedule\x12\x17\n\x0frepeat_interval\x18\x01 \x01(\t\x12_\n\x11schedule_end_date\x18\x02 \x01(\x0b\x32\x44.oak9.tython.gcp.storage.StorageTransferJobXScheduleXScheduleEndDate\x12\x63\n\x13schedule_start_date\x18\x03 \x01(\x0b\x32\x46.oak9.tython.gcp.storage.StorageTransferJobXScheduleXScheduleStartDate\x12^\n\x11start_time_of_day\x18\x04 \x01(\x0b\x32\x43.oak9.tython.gcp.storage.StorageTransferJobXScheduleXStartTimeOfDay\"p\n<StorageTransferJobXTransferSpecXAwsS3DataSourceXAwsAccessKey\x12\x15\n\raccess_key_id\x18\x01 \x01(\t\x12\x19\n\x11secret_access_key\x18\x02 \x01(\t\"\xc7\x01\n/StorageTransferJobXTransferSpecXAwsS3DataSource\x12\x13\n\x0b\x62ucket_name\x18\x01 \x01(\t\x12\x10\n\x08role_arn\x18\x02 \x01(\t\x12m\n\x0e\x61ws_access_key\x18\x03 \x01(\x0b\x32U.oak9.tython.gcp.storage.StorageTransferJobXTransferSpecXAwsS3DataSourceXAwsAccessKey\"`\nKStorageTransferJobXTransferSpecXAzureBlobStorageDataSourceXAzureCredentials\x12\x11\n\tsas_token\x18\x01 \x01(\t\"\xf7\x01\n:StorageTransferJobXTransferSpecXAzureBlobStorageDataSource\x12\x11\n\tcontainer\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x17\n\x0fstorage_account\x18\x03 \x01(\t\x12\x7f\n\x11\x61zure_credentials\x18\x04 \x01(\x0b\x32\x64.oak9.tython.gcp.storage.StorageTransferJobXTransferSpecXAzureBlobStorageDataSourceXAzureCredentials\"P\n+StorageTransferJobXTransferSpecXGcsDataSink\x12\x13\n\x0b\x62ucket_name\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\"R\n-StorageTransferJobXTransferSpecXGcsDataSource\x12\x13\n\x0b\x62ucket_name\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\"B\n.StorageTransferJobXTransferSpecXHttpDataSource\x12\x10\n\x08list_url\x18\x01 \x01(\t\"\xca\x01\n0StorageTransferJobXTransferSpecXObjectConditions\x12\x18\n\x10\x65xclude_prefixes\x18\x01 \x03(\t\x12\x18\n\x10include_prefixes\x18\x02 \x03(\t\x12\x30\n(max_time_elapsed_since_last_modification\x18\x03 \x01(\t\x12\x30\n(min_time_elapsed_since_last_modification\x18\x04 \x01(\t\"G\n-StorageTransferJobXTransferSpecXPosixDataSink\x12\x16\n\x0eroot_directory\x18\x01 \x01(\t\"I\n/StorageTransferJobXTransferSpecXPosixDataSource\x12\x16\n\x0eroot_directory\x18\x01 \x01(\t\"\xbf\x01\n/StorageTransferJobXTransferSpecXTransferOptions\x12\x31\n)delete_objects_from_source_after_transfer\x18\x01 \x01(\x08\x12%\n\x1d\x64\x65lete_objects_unique_in_sink\x18\x02 \x01(\x08\x12\x32\n*overwrite_objects_already_existing_in_sink\x18\x03 \x01(\x08\"\xb5\x07\n\x1fStorageTransferJobXTransferSpec\x12\x64\n\x12\x61ws_s3_data_source\x18\x01 \x01(\x0b\x32H.oak9.tython.gcp.storage.StorageTransferJobXTransferSpecXAwsS3DataSource\x12{\n\x1e\x61zure_blob_storage_data_source\x18\x02 \x01(\x0b\x32S.oak9.tython.gcp.storage.StorageTransferJobXTransferSpecXAzureBlobStorageDataSource\x12[\n\rgcs_data_sink\x18\x03 \x01(\x0b\x32\x44.oak9.tython.gcp.storage.StorageTransferJobXTransferSpecXGcsDataSink\x12_\n\x0fgcs_data_source\x18\x04 \x01(\x0b\x32\x46.oak9.tython.gcp.storage.StorageTransferJobXTransferSpecXGcsDataSource\x12\x61\n\x10http_data_source\x18\x05 \x01(\x0b\x32G.oak9.tython.gcp.storage.StorageTransferJobXTransferSpecXHttpDataSource\x12\x64\n\x11object_conditions\x18\x06 \x01(\x0b\x32I.oak9.tython.gcp.storage.StorageTransferJobXTransferSpecXObjectConditions\x12_\n\x0fposix_data_sink\x18\x07 \x01(\x0b\x32\x46.oak9.tython.gcp.storage.StorageTransferJobXTransferSpecXPosixDataSink\x12\x63\n\x11posix_data_source\x18\x08 \x01(\x0b\x32H.oak9.tython.gcp.storage.StorageTransferJobXTransferSpecXPosixDataSource\x12\x62\n\x10transfer_options\x18\t \x01(\x0b\x32H.oak9.tython.gcp.storage.StorageTransferJobXTransferSpecXTransferOptions\"\x84\x03\n\x12StorageTransferJob\x12\x15\n\rcreation_time\x18\x01 \x01(\t\x12\x15\n\rdeletion_time\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\n\n\x02id\x18\x04 \x01(\t\x12\x1e\n\x16last_modification_time\x18\x05 \x01(\t\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x0f\n\x07project\x18\x07 \x01(\t\x12\x0e\n\x06status\x18\x08 \x01(\t\x12\x46\n\x08schedule\x18\t \x01(\x0b\x32\x34.oak9.tython.gcp.storage.StorageTransferJobXSchedule\x12O\n\rtransfer_spec\x18\n \x01(\x0b\x32\x38.oak9.tython.gcp.storage.StorageTransferJobXTransferSpec\x12\x37\n\rresource_info\x18\x0b \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_storage_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _STORAGEBUCKET_LABELSENTRY._options = None
  _STORAGEBUCKET_LABELSENTRY._serialized_options = b'8\001'
  _STORAGEBUCKETOBJECT_METADATAENTRY._options = None
  _STORAGEBUCKETOBJECT_METADATAENTRY._serialized_options = b'8\001'
  _STORAGEDEFAULTOBJECTACCESSCONTROL_PROJECTTEAMENTRY._options = None
  _STORAGEDEFAULTOBJECTACCESSCONTROL_PROJECTTEAMENTRY._serialized_options = b'8\001'
  _STORAGENOTIFICATION_CUSTOMATTRIBUTESENTRY._options = None
  _STORAGENOTIFICATION_CUSTOMATTRIBUTESENTRY._serialized_options = b'8\001'
  _STORAGEOBJECTACCESSCONTROL_PROJECTTEAMENTRY._options = None
  _STORAGEOBJECTACCESSCONTROL_PROJECTTEAMENTRY._serialized_options = b'8\001'
  _STORAGEBUCKETXCORS._serialized_start=71
  _STORAGEBUCKETXCORS._serialized_end=173
  _STORAGEBUCKETXENCRYPTION._serialized_start=175
  _STORAGEBUCKETXENCRYPTION._serialized_end=231
  _STORAGEBUCKETXLIFECYCLERULEXACTION._serialized_start=233
  _STORAGEBUCKETXLIFECYCLERULEXACTION._serialized_end=306
  _STORAGEBUCKETXLIFECYCLERULEXCONDITION._serialized_start=309
  _STORAGEBUCKETXLIFECYCLERULEXCONDITION._serialized_end=640
  _STORAGEBUCKETXLIFECYCLERULE._serialized_start=643
  _STORAGEBUCKETXLIFECYCLERULE._serialized_end=832
  _STORAGEBUCKETXLOGGING._serialized_start=834
  _STORAGEBUCKETXLOGGING._serialized_end=904
  _STORAGEBUCKETXRETENTIONPOLICY._serialized_start=906
  _STORAGEBUCKETXRETENTIONPOLICY._serialized_end=982
  _STORAGEBUCKETXTIMEOUTS._serialized_start=984
  _STORAGEBUCKETXTIMEOUTS._serialized_end=1054
  _STORAGEBUCKETXVERSIONING._serialized_start=1056
  _STORAGEBUCKETXVERSIONING._serialized_end=1099
  _STORAGEBUCKETXWEBSITE._serialized_start=1101
  _STORAGEBUCKETXWEBSITE._serialized_end=1174
  _STORAGEBUCKET._serialized_start=1177
  _STORAGEBUCKET._serialized_end=2156
  _STORAGEBUCKET_LABELSENTRY._serialized_start=2111
  _STORAGEBUCKET_LABELSENTRY._serialized_end=2156
  _STORAGEBUCKETACCESSCONTROLXTIMEOUTS._serialized_start=2158
  _STORAGEBUCKETACCESSCONTROLXTIMEOUTS._serialized_end=2243
  _STORAGEBUCKETACCESSCONTROL._serialized_start=2246
  _STORAGEBUCKETACCESSCONTROL._serialized_end=2500
  _STORAGEBUCKETACL._serialized_start=2503
  _STORAGEBUCKETACL._serialized_end=2672
  _STORAGEBUCKETIAMBINDINGXCONDITION._serialized_start=2674
  _STORAGEBUCKETIAMBINDINGXCONDITION._serialized_end=2765
  _STORAGEBUCKETIAMBINDING._serialized_start=2768
  _STORAGEBUCKETIAMBINDING._serialized_end=3002
  _STORAGEBUCKETIAMMEMBERXCONDITION._serialized_start=3004
  _STORAGEBUCKETIAMMEMBERXCONDITION._serialized_end=3094
  _STORAGEBUCKETIAMMEMBER._serialized_start=3097
  _STORAGEBUCKETIAMMEMBER._serialized_end=3328
  _STORAGEBUCKETIAMPOLICY._serialized_start=3331
  _STORAGEBUCKETIAMPOLICY._serialized_end=3475
  _STORAGEBUCKETOBJECTXCUSTOMERENCRYPTION._serialized_start=3477
  _STORAGEBUCKETOBJECTXCUSTOMERENCRYPTION._serialized_end=3571
  _STORAGEBUCKETOBJECTXTIMEOUTS._serialized_start=3573
  _STORAGEBUCKETOBJECTXTIMEOUTS._serialized_end=3651
  _STORAGEBUCKETOBJECT._serialized_start=3654
  _STORAGEBUCKETOBJECT._serialized_end=4439
  _STORAGEBUCKETOBJECT_METADATAENTRY._serialized_start=4392
  _STORAGEBUCKETOBJECT_METADATAENTRY._serialized_end=4439
  _STORAGEDEFAULTOBJECTACCESSCONTROLXTIMEOUTS._serialized_start=4441
  _STORAGEDEFAULTOBJECTACCESSCONTROLXTIMEOUTS._serialized_end=4533
  _STORAGEDEFAULTOBJECTACCESSCONTROL._serialized_start=4536
  _STORAGEDEFAULTOBJECTACCESSCONTROL._serialized_end=5010
  _STORAGEDEFAULTOBJECTACCESSCONTROL_PROJECTTEAMENTRY._serialized_start=4960
  _STORAGEDEFAULTOBJECTACCESSCONTROL_PROJECTTEAMENTRY._serialized_end=5010
  _STORAGEDEFAULTOBJECTACL._serialized_start=5013
  _STORAGEDEFAULTOBJECTACL._serialized_end=5144
  _STORAGEHMACKEYXTIMEOUTS._serialized_start=5146
  _STORAGEHMACKEYXTIMEOUTS._serialized_end=5219
  _STORAGEHMACKEY._serialized_start=5222
  _STORAGEHMACKEY._serialized_end=5512
  _STORAGENOTIFICATION._serialized_start=5515
  _STORAGENOTIFICATION._serialized_end=5905
  _STORAGENOTIFICATION_CUSTOMATTRIBUTESENTRY._serialized_start=5850
  _STORAGENOTIFICATION_CUSTOMATTRIBUTESENTRY._serialized_end=5905
  _STORAGEOBJECTACCESSCONTROLXTIMEOUTS._serialized_start=5907
  _STORAGEOBJECTACCESSCONTROLXTIMEOUTS._serialized_end=5992
  _STORAGEOBJECTACCESSCONTROL._serialized_start=5995
  _STORAGEOBJECTACCESSCONTROL._serialized_end=6448
  _STORAGEOBJECTACCESSCONTROL_PROJECTTEAMENTRY._serialized_start=4960
  _STORAGEOBJECTACCESSCONTROL_PROJECTTEAMENTRY._serialized_end=5010
  _STORAGEOBJECTACL._serialized_start=6451
  _STORAGEOBJECTACL._serialized_end=6615
  _STORAGETRANSFERJOBXSCHEDULEXSCHEDULEENDDATE._serialized_start=6617
  _STORAGETRANSFERJOBXSCHEDULEXSCHEDULEENDDATE._serialized_end=6704
  _STORAGETRANSFERJOBXSCHEDULEXSCHEDULESTARTDATE._serialized_start=6706
  _STORAGETRANSFERJOBXSCHEDULEXSCHEDULESTARTDATE._serialized_end=6795
  _STORAGETRANSFERJOBXSCHEDULEXSTARTTIMEOFDAY._serialized_start=6797
  _STORAGETRANSFERJOBXSCHEDULEXSTARTTIMEOFDAY._serialized_end=6905
  _STORAGETRANSFERJOBXSCHEDULE._serialized_start=6908
  _STORAGETRANSFERJOBXSCHEDULE._serialized_end=7256
  _STORAGETRANSFERJOBXTRANSFERSPECXAWSS3DATASOURCEXAWSACCESSKEY._serialized_start=7258
  _STORAGETRANSFERJOBXTRANSFERSPECXAWSS3DATASOURCEXAWSACCESSKEY._serialized_end=7370
  _STORAGETRANSFERJOBXTRANSFERSPECXAWSS3DATASOURCE._serialized_start=7373
  _STORAGETRANSFERJOBXTRANSFERSPECXAWSS3DATASOURCE._serialized_end=7572
  _STORAGETRANSFERJOBXTRANSFERSPECXAZUREBLOBSTORAGEDATASOURCEXAZURECREDENTIALS._serialized_start=7574
  _STORAGETRANSFERJOBXTRANSFERSPECXAZUREBLOBSTORAGEDATASOURCEXAZURECREDENTIALS._serialized_end=7670
  _STORAGETRANSFERJOBXTRANSFERSPECXAZUREBLOBSTORAGEDATASOURCE._serialized_start=7673
  _STORAGETRANSFERJOBXTRANSFERSPECXAZUREBLOBSTORAGEDATASOURCE._serialized_end=7920
  _STORAGETRANSFERJOBXTRANSFERSPECXGCSDATASINK._serialized_start=7922
  _STORAGETRANSFERJOBXTRANSFERSPECXGCSDATASINK._serialized_end=8002
  _STORAGETRANSFERJOBXTRANSFERSPECXGCSDATASOURCE._serialized_start=8004
  _STORAGETRANSFERJOBXTRANSFERSPECXGCSDATASOURCE._serialized_end=8086
  _STORAGETRANSFERJOBXTRANSFERSPECXHTTPDATASOURCE._serialized_start=8088
  _STORAGETRANSFERJOBXTRANSFERSPECXHTTPDATASOURCE._serialized_end=8154
  _STORAGETRANSFERJOBXTRANSFERSPECXOBJECTCONDITIONS._serialized_start=8157
  _STORAGETRANSFERJOBXTRANSFERSPECXOBJECTCONDITIONS._serialized_end=8359
  _STORAGETRANSFERJOBXTRANSFERSPECXPOSIXDATASINK._serialized_start=8361
  _STORAGETRANSFERJOBXTRANSFERSPECXPOSIXDATASINK._serialized_end=8432
  _STORAGETRANSFERJOBXTRANSFERSPECXPOSIXDATASOURCE._serialized_start=8434
  _STORAGETRANSFERJOBXTRANSFERSPECXPOSIXDATASOURCE._serialized_end=8507
  _STORAGETRANSFERJOBXTRANSFERSPECXTRANSFEROPTIONS._serialized_start=8510
  _STORAGETRANSFERJOBXTRANSFERSPECXTRANSFEROPTIONS._serialized_end=8701
  _STORAGETRANSFERJOBXTRANSFERSPEC._serialized_start=8704
  _STORAGETRANSFERJOBXTRANSFERSPEC._serialized_end=9653
  _STORAGETRANSFERJOB._serialized_start=9656
  _STORAGETRANSFERJOB._serialized_end=10044
# @@protoc_insertion_point(module_scope)
