"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class GameServicesGameServerClusterXConnectionInfoXGkeClusterReference(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_FIELD_NUMBER: builtins.int
    cluster: builtins.str
    def __init__(
        self,
        *,
        cluster: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cluster", b"cluster"]) -> None: ...

global___GameServicesGameServerClusterXConnectionInfoXGkeClusterReference = GameServicesGameServerClusterXConnectionInfoXGkeClusterReference

@typing_extensions.final
class GameServicesGameServerClusterXConnectionInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAMESPACE_FIELD_NUMBER: builtins.int
    GKE_CLUSTER_REFERENCE_FIELD_NUMBER: builtins.int
    namespace: builtins.str
    @property
    def gke_cluster_reference(self) -> global___GameServicesGameServerClusterXConnectionInfoXGkeClusterReference: ...
    def __init__(
        self,
        *,
        namespace: builtins.str = ...,
        gke_cluster_reference: global___GameServicesGameServerClusterXConnectionInfoXGkeClusterReference | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["gke_cluster_reference", b"gke_cluster_reference"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["gke_cluster_reference", b"gke_cluster_reference", "namespace", b"namespace"]) -> None: ...

global___GameServicesGameServerClusterXConnectionInfo = GameServicesGameServerClusterXConnectionInfo

@typing_extensions.final
class GameServicesGameServerClusterXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___GameServicesGameServerClusterXTimeouts = GameServicesGameServerClusterXTimeouts

@typing_extensions.final
class GameServicesGameServerCluster(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    REALM_ID_FIELD_NUMBER: builtins.int
    CONNECTION_INFO_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    description: builtins.str
    id: builtins.str
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    location: builtins.str
    name: builtins.str
    project: builtins.str
    realm_id: builtins.str
    @property
    def connection_info(self) -> global___GameServicesGameServerClusterXConnectionInfo: ...
    @property
    def timeouts(self) -> global___GameServicesGameServerClusterXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        description: builtins.str = ...,
        id: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        realm_id: builtins.str = ...,
        connection_info: global___GameServicesGameServerClusterXConnectionInfo | None = ...,
        timeouts: global___GameServicesGameServerClusterXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["connection_info", b"connection_info", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cluster_id", b"cluster_id", "connection_info", b"connection_info", "description", b"description", "id", b"id", "labels", b"labels", "location", b"location", "name", b"name", "project", b"project", "realm_id", b"realm_id", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> None: ...

global___GameServicesGameServerCluster = GameServicesGameServerCluster

@typing_extensions.final
class GameServicesGameServerConfigXFleetConfigs(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FLEET_SPEC_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    fleet_spec: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        fleet_spec: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["fleet_spec", b"fleet_spec", "name", b"name"]) -> None: ...

global___GameServicesGameServerConfigXFleetConfigs = GameServicesGameServerConfigXFleetConfigs

@typing_extensions.final
class GameServicesGameServerConfigXScalingConfigsXSchedules(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CRON_JOB_DURATION_FIELD_NUMBER: builtins.int
    CRON_SPEC_FIELD_NUMBER: builtins.int
    END_TIME_FIELD_NUMBER: builtins.int
    START_TIME_FIELD_NUMBER: builtins.int
    cron_job_duration: builtins.str
    cron_spec: builtins.str
    end_time: builtins.str
    start_time: builtins.str
    def __init__(
        self,
        *,
        cron_job_duration: builtins.str = ...,
        cron_spec: builtins.str = ...,
        end_time: builtins.str = ...,
        start_time: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cron_job_duration", b"cron_job_duration", "cron_spec", b"cron_spec", "end_time", b"end_time", "start_time", b"start_time"]) -> None: ...

global___GameServicesGameServerConfigXScalingConfigsXSchedules = GameServicesGameServerConfigXScalingConfigsXSchedules

@typing_extensions.final
class GameServicesGameServerConfigXScalingConfigsXSelectors(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    LABELS_FIELD_NUMBER: builtins.int
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["labels", b"labels"]) -> None: ...

global___GameServicesGameServerConfigXScalingConfigsXSelectors = GameServicesGameServerConfigXScalingConfigsXSelectors

@typing_extensions.final
class GameServicesGameServerConfigXScalingConfigs(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FLEET_AUTOSCALER_SPEC_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    SCHEDULES_FIELD_NUMBER: builtins.int
    SELECTORS_FIELD_NUMBER: builtins.int
    fleet_autoscaler_spec: builtins.str
    name: builtins.str
    @property
    def schedules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___GameServicesGameServerConfigXScalingConfigsXSchedules]: ...
    @property
    def selectors(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___GameServicesGameServerConfigXScalingConfigsXSelectors]: ...
    def __init__(
        self,
        *,
        fleet_autoscaler_spec: builtins.str = ...,
        name: builtins.str = ...,
        schedules: collections.abc.Iterable[global___GameServicesGameServerConfigXScalingConfigsXSchedules] | None = ...,
        selectors: collections.abc.Iterable[global___GameServicesGameServerConfigXScalingConfigsXSelectors] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["fleet_autoscaler_spec", b"fleet_autoscaler_spec", "name", b"name", "schedules", b"schedules", "selectors", b"selectors"]) -> None: ...

global___GameServicesGameServerConfigXScalingConfigs = GameServicesGameServerConfigXScalingConfigs

@typing_extensions.final
class GameServicesGameServerConfigXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete"]) -> None: ...

global___GameServicesGameServerConfigXTimeouts = GameServicesGameServerConfigXTimeouts

@typing_extensions.final
class GameServicesGameServerConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    CONFIG_ID_FIELD_NUMBER: builtins.int
    DEPLOYMENT_ID_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    FLEET_CONFIGS_FIELD_NUMBER: builtins.int
    SCALING_CONFIGS_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    config_id: builtins.str
    deployment_id: builtins.str
    description: builtins.str
    id: builtins.str
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    location: builtins.str
    name: builtins.str
    project: builtins.str
    @property
    def fleet_configs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___GameServicesGameServerConfigXFleetConfigs]: ...
    @property
    def scaling_configs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___GameServicesGameServerConfigXScalingConfigs]: ...
    @property
    def timeouts(self) -> global___GameServicesGameServerConfigXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        config_id: builtins.str = ...,
        deployment_id: builtins.str = ...,
        description: builtins.str = ...,
        id: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        fleet_configs: collections.abc.Iterable[global___GameServicesGameServerConfigXFleetConfigs] | None = ...,
        scaling_configs: collections.abc.Iterable[global___GameServicesGameServerConfigXScalingConfigs] | None = ...,
        timeouts: global___GameServicesGameServerConfigXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["config_id", b"config_id", "deployment_id", b"deployment_id", "description", b"description", "fleet_configs", b"fleet_configs", "id", b"id", "labels", b"labels", "location", b"location", "name", b"name", "project", b"project", "resource_info", b"resource_info", "scaling_configs", b"scaling_configs", "timeouts", b"timeouts"]) -> None: ...

global___GameServicesGameServerConfig = GameServicesGameServerConfig

@typing_extensions.final
class GameServicesGameServerDeploymentXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___GameServicesGameServerDeploymentXTimeouts = GameServicesGameServerDeploymentXTimeouts

@typing_extensions.final
class GameServicesGameServerDeployment(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    DEPLOYMENT_ID_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    deployment_id: builtins.str
    description: builtins.str
    id: builtins.str
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    location: builtins.str
    name: builtins.str
    project: builtins.str
    @property
    def timeouts(self) -> global___GameServicesGameServerDeploymentXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        deployment_id: builtins.str = ...,
        description: builtins.str = ...,
        id: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        timeouts: global___GameServicesGameServerDeploymentXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["deployment_id", b"deployment_id", "description", b"description", "id", b"id", "labels", b"labels", "location", b"location", "name", b"name", "project", b"project", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> None: ...

global___GameServicesGameServerDeployment = GameServicesGameServerDeployment

@typing_extensions.final
class GameServicesGameServerDeploymentRolloutXGameServerConfigOverridesXRealmsSelector(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REALMS_FIELD_NUMBER: builtins.int
    @property
    def realms(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        realms: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["realms", b"realms"]) -> None: ...

global___GameServicesGameServerDeploymentRolloutXGameServerConfigOverridesXRealmsSelector = GameServicesGameServerDeploymentRolloutXGameServerConfigOverridesXRealmsSelector

@typing_extensions.final
class GameServicesGameServerDeploymentRolloutXGameServerConfigOverrides(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONFIG_VERSION_FIELD_NUMBER: builtins.int
    REALMS_SELECTOR_FIELD_NUMBER: builtins.int
    config_version: builtins.str
    @property
    def realms_selector(self) -> global___GameServicesGameServerDeploymentRolloutXGameServerConfigOverridesXRealmsSelector: ...
    def __init__(
        self,
        *,
        config_version: builtins.str = ...,
        realms_selector: global___GameServicesGameServerDeploymentRolloutXGameServerConfigOverridesXRealmsSelector | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["realms_selector", b"realms_selector"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["config_version", b"config_version", "realms_selector", b"realms_selector"]) -> None: ...

global___GameServicesGameServerDeploymentRolloutXGameServerConfigOverrides = GameServicesGameServerDeploymentRolloutXGameServerConfigOverrides

@typing_extensions.final
class GameServicesGameServerDeploymentRolloutXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___GameServicesGameServerDeploymentRolloutXTimeouts = GameServicesGameServerDeploymentRolloutXTimeouts

@typing_extensions.final
class GameServicesGameServerDeploymentRollout(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEFAULT_GAME_SERVER_CONFIG_FIELD_NUMBER: builtins.int
    DEPLOYMENT_ID_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    GAME_SERVER_CONFIG_OVERRIDES_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    default_game_server_config: builtins.str
    deployment_id: builtins.str
    id: builtins.str
    name: builtins.str
    project: builtins.str
    @property
    def game_server_config_overrides(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___GameServicesGameServerDeploymentRolloutXGameServerConfigOverrides]: ...
    @property
    def timeouts(self) -> global___GameServicesGameServerDeploymentRolloutXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        default_game_server_config: builtins.str = ...,
        deployment_id: builtins.str = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        game_server_config_overrides: collections.abc.Iterable[global___GameServicesGameServerDeploymentRolloutXGameServerConfigOverrides] | None = ...,
        timeouts: global___GameServicesGameServerDeploymentRolloutXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["default_game_server_config", b"default_game_server_config", "deployment_id", b"deployment_id", "game_server_config_overrides", b"game_server_config_overrides", "id", b"id", "name", b"name", "project", b"project", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> None: ...

global___GameServicesGameServerDeploymentRollout = GameServicesGameServerDeploymentRollout

@typing_extensions.final
class GameServicesRealmXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___GameServicesRealmXTimeouts = GameServicesRealmXTimeouts

@typing_extensions.final
class GameServicesRealm(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    DESCRIPTION_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    REALM_ID_FIELD_NUMBER: builtins.int
    TIME_ZONE_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    description: builtins.str
    etag: builtins.str
    id: builtins.str
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    location: builtins.str
    name: builtins.str
    project: builtins.str
    realm_id: builtins.str
    time_zone: builtins.str
    @property
    def timeouts(self) -> global___GameServicesRealmXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        realm_id: builtins.str = ...,
        time_zone: builtins.str = ...,
        timeouts: global___GameServicesRealmXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "etag", b"etag", "id", b"id", "labels", b"labels", "location", b"location", "name", b"name", "project", b"project", "realm_id", b"realm_id", "resource_info", b"resource_info", "time_zone", b"time_zone", "timeouts", b"timeouts"]) -> None: ...

global___GameServicesRealm = GameServicesRealm
