# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_wafv2.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13\x61ws/aws_wafv2.proto\x12\x15oak9.tython.aws.wafv2\x1a\x13shared/shared.proto\"\x84\x02\n\x05IPSet\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\r\n\x05scope\x18\x04 \x01(\t\x12\x1a\n\x12ip_address_version\x18\x05 \x01(\t\x12\x11\n\taddresses\x18\x06 \x03(\t\x12\x34\n\x04tags\x18\x07 \x03(\x0b\x32&.oak9.tython.aws.wafv2.IPSet.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa9\x02\n\x05WAFv2\x12,\n\x06ip_set\x18\x01 \x03(\x0b\x32\x1c.oak9.tython.aws.wafv2.IPSet\x12\x41\n\x11regex_pattern_set\x18\x02 \x03(\x0b\x32&.oak9.tython.aws.wafv2.RegexPatternSet\x12\x34\n\nrule_group\x18\x03 \x03(\x0b\x32 .oak9.tython.aws.wafv2.RuleGroup\x12\x30\n\tweb_a_c_l\x18\x04 \x01(\x0b\x32\x1d.oak9.tython.aws.wafv2.WebACL\x12G\n\x15web_a_c_l_association\x18\x05 \x03(\x0b\x32(.oak9.tython.aws.wafv2.WebACLAssociation\"\x8a\x02\n\x0fRegexPatternSet\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x1f\n\x17regular_expression_list\x18\x04 \x03(\t\x12\r\n\x05scope\x18\x05 \x01(\t\x12>\n\x04tags\x18\x06 \x03(\x0b\x32\x30.oak9.tython.aws.wafv2.RegexPatternSet.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x8c\x08\n\x15RuleGroupFieldToMatch\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12U\n\rsingle_header\x18\x02 \x03(\x0b\x32>.oak9.tython.aws.wafv2.RuleGroupFieldToMatch.SingleHeaderEntry\x12\x64\n\x15single_query_argument\x18\x03 \x03(\x0b\x32\x45.oak9.tython.aws.wafv2.RuleGroupFieldToMatch.SingleQueryArgumentEntry\x12`\n\x13\x61ll_query_arguments\x18\x04 \x03(\x0b\x32\x43.oak9.tython.aws.wafv2.RuleGroupFieldToMatch.AllQueryArgumentsEntry\x12K\n\x08uri_path\x18\x05 \x03(\x0b\x32\x39.oak9.tython.aws.wafv2.RuleGroupFieldToMatch.UriPathEntry\x12S\n\x0cquery_string\x18\x06 \x03(\x0b\x32=.oak9.tython.aws.wafv2.RuleGroupFieldToMatch.QueryStringEntry\x12\x44\n\x04\x62ody\x18\x07 \x03(\x0b\x32\x36.oak9.tython.aws.wafv2.RuleGroupFieldToMatch.BodyEntry\x12H\n\x06method\x18\x08 \x03(\x0b\x32\x38.oak9.tython.aws.wafv2.RuleGroupFieldToMatch.MethodEntry\x1a\x33\n\x11SingleHeaderEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a:\n\x18SingleQueryArgumentEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x38\n\x16\x41llQueryArgumentsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a.\n\x0cUriPathEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x32\n\x10QueryStringEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a+\n\tBodyEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a-\n\x0bMethodEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"h\n\x1bRuleGroupTextTransformation\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08priority\x18\x02 \x01(\x05\"\xc2\x02\n\x1bRuleGroupByteMatchStatement\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rsearch_string\x18\x02 \x01(\t\x12\x1c\n\x14search_string_base64\x18\x03 \x01(\t\x12\x44\n\x0e\x66ield_to_match\x18\x04 \x01(\x0b\x32,.oak9.tython.aws.wafv2.RuleGroupFieldToMatch\x12P\n\x14text_transformations\x18\x05 \x03(\x0b\x32\x32.oak9.tython.aws.wafv2.RuleGroupTextTransformation\x12\x1d\n\x15positional_constraint\x18\x06 \x01(\t\"\xee\x01\n\x1bRuleGroupSqliMatchStatement\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x44\n\x0e\x66ield_to_match\x18\x02 \x01(\x0b\x32,.oak9.tython.aws.wafv2.RuleGroupFieldToMatch\x12P\n\x14text_transformations\x18\x03 \x03(\x0b\x32\x32.oak9.tython.aws.wafv2.RuleGroupTextTransformation\"\xed\x01\n\x1aRuleGroupXssMatchStatement\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x44\n\x0e\x66ield_to_match\x18\x02 \x01(\x0b\x32,.oak9.tython.aws.wafv2.RuleGroupFieldToMatch\x12P\n\x14text_transformations\x18\x03 \x03(\x0b\x32\x32.oak9.tython.aws.wafv2.RuleGroupTextTransformation\"\x9e\x02\n RuleGroupSizeConstraintStatement\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x44\n\x0e\x66ield_to_match\x18\x02 \x01(\x0b\x32,.oak9.tython.aws.wafv2.RuleGroupFieldToMatch\x12\x1b\n\x13\x63omparison_operator\x18\x03 \x01(\t\x12\x0c\n\x04size\x18\x04 \x01(\x05\x12P\n\x14text_transformations\x18\x05 \x03(\x0b\x32\x32.oak9.tython.aws.wafv2.RuleGroupTextTransformation\"\x8c\x01\n!RuleGroupForwardedIPConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0bheader_name\x18\x02 \x01(\t\x12\x19\n\x11\x66\x61llback_behavior\x18\x03 \x01(\t\"\xc3\x01\n\x1aRuleGroupGeoMatchStatement\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rcountry_codes\x18\x02 \x03(\t\x12U\n\x13\x66orwarded_ip_config\x18\x03 \x01(\x0b\x32\x38.oak9.tython.aws.wafv2.RuleGroupForwardedIPConfiguration\"\xa3\x01\n&RuleGroupIPSetForwardedIPConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0bheader_name\x18\x02 \x01(\t\x12\x19\n\x11\x66\x61llback_behavior\x18\x03 \x01(\t\x12\x10\n\x08position\x18\x04 \x01(\t\"\xcb\x01\n RuleGroupIPSetReferenceStatement\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0b\n\x03\x61rn\x18\x02 \x01(\t\x12\x61\n\x1aip_set_forwarded_ip_config\x18\x03 \x01(\x0b\x32=.oak9.tython.aws.wafv2.RuleGroupIPSetForwardedIPConfiguration\"\x8a\x02\n*RuleGroupRegexPatternSetReferenceStatement\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0b\n\x03\x61rn\x18\x02 \x01(\t\x12\x44\n\x0e\x66ield_to_match\x18\x03 \x01(\x0b\x32,.oak9.tython.aws.wafv2.RuleGroupFieldToMatch\x12P\n\x14text_transformations\x18\x04 \x03(\x0b\x32\x32.oak9.tython.aws.wafv2.RuleGroupTextTransformation\"\xc1\x05\n\x17RuleGroupStatementThree\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12P\n\x14\x62yte_match_statement\x18\x02 \x01(\x0b\x32\x32.oak9.tython.aws.wafv2.RuleGroupByteMatchStatement\x12P\n\x14sqli_match_statement\x18\x03 \x01(\x0b\x32\x32.oak9.tython.aws.wafv2.RuleGroupSqliMatchStatement\x12N\n\x13xss_match_statement\x18\x04 \x01(\x0b\x32\x31.oak9.tython.aws.wafv2.RuleGroupXssMatchStatement\x12Z\n\x19size_constraint_statement\x18\x05 \x01(\x0b\x32\x37.oak9.tython.aws.wafv2.RuleGroupSizeConstraintStatement\x12N\n\x13geo_match_statement\x18\x06 \x01(\x0b\x32\x31.oak9.tython.aws.wafv2.RuleGroupGeoMatchStatement\x12[\n\x1aip_set_reference_statement\x18\x07 \x01(\x0b\x32\x37.oak9.tython.aws.wafv2.RuleGroupIPSetReferenceStatement\x12p\n%regex_pattern_set_reference_statement\x18\x08 \x01(\x0b\x32\x41.oak9.tython.aws.wafv2.RuleGroupRegexPatternSetReferenceStatement\"\xa9\x02\n\x1eRuleGroupRateBasedStatementTwo\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\r\n\x05limit\x18\x02 \x01(\x05\x12\x1a\n\x12\x61ggregate_key_type\x18\x03 \x01(\t\x12L\n\x14scope_down_statement\x18\x04 \x01(\x0b\x32..oak9.tython.aws.wafv2.RuleGroupStatementThree\x12U\n\x13\x66orwarded_ip_config\x18\x05 \x01(\x0b\x32\x38.oak9.tython.aws.wafv2.RuleGroupForwardedIPConfiguration\"\x97\x01\n\x18RuleGroupAndStatementTwo\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x42\n\nstatements\x18\x02 \x03(\x0b\x32..oak9.tython.aws.wafv2.RuleGroupStatementThree\"\x96\x01\n\x17RuleGroupOrStatementTwo\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x42\n\nstatements\x18\x02 \x03(\x0b\x32..oak9.tython.aws.wafv2.RuleGroupStatementThree\"\x96\x01\n\x18RuleGroupNotStatementTwo\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x41\n\tstatement\x18\x02 \x01(\x0b\x32..oak9.tython.aws.wafv2.RuleGroupStatementThree\"\xea\x07\n\x15RuleGroupStatementTwo\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12P\n\x14\x62yte_match_statement\x18\x02 \x01(\x0b\x32\x32.oak9.tython.aws.wafv2.RuleGroupByteMatchStatement\x12P\n\x14sqli_match_statement\x18\x03 \x01(\x0b\x32\x32.oak9.tython.aws.wafv2.RuleGroupSqliMatchStatement\x12N\n\x13xss_match_statement\x18\x04 \x01(\x0b\x32\x31.oak9.tython.aws.wafv2.RuleGroupXssMatchStatement\x12Z\n\x19size_constraint_statement\x18\x05 \x01(\x0b\x32\x37.oak9.tython.aws.wafv2.RuleGroupSizeConstraintStatement\x12N\n\x13geo_match_statement\x18\x06 \x01(\x0b\x32\x31.oak9.tython.aws.wafv2.RuleGroupGeoMatchStatement\x12[\n\x1aip_set_reference_statement\x18\x07 \x01(\x0b\x32\x37.oak9.tython.aws.wafv2.RuleGroupIPSetReferenceStatement\x12p\n%regex_pattern_set_reference_statement\x18\x08 \x01(\x0b\x32\x41.oak9.tython.aws.wafv2.RuleGroupRegexPatternSetReferenceStatement\x12S\n\x14rate_based_statement\x18\t \x01(\x0b\x32\x35.oak9.tython.aws.wafv2.RuleGroupRateBasedStatementTwo\x12\x46\n\rand_statement\x18\n \x01(\x0b\x32/.oak9.tython.aws.wafv2.RuleGroupAndStatementTwo\x12\x44\n\x0cor_statement\x18\x0b \x01(\x0b\x32..oak9.tython.aws.wafv2.RuleGroupOrStatementTwo\x12\x46\n\rnot_statement\x18\x0c \x01(\x0b\x32/.oak9.tython.aws.wafv2.RuleGroupNotStatementTwo\"\xa7\x02\n\x1eRuleGroupRateBasedStatementOne\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\r\n\x05limit\x18\x02 \x01(\x05\x12\x1a\n\x12\x61ggregate_key_type\x18\x03 \x01(\t\x12J\n\x14scope_down_statement\x18\x04 \x01(\x0b\x32,.oak9.tython.aws.wafv2.RuleGroupStatementTwo\x12U\n\x13\x66orwarded_ip_config\x18\x05 \x01(\x0b\x32\x38.oak9.tython.aws.wafv2.RuleGroupForwardedIPConfiguration\"\x95\x01\n\x18RuleGroupAndStatementOne\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12@\n\nstatements\x18\x02 \x03(\x0b\x32,.oak9.tython.aws.wafv2.RuleGroupStatementTwo\"\x94\x01\n\x17RuleGroupOrStatementOne\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12@\n\nstatements\x18\x02 \x03(\x0b\x32,.oak9.tython.aws.wafv2.RuleGroupStatementTwo\"\x94\x01\n\x18RuleGroupNotStatementOne\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12?\n\tstatement\x18\x02 \x01(\x0b\x32,.oak9.tython.aws.wafv2.RuleGroupStatementTwo\"\xea\x07\n\x15RuleGroupStatementOne\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12P\n\x14\x62yte_match_statement\x18\x02 \x01(\x0b\x32\x32.oak9.tython.aws.wafv2.RuleGroupByteMatchStatement\x12P\n\x14sqli_match_statement\x18\x03 \x01(\x0b\x32\x32.oak9.tython.aws.wafv2.RuleGroupSqliMatchStatement\x12N\n\x13xss_match_statement\x18\x04 \x01(\x0b\x32\x31.oak9.tython.aws.wafv2.RuleGroupXssMatchStatement\x12Z\n\x19size_constraint_statement\x18\x05 \x01(\x0b\x32\x37.oak9.tython.aws.wafv2.RuleGroupSizeConstraintStatement\x12N\n\x13geo_match_statement\x18\x06 \x01(\x0b\x32\x31.oak9.tython.aws.wafv2.RuleGroupGeoMatchStatement\x12[\n\x1aip_set_reference_statement\x18\x07 \x01(\x0b\x32\x37.oak9.tython.aws.wafv2.RuleGroupIPSetReferenceStatement\x12p\n%regex_pattern_set_reference_statement\x18\x08 \x01(\x0b\x32\x41.oak9.tython.aws.wafv2.RuleGroupRegexPatternSetReferenceStatement\x12S\n\x14rate_based_statement\x18\t \x01(\x0b\x32\x35.oak9.tython.aws.wafv2.RuleGroupRateBasedStatementOne\x12\x46\n\rand_statement\x18\n \x01(\x0b\x32/.oak9.tython.aws.wafv2.RuleGroupAndStatementOne\x12\x44\n\x0cor_statement\x18\x0b \x01(\x0b\x32..oak9.tython.aws.wafv2.RuleGroupOrStatementOne\x12\x46\n\rnot_statement\x18\x0c \x01(\x0b\x32/.oak9.tython.aws.wafv2.RuleGroupNotStatementOne\"\xaa\x03\n\x13RuleGroupRuleAction\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x44\n\x05\x61llow\x18\x02 \x03(\x0b\x32\x35.oak9.tython.aws.wafv2.RuleGroupRuleAction.AllowEntry\x12\x44\n\x05\x62lock\x18\x03 \x03(\x0b\x32\x35.oak9.tython.aws.wafv2.RuleGroupRuleAction.BlockEntry\x12\x44\n\x05\x63ount\x18\x04 \x03(\x0b\x32\x35.oak9.tython.aws.wafv2.RuleGroupRuleAction.CountEntry\x1a,\n\nAllowEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a,\n\nBlockEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a,\n\nCountEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb0\x01\n\x19RuleGroupVisibilityConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12 \n\x18sampled_requests_enabled\x18\x02 \x01(\x08\x12#\n\x1b\x63loud_watch_metrics_enabled\x18\x03 \x01(\x08\x12\x13\n\x0bmetric_name\x18\x04 \x01(\t\"\xb2\x02\n\rRuleGroupRule\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08priority\x18\x03 \x01(\x05\x12?\n\tstatement\x18\x04 \x01(\x0b\x32,.oak9.tython.aws.wafv2.RuleGroupStatementOne\x12:\n\x06\x61\x63tion\x18\x05 \x01(\x0b\x32*.oak9.tython.aws.wafv2.RuleGroupRuleAction\x12K\n\x11visibility_config\x18\x06 \x01(\x0b\x32\x30.oak9.tython.aws.wafv2.RuleGroupVisibilityConfig\"\xf1\x02\n\tRuleGroup\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08\x63\x61pacity\x18\x02 \x01(\x05\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\r\n\x05scope\x18\x05 \x01(\t\x12\x33\n\x05rules\x18\x06 \x03(\x0b\x32$.oak9.tython.aws.wafv2.RuleGroupRule\x12K\n\x11visibility_config\x18\x07 \x01(\x0b\x32\x30.oak9.tython.aws.wafv2.RuleGroupVisibilityConfig\x12\x38\n\x04tags\x18\x08 \x03(\x0b\x32*.oak9.tython.aws.wafv2.RuleGroup.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb6\x02\n\x13WebACLDefaultAction\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x44\n\x05\x61llow\x18\x02 \x03(\x0b\x32\x35.oak9.tython.aws.wafv2.WebACLDefaultAction.AllowEntry\x12\x44\n\x05\x62lock\x18\x03 \x03(\x0b\x32\x35.oak9.tython.aws.wafv2.WebACLDefaultAction.BlockEntry\x1a,\n\nAllowEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a,\n\nBlockEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xf4\x07\n\x12WebACLFieldToMatch\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12R\n\rsingle_header\x18\x02 \x03(\x0b\x32;.oak9.tython.aws.wafv2.WebACLFieldToMatch.SingleHeaderEntry\x12\x61\n\x15single_query_argument\x18\x03 \x03(\x0b\x32\x42.oak9.tython.aws.wafv2.WebACLFieldToMatch.SingleQueryArgumentEntry\x12]\n\x13\x61ll_query_arguments\x18\x04 \x03(\x0b\x32@.oak9.tython.aws.wafv2.WebACLFieldToMatch.AllQueryArgumentsEntry\x12H\n\x08uri_path\x18\x05 \x03(\x0b\x32\x36.oak9.tython.aws.wafv2.WebACLFieldToMatch.UriPathEntry\x12P\n\x0cquery_string\x18\x06 \x03(\x0b\x32:.oak9.tython.aws.wafv2.WebACLFieldToMatch.QueryStringEntry\x12\x41\n\x04\x62ody\x18\x07 \x03(\x0b\x32\x33.oak9.tython.aws.wafv2.WebACLFieldToMatch.BodyEntry\x12\x45\n\x06method\x18\x08 \x03(\x0b\x32\x35.oak9.tython.aws.wafv2.WebACLFieldToMatch.MethodEntry\x1a\x33\n\x11SingleHeaderEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a:\n\x18SingleQueryArgumentEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x38\n\x16\x41llQueryArgumentsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a.\n\x0cUriPathEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x32\n\x10QueryStringEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a+\n\tBodyEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a-\n\x0bMethodEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"e\n\x18WebACLTextTransformation\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08priority\x18\x02 \x01(\x05\"\xb9\x02\n\x18WebACLByteMatchStatement\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rsearch_string\x18\x02 \x01(\t\x12\x1c\n\x14search_string_base64\x18\x03 \x01(\t\x12\x41\n\x0e\x66ield_to_match\x18\x04 \x01(\x0b\x32).oak9.tython.aws.wafv2.WebACLFieldToMatch\x12M\n\x14text_transformations\x18\x05 \x03(\x0b\x32/.oak9.tython.aws.wafv2.WebACLTextTransformation\x12\x1d\n\x15positional_constraint\x18\x06 \x01(\t\"\xe5\x01\n\x18WebACLSqliMatchStatement\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x41\n\x0e\x66ield_to_match\x18\x02 \x01(\x0b\x32).oak9.tython.aws.wafv2.WebACLFieldToMatch\x12M\n\x14text_transformations\x18\x03 \x03(\x0b\x32/.oak9.tython.aws.wafv2.WebACLTextTransformation\"\xe4\x01\n\x17WebACLXssMatchStatement\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x41\n\x0e\x66ield_to_match\x18\x02 \x01(\x0b\x32).oak9.tython.aws.wafv2.WebACLFieldToMatch\x12M\n\x14text_transformations\x18\x03 \x03(\x0b\x32/.oak9.tython.aws.wafv2.WebACLTextTransformation\"\x95\x02\n\x1dWebACLSizeConstraintStatement\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x41\n\x0e\x66ield_to_match\x18\x02 \x01(\x0b\x32).oak9.tython.aws.wafv2.WebACLFieldToMatch\x12\x1b\n\x13\x63omparison_operator\x18\x03 \x01(\t\x12\x0c\n\x04size\x18\x04 \x01(\x05\x12M\n\x14text_transformations\x18\x05 \x03(\x0b\x32/.oak9.tython.aws.wafv2.WebACLTextTransformation\"\x89\x01\n\x1eWebACLForwardedIPConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0bheader_name\x18\x02 \x01(\t\x12\x19\n\x11\x66\x61llback_behavior\x18\x03 \x01(\t\"\xbd\x01\n\x17WebACLGeoMatchStatement\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rcountry_codes\x18\x02 \x03(\t\x12R\n\x13\x66orwarded_ip_config\x18\x03 \x01(\x0b\x32\x35.oak9.tython.aws.wafv2.WebACLForwardedIPConfiguration\"[\n\x12WebACLExcludedRule\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\"\xac\x01\n!WebACLRuleGroupReferenceStatement\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0b\n\x03\x61rn\x18\x02 \x01(\t\x12\x41\n\x0e\x65xcluded_rules\x18\x03 \x03(\x0b\x32).oak9.tython.aws.wafv2.WebACLExcludedRule\"\xa0\x01\n#WebACLIPSetForwardedIPConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0bheader_name\x18\x02 \x01(\t\x12\x19\n\x11\x66\x61llback_behavior\x18\x03 \x01(\t\x12\x10\n\x08position\x18\x04 \x01(\t\"\xc5\x01\n\x1dWebACLIPSetReferenceStatement\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0b\n\x03\x61rn\x18\x02 \x01(\t\x12^\n\x1aip_set_forwarded_ip_config\x18\x03 \x01(\x0b\x32:.oak9.tython.aws.wafv2.WebACLIPSetForwardedIPConfiguration\"\x81\x02\n\'WebACLRegexPatternSetReferenceStatement\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0b\n\x03\x61rn\x18\x02 \x01(\t\x12\x41\n\x0e\x66ield_to_match\x18\x03 \x01(\x0b\x32).oak9.tython.aws.wafv2.WebACLFieldToMatch\x12M\n\x14text_transformations\x18\x04 \x03(\x0b\x32/.oak9.tython.aws.wafv2.WebACLTextTransformation\"\xc0\x01\n\x1fWebACLManagedRuleGroupStatement\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0bvendor_name\x18\x03 \x01(\t\x12\x41\n\x0e\x65xcluded_rules\x18\x04 \x03(\x0b\x32).oak9.tython.aws.wafv2.WebACLExcludedRule\"\xe9\x06\n\x14WebACLStatementThree\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12M\n\x14\x62yte_match_statement\x18\x02 \x01(\x0b\x32/.oak9.tython.aws.wafv2.WebACLByteMatchStatement\x12M\n\x14sqli_match_statement\x18\x03 \x01(\x0b\x32/.oak9.tython.aws.wafv2.WebACLSqliMatchStatement\x12K\n\x13xss_match_statement\x18\x04 \x01(\x0b\x32..oak9.tython.aws.wafv2.WebACLXssMatchStatement\x12W\n\x19size_constraint_statement\x18\x05 \x01(\x0b\x32\x34.oak9.tython.aws.wafv2.WebACLSizeConstraintStatement\x12K\n\x13geo_match_statement\x18\x06 \x01(\x0b\x32..oak9.tython.aws.wafv2.WebACLGeoMatchStatement\x12`\n\x1erule_group_reference_statement\x18\x07 \x01(\x0b\x32\x38.oak9.tython.aws.wafv2.WebACLRuleGroupReferenceStatement\x12X\n\x1aip_set_reference_statement\x18\x08 \x01(\x0b\x32\x34.oak9.tython.aws.wafv2.WebACLIPSetReferenceStatement\x12m\n%regex_pattern_set_reference_statement\x18\t \x01(\x0b\x32>.oak9.tython.aws.wafv2.WebACLRegexPatternSetReferenceStatement\x12\\\n\x1cmanaged_rule_group_statement\x18\n \x01(\x0b\x32\x36.oak9.tython.aws.wafv2.WebACLManagedRuleGroupStatement\"\xa0\x02\n\x1bWebACLRateBasedStatementTwo\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\r\n\x05limit\x18\x02 \x01(\x05\x12\x1a\n\x12\x61ggregate_key_type\x18\x03 \x01(\t\x12I\n\x14scope_down_statement\x18\x04 \x01(\x0b\x32+.oak9.tython.aws.wafv2.WebACLStatementThree\x12R\n\x13\x66orwarded_ip_config\x18\x05 \x01(\x0b\x32\x35.oak9.tython.aws.wafv2.WebACLForwardedIPConfiguration\"\x91\x01\n\x15WebACLAndStatementTwo\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12?\n\nstatements\x18\x02 \x03(\x0b\x32+.oak9.tython.aws.wafv2.WebACLStatementThree\"\x90\x01\n\x14WebACLOrStatementTwo\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12?\n\nstatements\x18\x02 \x03(\x0b\x32+.oak9.tython.aws.wafv2.WebACLStatementThree\"\x90\x01\n\x15WebACLNotStatementTwo\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12>\n\tstatement\x18\x02 \x01(\x0b\x32+.oak9.tython.aws.wafv2.WebACLStatementThree\"\x86\t\n\x12WebACLStatementTwo\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12M\n\x14\x62yte_match_statement\x18\x02 \x01(\x0b\x32/.oak9.tython.aws.wafv2.WebACLByteMatchStatement\x12M\n\x14sqli_match_statement\x18\x03 \x01(\x0b\x32/.oak9.tython.aws.wafv2.WebACLSqliMatchStatement\x12K\n\x13xss_match_statement\x18\x04 \x01(\x0b\x32..oak9.tython.aws.wafv2.WebACLXssMatchStatement\x12W\n\x19size_constraint_statement\x18\x05 \x01(\x0b\x32\x34.oak9.tython.aws.wafv2.WebACLSizeConstraintStatement\x12K\n\x13geo_match_statement\x18\x06 \x01(\x0b\x32..oak9.tython.aws.wafv2.WebACLGeoMatchStatement\x12`\n\x1erule_group_reference_statement\x18\x07 \x01(\x0b\x32\x38.oak9.tython.aws.wafv2.WebACLRuleGroupReferenceStatement\x12X\n\x1aip_set_reference_statement\x18\x08 \x01(\x0b\x32\x34.oak9.tython.aws.wafv2.WebACLIPSetReferenceStatement\x12m\n%regex_pattern_set_reference_statement\x18\t \x01(\x0b\x32>.oak9.tython.aws.wafv2.WebACLRegexPatternSetReferenceStatement\x12\\\n\x1cmanaged_rule_group_statement\x18\n \x01(\x0b\x32\x36.oak9.tython.aws.wafv2.WebACLManagedRuleGroupStatement\x12P\n\x14rate_based_statement\x18\x0b \x01(\x0b\x32\x32.oak9.tython.aws.wafv2.WebACLRateBasedStatementTwo\x12\x43\n\rand_statement\x18\x0c \x01(\x0b\x32,.oak9.tython.aws.wafv2.WebACLAndStatementTwo\x12\x41\n\x0cor_statement\x18\r \x01(\x0b\x32+.oak9.tython.aws.wafv2.WebACLOrStatementTwo\x12\x43\n\rnot_statement\x18\x0e \x01(\x0b\x32,.oak9.tython.aws.wafv2.WebACLNotStatementTwo\"\x9e\x02\n\x1bWebACLRateBasedStatementOne\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\r\n\x05limit\x18\x02 \x01(\x05\x12\x1a\n\x12\x61ggregate_key_type\x18\x03 \x01(\t\x12G\n\x14scope_down_statement\x18\x04 \x01(\x0b\x32).oak9.tython.aws.wafv2.WebACLStatementTwo\x12R\n\x13\x66orwarded_ip_config\x18\x05 \x01(\x0b\x32\x35.oak9.tython.aws.wafv2.WebACLForwardedIPConfiguration\"\x8f\x01\n\x15WebACLAndStatementOne\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12=\n\nstatements\x18\x02 \x03(\x0b\x32).oak9.tython.aws.wafv2.WebACLStatementTwo\"\x8e\x01\n\x14WebACLOrStatementOne\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12=\n\nstatements\x18\x02 \x03(\x0b\x32).oak9.tython.aws.wafv2.WebACLStatementTwo\"\x8e\x01\n\x15WebACLNotStatementOne\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12<\n\tstatement\x18\x02 \x01(\x0b\x32).oak9.tython.aws.wafv2.WebACLStatementTwo\"\x86\t\n\x12WebACLStatementOne\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12M\n\x14\x62yte_match_statement\x18\x02 \x01(\x0b\x32/.oak9.tython.aws.wafv2.WebACLByteMatchStatement\x12M\n\x14sqli_match_statement\x18\x03 \x01(\x0b\x32/.oak9.tython.aws.wafv2.WebACLSqliMatchStatement\x12K\n\x13xss_match_statement\x18\x04 \x01(\x0b\x32..oak9.tython.aws.wafv2.WebACLXssMatchStatement\x12W\n\x19size_constraint_statement\x18\x05 \x01(\x0b\x32\x34.oak9.tython.aws.wafv2.WebACLSizeConstraintStatement\x12K\n\x13geo_match_statement\x18\x06 \x01(\x0b\x32..oak9.tython.aws.wafv2.WebACLGeoMatchStatement\x12`\n\x1erule_group_reference_statement\x18\x07 \x01(\x0b\x32\x38.oak9.tython.aws.wafv2.WebACLRuleGroupReferenceStatement\x12X\n\x1aip_set_reference_statement\x18\x08 \x01(\x0b\x32\x34.oak9.tython.aws.wafv2.WebACLIPSetReferenceStatement\x12m\n%regex_pattern_set_reference_statement\x18\t \x01(\x0b\x32>.oak9.tython.aws.wafv2.WebACLRegexPatternSetReferenceStatement\x12\\\n\x1cmanaged_rule_group_statement\x18\n \x01(\x0b\x32\x36.oak9.tython.aws.wafv2.WebACLManagedRuleGroupStatement\x12P\n\x14rate_based_statement\x18\x0b \x01(\x0b\x32\x32.oak9.tython.aws.wafv2.WebACLRateBasedStatementOne\x12\x43\n\rand_statement\x18\x0c \x01(\x0b\x32,.oak9.tython.aws.wafv2.WebACLAndStatementOne\x12\x41\n\x0cor_statement\x18\r \x01(\x0b\x32+.oak9.tython.aws.wafv2.WebACLOrStatementOne\x12\x43\n\rnot_statement\x18\x0e \x01(\x0b\x32,.oak9.tython.aws.wafv2.WebACLNotStatementOne\"\x9e\x03\n\x10WebACLRuleAction\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x41\n\x05\x61llow\x18\x02 \x03(\x0b\x32\x32.oak9.tython.aws.wafv2.WebACLRuleAction.AllowEntry\x12\x41\n\x05\x62lock\x18\x03 \x03(\x0b\x32\x32.oak9.tython.aws.wafv2.WebACLRuleAction.BlockEntry\x12\x41\n\x05\x63ount\x18\x04 \x03(\x0b\x32\x32.oak9.tython.aws.wafv2.WebACLRuleAction.CountEntry\x1a,\n\nAllowEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a,\n\nBlockEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a,\n\nCountEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb6\x02\n\x14WebACLOverrideAction\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x45\n\x05\x63ount\x18\x02 \x03(\x0b\x32\x36.oak9.tython.aws.wafv2.WebACLOverrideAction.CountEntry\x12\x43\n\x04none\x18\x03 \x03(\x0b\x32\x35.oak9.tython.aws.wafv2.WebACLOverrideAction.NoneEntry\x1a,\n\nCountEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a+\n\tNoneEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xad\x01\n\x16WebACLVisibilityConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12 \n\x18sampled_requests_enabled\x18\x02 \x01(\x08\x12#\n\x1b\x63loud_watch_metrics_enabled\x18\x03 \x01(\x08\x12\x13\n\x0bmetric_name\x18\x04 \x01(\t\"\xec\x02\n\nWebACLRule\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08priority\x18\x03 \x01(\x05\x12<\n\tstatement\x18\x04 \x01(\x0b\x32).oak9.tython.aws.wafv2.WebACLStatementOne\x12\x37\n\x06\x61\x63tion\x18\x05 \x01(\x0b\x32\'.oak9.tython.aws.wafv2.WebACLRuleAction\x12\x44\n\x0foverride_action\x18\x06 \x01(\x0b\x32+.oak9.tython.aws.wafv2.WebACLOverrideAction\x12H\n\x11visibility_config\x18\x07 \x01(\x0b\x32-.oak9.tython.aws.wafv2.WebACLVisibilityConfig\"\x8c\x04\n\x06WebACL\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x42\n\x0e\x64\x65\x66\x61ult_action\x18\x02 \x01(\x0b\x32*.oak9.tython.aws.wafv2.WebACLDefaultAction\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\r\n\x05scope\x18\x05 \x01(\t\x12\x30\n\x05rules\x18\x06 \x03(\x0b\x32!.oak9.tython.aws.wafv2.WebACLRule\x12H\n\x11visibility_config\x18\x07 \x01(\x0b\x32-.oak9.tython.aws.wafv2.WebACLVisibilityConfig\x12\x35\n\x04tags\x18\x08 \x03(\x0b\x32\'.oak9.tython.aws.wafv2.WebACL.TagsEntry\x12\x0b\n\x03\x61rn\x18\t \x01(\t\x12\x10\n\x08\x63\x61pacity\x18\n \x01(\t\x12\x17\n\x0flabel_namespace\x18\x0b \x01(\t\x12#\n\x1bmanaged_by_firewall_manager\x18\x0c \x01(\t\x12\x16\n\x0e\x63\x61ptcha_config\x18\r \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"y\n\x11WebACLAssociation\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0cresource_arn\x18\x02 \x01(\t\x12\x15\n\rweb_a_c_l_arn\x18\x03 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_wafv2_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _IPSET_TAGSENTRY._options = None
  _IPSET_TAGSENTRY._serialized_options = b'8\001'
  _REGEXPATTERNSET_TAGSENTRY._options = None
  _REGEXPATTERNSET_TAGSENTRY._serialized_options = b'8\001'
  _RULEGROUPFIELDTOMATCH_SINGLEHEADERENTRY._options = None
  _RULEGROUPFIELDTOMATCH_SINGLEHEADERENTRY._serialized_options = b'8\001'
  _RULEGROUPFIELDTOMATCH_SINGLEQUERYARGUMENTENTRY._options = None
  _RULEGROUPFIELDTOMATCH_SINGLEQUERYARGUMENTENTRY._serialized_options = b'8\001'
  _RULEGROUPFIELDTOMATCH_ALLQUERYARGUMENTSENTRY._options = None
  _RULEGROUPFIELDTOMATCH_ALLQUERYARGUMENTSENTRY._serialized_options = b'8\001'
  _RULEGROUPFIELDTOMATCH_URIPATHENTRY._options = None
  _RULEGROUPFIELDTOMATCH_URIPATHENTRY._serialized_options = b'8\001'
  _RULEGROUPFIELDTOMATCH_QUERYSTRINGENTRY._options = None
  _RULEGROUPFIELDTOMATCH_QUERYSTRINGENTRY._serialized_options = b'8\001'
  _RULEGROUPFIELDTOMATCH_BODYENTRY._options = None
  _RULEGROUPFIELDTOMATCH_BODYENTRY._serialized_options = b'8\001'
  _RULEGROUPFIELDTOMATCH_METHODENTRY._options = None
  _RULEGROUPFIELDTOMATCH_METHODENTRY._serialized_options = b'8\001'
  _RULEGROUPRULEACTION_ALLOWENTRY._options = None
  _RULEGROUPRULEACTION_ALLOWENTRY._serialized_options = b'8\001'
  _RULEGROUPRULEACTION_BLOCKENTRY._options = None
  _RULEGROUPRULEACTION_BLOCKENTRY._serialized_options = b'8\001'
  _RULEGROUPRULEACTION_COUNTENTRY._options = None
  _RULEGROUPRULEACTION_COUNTENTRY._serialized_options = b'8\001'
  _RULEGROUP_TAGSENTRY._options = None
  _RULEGROUP_TAGSENTRY._serialized_options = b'8\001'
  _WEBACLDEFAULTACTION_ALLOWENTRY._options = None
  _WEBACLDEFAULTACTION_ALLOWENTRY._serialized_options = b'8\001'
  _WEBACLDEFAULTACTION_BLOCKENTRY._options = None
  _WEBACLDEFAULTACTION_BLOCKENTRY._serialized_options = b'8\001'
  _WEBACLFIELDTOMATCH_SINGLEHEADERENTRY._options = None
  _WEBACLFIELDTOMATCH_SINGLEHEADERENTRY._serialized_options = b'8\001'
  _WEBACLFIELDTOMATCH_SINGLEQUERYARGUMENTENTRY._options = None
  _WEBACLFIELDTOMATCH_SINGLEQUERYARGUMENTENTRY._serialized_options = b'8\001'
  _WEBACLFIELDTOMATCH_ALLQUERYARGUMENTSENTRY._options = None
  _WEBACLFIELDTOMATCH_ALLQUERYARGUMENTSENTRY._serialized_options = b'8\001'
  _WEBACLFIELDTOMATCH_URIPATHENTRY._options = None
  _WEBACLFIELDTOMATCH_URIPATHENTRY._serialized_options = b'8\001'
  _WEBACLFIELDTOMATCH_QUERYSTRINGENTRY._options = None
  _WEBACLFIELDTOMATCH_QUERYSTRINGENTRY._serialized_options = b'8\001'
  _WEBACLFIELDTOMATCH_BODYENTRY._options = None
  _WEBACLFIELDTOMATCH_BODYENTRY._serialized_options = b'8\001'
  _WEBACLFIELDTOMATCH_METHODENTRY._options = None
  _WEBACLFIELDTOMATCH_METHODENTRY._serialized_options = b'8\001'
  _WEBACLRULEACTION_ALLOWENTRY._options = None
  _WEBACLRULEACTION_ALLOWENTRY._serialized_options = b'8\001'
  _WEBACLRULEACTION_BLOCKENTRY._options = None
  _WEBACLRULEACTION_BLOCKENTRY._serialized_options = b'8\001'
  _WEBACLRULEACTION_COUNTENTRY._options = None
  _WEBACLRULEACTION_COUNTENTRY._serialized_options = b'8\001'
  _WEBACLOVERRIDEACTION_COUNTENTRY._options = None
  _WEBACLOVERRIDEACTION_COUNTENTRY._serialized_options = b'8\001'
  _WEBACLOVERRIDEACTION_NONEENTRY._options = None
  _WEBACLOVERRIDEACTION_NONEENTRY._serialized_options = b'8\001'
  _WEBACL_TAGSENTRY._options = None
  _WEBACL_TAGSENTRY._serialized_options = b'8\001'
  _IPSET._serialized_start=68
  _IPSET._serialized_end=328
  _IPSET_TAGSENTRY._serialized_start=285
  _IPSET_TAGSENTRY._serialized_end=328
  _WAFV2._serialized_start=331
  _WAFV2._serialized_end=628
  _REGEXPATTERNSET._serialized_start=631
  _REGEXPATTERNSET._serialized_end=897
  _REGEXPATTERNSET_TAGSENTRY._serialized_start=285
  _REGEXPATTERNSET_TAGSENTRY._serialized_end=328
  _RULEGROUPFIELDTOMATCH._serialized_start=900
  _RULEGROUPFIELDTOMATCH._serialized_end=1936
  _RULEGROUPFIELDTOMATCH_SINGLEHEADERENTRY._serialized_start=1575
  _RULEGROUPFIELDTOMATCH_SINGLEHEADERENTRY._serialized_end=1626
  _RULEGROUPFIELDTOMATCH_SINGLEQUERYARGUMENTENTRY._serialized_start=1628
  _RULEGROUPFIELDTOMATCH_SINGLEQUERYARGUMENTENTRY._serialized_end=1686
  _RULEGROUPFIELDTOMATCH_ALLQUERYARGUMENTSENTRY._serialized_start=1688
  _RULEGROUPFIELDTOMATCH_ALLQUERYARGUMENTSENTRY._serialized_end=1744
  _RULEGROUPFIELDTOMATCH_URIPATHENTRY._serialized_start=1746
  _RULEGROUPFIELDTOMATCH_URIPATHENTRY._serialized_end=1792
  _RULEGROUPFIELDTOMATCH_QUERYSTRINGENTRY._serialized_start=1794
  _RULEGROUPFIELDTOMATCH_QUERYSTRINGENTRY._serialized_end=1844
  _RULEGROUPFIELDTOMATCH_BODYENTRY._serialized_start=1846
  _RULEGROUPFIELDTOMATCH_BODYENTRY._serialized_end=1889
  _RULEGROUPFIELDTOMATCH_METHODENTRY._serialized_start=1891
  _RULEGROUPFIELDTOMATCH_METHODENTRY._serialized_end=1936
  _RULEGROUPTEXTTRANSFORMATION._serialized_start=1938
  _RULEGROUPTEXTTRANSFORMATION._serialized_end=2042
  _RULEGROUPBYTEMATCHSTATEMENT._serialized_start=2045
  _RULEGROUPBYTEMATCHSTATEMENT._serialized_end=2367
  _RULEGROUPSQLIMATCHSTATEMENT._serialized_start=2370
  _RULEGROUPSQLIMATCHSTATEMENT._serialized_end=2608
  _RULEGROUPXSSMATCHSTATEMENT._serialized_start=2611
  _RULEGROUPXSSMATCHSTATEMENT._serialized_end=2848
  _RULEGROUPSIZECONSTRAINTSTATEMENT._serialized_start=2851
  _RULEGROUPSIZECONSTRAINTSTATEMENT._serialized_end=3137
  _RULEGROUPFORWARDEDIPCONFIGURATION._serialized_start=3140
  _RULEGROUPFORWARDEDIPCONFIGURATION._serialized_end=3280
  _RULEGROUPGEOMATCHSTATEMENT._serialized_start=3283
  _RULEGROUPGEOMATCHSTATEMENT._serialized_end=3478
  _RULEGROUPIPSETFORWARDEDIPCONFIGURATION._serialized_start=3481
  _RULEGROUPIPSETFORWARDEDIPCONFIGURATION._serialized_end=3644
  _RULEGROUPIPSETREFERENCESTATEMENT._serialized_start=3647
  _RULEGROUPIPSETREFERENCESTATEMENT._serialized_end=3850
  _RULEGROUPREGEXPATTERNSETREFERENCESTATEMENT._serialized_start=3853
  _RULEGROUPREGEXPATTERNSETREFERENCESTATEMENT._serialized_end=4119
  _RULEGROUPSTATEMENTTHREE._serialized_start=4122
  _RULEGROUPSTATEMENTTHREE._serialized_end=4827
  _RULEGROUPRATEBASEDSTATEMENTTWO._serialized_start=4830
  _RULEGROUPRATEBASEDSTATEMENTTWO._serialized_end=5127
  _RULEGROUPANDSTATEMENTTWO._serialized_start=5130
  _RULEGROUPANDSTATEMENTTWO._serialized_end=5281
  _RULEGROUPORSTATEMENTTWO._serialized_start=5284
  _RULEGROUPORSTATEMENTTWO._serialized_end=5434
  _RULEGROUPNOTSTATEMENTTWO._serialized_start=5437
  _RULEGROUPNOTSTATEMENTTWO._serialized_end=5587
  _RULEGROUPSTATEMENTTWO._serialized_start=5590
  _RULEGROUPSTATEMENTTWO._serialized_end=6592
  _RULEGROUPRATEBASEDSTATEMENTONE._serialized_start=6595
  _RULEGROUPRATEBASEDSTATEMENTONE._serialized_end=6890
  _RULEGROUPANDSTATEMENTONE._serialized_start=6893
  _RULEGROUPANDSTATEMENTONE._serialized_end=7042
  _RULEGROUPORSTATEMENTONE._serialized_start=7045
  _RULEGROUPORSTATEMENTONE._serialized_end=7193
  _RULEGROUPNOTSTATEMENTONE._serialized_start=7196
  _RULEGROUPNOTSTATEMENTONE._serialized_end=7344
  _RULEGROUPSTATEMENTONE._serialized_start=7347
  _RULEGROUPSTATEMENTONE._serialized_end=8349
  _RULEGROUPRULEACTION._serialized_start=8352
  _RULEGROUPRULEACTION._serialized_end=8778
  _RULEGROUPRULEACTION_ALLOWENTRY._serialized_start=8642
  _RULEGROUPRULEACTION_ALLOWENTRY._serialized_end=8686
  _RULEGROUPRULEACTION_BLOCKENTRY._serialized_start=8688
  _RULEGROUPRULEACTION_BLOCKENTRY._serialized_end=8732
  _RULEGROUPRULEACTION_COUNTENTRY._serialized_start=8734
  _RULEGROUPRULEACTION_COUNTENTRY._serialized_end=8778
  _RULEGROUPVISIBILITYCONFIG._serialized_start=8781
  _RULEGROUPVISIBILITYCONFIG._serialized_end=8957
  _RULEGROUPRULE._serialized_start=8960
  _RULEGROUPRULE._serialized_end=9266
  _RULEGROUP._serialized_start=9269
  _RULEGROUP._serialized_end=9638
  _RULEGROUP_TAGSENTRY._serialized_start=285
  _RULEGROUP_TAGSENTRY._serialized_end=328
  _WEBACLDEFAULTACTION._serialized_start=9641
  _WEBACLDEFAULTACTION._serialized_end=9951
  _WEBACLDEFAULTACTION_ALLOWENTRY._serialized_start=8642
  _WEBACLDEFAULTACTION_ALLOWENTRY._serialized_end=8686
  _WEBACLDEFAULTACTION_BLOCKENTRY._serialized_start=8688
  _WEBACLDEFAULTACTION_BLOCKENTRY._serialized_end=8732
  _WEBACLFIELDTOMATCH._serialized_start=9954
  _WEBACLFIELDTOMATCH._serialized_end=10966
  _WEBACLFIELDTOMATCH_SINGLEHEADERENTRY._serialized_start=1575
  _WEBACLFIELDTOMATCH_SINGLEHEADERENTRY._serialized_end=1626
  _WEBACLFIELDTOMATCH_SINGLEQUERYARGUMENTENTRY._serialized_start=1628
  _WEBACLFIELDTOMATCH_SINGLEQUERYARGUMENTENTRY._serialized_end=1686
  _WEBACLFIELDTOMATCH_ALLQUERYARGUMENTSENTRY._serialized_start=1688
  _WEBACLFIELDTOMATCH_ALLQUERYARGUMENTSENTRY._serialized_end=1744
  _WEBACLFIELDTOMATCH_URIPATHENTRY._serialized_start=1746
  _WEBACLFIELDTOMATCH_URIPATHENTRY._serialized_end=1792
  _WEBACLFIELDTOMATCH_QUERYSTRINGENTRY._serialized_start=1794
  _WEBACLFIELDTOMATCH_QUERYSTRINGENTRY._serialized_end=1844
  _WEBACLFIELDTOMATCH_BODYENTRY._serialized_start=1846
  _WEBACLFIELDTOMATCH_BODYENTRY._serialized_end=1889
  _WEBACLFIELDTOMATCH_METHODENTRY._serialized_start=1891
  _WEBACLFIELDTOMATCH_METHODENTRY._serialized_end=1936
  _WEBACLTEXTTRANSFORMATION._serialized_start=10968
  _WEBACLTEXTTRANSFORMATION._serialized_end=11069
  _WEBACLBYTEMATCHSTATEMENT._serialized_start=11072
  _WEBACLBYTEMATCHSTATEMENT._serialized_end=11385
  _WEBACLSQLIMATCHSTATEMENT._serialized_start=11388
  _WEBACLSQLIMATCHSTATEMENT._serialized_end=11617
  _WEBACLXSSMATCHSTATEMENT._serialized_start=11620
  _WEBACLXSSMATCHSTATEMENT._serialized_end=11848
  _WEBACLSIZECONSTRAINTSTATEMENT._serialized_start=11851
  _WEBACLSIZECONSTRAINTSTATEMENT._serialized_end=12128
  _WEBACLFORWARDEDIPCONFIGURATION._serialized_start=12131
  _WEBACLFORWARDEDIPCONFIGURATION._serialized_end=12268
  _WEBACLGEOMATCHSTATEMENT._serialized_start=12271
  _WEBACLGEOMATCHSTATEMENT._serialized_end=12460
  _WEBACLEXCLUDEDRULE._serialized_start=12462
  _WEBACLEXCLUDEDRULE._serialized_end=12553
  _WEBACLRULEGROUPREFERENCESTATEMENT._serialized_start=12556
  _WEBACLRULEGROUPREFERENCESTATEMENT._serialized_end=12728
  _WEBACLIPSETFORWARDEDIPCONFIGURATION._serialized_start=12731
  _WEBACLIPSETFORWARDEDIPCONFIGURATION._serialized_end=12891
  _WEBACLIPSETREFERENCESTATEMENT._serialized_start=12894
  _WEBACLIPSETREFERENCESTATEMENT._serialized_end=13091
  _WEBACLREGEXPATTERNSETREFERENCESTATEMENT._serialized_start=13094
  _WEBACLREGEXPATTERNSETREFERENCESTATEMENT._serialized_end=13351
  _WEBACLMANAGEDRULEGROUPSTATEMENT._serialized_start=13354
  _WEBACLMANAGEDRULEGROUPSTATEMENT._serialized_end=13546
  _WEBACLSTATEMENTTHREE._serialized_start=13549
  _WEBACLSTATEMENTTHREE._serialized_end=14422
  _WEBACLRATEBASEDSTATEMENTTWO._serialized_start=14425
  _WEBACLRATEBASEDSTATEMENTTWO._serialized_end=14713
  _WEBACLANDSTATEMENTTWO._serialized_start=14716
  _WEBACLANDSTATEMENTTWO._serialized_end=14861
  _WEBACLORSTATEMENTTWO._serialized_start=14864
  _WEBACLORSTATEMENTTWO._serialized_end=15008
  _WEBACLNOTSTATEMENTTWO._serialized_start=15011
  _WEBACLNOTSTATEMENTTWO._serialized_end=15155
  _WEBACLSTATEMENTTWO._serialized_start=15158
  _WEBACLSTATEMENTTWO._serialized_end=16316
  _WEBACLRATEBASEDSTATEMENTONE._serialized_start=16319
  _WEBACLRATEBASEDSTATEMENTONE._serialized_end=16605
  _WEBACLANDSTATEMENTONE._serialized_start=16608
  _WEBACLANDSTATEMENTONE._serialized_end=16751
  _WEBACLORSTATEMENTONE._serialized_start=16754
  _WEBACLORSTATEMENTONE._serialized_end=16896
  _WEBACLNOTSTATEMENTONE._serialized_start=16899
  _WEBACLNOTSTATEMENTONE._serialized_end=17041
  _WEBACLSTATEMENTONE._serialized_start=17044
  _WEBACLSTATEMENTONE._serialized_end=18202
  _WEBACLRULEACTION._serialized_start=18205
  _WEBACLRULEACTION._serialized_end=18619
  _WEBACLRULEACTION_ALLOWENTRY._serialized_start=8642
  _WEBACLRULEACTION_ALLOWENTRY._serialized_end=8686
  _WEBACLRULEACTION_BLOCKENTRY._serialized_start=8688
  _WEBACLRULEACTION_BLOCKENTRY._serialized_end=8732
  _WEBACLRULEACTION_COUNTENTRY._serialized_start=8734
  _WEBACLRULEACTION_COUNTENTRY._serialized_end=8778
  _WEBACLOVERRIDEACTION._serialized_start=18622
  _WEBACLOVERRIDEACTION._serialized_end=18932
  _WEBACLOVERRIDEACTION_COUNTENTRY._serialized_start=8734
  _WEBACLOVERRIDEACTION_COUNTENTRY._serialized_end=8778
  _WEBACLOVERRIDEACTION_NONEENTRY._serialized_start=18889
  _WEBACLOVERRIDEACTION_NONEENTRY._serialized_end=18932
  _WEBACLVISIBILITYCONFIG._serialized_start=18935
  _WEBACLVISIBILITYCONFIG._serialized_end=19108
  _WEBACLRULE._serialized_start=19111
  _WEBACLRULE._serialized_end=19475
  _WEBACL._serialized_start=19478
  _WEBACL._serialized_end=20002
  _WEBACL_TAGSENTRY._serialized_start=285
  _WEBACL_TAGSENTRY._serialized_end=328
  _WEBACLASSOCIATION._serialized_start=20004
  _WEBACLASSOCIATION._serialized_end=20125
# @@protoc_insertion_point(module_scope)
