# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_codestar.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16\x61ws/aws_codestar.proto\x12\x18oak9.tython.aws.codestar\x1a\x13shared/shared.proto\"\x82\x01\n\x12GitHubRepositoryS3\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0eobject_version\x18\x02 \x01(\t\x12\x0e\n\x06\x62ucket\x18\x03 \x01(\t\x12\x0b\n\x03key\x18\x04 \x01(\t\"\x89\x01\n\x14GitHubRepositoryCode\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x38\n\x02s3\x18\x02 \x01(\x0b\x32,.oak9.tython.aws.codestar.GitHubRepositoryS3\"\xa8\x02\n\x10GitHubRepository\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\renable_issues\x18\x02 \x01(\x08\x12\x17\n\x0frepository_name\x18\x03 \x01(\t\x12\x1f\n\x17repository_access_token\x18\x04 \x01(\t\x12\x18\n\x10repository_owner\x18\x05 \x01(\t\x12\x12\n\nis_private\x18\x06 \x01(\x08\x12<\n\x04\x63ode\x18\x07 \x01(\x0b\x32..oak9.tython.aws.codestar.GitHubRepositoryCode\x12\x1e\n\x16repository_description\x18\x08 \x01(\t\"R\n\x08\x43odeStar\x12\x46\n\x12git_hub_repository\x18\x01 \x03(\x0b\x32*.oak9.tython.aws.codestar.GitHubRepositoryb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_codestar_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GITHUBREPOSITORYS3._serialized_start=74
  _GITHUBREPOSITORYS3._serialized_end=204
  _GITHUBREPOSITORYCODE._serialized_start=207
  _GITHUBREPOSITORYCODE._serialized_end=344
  _GITHUBREPOSITORY._serialized_start=347
  _GITHUBREPOSITORY._serialized_end=643
  _CODESTAR._serialized_start=645
  _CODESTAR._serialized_end=727
# @@protoc_insertion_point(module_scope)
