# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_compute_forwarding.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n gcp/gcp_compute_forwarding.proto\x12\"oak9.tython.gcp.compute_forwarding\x1a\x13shared/shared.proto\"Y\n3ComputeForwardingRuleXServiceDirectoryRegistrations\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0f\n\x07service\x18\x02 \x01(\t\"P\n\x1e\x43omputeForwardingRuleXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xcf\x07\n\x15\x43omputeForwardingRule\x12\x11\n\tall_ports\x18\x01 \x01(\x08\x12\x1b\n\x13\x61llow_global_access\x18\x02 \x01(\x08\x12\x17\n\x0f\x62\x61\x63kend_service\x18\x03 \x01(\t\x12\x1a\n\x12\x63reation_timestamp\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12\n\n\x02id\x18\x06 \x01(\t\x12\x12\n\nip_address\x18\x07 \x01(\t\x12\x13\n\x0bip_protocol\x18\x08 \x01(\t\x12\x1e\n\x16is_mirroring_collector\x18\t \x01(\x08\x12\x19\n\x11label_fingerprint\x18\n \x01(\t\x12U\n\x06labels\x18\x0b \x03(\x0b\x32\x45.oak9.tython.gcp.compute_forwarding.ComputeForwardingRule.LabelsEntry\x12\x1d\n\x15load_balancing_scheme\x18\x0c \x01(\t\x12\x0c\n\x04name\x18\r \x01(\t\x12\x0f\n\x07network\x18\x0e \x01(\t\x12\x14\n\x0cnetwork_tier\x18\x0f \x01(\t\x12\x12\n\nport_range\x18\x10 \x01(\t\x12\r\n\x05ports\x18\x11 \x03(\t\x12\x0f\n\x07project\x18\x12 \x01(\t\x12\x19\n\x11psc_connection_id\x18\x13 \x01(\t\x12\x1d\n\x15psc_connection_status\x18\x14 \x01(\t\x12\x0e\n\x06region\x18\x15 \x01(\t\x12\x11\n\tself_link\x18\x16 \x01(\t\x12\x15\n\rservice_label\x18\x17 \x01(\t\x12\x14\n\x0cservice_name\x18\x18 \x01(\t\x12\x12\n\nsubnetwork\x18\x19 \x01(\t\x12\x0e\n\x06target\x18\x1a \x01(\t\x12\x80\x01\n\x1fservice_directory_registrations\x18\x1b \x03(\x0b\x32W.oak9.tython.gcp.compute_forwarding.ComputeForwardingRuleXServiceDirectoryRegistrations\x12T\n\x08timeouts\x18\x1c \x01(\x0b\x32\x42.oak9.tython.gcp.compute_forwarding.ComputeForwardingRuleXTimeouts\x12\x37\n\rresource_info\x18\x1d \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_compute_forwarding_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMPUTEFORWARDINGRULE_LABELSENTRY._options = None
  _COMPUTEFORWARDINGRULE_LABELSENTRY._serialized_options = b'8\001'
  _COMPUTEFORWARDINGRULEXSERVICEDIRECTORYREGISTRATIONS._serialized_start=93
  _COMPUTEFORWARDINGRULEXSERVICEDIRECTORYREGISTRATIONS._serialized_end=182
  _COMPUTEFORWARDINGRULEXTIMEOUTS._serialized_start=184
  _COMPUTEFORWARDINGRULEXTIMEOUTS._serialized_end=264
  _COMPUTEFORWARDINGRULE._serialized_start=267
  _COMPUTEFORWARDINGRULE._serialized_end=1242
  _COMPUTEFORWARDINGRULE_LABELSENTRY._serialized_start=1197
  _COMPUTEFORWARDINGRULE_LABELSENTRY._serialized_end=1242
# @@protoc_insertion_point(module_scope)
