# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: azure/azure_microsoft_streamanalytics.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+azure/azure_microsoft_streamanalytics.proto\x12+oak9.tython.azure.microsoft_streamanalytics\x1a\x13shared/shared.proto\"\x96\x03\n\x19Microsoft_StreamAnalytics\x12Q\n\rstreamingjobs\x18\x01 \x01(\x0b\x32:.oak9.tython.azure.microsoft_streamanalytics.Streamingjobs\x12\x64\n\x17streamingjobs_functions\x18\x02 \x03(\x0b\x32\x43.oak9.tython.azure.microsoft_streamanalytics.StreamingjobsFunctions\x12^\n\x14streamingjobs_inputs\x18\x03 \x03(\x0b\x32@.oak9.tython.azure.microsoft_streamanalytics.StreamingjobsInputs\x12`\n\x15streamingjobs_outputs\x18\x04 \x03(\x0b\x32\x41.oak9.tython.azure.microsoft_streamanalytics.StreamingjobsOutputs\"\xac\x01\n\x1cStreamingjobsTransformations\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05query\x18\x03 \x01(\t\x12\x17\n\x0fstreaming_units\x18\x04 \x01(\x05\x12\x1d\n\x15valid_streaming_units\x18\x05 \x03(\x05\"\xad\x02\n\x14StreamingjobsOutputs\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12Q\n\ndatasource\x18\x03 \x01(\x0b\x32=.oak9.tython.azure.microsoft_streamanalytics.OutputDataSource\x12Q\n\rserialization\x18\x04 \x01(\x0b\x32:.oak9.tython.azure.microsoft_streamanalytics.Serialization\x12\x13\n\x0bsize_window\x18\x05 \x01(\x01\x12\x13\n\x0btime_window\x18\x06 \x01(\t\"\x95\x02\n\x13StreamingjobsInputs\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12M\n\x0b\x63ompression\x18\x03 \x01(\x0b\x32\x38.oak9.tython.azure.microsoft_streamanalytics.Compression\x12\x15\n\rpartition_key\x18\x04 \x01(\t\x12Q\n\rserialization\x18\x05 \x01(\x0b\x32:.oak9.tython.azure.microsoft_streamanalytics.Serialization\"\xc7\x02\n\x16StreamingjobsFunctions\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12M\n\x07\x62inding\x18\x03 \x01(\x0b\x32<.oak9.tython.azure.microsoft_streamanalytics.FunctionBinding\x12J\n\x06inputs\x18\x04 \x03(\x0b\x32:.oak9.tython.azure.microsoft_streamanalytics.FunctionInput\x12K\n\x06output\x18\x05 \x01(\x0b\x32;.oak9.tython.azure.microsoft_streamanalytics.FunctionOutput\"\xcb\t\n\rStreamingjobs\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12G\n\x08identity\x18\x02 \x01(\x0b\x32\x35.oak9.tython.azure.microsoft_streamanalytics.Identity\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12I\n\x07\x63luster\x18\x05 \x01(\x0b\x32\x38.oak9.tython.azure.microsoft_streamanalytics.ClusterInfo\x12\x1b\n\x13\x63ompatibility_level\x18\x06 \x01(\t\x12\x1e\n\x16\x63ontent_storage_policy\x18\x07 \x01(\t\x12\x13\n\x0b\x64\x61ta_locale\x18\x08 \x01(\t\x12\x30\n(events_late_arrival_max_delay_in_seconds\x18\t \x01(\x05\x12\x30\n(events_out_of_order_max_delay_in_seconds\x18\n \x01(\x05\x12\"\n\x1a\x65vents_out_of_order_policy\x18\x0b \x01(\t\x12H\n\texternals\x18\x0c \x01(\x0b\x32\x35.oak9.tython.azure.microsoft_streamanalytics.External\x12H\n\tfunctions\x18\r \x03(\x0b\x32\x35.oak9.tython.azure.microsoft_streamanalytics.Function\x12\x42\n\x06inputs\x18\x0e \x03(\x0b\x32\x32.oak9.tython.azure.microsoft_streamanalytics.Input\x12[\n\x13job_storage_account\x18\x0f \x01(\x0b\x32>.oak9.tython.azure.microsoft_streamanalytics.JobStorageAccount\x12\x10\n\x08job_type\x18\x10 \x01(\t\x12\x1b\n\x13output_error_policy\x18\x11 \x01(\t\x12\x44\n\x07outputs\x18\x12 \x03(\x0b\x32\x33.oak9.tython.azure.microsoft_streamanalytics.Output\x12\x19\n\x11output_start_mode\x18\x13 \x01(\t\x12\x19\n\x11output_start_time\x18\x14 \x01(\t\x12=\n\x03sku\x18\x15 \x01(\x0b\x32\x30.oak9.tython.azure.microsoft_streamanalytics.Sku\x12S\n\x0etransformation\x18\x16 \x01(\x0b\x32;.oak9.tython.azure.microsoft_streamanalytics.Transformation\x12R\n\x04tags\x18\x17 \x03(\x0b\x32\x44.oak9.tython.azure.microsoft_streamanalytics.Streamingjobs.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"e\n\x0eTransformation\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05query\x18\x02 \x01(\t\x12\x17\n\x0fstreaming_units\x18\x03 \x01(\x05\x12\x1d\n\x15valid_streaming_units\x18\x04 \x03(\x05\"\x13\n\x03Sku\x12\x0c\n\x04name\x18\x01 \x01(\t\"\xe6\x01\n\x06Output\x12\x0c\n\x04name\x18\x01 \x01(\t\x12Q\n\ndatasource\x18\x02 \x01(\x0b\x32=.oak9.tython.azure.microsoft_streamanalytics.OutputDataSource\x12Q\n\rserialization\x18\x03 \x01(\x0b\x32:.oak9.tython.azure.microsoft_streamanalytics.Serialization\x12\x13\n\x0bsize_window\x18\x04 \x01(\x01\x12\x13\n\x0btime_window\x18\x05 \x01(\t\" \n\x10OutputDataSource\x12\x0c\n\x04name\x18\x01 \x01(\t\"[\n\x11JobStorageAccount\x12\x13\n\x0b\x61\x63\x63ount_key\x18\x01 \x01(\t\x12\x14\n\x0c\x61\x63\x63ount_name\x18\x02 \x01(\t\x12\x1b\n\x13\x61uthentication_mode\x18\x03 \x01(\t\"\xce\x01\n\x05Input\x12\x0c\n\x04name\x18\x01 \x01(\t\x12M\n\x0b\x63ompression\x18\x02 \x01(\x0b\x32\x38.oak9.tython.azure.microsoft_streamanalytics.Compression\x12\x15\n\rpartition_key\x18\x03 \x01(\t\x12Q\n\rserialization\x18\x04 \x01(\x0b\x32:.oak9.tython.azure.microsoft_streamanalytics.Serialization\"\x1d\n\rSerialization\x12\x0c\n\x04name\x18\x01 \x01(\t\"\x1b\n\x0b\x43ompression\x12\x0c\n\x04type\x18\x01 \x01(\t\"\x80\x02\n\x08\x46unction\x12\x0c\n\x04name\x18\x01 \x01(\t\x12M\n\x07\x62inding\x18\x02 \x01(\x0b\x32<.oak9.tython.azure.microsoft_streamanalytics.FunctionBinding\x12J\n\x06inputs\x18\x03 \x03(\x0b\x32:.oak9.tython.azure.microsoft_streamanalytics.FunctionInput\x12K\n\x06output\x18\x04 \x01(\x0b\x32;.oak9.tython.azure.microsoft_streamanalytics.FunctionOutput\"#\n\x0e\x46unctionOutput\x12\x11\n\tdata_type\x18\x01 \x01(\t\"F\n\rFunctionInput\x12\x11\n\tdata_type\x18\x01 \x01(\t\x12\"\n\x1ais_configuration_parameter\x18\x02 \x01(\x08\"0\n\x0f\x46unctionBinding\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07\x61pi_key\x18\x02 \x01(\t\"\x81\x01\n\x08\x45xternal\x12\x11\n\tcontainer\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\x12T\n\x0fstorage_account\x18\x03 \x01(\x0b\x32;.oak9.tython.azure.microsoft_streamanalytics.StorageAccount\";\n\x0eStorageAccount\x12\x13\n\x0b\x61\x63\x63ount_key\x18\x01 \x01(\t\x12\x14\n\x0c\x61\x63\x63ount_name\x18\x02 \x01(\t\"\x19\n\x0b\x43lusterInfo\x12\n\n\x02id\x18\x01 \x01(\t\"\xf5\x01\n\x08Identity\x12\x14\n\x0cprincipal_id\x18\x01 \x01(\t\x12\x11\n\ttenant_id\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\x12s\n\x18user_assigned_identities\x18\x04 \x03(\x0b\x32Q.oak9.tython.azure.microsoft_streamanalytics.Identity.UserAssignedIdentitiesEntry\x1a=\n\x1bUserAssignedIdentitiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'azure.azure_microsoft_streamanalytics_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _STREAMINGJOBS_TAGSENTRY._options = None
  _STREAMINGJOBS_TAGSENTRY._serialized_options = b'8\001'
  _IDENTITY_USERASSIGNEDIDENTITIESENTRY._options = None
  _IDENTITY_USERASSIGNEDIDENTITIESENTRY._serialized_options = b'8\001'
  _MICROSOFT_STREAMANALYTICS._serialized_start=114
  _MICROSOFT_STREAMANALYTICS._serialized_end=520
  _STREAMINGJOBSTRANSFORMATIONS._serialized_start=523
  _STREAMINGJOBSTRANSFORMATIONS._serialized_end=695
  _STREAMINGJOBSOUTPUTS._serialized_start=698
  _STREAMINGJOBSOUTPUTS._serialized_end=999
  _STREAMINGJOBSINPUTS._serialized_start=1002
  _STREAMINGJOBSINPUTS._serialized_end=1279
  _STREAMINGJOBSFUNCTIONS._serialized_start=1282
  _STREAMINGJOBSFUNCTIONS._serialized_end=1609
  _STREAMINGJOBS._serialized_start=1612
  _STREAMINGJOBS._serialized_end=2839
  _STREAMINGJOBS_TAGSENTRY._serialized_start=2796
  _STREAMINGJOBS_TAGSENTRY._serialized_end=2839
  _TRANSFORMATION._serialized_start=2841
  _TRANSFORMATION._serialized_end=2942
  _SKU._serialized_start=2944
  _SKU._serialized_end=2963
  _OUTPUT._serialized_start=2966
  _OUTPUT._serialized_end=3196
  _OUTPUTDATASOURCE._serialized_start=3198
  _OUTPUTDATASOURCE._serialized_end=3230
  _JOBSTORAGEACCOUNT._serialized_start=3232
  _JOBSTORAGEACCOUNT._serialized_end=3323
  _INPUT._serialized_start=3326
  _INPUT._serialized_end=3532
  _SERIALIZATION._serialized_start=3534
  _SERIALIZATION._serialized_end=3563
  _COMPRESSION._serialized_start=3565
  _COMPRESSION._serialized_end=3592
  _FUNCTION._serialized_start=3595
  _FUNCTION._serialized_end=3851
  _FUNCTIONOUTPUT._serialized_start=3853
  _FUNCTIONOUTPUT._serialized_end=3888
  _FUNCTIONINPUT._serialized_start=3890
  _FUNCTIONINPUT._serialized_end=3960
  _FUNCTIONBINDING._serialized_start=3962
  _FUNCTIONBINDING._serialized_end=4010
  _EXTERNAL._serialized_start=4013
  _EXTERNAL._serialized_end=4142
  _STORAGEACCOUNT._serialized_start=4144
  _STORAGEACCOUNT._serialized_end=4203
  _CLUSTERINFO._serialized_start=4205
  _CLUSTERINFO._serialized_end=4230
  _IDENTITY._serialized_start=4233
  _IDENTITY._serialized_end=4478
  _IDENTITY_USERASSIGNEDIDENTITIESENTRY._serialized_start=4417
  _IDENTITY_USERASSIGNEDIDENTITIESENTRY._serialized_end=4478
# @@protoc_insertion_point(module_scope)
