"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Microsoft_HealthcareApis(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERVICES_FIELD_NUMBER: builtins.int
    @property
    def services(self) -> global___Services: ...
    def __init__(
        self,
        *,
        services: global___Services | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["services", b"services"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["services", b"services"]) -> None: ...

global___Microsoft_HealthcareApis = Microsoft_HealthcareApis

@typing_extensions.final
class WorkspacesPrivateEndpointConnections(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PRIVATE_ENDPOINT_FIELD_NUMBER: builtins.int
    PRIVATE_LINK_SERVICE_CONNECTION_STATE_FIELD_NUMBER: builtins.int
    PROVISIONING_STATE_FIELD_NUMBER: builtins.int
    SYSTEM_DATA_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def private_endpoint(self) -> global___PrivateEndpoint: ...
    @property
    def private_link_service_connection_state(self) -> global___PrivateLinkServiceConnectionState: ...
    provisioning_state: builtins.str
    @property
    def system_data(self) -> global___SystemData: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        private_endpoint: global___PrivateEndpoint | None = ...,
        private_link_service_connection_state: global___PrivateLinkServiceConnectionState | None = ...,
        provisioning_state: builtins.str = ...,
        system_data: global___SystemData | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["private_endpoint", b"private_endpoint", "private_link_service_connection_state", b"private_link_service_connection_state", "resource_info", b"resource_info", "system_data", b"system_data"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "private_endpoint", b"private_endpoint", "private_link_service_connection_state", b"private_link_service_connection_state", "provisioning_state", b"provisioning_state", "resource_info", b"resource_info", "system_data", b"system_data"]) -> None: ...

global___WorkspacesPrivateEndpointConnections = WorkspacesPrivateEndpointConnections

@typing_extensions.final
class WorkspacesIotconnectorsFhirdestinations(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    FHIR_MAPPING_FIELD_NUMBER: builtins.int
    FHIR_SERVICE_RESOURCE_ID_FIELD_NUMBER: builtins.int
    PROVISIONING_STATE_FIELD_NUMBER: builtins.int
    RESOURCE_IDENTITY_RESOLUTION_TYPE_FIELD_NUMBER: builtins.int
    SYSTEM_DATA_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    etag: builtins.str
    location: builtins.str
    name: builtins.str
    @property
    def fhir_mapping(self) -> global___IotMappingProperties: ...
    fhir_service_resource_id: builtins.str
    provisioning_state: builtins.str
    resource_identity_resolution_type: builtins.str
    @property
    def system_data(self) -> global___SystemData: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        etag: builtins.str = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        fhir_mapping: global___IotMappingProperties | None = ...,
        fhir_service_resource_id: builtins.str = ...,
        provisioning_state: builtins.str = ...,
        resource_identity_resolution_type: builtins.str = ...,
        system_data: global___SystemData | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["fhir_mapping", b"fhir_mapping", "resource_info", b"resource_info", "system_data", b"system_data"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["etag", b"etag", "fhir_mapping", b"fhir_mapping", "fhir_service_resource_id", b"fhir_service_resource_id", "location", b"location", "name", b"name", "provisioning_state", b"provisioning_state", "resource_identity_resolution_type", b"resource_identity_resolution_type", "resource_info", b"resource_info", "system_data", b"system_data"]) -> None: ...

global___WorkspacesIotconnectorsFhirdestinations = WorkspacesIotconnectorsFhirdestinations

@typing_extensions.final
class WorkspacesIotconnectors(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    IDENTITY_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DEVICE_MAPPING_FIELD_NUMBER: builtins.int
    INGESTION_ENDPOINT_CONFIGURATION_FIELD_NUMBER: builtins.int
    PROVISIONING_STATE_FIELD_NUMBER: builtins.int
    SYSTEM_DATA_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    WORKSPACES_IOTCONNECTORS_FHIRDESTINATIONS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def identity(self) -> global___ServiceManagedIdentityIdentity: ...
    location: builtins.str
    name: builtins.str
    @property
    def device_mapping(self) -> global___IotMappingProperties: ...
    @property
    def ingestion_endpoint_configuration(self) -> global___IotEventHubIngestionEndpointConfiguration: ...
    provisioning_state: builtins.str
    @property
    def system_data(self) -> global___SystemData: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def workspaces_iotconnectors_fhirdestinations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___WorkspacesIotconnectorsFhirdestinations]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        identity: global___ServiceManagedIdentityIdentity | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        device_mapping: global___IotMappingProperties | None = ...,
        ingestion_endpoint_configuration: global___IotEventHubIngestionEndpointConfiguration | None = ...,
        provisioning_state: builtins.str = ...,
        system_data: global___SystemData | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        workspaces_iotconnectors_fhirdestinations: collections.abc.Iterable[global___WorkspacesIotconnectorsFhirdestinations] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["device_mapping", b"device_mapping", "identity", b"identity", "ingestion_endpoint_configuration", b"ingestion_endpoint_configuration", "resource_info", b"resource_info", "system_data", b"system_data"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["device_mapping", b"device_mapping", "identity", b"identity", "ingestion_endpoint_configuration", b"ingestion_endpoint_configuration", "location", b"location", "name", b"name", "provisioning_state", b"provisioning_state", "resource_info", b"resource_info", "system_data", b"system_data", "tags", b"tags", "workspaces_iotconnectors_fhirdestinations", b"workspaces_iotconnectors_fhirdestinations"]) -> None: ...

global___WorkspacesIotconnectors = WorkspacesIotconnectors

@typing_extensions.final
class IotEventHubIngestionEndpointConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONSUMER_GROUP_FIELD_NUMBER: builtins.int
    EVENT_HUB_NAME_FIELD_NUMBER: builtins.int
    FULLY_QUALIFIED_EVENT_HUB_NAMESPACE_FIELD_NUMBER: builtins.int
    consumer_group: builtins.str
    event_hub_name: builtins.str
    fully_qualified_event_hub_namespace: builtins.str
    def __init__(
        self,
        *,
        consumer_group: builtins.str = ...,
        event_hub_name: builtins.str = ...,
        fully_qualified_event_hub_namespace: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["consumer_group", b"consumer_group", "event_hub_name", b"event_hub_name", "fully_qualified_event_hub_namespace", b"fully_qualified_event_hub_namespace"]) -> None: ...

global___IotEventHubIngestionEndpointConfiguration = IotEventHubIngestionEndpointConfiguration

@typing_extensions.final
class IotMappingProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class ContentEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    CONTENT_FIELD_NUMBER: builtins.int
    @property
    def content(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        content: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["content", b"content"]) -> None: ...

global___IotMappingProperties = IotMappingProperties

@typing_extensions.final
class WorkspacesFhirservices(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    IDENTITY_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ACCESS_POLICIES_FIELD_NUMBER: builtins.int
    ACR_CONFIGURATION_FIELD_NUMBER: builtins.int
    AUTHENTICATION_CONFIGURATION_FIELD_NUMBER: builtins.int
    CORS_CONFIGURATION_FIELD_NUMBER: builtins.int
    EVENT_STATE_FIELD_NUMBER: builtins.int
    EXPORT_CONFIGURATION_FIELD_NUMBER: builtins.int
    PROVISIONING_STATE_FIELD_NUMBER: builtins.int
    PUBLIC_NETWORK_ACCESS_FIELD_NUMBER: builtins.int
    RESOURCE_VERSION_POLICY_CONFIGURATION_FIELD_NUMBER: builtins.int
    SYSTEM_DATA_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def identity(self) -> global___ServiceManagedIdentityIdentity: ...
    kind: builtins.str
    location: builtins.str
    name: builtins.str
    @property
    def access_policies(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___FhirServiceAccessPolicyEntry]: ...
    @property
    def acr_configuration(self) -> global___FhirServiceAcrConfiguration: ...
    @property
    def authentication_configuration(self) -> global___FhirServiceAuthenticationConfiguration: ...
    @property
    def cors_configuration(self) -> global___FhirServiceCorsConfiguration: ...
    event_state: builtins.str
    @property
    def export_configuration(self) -> global___FhirServiceExportConfiguration: ...
    provisioning_state: builtins.str
    public_network_access: builtins.str
    @property
    def resource_version_policy_configuration(self) -> global___ResourceVersionPolicyConfiguration: ...
    @property
    def system_data(self) -> global___SystemData: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        identity: global___ServiceManagedIdentityIdentity | None = ...,
        kind: builtins.str = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        access_policies: collections.abc.Iterable[global___FhirServiceAccessPolicyEntry] | None = ...,
        acr_configuration: global___FhirServiceAcrConfiguration | None = ...,
        authentication_configuration: global___FhirServiceAuthenticationConfiguration | None = ...,
        cors_configuration: global___FhirServiceCorsConfiguration | None = ...,
        event_state: builtins.str = ...,
        export_configuration: global___FhirServiceExportConfiguration | None = ...,
        provisioning_state: builtins.str = ...,
        public_network_access: builtins.str = ...,
        resource_version_policy_configuration: global___ResourceVersionPolicyConfiguration | None = ...,
        system_data: global___SystemData | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["acr_configuration", b"acr_configuration", "authentication_configuration", b"authentication_configuration", "cors_configuration", b"cors_configuration", "export_configuration", b"export_configuration", "identity", b"identity", "resource_info", b"resource_info", "resource_version_policy_configuration", b"resource_version_policy_configuration", "system_data", b"system_data"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["access_policies", b"access_policies", "acr_configuration", b"acr_configuration", "authentication_configuration", b"authentication_configuration", "cors_configuration", b"cors_configuration", "event_state", b"event_state", "export_configuration", b"export_configuration", "identity", b"identity", "kind", b"kind", "location", b"location", "name", b"name", "provisioning_state", b"provisioning_state", "public_network_access", b"public_network_access", "resource_info", b"resource_info", "resource_version_policy_configuration", b"resource_version_policy_configuration", "system_data", b"system_data", "tags", b"tags"]) -> None: ...

global___WorkspacesFhirservices = WorkspacesFhirservices

@typing_extensions.final
class ResourceVersionPolicyConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class ResourceTypeOverridesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    DEFAULT_FIELD_NUMBER: builtins.int
    RESOURCE_TYPE_OVERRIDES_FIELD_NUMBER: builtins.int
    default: builtins.str
    @property
    def resource_type_overrides(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        default: builtins.str = ...,
        resource_type_overrides: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["default", b"default", "resource_type_overrides", b"resource_type_overrides"]) -> None: ...

global___ResourceVersionPolicyConfiguration = ResourceVersionPolicyConfiguration

@typing_extensions.final
class FhirServiceExportConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STORAGE_ACCOUNT_NAME_FIELD_NUMBER: builtins.int
    storage_account_name: builtins.str
    def __init__(
        self,
        *,
        storage_account_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["storage_account_name", b"storage_account_name"]) -> None: ...

global___FhirServiceExportConfiguration = FhirServiceExportConfiguration

@typing_extensions.final
class FhirServiceCorsConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALLOW_CREDENTIALS_FIELD_NUMBER: builtins.int
    HEADERS_FIELD_NUMBER: builtins.int
    MAX_AGE_FIELD_NUMBER: builtins.int
    METHODS_FIELD_NUMBER: builtins.int
    ORIGINS_FIELD_NUMBER: builtins.int
    allow_credentials: builtins.bool
    @property
    def headers(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    max_age: builtins.int
    @property
    def methods(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def origins(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        allow_credentials: builtins.bool = ...,
        headers: collections.abc.Iterable[builtins.str] | None = ...,
        max_age: builtins.int = ...,
        methods: collections.abc.Iterable[builtins.str] | None = ...,
        origins: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["allow_credentials", b"allow_credentials", "headers", b"headers", "max_age", b"max_age", "methods", b"methods", "origins", b"origins"]) -> None: ...

global___FhirServiceCorsConfiguration = FhirServiceCorsConfiguration

@typing_extensions.final
class FhirServiceAuthenticationConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUDIENCE_FIELD_NUMBER: builtins.int
    AUTHORITY_FIELD_NUMBER: builtins.int
    SMART_PROXY_ENABLED_FIELD_NUMBER: builtins.int
    audience: builtins.str
    authority: builtins.str
    smart_proxy_enabled: builtins.bool
    def __init__(
        self,
        *,
        audience: builtins.str = ...,
        authority: builtins.str = ...,
        smart_proxy_enabled: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["audience", b"audience", "authority", b"authority", "smart_proxy_enabled", b"smart_proxy_enabled"]) -> None: ...

global___FhirServiceAuthenticationConfiguration = FhirServiceAuthenticationConfiguration

@typing_extensions.final
class FhirServiceAcrConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOGIN_SERVERS_FIELD_NUMBER: builtins.int
    OCI_ARTIFACTS_FIELD_NUMBER: builtins.int
    @property
    def login_servers(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def oci_artifacts(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServiceOciArtifactEntry]: ...
    def __init__(
        self,
        *,
        login_servers: collections.abc.Iterable[builtins.str] | None = ...,
        oci_artifacts: collections.abc.Iterable[global___ServiceOciArtifactEntry] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["login_servers", b"login_servers", "oci_artifacts", b"oci_artifacts"]) -> None: ...

global___FhirServiceAcrConfiguration = FhirServiceAcrConfiguration

@typing_extensions.final
class FhirServiceAccessPolicyEntry(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OBJECT_ID_FIELD_NUMBER: builtins.int
    object_id: builtins.str
    def __init__(
        self,
        *,
        object_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["object_id", b"object_id"]) -> None: ...

global___FhirServiceAccessPolicyEntry = FhirServiceAccessPolicyEntry

@typing_extensions.final
class WorkspacesDicomservices(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    IDENTITY_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    AUTHENTICATION_CONFIGURATION_FIELD_NUMBER: builtins.int
    PROVISIONING_STATE_FIELD_NUMBER: builtins.int
    PUBLIC_NETWORK_ACCESS_FIELD_NUMBER: builtins.int
    SYSTEM_DATA_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def identity(self) -> global___ServiceManagedIdentityIdentity: ...
    location: builtins.str
    name: builtins.str
    @property
    def authentication_configuration(self) -> global___DicomServiceAuthenticationConfiguration: ...
    provisioning_state: builtins.str
    public_network_access: builtins.str
    @property
    def system_data(self) -> global___SystemData: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        identity: global___ServiceManagedIdentityIdentity | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        authentication_configuration: global___DicomServiceAuthenticationConfiguration | None = ...,
        provisioning_state: builtins.str = ...,
        public_network_access: builtins.str = ...,
        system_data: global___SystemData | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["authentication_configuration", b"authentication_configuration", "identity", b"identity", "resource_info", b"resource_info", "system_data", b"system_data"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["authentication_configuration", b"authentication_configuration", "identity", b"identity", "location", b"location", "name", b"name", "provisioning_state", b"provisioning_state", "public_network_access", b"public_network_access", "resource_info", b"resource_info", "system_data", b"system_data", "tags", b"tags"]) -> None: ...

global___WorkspacesDicomservices = WorkspacesDicomservices

@typing_extensions.final
class DicomServiceAuthenticationConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___DicomServiceAuthenticationConfiguration = DicomServiceAuthenticationConfiguration

@typing_extensions.final
class ServiceManagedIdentityIdentity(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class UserAssignedIdentitiesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    TYPE_FIELD_NUMBER: builtins.int
    USER_ASSIGNED_IDENTITIES_FIELD_NUMBER: builtins.int
    type: builtins.str
    @property
    def user_assigned_identities(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        type: builtins.str = ...,
        user_assigned_identities: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["type", b"type", "user_assigned_identities", b"user_assigned_identities"]) -> None: ...

global___ServiceManagedIdentityIdentity = ServiceManagedIdentityIdentity

@typing_extensions.final
class Workspaces(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROVISIONING_STATE_FIELD_NUMBER: builtins.int
    PUBLIC_NETWORK_ACCESS_FIELD_NUMBER: builtins.int
    SYSTEM_DATA_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    WORKSPACES_DICOMSERVICES_FIELD_NUMBER: builtins.int
    WORKSPACES_IOTCONNECTORS_FIELD_NUMBER: builtins.int
    WORKSPACES_FHIRSERVICES_FIELD_NUMBER: builtins.int
    WORKSPACES_PRIVATE_ENDPOINT_CONNECTIONS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    location: builtins.str
    name: builtins.str
    provisioning_state: builtins.str
    public_network_access: builtins.str
    @property
    def system_data(self) -> global___SystemData: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def workspaces_dicomservices(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___WorkspacesDicomservices]: ...
    @property
    def workspaces_iotconnectors(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___WorkspacesIotconnectors]: ...
    @property
    def workspaces_fhirservices(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___WorkspacesFhirservices]: ...
    @property
    def workspaces_private_endpoint_connections(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___WorkspacesPrivateEndpointConnections]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        provisioning_state: builtins.str = ...,
        public_network_access: builtins.str = ...,
        system_data: global___SystemData | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        workspaces_dicomservices: collections.abc.Iterable[global___WorkspacesDicomservices] | None = ...,
        workspaces_iotconnectors: collections.abc.Iterable[global___WorkspacesIotconnectors] | None = ...,
        workspaces_fhirservices: collections.abc.Iterable[global___WorkspacesFhirservices] | None = ...,
        workspaces_private_endpoint_connections: collections.abc.Iterable[global___WorkspacesPrivateEndpointConnections] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "system_data", b"system_data"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["location", b"location", "name", b"name", "provisioning_state", b"provisioning_state", "public_network_access", b"public_network_access", "resource_info", b"resource_info", "system_data", b"system_data", "tags", b"tags", "workspaces_dicomservices", b"workspaces_dicomservices", "workspaces_fhirservices", b"workspaces_fhirservices", "workspaces_iotconnectors", b"workspaces_iotconnectors", "workspaces_private_endpoint_connections", b"workspaces_private_endpoint_connections"]) -> None: ...

global___Workspaces = Workspaces

@typing_extensions.final
class ServicesPrivateEndpointConnections(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PRIVATE_ENDPOINT_FIELD_NUMBER: builtins.int
    PRIVATE_LINK_SERVICE_CONNECTION_STATE_FIELD_NUMBER: builtins.int
    PROVISIONING_STATE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def private_endpoint(self) -> global___PrivateEndpoint: ...
    @property
    def private_link_service_connection_state(self) -> global___PrivateLinkServiceConnectionState: ...
    provisioning_state: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        private_endpoint: global___PrivateEndpoint | None = ...,
        private_link_service_connection_state: global___PrivateLinkServiceConnectionState | None = ...,
        provisioning_state: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["private_endpoint", b"private_endpoint", "private_link_service_connection_state", b"private_link_service_connection_state", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "private_endpoint", b"private_endpoint", "private_link_service_connection_state", b"private_link_service_connection_state", "provisioning_state", b"provisioning_state", "resource_info", b"resource_info"]) -> None: ...

global___ServicesPrivateEndpointConnections = ServicesPrivateEndpointConnections

@typing_extensions.final
class Services(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    IDENTITY_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ACCESS_POLICIES_FIELD_NUMBER: builtins.int
    ACR_CONFIGURATION_FIELD_NUMBER: builtins.int
    AUTHENTICATION_CONFIGURATION_FIELD_NUMBER: builtins.int
    CORS_CONFIGURATION_FIELD_NUMBER: builtins.int
    COSMOS_DB_CONFIGURATION_FIELD_NUMBER: builtins.int
    EXPORT_CONFIGURATION_FIELD_NUMBER: builtins.int
    PRIVATE_ENDPOINT_CONNECTIONS_FIELD_NUMBER: builtins.int
    PROVISIONING_STATE_FIELD_NUMBER: builtins.int
    PUBLIC_NETWORK_ACCESS_FIELD_NUMBER: builtins.int
    SYSTEM_DATA_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    etag: builtins.str
    @property
    def identity(self) -> global___ServicesResourceIdentity: ...
    kind: builtins.str
    location: builtins.str
    name: builtins.str
    @property
    def access_policies(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServiceAccessPolicyEntry]: ...
    @property
    def acr_configuration(self) -> global___ServiceAcrConfigurationInfo: ...
    @property
    def authentication_configuration(self) -> global___ServiceAuthenticationConfigurationInfo: ...
    @property
    def cors_configuration(self) -> global___ServiceCorsConfigurationInfo: ...
    @property
    def cosmos_db_configuration(self) -> global___ServiceCosmosDbConfigurationInfo: ...
    @property
    def export_configuration(self) -> global___ServiceExportConfigurationInfo: ...
    @property
    def private_endpoint_connections(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PrivateEndpointConnection]: ...
    provisioning_state: builtins.str
    public_network_access: builtins.str
    @property
    def system_data(self) -> global___SystemData: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        etag: builtins.str = ...,
        identity: global___ServicesResourceIdentity | None = ...,
        kind: builtins.str = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        access_policies: collections.abc.Iterable[global___ServiceAccessPolicyEntry] | None = ...,
        acr_configuration: global___ServiceAcrConfigurationInfo | None = ...,
        authentication_configuration: global___ServiceAuthenticationConfigurationInfo | None = ...,
        cors_configuration: global___ServiceCorsConfigurationInfo | None = ...,
        cosmos_db_configuration: global___ServiceCosmosDbConfigurationInfo | None = ...,
        export_configuration: global___ServiceExportConfigurationInfo | None = ...,
        private_endpoint_connections: collections.abc.Iterable[global___PrivateEndpointConnection] | None = ...,
        provisioning_state: builtins.str = ...,
        public_network_access: builtins.str = ...,
        system_data: global___SystemData | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["acr_configuration", b"acr_configuration", "authentication_configuration", b"authentication_configuration", "cors_configuration", b"cors_configuration", "cosmos_db_configuration", b"cosmos_db_configuration", "export_configuration", b"export_configuration", "identity", b"identity", "resource_info", b"resource_info", "system_data", b"system_data"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["access_policies", b"access_policies", "acr_configuration", b"acr_configuration", "authentication_configuration", b"authentication_configuration", "cors_configuration", b"cors_configuration", "cosmos_db_configuration", b"cosmos_db_configuration", "etag", b"etag", "export_configuration", b"export_configuration", "identity", b"identity", "kind", b"kind", "location", b"location", "name", b"name", "private_endpoint_connections", b"private_endpoint_connections", "provisioning_state", b"provisioning_state", "public_network_access", b"public_network_access", "resource_info", b"resource_info", "system_data", b"system_data", "tags", b"tags"]) -> None: ...

global___Services = Services

@typing_extensions.final
class SystemData(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATED_AT_FIELD_NUMBER: builtins.int
    CREATED_BY_FIELD_NUMBER: builtins.int
    CREATED_BY_TYPE_FIELD_NUMBER: builtins.int
    LAST_MODIFIED_AT_FIELD_NUMBER: builtins.int
    LAST_MODIFIED_BY_FIELD_NUMBER: builtins.int
    LAST_MODIFIED_BY_TYPE_FIELD_NUMBER: builtins.int
    created_at: builtins.str
    created_by: builtins.str
    created_by_type: builtins.str
    last_modified_at: builtins.str
    last_modified_by: builtins.str
    last_modified_by_type: builtins.str
    def __init__(
        self,
        *,
        created_at: builtins.str = ...,
        created_by: builtins.str = ...,
        created_by_type: builtins.str = ...,
        last_modified_at: builtins.str = ...,
        last_modified_by: builtins.str = ...,
        last_modified_by_type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["created_at", b"created_at", "created_by", b"created_by", "created_by_type", b"created_by_type", "last_modified_at", b"last_modified_at", "last_modified_by", b"last_modified_by", "last_modified_by_type", b"last_modified_by_type"]) -> None: ...

global___SystemData = SystemData

@typing_extensions.final
class PrivateEndpointConnection(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PRIVATE_ENDPOINT_FIELD_NUMBER: builtins.int
    PRIVATE_LINK_SERVICE_CONNECTION_STATE_FIELD_NUMBER: builtins.int
    PROVISIONING_STATE_FIELD_NUMBER: builtins.int
    @property
    def private_endpoint(self) -> global___PrivateEndpoint: ...
    @property
    def private_link_service_connection_state(self) -> global___PrivateLinkServiceConnectionState: ...
    provisioning_state: builtins.str
    def __init__(
        self,
        *,
        private_endpoint: global___PrivateEndpoint | None = ...,
        private_link_service_connection_state: global___PrivateLinkServiceConnectionState | None = ...,
        provisioning_state: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["private_endpoint", b"private_endpoint", "private_link_service_connection_state", b"private_link_service_connection_state"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["private_endpoint", b"private_endpoint", "private_link_service_connection_state", b"private_link_service_connection_state", "provisioning_state", b"provisioning_state"]) -> None: ...

global___PrivateEndpointConnection = PrivateEndpointConnection

@typing_extensions.final
class PrivateLinkServiceConnectionState(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACTIONS_REQUIRED_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    actions_required: builtins.str
    description: builtins.str
    status: builtins.str
    def __init__(
        self,
        *,
        actions_required: builtins.str = ...,
        description: builtins.str = ...,
        status: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["actions_required", b"actions_required", "description", b"description", "status", b"status"]) -> None: ...

global___PrivateLinkServiceConnectionState = PrivateLinkServiceConnectionState

@typing_extensions.final
class PrivateEndpoint(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___PrivateEndpoint = PrivateEndpoint

@typing_extensions.final
class ServiceExportConfigurationInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STORAGE_ACCOUNT_NAME_FIELD_NUMBER: builtins.int
    storage_account_name: builtins.str
    def __init__(
        self,
        *,
        storage_account_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["storage_account_name", b"storage_account_name"]) -> None: ...

global___ServiceExportConfigurationInfo = ServiceExportConfigurationInfo

@typing_extensions.final
class ServiceCosmosDbConfigurationInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_VAULT_KEY_URI_FIELD_NUMBER: builtins.int
    OFFER_THROUGHPUT_FIELD_NUMBER: builtins.int
    key_vault_key_uri: builtins.str
    offer_throughput: builtins.int
    def __init__(
        self,
        *,
        key_vault_key_uri: builtins.str = ...,
        offer_throughput: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["key_vault_key_uri", b"key_vault_key_uri", "offer_throughput", b"offer_throughput"]) -> None: ...

global___ServiceCosmosDbConfigurationInfo = ServiceCosmosDbConfigurationInfo

@typing_extensions.final
class ServiceCorsConfigurationInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALLOW_CREDENTIALS_FIELD_NUMBER: builtins.int
    HEADERS_FIELD_NUMBER: builtins.int
    MAX_AGE_FIELD_NUMBER: builtins.int
    METHODS_FIELD_NUMBER: builtins.int
    ORIGINS_FIELD_NUMBER: builtins.int
    allow_credentials: builtins.bool
    @property
    def headers(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    max_age: builtins.int
    @property
    def methods(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def origins(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        allow_credentials: builtins.bool = ...,
        headers: collections.abc.Iterable[builtins.str] | None = ...,
        max_age: builtins.int = ...,
        methods: collections.abc.Iterable[builtins.str] | None = ...,
        origins: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["allow_credentials", b"allow_credentials", "headers", b"headers", "max_age", b"max_age", "methods", b"methods", "origins", b"origins"]) -> None: ...

global___ServiceCorsConfigurationInfo = ServiceCorsConfigurationInfo

@typing_extensions.final
class ServiceAuthenticationConfigurationInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUDIENCE_FIELD_NUMBER: builtins.int
    AUTHORITY_FIELD_NUMBER: builtins.int
    SMART_PROXY_ENABLED_FIELD_NUMBER: builtins.int
    audience: builtins.str
    authority: builtins.str
    smart_proxy_enabled: builtins.bool
    def __init__(
        self,
        *,
        audience: builtins.str = ...,
        authority: builtins.str = ...,
        smart_proxy_enabled: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["audience", b"audience", "authority", b"authority", "smart_proxy_enabled", b"smart_proxy_enabled"]) -> None: ...

global___ServiceAuthenticationConfigurationInfo = ServiceAuthenticationConfigurationInfo

@typing_extensions.final
class ServiceAcrConfigurationInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOGIN_SERVERS_FIELD_NUMBER: builtins.int
    OCI_ARTIFACTS_FIELD_NUMBER: builtins.int
    @property
    def login_servers(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def oci_artifacts(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServiceOciArtifactEntry]: ...
    def __init__(
        self,
        *,
        login_servers: collections.abc.Iterable[builtins.str] | None = ...,
        oci_artifacts: collections.abc.Iterable[global___ServiceOciArtifactEntry] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["login_servers", b"login_servers", "oci_artifacts", b"oci_artifacts"]) -> None: ...

global___ServiceAcrConfigurationInfo = ServiceAcrConfigurationInfo

@typing_extensions.final
class ServiceOciArtifactEntry(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DIGEST_FIELD_NUMBER: builtins.int
    IMAGE_NAME_FIELD_NUMBER: builtins.int
    LOGIN_SERVER_FIELD_NUMBER: builtins.int
    digest: builtins.str
    image_name: builtins.str
    login_server: builtins.str
    def __init__(
        self,
        *,
        digest: builtins.str = ...,
        image_name: builtins.str = ...,
        login_server: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["digest", b"digest", "image_name", b"image_name", "login_server", b"login_server"]) -> None: ...

global___ServiceOciArtifactEntry = ServiceOciArtifactEntry

@typing_extensions.final
class ServiceAccessPolicyEntry(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OBJECT_ID_FIELD_NUMBER: builtins.int
    object_id: builtins.str
    def __init__(
        self,
        *,
        object_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["object_id", b"object_id"]) -> None: ...

global___ServiceAccessPolicyEntry = ServiceAccessPolicyEntry

@typing_extensions.final
class ServicesResourceIdentity(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    type: builtins.str
    def __init__(
        self,
        *,
        type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["type", b"type"]) -> None: ...

global___ServicesResourceIdentity = ServicesResourceIdentity
