"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class CustomResourceColumnDefinition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    FORMAT_FIELD_NUMBER: builtins.int
    JSON_PATH_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PRIORITY_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    description: builtins.str
    format: builtins.str
    json_path: builtins.str
    name: builtins.str
    priority: builtins.int
    type: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        format: builtins.str = ...,
        json_path: builtins.str = ...,
        name: builtins.str = ...,
        priority: builtins.int = ...,
        type: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "format", b"format", "json_path", b"json_path", "name", b"name", "priority", b"priority", "resource_info", b"resource_info", "type", b"type"]) -> None: ...

global___CustomResourceColumnDefinition = CustomResourceColumnDefinition

@typing_extensions.final
class CustomResourceConversion(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STRATEGY_FIELD_NUMBER: builtins.int
    WEBHOOK_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    strategy: builtins.str
    @property
    def webhook(self) -> global___WebhookConversion: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        strategy: builtins.str = ...,
        webhook: global___WebhookConversion | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "webhook", b"webhook"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "strategy", b"strategy", "webhook", b"webhook"]) -> None: ...

global___CustomResourceConversion = CustomResourceConversion

@typing_extensions.final
class CustomResourceDefinition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    SPEC_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta: ...
    @property
    def spec(self) -> global___CustomResourceDefinitionSpec: ...
    @property
    def status(self) -> global___CustomResourceDefinitionStatus: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta | None = ...,
        spec: global___CustomResourceDefinitionSpec | None = ...,
        status: global___CustomResourceDefinitionStatus | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info", "spec", b"spec", "status", b"status"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info", "spec", b"spec", "status", b"status"]) -> None: ...

global___CustomResourceDefinition = CustomResourceDefinition

@typing_extensions.final
class CustomResourceDefinitionCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LAST_TRANSITION_TIME_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    REASON_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def last_transition_time(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.Time: ...
    message: builtins.str
    reason: builtins.str
    status: builtins.str
    type: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        last_transition_time: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.Time | None = ...,
        message: builtins.str = ...,
        reason: builtins.str = ...,
        status: builtins.str = ...,
        type: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["last_transition_time", b"last_transition_time", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["last_transition_time", b"last_transition_time", "message", b"message", "reason", b"reason", "resource_info", b"resource_info", "status", b"status", "type", b"type"]) -> None: ...

global___CustomResourceDefinitionCondition = CustomResourceDefinitionCondition

@typing_extensions.final
class CustomResourceDefinitionList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CustomResourceDefinition]: ...
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        items: collections.abc.Iterable[global___CustomResourceDefinition] | None = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "items", b"items", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info"]) -> None: ...

global___CustomResourceDefinitionList = CustomResourceDefinitionList

@typing_extensions.final
class CustomResourceDefinitionNames(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CATEGORIES_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    LIST_KIND_FIELD_NUMBER: builtins.int
    PLURAL_FIELD_NUMBER: builtins.int
    SHORT_NAMES_FIELD_NUMBER: builtins.int
    SINGULAR_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def categories(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    kind: builtins.str
    list_kind: builtins.str
    plural: builtins.str
    @property
    def short_names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    singular: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        categories: collections.abc.Iterable[builtins.str] | None = ...,
        kind: builtins.str = ...,
        list_kind: builtins.str = ...,
        plural: builtins.str = ...,
        short_names: collections.abc.Iterable[builtins.str] | None = ...,
        singular: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["categories", b"categories", "kind", b"kind", "list_kind", b"list_kind", "plural", b"plural", "resource_info", b"resource_info", "short_names", b"short_names", "singular", b"singular"]) -> None: ...

global___CustomResourceDefinitionNames = CustomResourceDefinitionNames

@typing_extensions.final
class CustomResourceDefinitionSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONVERSION_FIELD_NUMBER: builtins.int
    GROUP_FIELD_NUMBER: builtins.int
    NAMES_FIELD_NUMBER: builtins.int
    PRESERVE_UNKNOWN_FIELDS_FIELD_NUMBER: builtins.int
    SCOPE_FIELD_NUMBER: builtins.int
    VERSIONS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def conversion(self) -> global___CustomResourceConversion: ...
    group: builtins.str
    @property
    def names(self) -> global___CustomResourceDefinitionNames: ...
    preserve_unknown_fields: builtins.bool
    scope: builtins.str
    @property
    def versions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CustomResourceDefinitionVersion]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        conversion: global___CustomResourceConversion | None = ...,
        group: builtins.str = ...,
        names: global___CustomResourceDefinitionNames | None = ...,
        preserve_unknown_fields: builtins.bool = ...,
        scope: builtins.str = ...,
        versions: collections.abc.Iterable[global___CustomResourceDefinitionVersion] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["conversion", b"conversion", "names", b"names", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["conversion", b"conversion", "group", b"group", "names", b"names", "preserve_unknown_fields", b"preserve_unknown_fields", "resource_info", b"resource_info", "scope", b"scope", "versions", b"versions"]) -> None: ...

global___CustomResourceDefinitionSpec = CustomResourceDefinitionSpec

@typing_extensions.final
class CustomResourceDefinitionStatus(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACCEPTED_NAMES_FIELD_NUMBER: builtins.int
    CONDITIONS_FIELD_NUMBER: builtins.int
    STORED_VERSIONS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def accepted_names(self) -> global___CustomResourceDefinitionNames: ...
    @property
    def conditions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CustomResourceDefinitionCondition]: ...
    @property
    def stored_versions(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        accepted_names: global___CustomResourceDefinitionNames | None = ...,
        conditions: collections.abc.Iterable[global___CustomResourceDefinitionCondition] | None = ...,
        stored_versions: collections.abc.Iterable[builtins.str] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["accepted_names", b"accepted_names", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["accepted_names", b"accepted_names", "conditions", b"conditions", "resource_info", b"resource_info", "stored_versions", b"stored_versions"]) -> None: ...

global___CustomResourceDefinitionStatus = CustomResourceDefinitionStatus

@typing_extensions.final
class CustomResourceDefinitionVersion(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADDITIONAL_PRINTER_COLUMNS_FIELD_NUMBER: builtins.int
    DEPRECATED_FIELD_NUMBER: builtins.int
    DEPRECATION_WARNING_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    SCHEMA_FIELD_NUMBER: builtins.int
    SERVED_FIELD_NUMBER: builtins.int
    STORAGE_FIELD_NUMBER: builtins.int
    SUBRESOURCES_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def additional_printer_columns(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CustomResourceColumnDefinition]: ...
    deprecated: builtins.bool
    deprecation_warning: builtins.str
    name: builtins.str
    @property
    def schema(self) -> global___CustomResourceValidation: ...
    served: builtins.bool
    storage: builtins.bool
    @property
    def subresources(self) -> global___CustomResourceSubresources: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        additional_printer_columns: collections.abc.Iterable[global___CustomResourceColumnDefinition] | None = ...,
        deprecated: builtins.bool = ...,
        deprecation_warning: builtins.str = ...,
        name: builtins.str = ...,
        schema: global___CustomResourceValidation | None = ...,
        served: builtins.bool = ...,
        storage: builtins.bool = ...,
        subresources: global___CustomResourceSubresources | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "schema", b"schema", "subresources", b"subresources"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["additional_printer_columns", b"additional_printer_columns", "deprecated", b"deprecated", "deprecation_warning", b"deprecation_warning", "name", b"name", "resource_info", b"resource_info", "schema", b"schema", "served", b"served", "storage", b"storage", "subresources", b"subresources"]) -> None: ...

global___CustomResourceDefinitionVersion = CustomResourceDefinitionVersion

@typing_extensions.final
class CustomResourceSubresourceScale(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LABEL_SELECTOR_PATH_FIELD_NUMBER: builtins.int
    SPEC_REPLICAS_PATH_FIELD_NUMBER: builtins.int
    STATUS_REPLICAS_PATH_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    label_selector_path: builtins.str
    spec_replicas_path: builtins.str
    status_replicas_path: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        label_selector_path: builtins.str = ...,
        spec_replicas_path: builtins.str = ...,
        status_replicas_path: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["label_selector_path", b"label_selector_path", "resource_info", b"resource_info", "spec_replicas_path", b"spec_replicas_path", "status_replicas_path", b"status_replicas_path"]) -> None: ...

global___CustomResourceSubresourceScale = CustomResourceSubresourceScale

@typing_extensions.final
class CustomResourceSubresourceStatus(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> None: ...

global___CustomResourceSubresourceStatus = CustomResourceSubresourceStatus

@typing_extensions.final
class CustomResourceSubresources(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SCALE_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def scale(self) -> global___CustomResourceSubresourceScale: ...
    @property
    def status(self) -> global___CustomResourceSubresourceStatus: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        scale: global___CustomResourceSubresourceScale | None = ...,
        status: global___CustomResourceSubresourceStatus | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "scale", b"scale", "status", b"status"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "scale", b"scale", "status", b"status"]) -> None: ...

global___CustomResourceSubresources = CustomResourceSubresources

@typing_extensions.final
class CustomResourceValidation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPEN_A_P_I_V3_SCHEMA_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def open_a_p_i_v3_schema(self) -> global___JSONSchemaProps: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        open_a_p_i_v3_schema: global___JSONSchemaProps | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["open_a_p_i_v3_schema", b"open_a_p_i_v3_schema", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["open_a_p_i_v3_schema", b"open_a_p_i_v3_schema", "resource_info", b"resource_info"]) -> None: ...

global___CustomResourceValidation = CustomResourceValidation

@typing_extensions.final
class ExternalDocumentation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    description: builtins.str
    url: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        url: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "resource_info", b"resource_info", "url", b"url"]) -> None: ...

global___ExternalDocumentation = ExternalDocumentation

@typing_extensions.final
class JSON(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> None: ...

global___JSON = JSON

@typing_extensions.final
class JSONSchemaProps(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class DefinitionsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class DependenciesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class PatternPropertiesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class PropertiesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    ADDITIONAL_ITEMS_FIELD_NUMBER: builtins.int
    ADDITIONAL_PROPERTIES_FIELD_NUMBER: builtins.int
    ALL_OF_FIELD_NUMBER: builtins.int
    ANY_OF_FIELD_NUMBER: builtins.int
    DEFAULT_FIELD_NUMBER: builtins.int
    DEFINITIONS_FIELD_NUMBER: builtins.int
    DEPENDENCIES_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ENUM_FIELD_NUMBER: builtins.int
    EXAMPLE_FIELD_NUMBER: builtins.int
    EXCLUSIVE_MAXIMUM_FIELD_NUMBER: builtins.int
    EXCLUSIVE_MINIMUM_FIELD_NUMBER: builtins.int
    EXTERNAL_DOCS_FIELD_NUMBER: builtins.int
    FORMAT_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    MAX_ITEMS_FIELD_NUMBER: builtins.int
    MAX_LENGTH_FIELD_NUMBER: builtins.int
    MAX_PROPERTIES_FIELD_NUMBER: builtins.int
    MAXIMUM_FIELD_NUMBER: builtins.int
    MIN_ITEMS_FIELD_NUMBER: builtins.int
    MIN_LENGTH_FIELD_NUMBER: builtins.int
    MIN_PROPERTIES_FIELD_NUMBER: builtins.int
    MINIMUM_FIELD_NUMBER: builtins.int
    MULTIPLE_OF_FIELD_NUMBER: builtins.int
    NOT_FIELD_NUMBER: builtins.int
    NULLABLE_FIELD_NUMBER: builtins.int
    ONE_OF_FIELD_NUMBER: builtins.int
    PATTERN_FIELD_NUMBER: builtins.int
    PATTERN_PROPERTIES_FIELD_NUMBER: builtins.int
    PROPERTIES_FIELD_NUMBER: builtins.int
    REQUIRED_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    UNIQUE_ITEMS_FIELD_NUMBER: builtins.int
    XKUBERNETESEMBEDDEDRESOURCE_FIELD_NUMBER: builtins.int
    XKUBERNETESINTORSTRING_FIELD_NUMBER: builtins.int
    XKUBERNETESLISTMAPKEYS_FIELD_NUMBER: builtins.int
    XKUBERNETESLISTTYPE_FIELD_NUMBER: builtins.int
    XKUBERNETESMAPTYPE_FIELD_NUMBER: builtins.int
    XKUBERNETESPRESERVEUNKNOWNFIELDS_FIELD_NUMBER: builtins.int
    XKUBERNETESVALIDATIONS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def additional_items(self) -> global___JSONSchemaPropsOrBool: ...
    @property
    def additional_properties(self) -> global___JSONSchemaPropsOrBool: ...
    @property
    def all_of(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___JSONSchemaProps]: ...
    @property
    def any_of(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___JSONSchemaProps]: ...
    @property
    def default(self) -> global___JSON: ...
    @property
    def definitions(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def dependencies(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    description: builtins.str
    @property
    def enum(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___JSON]: ...
    @property
    def example(self) -> global___JSON: ...
    exclusive_maximum: builtins.bool
    exclusive_minimum: builtins.bool
    @property
    def external_docs(self) -> global___ExternalDocumentation: ...
    format: builtins.str
    id: builtins.str
    @property
    def items(self) -> global___JSONSchemaPropsOrArray: ...
    max_items: builtins.int
    max_length: builtins.int
    max_properties: builtins.int
    maximum: builtins.float
    min_items: builtins.int
    min_length: builtins.int
    min_properties: builtins.int
    minimum: builtins.float
    multiple_of: builtins.float
    nullable: builtins.bool
    @property
    def one_of(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___JSONSchemaProps]: ...
    pattern: builtins.str
    @property
    def pattern_properties(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def properties(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def required(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    title: builtins.str
    type: builtins.str
    unique_items: builtins.bool
    xkubernetesembeddedresource: builtins.bool
    xkubernetesintorstring: builtins.bool
    @property
    def xkuberneteslistmapkeys(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    xkuberneteslisttype: builtins.str
    xkubernetesmaptype: builtins.str
    xkubernetespreserveunknownfields: builtins.bool
    @property
    def xkubernetesvalidations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ValidationRule]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        additional_items: global___JSONSchemaPropsOrBool | None = ...,
        additional_properties: global___JSONSchemaPropsOrBool | None = ...,
        all_of: collections.abc.Iterable[global___JSONSchemaProps] | None = ...,
        any_of: collections.abc.Iterable[global___JSONSchemaProps] | None = ...,
        default: global___JSON | None = ...,
        definitions: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        dependencies: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        description: builtins.str = ...,
        enum: collections.abc.Iterable[global___JSON] | None = ...,
        example: global___JSON | None = ...,
        exclusive_maximum: builtins.bool = ...,
        exclusive_minimum: builtins.bool = ...,
        external_docs: global___ExternalDocumentation | None = ...,
        format: builtins.str = ...,
        id: builtins.str = ...,
        items: global___JSONSchemaPropsOrArray | None = ...,
        max_items: builtins.int = ...,
        max_length: builtins.int = ...,
        max_properties: builtins.int = ...,
        maximum: builtins.float = ...,
        min_items: builtins.int = ...,
        min_length: builtins.int = ...,
        min_properties: builtins.int = ...,
        minimum: builtins.float = ...,
        multiple_of: builtins.float = ...,
        nullable: builtins.bool = ...,
        one_of: collections.abc.Iterable[global___JSONSchemaProps] | None = ...,
        pattern: builtins.str = ...,
        pattern_properties: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        properties: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        required: collections.abc.Iterable[builtins.str] | None = ...,
        title: builtins.str = ...,
        type: builtins.str = ...,
        unique_items: builtins.bool = ...,
        xkubernetesembeddedresource: builtins.bool = ...,
        xkubernetesintorstring: builtins.bool = ...,
        xkuberneteslistmapkeys: collections.abc.Iterable[builtins.str] | None = ...,
        xkuberneteslisttype: builtins.str = ...,
        xkubernetesmaptype: builtins.str = ...,
        xkubernetespreserveunknownfields: builtins.bool = ...,
        xkubernetesvalidations: collections.abc.Iterable[global___ValidationRule] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["additional_items", b"additional_items", "additional_properties", b"additional_properties", "default", b"default", "example", b"example", "external_docs", b"external_docs", "items", b"items", "not", b"not", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["additional_items", b"additional_items", "additional_properties", b"additional_properties", "all_of", b"all_of", "any_of", b"any_of", "default", b"default", "definitions", b"definitions", "dependencies", b"dependencies", "description", b"description", "enum", b"enum", "example", b"example", "exclusive_maximum", b"exclusive_maximum", "exclusive_minimum", b"exclusive_minimum", "external_docs", b"external_docs", "format", b"format", "id", b"id", "items", b"items", "max_items", b"max_items", "max_length", b"max_length", "max_properties", b"max_properties", "maximum", b"maximum", "min_items", b"min_items", "min_length", b"min_length", "min_properties", b"min_properties", "minimum", b"minimum", "multiple_of", b"multiple_of", "not", b"not", "nullable", b"nullable", "one_of", b"one_of", "pattern", b"pattern", "pattern_properties", b"pattern_properties", "properties", b"properties", "required", b"required", "resource_info", b"resource_info", "title", b"title", "type", b"type", "unique_items", b"unique_items", "xkubernetesembeddedresource", b"xkubernetesembeddedresource", "xkubernetesintorstring", b"xkubernetesintorstring", "xkuberneteslistmapkeys", b"xkuberneteslistmapkeys", "xkuberneteslisttype", b"xkuberneteslisttype", "xkubernetesmaptype", b"xkubernetesmaptype", "xkubernetespreserveunknownfields", b"xkubernetespreserveunknownfields", "xkubernetesvalidations", b"xkubernetesvalidations"]) -> None: ...

global___JSONSchemaProps = JSONSchemaProps

@typing_extensions.final
class JSONSchemaPropsOrArray(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> None: ...

global___JSONSchemaPropsOrArray = JSONSchemaPropsOrArray

@typing_extensions.final
class JSONSchemaPropsOrBool(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> None: ...

global___JSONSchemaPropsOrBool = JSONSchemaPropsOrBool

@typing_extensions.final
class JSONSchemaPropsOrStringArray(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> None: ...

global___JSONSchemaPropsOrStringArray = JSONSchemaPropsOrStringArray

@typing_extensions.final
class ServiceReference(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    NAMESPACE_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    PORT_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    name: builtins.str
    namespace: builtins.str
    path: builtins.str
    port: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        namespace: builtins.str = ...,
        path: builtins.str = ...,
        port: builtins.int = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "namespace", b"namespace", "path", b"path", "port", b"port", "resource_info", b"resource_info"]) -> None: ...

global___ServiceReference = ServiceReference

@typing_extensions.final
class ValidationRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MESSAGE_FIELD_NUMBER: builtins.int
    RULE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    message: builtins.str
    rule: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        message: builtins.str = ...,
        rule: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["message", b"message", "resource_info", b"resource_info", "rule", b"rule"]) -> None: ...

global___ValidationRule = ValidationRule

@typing_extensions.final
class WebhookClientConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CA_BUNDLE_FIELD_NUMBER: builtins.int
    SERVICE_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ca_bundle: builtins.str
    @property
    def service(self) -> global___ServiceReference: ...
    url: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        ca_bundle: builtins.str = ...,
        service: global___ServiceReference | None = ...,
        url: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "service", b"service"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ca_bundle", b"ca_bundle", "resource_info", b"resource_info", "service", b"service", "url", b"url"]) -> None: ...

global___WebhookClientConfig = WebhookClientConfig

@typing_extensions.final
class WebhookConversion(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLIENT_CONFIG_FIELD_NUMBER: builtins.int
    CONVERSION_REVIEW_VERSIONS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def client_config(self) -> global___WebhookClientConfig: ...
    @property
    def conversion_review_versions(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        client_config: global___WebhookClientConfig | None = ...,
        conversion_review_versions: collections.abc.Iterable[builtins.str] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["client_config", b"client_config", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["client_config", b"client_config", "conversion_review_versions", b"conversion_review_versions", "resource_info", b"resource_info"]) -> None: ...

global___WebhookConversion = WebhookConversion
