# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_compute_url.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19gcp/gcp_compute_url.proto\x12\x1boak9.tython.gcp.compute_url\x1a\x13shared/shared.proto\"\xe6\x01\n+ComputeUrlMapXDefaultRouteActionXCorsPolicy\x12\x19\n\x11\x61llow_credentials\x18\x01 \x01(\x08\x12\x15\n\rallow_headers\x18\x02 \x03(\t\x12\x15\n\rallow_methods\x18\x03 \x03(\t\x12\x1c\n\x14\x61llow_origin_regexes\x18\x04 \x03(\t\x12\x15\n\rallow_origins\x18\x05 \x03(\t\x12\x10\n\x08\x64isabled\x18\x06 \x01(\x08\x12\x16\n\x0e\x65xpose_headers\x18\x07 \x03(\t\x12\x0f\n\x07max_age\x18\x08 \x01(\x01\"f\n;ComputeUrlMapXDefaultRouteActionXFaultInjectionPolicyXAbort\x12\x13\n\x0bhttp_status\x18\x01 \x01(\x01\x12\x12\n\npercentage\x18\x02 \x01(\x01\"h\nFComputeUrlMapXDefaultRouteActionXFaultInjectionPolicyXDelayXFixedDelay\x12\r\n\x05nanos\x18\x01 \x01(\x01\x12\x0f\n\x07seconds\x18\x02 \x01(\t\"\xcb\x01\n;ComputeUrlMapXDefaultRouteActionXFaultInjectionPolicyXDelay\x12\x12\n\npercentage\x18\x01 \x01(\x01\x12x\n\x0b\x66ixed_delay\x18\x02 \x01(\x0b\x32\x63.oak9.tython.gcp.compute_url.ComputeUrlMapXDefaultRouteActionXFaultInjectionPolicyXDelayXFixedDelay\"\x89\x02\n5ComputeUrlMapXDefaultRouteActionXFaultInjectionPolicy\x12g\n\x05\x61\x62ort\x18\x01 \x01(\x0b\x32X.oak9.tython.gcp.compute_url.ComputeUrlMapXDefaultRouteActionXFaultInjectionPolicyXAbort\x12g\n\x05\x64\x65lay\x18\x02 \x01(\x0b\x32X.oak9.tython.gcp.compute_url.ComputeUrlMapXDefaultRouteActionXFaultInjectionPolicyXDelay\"O\n4ComputeUrlMapXDefaultRouteActionXRequestMirrorPolicy\x12\x17\n\x0f\x62\x61\x63kend_service\x18\x01 \x01(\t\"\\\n:ComputeUrlMapXDefaultRouteActionXRetryPolicyXPerTryTimeout\x12\r\n\x05nanos\x18\x01 \x01(\x01\x12\x0f\n\x07seconds\x18\x02 \x01(\t\"\xcf\x01\n,ComputeUrlMapXDefaultRouteActionXRetryPolicy\x12\x13\n\x0bnum_retries\x18\x01 \x01(\x01\x12\x18\n\x10retry_conditions\x18\x02 \x03(\t\x12p\n\x0fper_try_timeout\x18\x03 \x01(\x0b\x32W.oak9.tython.gcp.compute_url.ComputeUrlMapXDefaultRouteActionXRetryPolicyXPerTryTimeout\"J\n(ComputeUrlMapXDefaultRouteActionXTimeout\x12\r\n\x05nanos\x18\x01 \x01(\x01\x12\x0f\n\x07seconds\x18\x02 \x01(\t\"`\n+ComputeUrlMapXDefaultRouteActionXUrlRewrite\x12\x14\n\x0chost_rewrite\x18\x01 \x01(\t\x12\x1b\n\x13path_prefix_rewrite\x18\x02 \x01(\t\"\x97\x01\nYComputeUrlMapXDefaultRouteActionXWeightedBackendServicesXHeaderActionXRequestHeadersToAdd\x12\x13\n\x0bheader_name\x18\x01 \x01(\t\x12\x14\n\x0cheader_value\x18\x02 \x01(\t\x12\x0f\n\x07replace\x18\x03 \x01(\x08\"\x98\x01\nZComputeUrlMapXDefaultRouteActionXWeightedBackendServicesXHeaderActionXResponseHeadersToAdd\x12\x13\n\x0bheader_name\x18\x01 \x01(\t\x12\x14\n\x0cheader_value\x18\x02 \x01(\t\x12\x0f\n\x07replace\x18\x03 \x01(\x08\"\xc2\x03\nEComputeUrlMapXDefaultRouteActionXWeightedBackendServicesXHeaderAction\x12!\n\x19request_headers_to_remove\x18\x01 \x03(\t\x12\"\n\x1aresponse_headers_to_remove\x18\x02 \x03(\t\x12\x96\x01\n\x16request_headers_to_add\x18\x03 \x03(\x0b\x32v.oak9.tython.gcp.compute_url.ComputeUrlMapXDefaultRouteActionXWeightedBackendServicesXHeaderActionXRequestHeadersToAdd\x12\x98\x01\n\x17response_headers_to_add\x18\x04 \x03(\x0b\x32w.oak9.tython.gcp.compute_url.ComputeUrlMapXDefaultRouteActionXWeightedBackendServicesXHeaderActionXResponseHeadersToAdd\"\xde\x01\n8ComputeUrlMapXDefaultRouteActionXWeightedBackendServices\x12\x17\n\x0f\x62\x61\x63kend_service\x18\x01 \x01(\t\x12\x0e\n\x06weight\x18\x02 \x01(\x01\x12y\n\rheader_action\x18\x03 \x01(\x0b\x32\x62.oak9.tython.gcp.compute_url.ComputeUrlMapXDefaultRouteActionXWeightedBackendServicesXHeaderAction\"\xf9\x05\n ComputeUrlMapXDefaultRouteAction\x12]\n\x0b\x63ors_policy\x18\x01 \x01(\x0b\x32H.oak9.tython.gcp.compute_url.ComputeUrlMapXDefaultRouteActionXCorsPolicy\x12r\n\x16\x66\x61ult_injection_policy\x18\x02 \x01(\x0b\x32R.oak9.tython.gcp.compute_url.ComputeUrlMapXDefaultRouteActionXFaultInjectionPolicy\x12p\n\x15request_mirror_policy\x18\x03 \x01(\x0b\x32Q.oak9.tython.gcp.compute_url.ComputeUrlMapXDefaultRouteActionXRequestMirrorPolicy\x12_\n\x0cretry_policy\x18\x04 \x01(\x0b\x32I.oak9.tython.gcp.compute_url.ComputeUrlMapXDefaultRouteActionXRetryPolicy\x12V\n\x07timeout\x18\x05 \x01(\x0b\x32\x45.oak9.tython.gcp.compute_url.ComputeUrlMapXDefaultRouteActionXTimeout\x12]\n\x0burl_rewrite\x18\x06 \x01(\x0b\x32H.oak9.tython.gcp.compute_url.ComputeUrlMapXDefaultRouteActionXUrlRewrite\x12x\n\x19weighted_backend_services\x18\x07 \x03(\x0b\x32U.oak9.tython.gcp.compute_url.ComputeUrlMapXDefaultRouteActionXWeightedBackendServices\"\xb6\x01\n ComputeUrlMapXDefaultUrlRedirect\x12\x15\n\rhost_redirect\x18\x01 \x01(\t\x12\x16\n\x0ehttps_redirect\x18\x02 \x01(\x08\x12\x15\n\rpath_redirect\x18\x03 \x01(\t\x12\x17\n\x0fprefix_redirect\x18\x04 \x01(\t\x12\x1e\n\x16redirect_response_code\x18\x05 \x01(\t\x12\x13\n\x0bstrip_query\x18\x06 \x01(\x08\"l\n.ComputeUrlMapXHeaderActionXRequestHeadersToAdd\x12\x13\n\x0bheader_name\x18\x01 \x01(\t\x12\x14\n\x0cheader_value\x18\x02 \x01(\t\x12\x0f\n\x07replace\x18\x03 \x01(\x08\"m\n/ComputeUrlMapXHeaderActionXResponseHeadersToAdd\x12\x13\n\x0bheader_name\x18\x01 \x01(\t\x12\x14\n\x0cheader_value\x18\x02 \x01(\t\x12\x0f\n\x07replace\x18\x03 \x01(\x08\"\xbf\x02\n\x1a\x43omputeUrlMapXHeaderAction\x12!\n\x19request_headers_to_remove\x18\x01 \x03(\t\x12\"\n\x1aresponse_headers_to_remove\x18\x02 \x03(\t\x12k\n\x16request_headers_to_add\x18\x03 \x03(\x0b\x32K.oak9.tython.gcp.compute_url.ComputeUrlMapXHeaderActionXRequestHeadersToAdd\x12m\n\x17response_headers_to_add\x18\x04 \x03(\x0b\x32L.oak9.tython.gcp.compute_url.ComputeUrlMapXHeaderActionXResponseHeadersToAdd\"R\n\x16\x43omputeUrlMapXHostRule\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\r\n\x05hosts\x18\x02 \x03(\t\x12\x14\n\x0cpath_matcher\x18\x03 \x01(\t\"\xf2\x01\n7ComputeUrlMapXPathMatcherXDefaultRouteActionXCorsPolicy\x12\x19\n\x11\x61llow_credentials\x18\x01 \x01(\x08\x12\x15\n\rallow_headers\x18\x02 \x03(\t\x12\x15\n\rallow_methods\x18\x03 \x03(\t\x12\x1c\n\x14\x61llow_origin_regexes\x18\x04 \x03(\t\x12\x15\n\rallow_origins\x18\x05 \x03(\t\x12\x10\n\x08\x64isabled\x18\x06 \x01(\x08\x12\x16\n\x0e\x65xpose_headers\x18\x07 \x03(\t\x12\x0f\n\x07max_age\x18\x08 \x01(\x01\"r\nGComputeUrlMapXPathMatcherXDefaultRouteActionXFaultInjectionPolicyXAbort\x12\x13\n\x0bhttp_status\x18\x01 \x01(\x01\x12\x12\n\npercentage\x18\x02 \x01(\x01\"t\nRComputeUrlMapXPathMatcherXDefaultRouteActionXFaultInjectionPolicyXDelayXFixedDelay\x12\r\n\x05nanos\x18\x01 \x01(\x01\x12\x0f\n\x07seconds\x18\x02 \x01(\t\"\xe4\x01\nGComputeUrlMapXPathMatcherXDefaultRouteActionXFaultInjectionPolicyXDelay\x12\x12\n\npercentage\x18\x01 \x01(\x01\x12\x84\x01\n\x0b\x66ixed_delay\x18\x02 \x01(\x0b\x32o.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXDefaultRouteActionXFaultInjectionPolicyXDelayXFixedDelay\"\xad\x02\nAComputeUrlMapXPathMatcherXDefaultRouteActionXFaultInjectionPolicy\x12s\n\x05\x61\x62ort\x18\x01 \x01(\x0b\x32\x64.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXDefaultRouteActionXFaultInjectionPolicyXAbort\x12s\n\x05\x64\x65lay\x18\x02 \x01(\x0b\x32\x64.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXDefaultRouteActionXFaultInjectionPolicyXDelay\"[\n@ComputeUrlMapXPathMatcherXDefaultRouteActionXRequestMirrorPolicy\x12\x17\n\x0f\x62\x61\x63kend_service\x18\x01 \x01(\t\"h\nFComputeUrlMapXPathMatcherXDefaultRouteActionXRetryPolicyXPerTryTimeout\x12\r\n\x05nanos\x18\x01 \x01(\x01\x12\x0f\n\x07seconds\x18\x02 \x01(\t\"\xe7\x01\n8ComputeUrlMapXPathMatcherXDefaultRouteActionXRetryPolicy\x12\x13\n\x0bnum_retries\x18\x01 \x01(\x01\x12\x18\n\x10retry_conditions\x18\x02 \x03(\t\x12|\n\x0fper_try_timeout\x18\x03 \x01(\x0b\x32\x63.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXDefaultRouteActionXRetryPolicyXPerTryTimeout\"V\n4ComputeUrlMapXPathMatcherXDefaultRouteActionXTimeout\x12\r\n\x05nanos\x18\x01 \x01(\x01\x12\x0f\n\x07seconds\x18\x02 \x01(\t\"l\n7ComputeUrlMapXPathMatcherXDefaultRouteActionXUrlRewrite\x12\x14\n\x0chost_rewrite\x18\x01 \x01(\t\x12\x1b\n\x13path_prefix_rewrite\x18\x02 \x01(\t\"\xa3\x01\neComputeUrlMapXPathMatcherXDefaultRouteActionXWeightedBackendServicesXHeaderActionXRequestHeadersToAdd\x12\x13\n\x0bheader_name\x18\x01 \x01(\t\x12\x14\n\x0cheader_value\x18\x02 \x01(\t\x12\x0f\n\x07replace\x18\x03 \x01(\x08\"\xa4\x01\nfComputeUrlMapXPathMatcherXDefaultRouteActionXWeightedBackendServicesXHeaderActionXResponseHeadersToAdd\x12\x13\n\x0bheader_name\x18\x01 \x01(\t\x12\x14\n\x0cheader_value\x18\x02 \x01(\t\x12\x0f\n\x07replace\x18\x03 \x01(\x08\"\xe8\x03\nQComputeUrlMapXPathMatcherXDefaultRouteActionXWeightedBackendServicesXHeaderAction\x12!\n\x19request_headers_to_remove\x18\x01 \x03(\t\x12\"\n\x1aresponse_headers_to_remove\x18\x02 \x03(\t\x12\xa3\x01\n\x16request_headers_to_add\x18\x03 \x03(\x0b\x32\x82\x01.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXDefaultRouteActionXWeightedBackendServicesXHeaderActionXRequestHeadersToAdd\x12\xa5\x01\n\x17response_headers_to_add\x18\x04 \x03(\x0b\x32\x83\x01.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXDefaultRouteActionXWeightedBackendServicesXHeaderActionXResponseHeadersToAdd\"\xf7\x01\nDComputeUrlMapXPathMatcherXDefaultRouteActionXWeightedBackendServices\x12\x17\n\x0f\x62\x61\x63kend_service\x18\x01 \x01(\t\x12\x0e\n\x06weight\x18\x02 \x01(\x01\x12\x85\x01\n\rheader_action\x18\x03 \x01(\x0b\x32n.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXDefaultRouteActionXWeightedBackendServicesXHeaderAction\"\xda\x06\n,ComputeUrlMapXPathMatcherXDefaultRouteAction\x12i\n\x0b\x63ors_policy\x18\x01 \x01(\x0b\x32T.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXDefaultRouteActionXCorsPolicy\x12~\n\x16\x66\x61ult_injection_policy\x18\x02 \x01(\x0b\x32^.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXDefaultRouteActionXFaultInjectionPolicy\x12|\n\x15request_mirror_policy\x18\x03 \x01(\x0b\x32].oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXDefaultRouteActionXRequestMirrorPolicy\x12k\n\x0cretry_policy\x18\x04 \x01(\x0b\x32U.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXDefaultRouteActionXRetryPolicy\x12\x62\n\x07timeout\x18\x05 \x01(\x0b\x32Q.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXDefaultRouteActionXTimeout\x12i\n\x0burl_rewrite\x18\x06 \x01(\x0b\x32T.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXDefaultRouteActionXUrlRewrite\x12\x84\x01\n\x19weighted_backend_services\x18\x07 \x03(\x0b\x32\x61.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXDefaultRouteActionXWeightedBackendServices\"\xc2\x01\n,ComputeUrlMapXPathMatcherXDefaultUrlRedirect\x12\x15\n\rhost_redirect\x18\x01 \x01(\t\x12\x16\n\x0ehttps_redirect\x18\x02 \x01(\x08\x12\x15\n\rpath_redirect\x18\x03 \x01(\t\x12\x17\n\x0fprefix_redirect\x18\x04 \x01(\t\x12\x1e\n\x16redirect_response_code\x18\x05 \x01(\t\x12\x13\n\x0bstrip_query\x18\x06 \x01(\x08\"x\n:ComputeUrlMapXPathMatcherXHeaderActionXRequestHeadersToAdd\x12\x13\n\x0bheader_name\x18\x01 \x01(\t\x12\x14\n\x0cheader_value\x18\x02 \x01(\t\x12\x0f\n\x07replace\x18\x03 \x01(\x08\"y\n;ComputeUrlMapXPathMatcherXHeaderActionXResponseHeadersToAdd\x12\x13\n\x0bheader_name\x18\x01 \x01(\t\x12\x14\n\x0cheader_value\x18\x02 \x01(\t\x12\x0f\n\x07replace\x18\x03 \x01(\x08\"\xe3\x02\n&ComputeUrlMapXPathMatcherXHeaderAction\x12!\n\x19request_headers_to_remove\x18\x01 \x03(\t\x12\"\n\x1aresponse_headers_to_remove\x18\x02 \x03(\t\x12w\n\x16request_headers_to_add\x18\x03 \x03(\x0b\x32W.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXHeaderActionXRequestHeadersToAdd\x12y\n\x17response_headers_to_add\x18\x04 \x03(\x0b\x32X.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXHeaderActionXResponseHeadersToAdd\"\xf4\x01\n9ComputeUrlMapXPathMatcherXPathRuleXRouteActionXCorsPolicy\x12\x19\n\x11\x61llow_credentials\x18\x01 \x01(\x08\x12\x15\n\rallow_headers\x18\x02 \x03(\t\x12\x15\n\rallow_methods\x18\x03 \x03(\t\x12\x1c\n\x14\x61llow_origin_regexes\x18\x04 \x03(\t\x12\x15\n\rallow_origins\x18\x05 \x03(\t\x12\x10\n\x08\x64isabled\x18\x06 \x01(\x08\x12\x16\n\x0e\x65xpose_headers\x18\x07 \x03(\t\x12\x0f\n\x07max_age\x18\x08 \x01(\x01\"t\nIComputeUrlMapXPathMatcherXPathRuleXRouteActionXFaultInjectionPolicyXAbort\x12\x13\n\x0bhttp_status\x18\x01 \x01(\x01\x12\x12\n\npercentage\x18\x02 \x01(\x01\"v\nTComputeUrlMapXPathMatcherXPathRuleXRouteActionXFaultInjectionPolicyXDelayXFixedDelay\x12\r\n\x05nanos\x18\x01 \x01(\x01\x12\x0f\n\x07seconds\x18\x02 \x01(\t\"\xe8\x01\nIComputeUrlMapXPathMatcherXPathRuleXRouteActionXFaultInjectionPolicyXDelay\x12\x12\n\npercentage\x18\x01 \x01(\x01\x12\x86\x01\n\x0b\x66ixed_delay\x18\x02 \x01(\x0b\x32q.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXPathRuleXRouteActionXFaultInjectionPolicyXDelayXFixedDelay\"\xb3\x02\nCComputeUrlMapXPathMatcherXPathRuleXRouteActionXFaultInjectionPolicy\x12u\n\x05\x61\x62ort\x18\x01 \x01(\x0b\x32\x66.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXPathRuleXRouteActionXFaultInjectionPolicyXAbort\x12u\n\x05\x64\x65lay\x18\x02 \x01(\x0b\x32\x66.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXPathRuleXRouteActionXFaultInjectionPolicyXDelay\"]\nBComputeUrlMapXPathMatcherXPathRuleXRouteActionXRequestMirrorPolicy\x12\x17\n\x0f\x62\x61\x63kend_service\x18\x01 \x01(\t\"j\nHComputeUrlMapXPathMatcherXPathRuleXRouteActionXRetryPolicyXPerTryTimeout\x12\r\n\x05nanos\x18\x01 \x01(\x01\x12\x0f\n\x07seconds\x18\x02 \x01(\t\"\xeb\x01\n:ComputeUrlMapXPathMatcherXPathRuleXRouteActionXRetryPolicy\x12\x13\n\x0bnum_retries\x18\x01 \x01(\x01\x12\x18\n\x10retry_conditions\x18\x02 \x03(\t\x12~\n\x0fper_try_timeout\x18\x03 \x01(\x0b\x32\x65.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXPathRuleXRouteActionXRetryPolicyXPerTryTimeout\"X\n6ComputeUrlMapXPathMatcherXPathRuleXRouteActionXTimeout\x12\r\n\x05nanos\x18\x01 \x01(\x01\x12\x0f\n\x07seconds\x18\x02 \x01(\t\"n\n9ComputeUrlMapXPathMatcherXPathRuleXRouteActionXUrlRewrite\x12\x14\n\x0chost_rewrite\x18\x01 \x01(\t\x12\x1b\n\x13path_prefix_rewrite\x18\x02 \x01(\t\"\xa5\x01\ngComputeUrlMapXPathMatcherXPathRuleXRouteActionXWeightedBackendServicesXHeaderActionXRequestHeadersToAdd\x12\x13\n\x0bheader_name\x18\x01 \x01(\t\x12\x14\n\x0cheader_value\x18\x02 \x01(\t\x12\x0f\n\x07replace\x18\x03 \x01(\x08\"\xa6\x01\nhComputeUrlMapXPathMatcherXPathRuleXRouteActionXWeightedBackendServicesXHeaderActionXResponseHeadersToAdd\x12\x13\n\x0bheader_name\x18\x01 \x01(\t\x12\x14\n\x0cheader_value\x18\x02 \x01(\t\x12\x0f\n\x07replace\x18\x03 \x01(\x08\"\xee\x03\nSComputeUrlMapXPathMatcherXPathRuleXRouteActionXWeightedBackendServicesXHeaderAction\x12!\n\x19request_headers_to_remove\x18\x01 \x03(\t\x12\"\n\x1aresponse_headers_to_remove\x18\x02 \x03(\t\x12\xa5\x01\n\x16request_headers_to_add\x18\x03 \x03(\x0b\x32\x84\x01.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXPathRuleXRouteActionXWeightedBackendServicesXHeaderActionXRequestHeadersToAdd\x12\xa7\x01\n\x17response_headers_to_add\x18\x04 \x03(\x0b\x32\x85\x01.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXPathRuleXRouteActionXWeightedBackendServicesXHeaderActionXResponseHeadersToAdd\"\xfb\x01\nFComputeUrlMapXPathMatcherXPathRuleXRouteActionXWeightedBackendServices\x12\x17\n\x0f\x62\x61\x63kend_service\x18\x01 \x01(\t\x12\x0e\n\x06weight\x18\x02 \x01(\x01\x12\x87\x01\n\rheader_action\x18\x03 \x01(\x0b\x32p.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXPathRuleXRouteActionXWeightedBackendServicesXHeaderAction\"\xeb\x06\n.ComputeUrlMapXPathMatcherXPathRuleXRouteAction\x12k\n\x0b\x63ors_policy\x18\x01 \x01(\x0b\x32V.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXPathRuleXRouteActionXCorsPolicy\x12\x80\x01\n\x16\x66\x61ult_injection_policy\x18\x02 \x01(\x0b\x32`.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXPathRuleXRouteActionXFaultInjectionPolicy\x12~\n\x15request_mirror_policy\x18\x03 \x01(\x0b\x32_.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXPathRuleXRouteActionXRequestMirrorPolicy\x12m\n\x0cretry_policy\x18\x04 \x01(\x0b\x32W.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXPathRuleXRouteActionXRetryPolicy\x12\x64\n\x07timeout\x18\x05 \x01(\x0b\x32S.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXPathRuleXRouteActionXTimeout\x12k\n\x0burl_rewrite\x18\x06 \x01(\x0b\x32V.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXPathRuleXRouteActionXUrlRewrite\x12\x86\x01\n\x19weighted_backend_services\x18\x07 \x03(\x0b\x32\x63.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXPathRuleXRouteActionXWeightedBackendServices\"\xc4\x01\n.ComputeUrlMapXPathMatcherXPathRuleXUrlRedirect\x12\x15\n\rhost_redirect\x18\x01 \x01(\t\x12\x16\n\x0ehttps_redirect\x18\x02 \x01(\x08\x12\x15\n\rpath_redirect\x18\x03 \x01(\t\x12\x17\n\x0fprefix_redirect\x18\x04 \x01(\t\x12\x1e\n\x16redirect_response_code\x18\x05 \x01(\t\x12\x13\n\x0bstrip_query\x18\x06 \x01(\x08\"\x8a\x02\n\"ComputeUrlMapXPathMatcherXPathRule\x12\r\n\x05paths\x18\x01 \x03(\t\x12\x0f\n\x07service\x18\x02 \x01(\t\x12\x61\n\x0croute_action\x18\x03 \x01(\x0b\x32K.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXPathRuleXRouteAction\x12\x61\n\x0curl_redirect\x18\x04 \x01(\x0b\x32K.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXPathRuleXUrlRedirect\"\x83\x01\nEComputeUrlMapXPathMatcherXRouteRulesXHeaderActionXRequestHeadersToAdd\x12\x13\n\x0bheader_name\x18\x01 \x01(\t\x12\x14\n\x0cheader_value\x18\x02 \x01(\t\x12\x0f\n\x07replace\x18\x03 \x01(\x08\"\x84\x01\nFComputeUrlMapXPathMatcherXRouteRulesXHeaderActionXResponseHeadersToAdd\x12\x13\n\x0bheader_name\x18\x01 \x01(\t\x12\x14\n\x0cheader_value\x18\x02 \x01(\t\x12\x0f\n\x07replace\x18\x03 \x01(\x08\"\x86\x03\n1ComputeUrlMapXPathMatcherXRouteRulesXHeaderAction\x12!\n\x19request_headers_to_remove\x18\x01 \x03(\t\x12\"\n\x1aresponse_headers_to_remove\x18\x02 \x03(\t\x12\x82\x01\n\x16request_headers_to_add\x18\x03 \x03(\x0b\x32\x62.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXRouteRulesXHeaderActionXRequestHeadersToAdd\x12\x84\x01\n\x17response_headers_to_add\x18\x04 \x03(\x0b\x32\x63.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXRouteRulesXHeaderActionXResponseHeadersToAdd\"r\nHComputeUrlMapXPathMatcherXRouteRulesXMatchRulesXHeaderMatchesXRangeMatch\x12\x11\n\trange_end\x18\x01 \x01(\x01\x12\x13\n\x0brange_start\x18\x02 \x01(\x01\"\xd3\x02\n=ComputeUrlMapXPathMatcherXRouteRulesXMatchRulesXHeaderMatches\x12\x13\n\x0b\x65xact_match\x18\x01 \x01(\t\x12\x13\n\x0bheader_name\x18\x02 \x01(\t\x12\x14\n\x0cinvert_match\x18\x03 \x01(\x08\x12\x14\n\x0cprefix_match\x18\x04 \x01(\t\x12\x15\n\rpresent_match\x18\x05 \x01(\x08\x12\x13\n\x0bregex_match\x18\x06 \x01(\t\x12\x14\n\x0csuffix_match\x18\x07 \x01(\t\x12z\n\x0brange_match\x18\x08 \x01(\x0b\x32\x65.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXRouteRulesXMatchRulesXHeaderMatchesXRangeMatch\"k\nLComputeUrlMapXPathMatcherXRouteRulesXMatchRulesXMetadataFiltersXFilterLabels\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"\xe3\x01\n?ComputeUrlMapXPathMatcherXRouteRulesXMatchRulesXMetadataFilters\x12\x1d\n\x15\x66ilter_match_criteria\x18\x01 \x01(\t\x12\x80\x01\n\rfilter_labels\x18\x02 \x03(\x0b\x32i.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXRouteRulesXMatchRulesXMetadataFiltersXFilterLabels\"\x96\x01\nEComputeUrlMapXPathMatcherXRouteRulesXMatchRulesXQueryParameterMatches\x12\x13\n\x0b\x65xact_match\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x15\n\rpresent_match\x18\x03 \x01(\x08\x12\x13\n\x0bregex_match\x18\x04 \x01(\t\"\xfc\x03\n/ComputeUrlMapXPathMatcherXRouteRulesXMatchRules\x12\x17\n\x0f\x66ull_path_match\x18\x01 \x01(\t\x12\x13\n\x0bignore_case\x18\x02 \x01(\x08\x12\x14\n\x0cprefix_match\x18\x03 \x01(\t\x12\x13\n\x0bregex_match\x18\x04 \x01(\t\x12r\n\x0eheader_matches\x18\x05 \x03(\x0b\x32Z.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXRouteRulesXMatchRulesXHeaderMatches\x12v\n\x10metadata_filters\x18\x06 \x03(\x0b\x32\\.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXRouteRulesXMatchRulesXMetadataFilters\x12\x83\x01\n\x17query_parameter_matches\x18\x07 \x03(\x0b\x32\x62.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXRouteRulesXMatchRulesXQueryParameterMatches\"\xf6\x01\n;ComputeUrlMapXPathMatcherXRouteRulesXRouteActionXCorsPolicy\x12\x19\n\x11\x61llow_credentials\x18\x01 \x01(\x08\x12\x15\n\rallow_headers\x18\x02 \x03(\t\x12\x15\n\rallow_methods\x18\x03 \x03(\t\x12\x1c\n\x14\x61llow_origin_regexes\x18\x04 \x03(\t\x12\x15\n\rallow_origins\x18\x05 \x03(\t\x12\x10\n\x08\x64isabled\x18\x06 \x01(\x08\x12\x16\n\x0e\x65xpose_headers\x18\x07 \x03(\t\x12\x0f\n\x07max_age\x18\x08 \x01(\x01\"v\nKComputeUrlMapXPathMatcherXRouteRulesXRouteActionXFaultInjectionPolicyXAbort\x12\x13\n\x0bhttp_status\x18\x01 \x01(\x01\x12\x12\n\npercentage\x18\x02 \x01(\x01\"x\nVComputeUrlMapXPathMatcherXRouteRulesXRouteActionXFaultInjectionPolicyXDelayXFixedDelay\x12\r\n\x05nanos\x18\x01 \x01(\x01\x12\x0f\n\x07seconds\x18\x02 \x01(\t\"\xec\x01\nKComputeUrlMapXPathMatcherXRouteRulesXRouteActionXFaultInjectionPolicyXDelay\x12\x12\n\npercentage\x18\x01 \x01(\x01\x12\x88\x01\n\x0b\x66ixed_delay\x18\x02 \x01(\x0b\x32s.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXRouteRulesXRouteActionXFaultInjectionPolicyXDelayXFixedDelay\"\xb9\x02\nEComputeUrlMapXPathMatcherXRouteRulesXRouteActionXFaultInjectionPolicy\x12w\n\x05\x61\x62ort\x18\x01 \x01(\x0b\x32h.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXRouteRulesXRouteActionXFaultInjectionPolicyXAbort\x12w\n\x05\x64\x65lay\x18\x02 \x01(\x0b\x32h.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXRouteRulesXRouteActionXFaultInjectionPolicyXDelay\"_\nDComputeUrlMapXPathMatcherXRouteRulesXRouteActionXRequestMirrorPolicy\x12\x17\n\x0f\x62\x61\x63kend_service\x18\x01 \x01(\t\"l\nJComputeUrlMapXPathMatcherXRouteRulesXRouteActionXRetryPolicyXPerTryTimeout\x12\r\n\x05nanos\x18\x01 \x01(\x01\x12\x0f\n\x07seconds\x18\x02 \x01(\t\"\xf0\x01\n<ComputeUrlMapXPathMatcherXRouteRulesXRouteActionXRetryPolicy\x12\x13\n\x0bnum_retries\x18\x01 \x01(\x01\x12\x18\n\x10retry_conditions\x18\x02 \x03(\t\x12\x80\x01\n\x0fper_try_timeout\x18\x03 \x01(\x0b\x32g.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXRouteRulesXRouteActionXRetryPolicyXPerTryTimeout\"Z\n8ComputeUrlMapXPathMatcherXRouteRulesXRouteActionXTimeout\x12\r\n\x05nanos\x18\x01 \x01(\x01\x12\x0f\n\x07seconds\x18\x02 \x01(\t\"p\n;ComputeUrlMapXPathMatcherXRouteRulesXRouteActionXUrlRewrite\x12\x14\n\x0chost_rewrite\x18\x01 \x01(\t\x12\x1b\n\x13path_prefix_rewrite\x18\x02 \x01(\t\"\xa7\x01\niComputeUrlMapXPathMatcherXRouteRulesXRouteActionXWeightedBackendServicesXHeaderActionXRequestHeadersToAdd\x12\x13\n\x0bheader_name\x18\x01 \x01(\t\x12\x14\n\x0cheader_value\x18\x02 \x01(\t\x12\x0f\n\x07replace\x18\x03 \x01(\x08\"\xa8\x01\njComputeUrlMapXPathMatcherXRouteRulesXRouteActionXWeightedBackendServicesXHeaderActionXResponseHeadersToAdd\x12\x13\n\x0bheader_name\x18\x01 \x01(\t\x12\x14\n\x0cheader_value\x18\x02 \x01(\t\x12\x0f\n\x07replace\x18\x03 \x01(\x08\"\xf4\x03\nUComputeUrlMapXPathMatcherXRouteRulesXRouteActionXWeightedBackendServicesXHeaderAction\x12!\n\x19request_headers_to_remove\x18\x01 \x03(\t\x12\"\n\x1aresponse_headers_to_remove\x18\x02 \x03(\t\x12\xa7\x01\n\x16request_headers_to_add\x18\x03 \x03(\x0b\x32\x86\x01.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXRouteRulesXRouteActionXWeightedBackendServicesXHeaderActionXRequestHeadersToAdd\x12\xa9\x01\n\x17response_headers_to_add\x18\x04 \x03(\x0b\x32\x87\x01.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXRouteRulesXRouteActionXWeightedBackendServicesXHeaderActionXResponseHeadersToAdd\"\xff\x01\nHComputeUrlMapXPathMatcherXRouteRulesXRouteActionXWeightedBackendServices\x12\x17\n\x0f\x62\x61\x63kend_service\x18\x01 \x01(\t\x12\x0e\n\x06weight\x18\x02 \x01(\x01\x12\x89\x01\n\rheader_action\x18\x03 \x01(\x0b\x32r.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXRouteRulesXRouteActionXWeightedBackendServicesXHeaderAction\"\xfc\x06\n0ComputeUrlMapXPathMatcherXRouteRulesXRouteAction\x12m\n\x0b\x63ors_policy\x18\x01 \x01(\x0b\x32X.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXRouteRulesXRouteActionXCorsPolicy\x12\x82\x01\n\x16\x66\x61ult_injection_policy\x18\x02 \x01(\x0b\x32\x62.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXRouteRulesXRouteActionXFaultInjectionPolicy\x12\x80\x01\n\x15request_mirror_policy\x18\x03 \x01(\x0b\x32\x61.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXRouteRulesXRouteActionXRequestMirrorPolicy\x12o\n\x0cretry_policy\x18\x04 \x01(\x0b\x32Y.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXRouteRulesXRouteActionXRetryPolicy\x12\x66\n\x07timeout\x18\x05 \x01(\x0b\x32U.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXRouteRulesXRouteActionXTimeout\x12m\n\x0burl_rewrite\x18\x06 \x01(\x0b\x32X.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXRouteRulesXRouteActionXUrlRewrite\x12\x88\x01\n\x19weighted_backend_services\x18\x07 \x03(\x0b\x32\x65.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXRouteRulesXRouteActionXWeightedBackendServices\"\xc6\x01\n0ComputeUrlMapXPathMatcherXRouteRulesXUrlRedirect\x12\x15\n\rhost_redirect\x18\x01 \x01(\t\x12\x16\n\x0ehttps_redirect\x18\x02 \x01(\x08\x12\x15\n\rpath_redirect\x18\x03 \x01(\t\x12\x17\n\x0fprefix_redirect\x18\x04 \x01(\t\x12\x1e\n\x16redirect_response_code\x18\x05 \x01(\t\x12\x13\n\x0bstrip_query\x18\x06 \x01(\x08\"\xdd\x03\n$ComputeUrlMapXPathMatcherXRouteRules\x12\x10\n\x08priority\x18\x01 \x01(\x01\x12\x0f\n\x07service\x18\x02 \x01(\t\x12\x65\n\rheader_action\x18\x03 \x01(\x0b\x32N.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXRouteRulesXHeaderAction\x12\x61\n\x0bmatch_rules\x18\x04 \x03(\x0b\x32L.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXRouteRulesXMatchRules\x12\x63\n\x0croute_action\x18\x05 \x01(\x0b\x32M.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXRouteRulesXRouteAction\x12\x63\n\x0curl_redirect\x18\x06 \x01(\x0b\x32M.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXRouteRulesXUrlRedirect\"\xb1\x04\n\x19\x43omputeUrlMapXPathMatcher\x12\x17\n\x0f\x64\x65\x66\x61ult_service\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12g\n\x14\x64\x65\x66\x61ult_route_action\x18\x04 \x01(\x0b\x32I.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXDefaultRouteAction\x12g\n\x14\x64\x65\x66\x61ult_url_redirect\x18\x05 \x01(\x0b\x32I.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXDefaultUrlRedirect\x12Z\n\rheader_action\x18\x06 \x01(\x0b\x32\x43.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXHeaderAction\x12R\n\tpath_rule\x18\x07 \x03(\x0b\x32?.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXPathRule\x12V\n\x0broute_rules\x18\x08 \x03(\x0b\x32\x41.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXRouteRules\"V\n\x12\x43omputeUrlMapXTest\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x0c\n\x04host\x18\x02 \x01(\t\x12\x0c\n\x04path\x18\x03 \x01(\t\x12\x0f\n\x07service\x18\x04 \x01(\t\"H\n\x16\x43omputeUrlMapXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\x9b\x06\n\rComputeUrlMap\x12\x1a\n\x12\x63reation_timestamp\x18\x01 \x01(\t\x12\x17\n\x0f\x64\x65\x66\x61ult_service\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x13\n\x0b\x66ingerprint\x18\x04 \x01(\t\x12\n\n\x02id\x18\x05 \x01(\t\x12\x0e\n\x06map_id\x18\x06 \x01(\x01\x12\x0c\n\x04name\x18\x07 \x01(\t\x12\x0f\n\x07project\x18\x08 \x01(\t\x12\x11\n\tself_link\x18\t \x01(\t\x12[\n\x14\x64\x65\x66\x61ult_route_action\x18\n \x01(\x0b\x32=.oak9.tython.gcp.compute_url.ComputeUrlMapXDefaultRouteAction\x12[\n\x14\x64\x65\x66\x61ult_url_redirect\x18\x0b \x01(\x0b\x32=.oak9.tython.gcp.compute_url.ComputeUrlMapXDefaultUrlRedirect\x12N\n\rheader_action\x18\x0c \x01(\x0b\x32\x37.oak9.tython.gcp.compute_url.ComputeUrlMapXHeaderAction\x12\x46\n\thost_rule\x18\r \x03(\x0b\x32\x33.oak9.tython.gcp.compute_url.ComputeUrlMapXHostRule\x12L\n\x0cpath_matcher\x18\x0e \x03(\x0b\x32\x36.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcher\x12=\n\x04test\x18\x0f \x03(\x0b\x32/.oak9.tython.gcp.compute_url.ComputeUrlMapXTest\x12\x45\n\x08timeouts\x18\x10 \x01(\x0b\x32\x33.oak9.tython.gcp.compute_url.ComputeUrlMapXTimeouts\x12\x37\n\rresource_info\x18\x11 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_compute_url_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMPUTEURLMAPXDEFAULTROUTEACTIONXCORSPOLICY._serialized_start=80
  _COMPUTEURLMAPXDEFAULTROUTEACTIONXCORSPOLICY._serialized_end=310
  _COMPUTEURLMAPXDEFAULTROUTEACTIONXFAULTINJECTIONPOLICYXABORT._serialized_start=312
  _COMPUTEURLMAPXDEFAULTROUTEACTIONXFAULTINJECTIONPOLICYXABORT._serialized_end=414
  _COMPUTEURLMAPXDEFAULTROUTEACTIONXFAULTINJECTIONPOLICYXDELAYXFIXEDDELAY._serialized_start=416
  _COMPUTEURLMAPXDEFAULTROUTEACTIONXFAULTINJECTIONPOLICYXDELAYXFIXEDDELAY._serialized_end=520
  _COMPUTEURLMAPXDEFAULTROUTEACTIONXFAULTINJECTIONPOLICYXDELAY._serialized_start=523
  _COMPUTEURLMAPXDEFAULTROUTEACTIONXFAULTINJECTIONPOLICYXDELAY._serialized_end=726
  _COMPUTEURLMAPXDEFAULTROUTEACTIONXFAULTINJECTIONPOLICY._serialized_start=729
  _COMPUTEURLMAPXDEFAULTROUTEACTIONXFAULTINJECTIONPOLICY._serialized_end=994
  _COMPUTEURLMAPXDEFAULTROUTEACTIONXREQUESTMIRRORPOLICY._serialized_start=996
  _COMPUTEURLMAPXDEFAULTROUTEACTIONXREQUESTMIRRORPOLICY._serialized_end=1075
  _COMPUTEURLMAPXDEFAULTROUTEACTIONXRETRYPOLICYXPERTRYTIMEOUT._serialized_start=1077
  _COMPUTEURLMAPXDEFAULTROUTEACTIONXRETRYPOLICYXPERTRYTIMEOUT._serialized_end=1169
  _COMPUTEURLMAPXDEFAULTROUTEACTIONXRETRYPOLICY._serialized_start=1172
  _COMPUTEURLMAPXDEFAULTROUTEACTIONXRETRYPOLICY._serialized_end=1379
  _COMPUTEURLMAPXDEFAULTROUTEACTIONXTIMEOUT._serialized_start=1381
  _COMPUTEURLMAPXDEFAULTROUTEACTIONXTIMEOUT._serialized_end=1455
  _COMPUTEURLMAPXDEFAULTROUTEACTIONXURLREWRITE._serialized_start=1457
  _COMPUTEURLMAPXDEFAULTROUTEACTIONXURLREWRITE._serialized_end=1553
  _COMPUTEURLMAPXDEFAULTROUTEACTIONXWEIGHTEDBACKENDSERVICESXHEADERACTIONXREQUESTHEADERSTOADD._serialized_start=1556
  _COMPUTEURLMAPXDEFAULTROUTEACTIONXWEIGHTEDBACKENDSERVICESXHEADERACTIONXREQUESTHEADERSTOADD._serialized_end=1707
  _COMPUTEURLMAPXDEFAULTROUTEACTIONXWEIGHTEDBACKENDSERVICESXHEADERACTIONXRESPONSEHEADERSTOADD._serialized_start=1710
  _COMPUTEURLMAPXDEFAULTROUTEACTIONXWEIGHTEDBACKENDSERVICESXHEADERACTIONXRESPONSEHEADERSTOADD._serialized_end=1862
  _COMPUTEURLMAPXDEFAULTROUTEACTIONXWEIGHTEDBACKENDSERVICESXHEADERACTION._serialized_start=1865
  _COMPUTEURLMAPXDEFAULTROUTEACTIONXWEIGHTEDBACKENDSERVICESXHEADERACTION._serialized_end=2315
  _COMPUTEURLMAPXDEFAULTROUTEACTIONXWEIGHTEDBACKENDSERVICES._serialized_start=2318
  _COMPUTEURLMAPXDEFAULTROUTEACTIONXWEIGHTEDBACKENDSERVICES._serialized_end=2540
  _COMPUTEURLMAPXDEFAULTROUTEACTION._serialized_start=2543
  _COMPUTEURLMAPXDEFAULTROUTEACTION._serialized_end=3304
  _COMPUTEURLMAPXDEFAULTURLREDIRECT._serialized_start=3307
  _COMPUTEURLMAPXDEFAULTURLREDIRECT._serialized_end=3489
  _COMPUTEURLMAPXHEADERACTIONXREQUESTHEADERSTOADD._serialized_start=3491
  _COMPUTEURLMAPXHEADERACTIONXREQUESTHEADERSTOADD._serialized_end=3599
  _COMPUTEURLMAPXHEADERACTIONXRESPONSEHEADERSTOADD._serialized_start=3601
  _COMPUTEURLMAPXHEADERACTIONXRESPONSEHEADERSTOADD._serialized_end=3710
  _COMPUTEURLMAPXHEADERACTION._serialized_start=3713
  _COMPUTEURLMAPXHEADERACTION._serialized_end=4032
  _COMPUTEURLMAPXHOSTRULE._serialized_start=4034
  _COMPUTEURLMAPXHOSTRULE._serialized_end=4116
  _COMPUTEURLMAPXPATHMATCHERXDEFAULTROUTEACTIONXCORSPOLICY._serialized_start=4119
  _COMPUTEURLMAPXPATHMATCHERXDEFAULTROUTEACTIONXCORSPOLICY._serialized_end=4361
  _COMPUTEURLMAPXPATHMATCHERXDEFAULTROUTEACTIONXFAULTINJECTIONPOLICYXABORT._serialized_start=4363
  _COMPUTEURLMAPXPATHMATCHERXDEFAULTROUTEACTIONXFAULTINJECTIONPOLICYXABORT._serialized_end=4477
  _COMPUTEURLMAPXPATHMATCHERXDEFAULTROUTEACTIONXFAULTINJECTIONPOLICYXDELAYXFIXEDDELAY._serialized_start=4479
  _COMPUTEURLMAPXPATHMATCHERXDEFAULTROUTEACTIONXFAULTINJECTIONPOLICYXDELAYXFIXEDDELAY._serialized_end=4595
  _COMPUTEURLMAPXPATHMATCHERXDEFAULTROUTEACTIONXFAULTINJECTIONPOLICYXDELAY._serialized_start=4598
  _COMPUTEURLMAPXPATHMATCHERXDEFAULTROUTEACTIONXFAULTINJECTIONPOLICYXDELAY._serialized_end=4826
  _COMPUTEURLMAPXPATHMATCHERXDEFAULTROUTEACTIONXFAULTINJECTIONPOLICY._serialized_start=4829
  _COMPUTEURLMAPXPATHMATCHERXDEFAULTROUTEACTIONXFAULTINJECTIONPOLICY._serialized_end=5130
  _COMPUTEURLMAPXPATHMATCHERXDEFAULTROUTEACTIONXREQUESTMIRRORPOLICY._serialized_start=5132
  _COMPUTEURLMAPXPATHMATCHERXDEFAULTROUTEACTIONXREQUESTMIRRORPOLICY._serialized_end=5223
  _COMPUTEURLMAPXPATHMATCHERXDEFAULTROUTEACTIONXRETRYPOLICYXPERTRYTIMEOUT._serialized_start=5225
  _COMPUTEURLMAPXPATHMATCHERXDEFAULTROUTEACTIONXRETRYPOLICYXPERTRYTIMEOUT._serialized_end=5329
  _COMPUTEURLMAPXPATHMATCHERXDEFAULTROUTEACTIONXRETRYPOLICY._serialized_start=5332
  _COMPUTEURLMAPXPATHMATCHERXDEFAULTROUTEACTIONXRETRYPOLICY._serialized_end=5563
  _COMPUTEURLMAPXPATHMATCHERXDEFAULTROUTEACTIONXTIMEOUT._serialized_start=5565
  _COMPUTEURLMAPXPATHMATCHERXDEFAULTROUTEACTIONXTIMEOUT._serialized_end=5651
  _COMPUTEURLMAPXPATHMATCHERXDEFAULTROUTEACTIONXURLREWRITE._serialized_start=5653
  _COMPUTEURLMAPXPATHMATCHERXDEFAULTROUTEACTIONXURLREWRITE._serialized_end=5761
  _COMPUTEURLMAPXPATHMATCHERXDEFAULTROUTEACTIONXWEIGHTEDBACKENDSERVICESXHEADERACTIONXREQUESTHEADERSTOADD._serialized_start=5764
  _COMPUTEURLMAPXPATHMATCHERXDEFAULTROUTEACTIONXWEIGHTEDBACKENDSERVICESXHEADERACTIONXREQUESTHEADERSTOADD._serialized_end=5927
  _COMPUTEURLMAPXPATHMATCHERXDEFAULTROUTEACTIONXWEIGHTEDBACKENDSERVICESXHEADERACTIONXRESPONSEHEADERSTOADD._serialized_start=5930
  _COMPUTEURLMAPXPATHMATCHERXDEFAULTROUTEACTIONXWEIGHTEDBACKENDSERVICESXHEADERACTIONXRESPONSEHEADERSTOADD._serialized_end=6094
  _COMPUTEURLMAPXPATHMATCHERXDEFAULTROUTEACTIONXWEIGHTEDBACKENDSERVICESXHEADERACTION._serialized_start=6097
  _COMPUTEURLMAPXPATHMATCHERXDEFAULTROUTEACTIONXWEIGHTEDBACKENDSERVICESXHEADERACTION._serialized_end=6585
  _COMPUTEURLMAPXPATHMATCHERXDEFAULTROUTEACTIONXWEIGHTEDBACKENDSERVICES._serialized_start=6588
  _COMPUTEURLMAPXPATHMATCHERXDEFAULTROUTEACTIONXWEIGHTEDBACKENDSERVICES._serialized_end=6835
  _COMPUTEURLMAPXPATHMATCHERXDEFAULTROUTEACTION._serialized_start=6838
  _COMPUTEURLMAPXPATHMATCHERXDEFAULTROUTEACTION._serialized_end=7696
  _COMPUTEURLMAPXPATHMATCHERXDEFAULTURLREDIRECT._serialized_start=7699
  _COMPUTEURLMAPXPATHMATCHERXDEFAULTURLREDIRECT._serialized_end=7893
  _COMPUTEURLMAPXPATHMATCHERXHEADERACTIONXREQUESTHEADERSTOADD._serialized_start=7895
  _COMPUTEURLMAPXPATHMATCHERXHEADERACTIONXREQUESTHEADERSTOADD._serialized_end=8015
  _COMPUTEURLMAPXPATHMATCHERXHEADERACTIONXRESPONSEHEADERSTOADD._serialized_start=8017
  _COMPUTEURLMAPXPATHMATCHERXHEADERACTIONXRESPONSEHEADERSTOADD._serialized_end=8138
  _COMPUTEURLMAPXPATHMATCHERXHEADERACTION._serialized_start=8141
  _COMPUTEURLMAPXPATHMATCHERXHEADERACTION._serialized_end=8496
  _COMPUTEURLMAPXPATHMATCHERXPATHRULEXROUTEACTIONXCORSPOLICY._serialized_start=8499
  _COMPUTEURLMAPXPATHMATCHERXPATHRULEXROUTEACTIONXCORSPOLICY._serialized_end=8743
  _COMPUTEURLMAPXPATHMATCHERXPATHRULEXROUTEACTIONXFAULTINJECTIONPOLICYXABORT._serialized_start=8745
  _COMPUTEURLMAPXPATHMATCHERXPATHRULEXROUTEACTIONXFAULTINJECTIONPOLICYXABORT._serialized_end=8861
  _COMPUTEURLMAPXPATHMATCHERXPATHRULEXROUTEACTIONXFAULTINJECTIONPOLICYXDELAYXFIXEDDELAY._serialized_start=8863
  _COMPUTEURLMAPXPATHMATCHERXPATHRULEXROUTEACTIONXFAULTINJECTIONPOLICYXDELAYXFIXEDDELAY._serialized_end=8981
  _COMPUTEURLMAPXPATHMATCHERXPATHRULEXROUTEACTIONXFAULTINJECTIONPOLICYXDELAY._serialized_start=8984
  _COMPUTEURLMAPXPATHMATCHERXPATHRULEXROUTEACTIONXFAULTINJECTIONPOLICYXDELAY._serialized_end=9216
  _COMPUTEURLMAPXPATHMATCHERXPATHRULEXROUTEACTIONXFAULTINJECTIONPOLICY._serialized_start=9219
  _COMPUTEURLMAPXPATHMATCHERXPATHRULEXROUTEACTIONXFAULTINJECTIONPOLICY._serialized_end=9526
  _COMPUTEURLMAPXPATHMATCHERXPATHRULEXROUTEACTIONXREQUESTMIRRORPOLICY._serialized_start=9528
  _COMPUTEURLMAPXPATHMATCHERXPATHRULEXROUTEACTIONXREQUESTMIRRORPOLICY._serialized_end=9621
  _COMPUTEURLMAPXPATHMATCHERXPATHRULEXROUTEACTIONXRETRYPOLICYXPERTRYTIMEOUT._serialized_start=9623
  _COMPUTEURLMAPXPATHMATCHERXPATHRULEXROUTEACTIONXRETRYPOLICYXPERTRYTIMEOUT._serialized_end=9729
  _COMPUTEURLMAPXPATHMATCHERXPATHRULEXROUTEACTIONXRETRYPOLICY._serialized_start=9732
  _COMPUTEURLMAPXPATHMATCHERXPATHRULEXROUTEACTIONXRETRYPOLICY._serialized_end=9967
  _COMPUTEURLMAPXPATHMATCHERXPATHRULEXROUTEACTIONXTIMEOUT._serialized_start=9969
  _COMPUTEURLMAPXPATHMATCHERXPATHRULEXROUTEACTIONXTIMEOUT._serialized_end=10057
  _COMPUTEURLMAPXPATHMATCHERXPATHRULEXROUTEACTIONXURLREWRITE._serialized_start=10059
  _COMPUTEURLMAPXPATHMATCHERXPATHRULEXROUTEACTIONXURLREWRITE._serialized_end=10169
  _COMPUTEURLMAPXPATHMATCHERXPATHRULEXROUTEACTIONXWEIGHTEDBACKENDSERVICESXHEADERACTIONXREQUESTHEADERSTOADD._serialized_start=10172
  _COMPUTEURLMAPXPATHMATCHERXPATHRULEXROUTEACTIONXWEIGHTEDBACKENDSERVICESXHEADERACTIONXREQUESTHEADERSTOADD._serialized_end=10337
  _COMPUTEURLMAPXPATHMATCHERXPATHRULEXROUTEACTIONXWEIGHTEDBACKENDSERVICESXHEADERACTIONXRESPONSEHEADERSTOADD._serialized_start=10340
  _COMPUTEURLMAPXPATHMATCHERXPATHRULEXROUTEACTIONXWEIGHTEDBACKENDSERVICESXHEADERACTIONXRESPONSEHEADERSTOADD._serialized_end=10506
  _COMPUTEURLMAPXPATHMATCHERXPATHRULEXROUTEACTIONXWEIGHTEDBACKENDSERVICESXHEADERACTION._serialized_start=10509
  _COMPUTEURLMAPXPATHMATCHERXPATHRULEXROUTEACTIONXWEIGHTEDBACKENDSERVICESXHEADERACTION._serialized_end=11003
  _COMPUTEURLMAPXPATHMATCHERXPATHRULEXROUTEACTIONXWEIGHTEDBACKENDSERVICES._serialized_start=11006
  _COMPUTEURLMAPXPATHMATCHERXPATHRULEXROUTEACTIONXWEIGHTEDBACKENDSERVICES._serialized_end=11257
  _COMPUTEURLMAPXPATHMATCHERXPATHRULEXROUTEACTION._serialized_start=11260
  _COMPUTEURLMAPXPATHMATCHERXPATHRULEXROUTEACTION._serialized_end=12135
  _COMPUTEURLMAPXPATHMATCHERXPATHRULEXURLREDIRECT._serialized_start=12138
  _COMPUTEURLMAPXPATHMATCHERXPATHRULEXURLREDIRECT._serialized_end=12334
  _COMPUTEURLMAPXPATHMATCHERXPATHRULE._serialized_start=12337
  _COMPUTEURLMAPXPATHMATCHERXPATHRULE._serialized_end=12603
  _COMPUTEURLMAPXPATHMATCHERXROUTERULESXHEADERACTIONXREQUESTHEADERSTOADD._serialized_start=12606
  _COMPUTEURLMAPXPATHMATCHERXROUTERULESXHEADERACTIONXREQUESTHEADERSTOADD._serialized_end=12737
  _COMPUTEURLMAPXPATHMATCHERXROUTERULESXHEADERACTIONXRESPONSEHEADERSTOADD._serialized_start=12740
  _COMPUTEURLMAPXPATHMATCHERXROUTERULESXHEADERACTIONXRESPONSEHEADERSTOADD._serialized_end=12872
  _COMPUTEURLMAPXPATHMATCHERXROUTERULESXHEADERACTION._serialized_start=12875
  _COMPUTEURLMAPXPATHMATCHERXROUTERULESXHEADERACTION._serialized_end=13265
  _COMPUTEURLMAPXPATHMATCHERXROUTERULESXMATCHRULESXHEADERMATCHESXRANGEMATCH._serialized_start=13267
  _COMPUTEURLMAPXPATHMATCHERXROUTERULESXMATCHRULESXHEADERMATCHESXRANGEMATCH._serialized_end=13381
  _COMPUTEURLMAPXPATHMATCHERXROUTERULESXMATCHRULESXHEADERMATCHES._serialized_start=13384
  _COMPUTEURLMAPXPATHMATCHERXROUTERULESXMATCHRULESXHEADERMATCHES._serialized_end=13723
  _COMPUTEURLMAPXPATHMATCHERXROUTERULESXMATCHRULESXMETADATAFILTERSXFILTERLABELS._serialized_start=13725
  _COMPUTEURLMAPXPATHMATCHERXROUTERULESXMATCHRULESXMETADATAFILTERSXFILTERLABELS._serialized_end=13832
  _COMPUTEURLMAPXPATHMATCHERXROUTERULESXMATCHRULESXMETADATAFILTERS._serialized_start=13835
  _COMPUTEURLMAPXPATHMATCHERXROUTERULESXMATCHRULESXMETADATAFILTERS._serialized_end=14062
  _COMPUTEURLMAPXPATHMATCHERXROUTERULESXMATCHRULESXQUERYPARAMETERMATCHES._serialized_start=14065
  _COMPUTEURLMAPXPATHMATCHERXROUTERULESXMATCHRULESXQUERYPARAMETERMATCHES._serialized_end=14215
  _COMPUTEURLMAPXPATHMATCHERXROUTERULESXMATCHRULES._serialized_start=14218
  _COMPUTEURLMAPXPATHMATCHERXROUTERULESXMATCHRULES._serialized_end=14726
  _COMPUTEURLMAPXPATHMATCHERXROUTERULESXROUTEACTIONXCORSPOLICY._serialized_start=14729
  _COMPUTEURLMAPXPATHMATCHERXROUTERULESXROUTEACTIONXCORSPOLICY._serialized_end=14975
  _COMPUTEURLMAPXPATHMATCHERXROUTERULESXROUTEACTIONXFAULTINJECTIONPOLICYXABORT._serialized_start=14977
  _COMPUTEURLMAPXPATHMATCHERXROUTERULESXROUTEACTIONXFAULTINJECTIONPOLICYXABORT._serialized_end=15095
  _COMPUTEURLMAPXPATHMATCHERXROUTERULESXROUTEACTIONXFAULTINJECTIONPOLICYXDELAYXFIXEDDELAY._serialized_start=15097
  _COMPUTEURLMAPXPATHMATCHERXROUTERULESXROUTEACTIONXFAULTINJECTIONPOLICYXDELAYXFIXEDDELAY._serialized_end=15217
  _COMPUTEURLMAPXPATHMATCHERXROUTERULESXROUTEACTIONXFAULTINJECTIONPOLICYXDELAY._serialized_start=15220
  _COMPUTEURLMAPXPATHMATCHERXROUTERULESXROUTEACTIONXFAULTINJECTIONPOLICYXDELAY._serialized_end=15456
  _COMPUTEURLMAPXPATHMATCHERXROUTERULESXROUTEACTIONXFAULTINJECTIONPOLICY._serialized_start=15459
  _COMPUTEURLMAPXPATHMATCHERXROUTERULESXROUTEACTIONXFAULTINJECTIONPOLICY._serialized_end=15772
  _COMPUTEURLMAPXPATHMATCHERXROUTERULESXROUTEACTIONXREQUESTMIRRORPOLICY._serialized_start=15774
  _COMPUTEURLMAPXPATHMATCHERXROUTERULESXROUTEACTIONXREQUESTMIRRORPOLICY._serialized_end=15869
  _COMPUTEURLMAPXPATHMATCHERXROUTERULESXROUTEACTIONXRETRYPOLICYXPERTRYTIMEOUT._serialized_start=15871
  _COMPUTEURLMAPXPATHMATCHERXROUTERULESXROUTEACTIONXRETRYPOLICYXPERTRYTIMEOUT._serialized_end=15979
  _COMPUTEURLMAPXPATHMATCHERXROUTERULESXROUTEACTIONXRETRYPOLICY._serialized_start=15982
  _COMPUTEURLMAPXPATHMATCHERXROUTERULESXROUTEACTIONXRETRYPOLICY._serialized_end=16222
  _COMPUTEURLMAPXPATHMATCHERXROUTERULESXROUTEACTIONXTIMEOUT._serialized_start=16224
  _COMPUTEURLMAPXPATHMATCHERXROUTERULESXROUTEACTIONXTIMEOUT._serialized_end=16314
  _COMPUTEURLMAPXPATHMATCHERXROUTERULESXROUTEACTIONXURLREWRITE._serialized_start=16316
  _COMPUTEURLMAPXPATHMATCHERXROUTERULESXROUTEACTIONXURLREWRITE._serialized_end=16428
  _COMPUTEURLMAPXPATHMATCHERXROUTERULESXROUTEACTIONXWEIGHTEDBACKENDSERVICESXHEADERACTIONXREQUESTHEADERSTOADD._serialized_start=16431
  _COMPUTEURLMAPXPATHMATCHERXROUTERULESXROUTEACTIONXWEIGHTEDBACKENDSERVICESXHEADERACTIONXREQUESTHEADERSTOADD._serialized_end=16598
  _COMPUTEURLMAPXPATHMATCHERXROUTERULESXROUTEACTIONXWEIGHTEDBACKENDSERVICESXHEADERACTIONXRESPONSEHEADERSTOADD._serialized_start=16601
  _COMPUTEURLMAPXPATHMATCHERXROUTERULESXROUTEACTIONXWEIGHTEDBACKENDSERVICESXHEADERACTIONXRESPONSEHEADERSTOADD._serialized_end=16769
  _COMPUTEURLMAPXPATHMATCHERXROUTERULESXROUTEACTIONXWEIGHTEDBACKENDSERVICESXHEADERACTION._serialized_start=16772
  _COMPUTEURLMAPXPATHMATCHERXROUTERULESXROUTEACTIONXWEIGHTEDBACKENDSERVICESXHEADERACTION._serialized_end=17272
  _COMPUTEURLMAPXPATHMATCHERXROUTERULESXROUTEACTIONXWEIGHTEDBACKENDSERVICES._serialized_start=17275
  _COMPUTEURLMAPXPATHMATCHERXROUTERULESXROUTEACTIONXWEIGHTEDBACKENDSERVICES._serialized_end=17530
  _COMPUTEURLMAPXPATHMATCHERXROUTERULESXROUTEACTION._serialized_start=17533
  _COMPUTEURLMAPXPATHMATCHERXROUTERULESXROUTEACTION._serialized_end=18425
  _COMPUTEURLMAPXPATHMATCHERXROUTERULESXURLREDIRECT._serialized_start=18428
  _COMPUTEURLMAPXPATHMATCHERXROUTERULESXURLREDIRECT._serialized_end=18626
  _COMPUTEURLMAPXPATHMATCHERXROUTERULES._serialized_start=18629
  _COMPUTEURLMAPXPATHMATCHERXROUTERULES._serialized_end=19106
  _COMPUTEURLMAPXPATHMATCHER._serialized_start=19109
  _COMPUTEURLMAPXPATHMATCHER._serialized_end=19670
  _COMPUTEURLMAPXTEST._serialized_start=19672
  _COMPUTEURLMAPXTEST._serialized_end=19758
  _COMPUTEURLMAPXTIMEOUTS._serialized_start=19760
  _COMPUTEURLMAPXTIMEOUTS._serialized_end=19832
  _COMPUTEURLMAP._serialized_start=19835
  _COMPUTEURLMAP._serialized_end=20630
# @@protoc_insertion_point(module_scope)
