"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ComputeHealthCheckXGrpcHealthCheck(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GRPC_SERVICE_NAME_FIELD_NUMBER: builtins.int
    PORT_FIELD_NUMBER: builtins.int
    PORT_NAME_FIELD_NUMBER: builtins.int
    PORT_SPECIFICATION_FIELD_NUMBER: builtins.int
    grpc_service_name: builtins.str
    port: builtins.float
    port_name: builtins.str
    port_specification: builtins.str
    def __init__(
        self,
        *,
        grpc_service_name: builtins.str = ...,
        port: builtins.float = ...,
        port_name: builtins.str = ...,
        port_specification: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["grpc_service_name", b"grpc_service_name", "port", b"port", "port_name", b"port_name", "port_specification", b"port_specification"]) -> None: ...

global___ComputeHealthCheckXGrpcHealthCheck = ComputeHealthCheckXGrpcHealthCheck

@typing_extensions.final
class ComputeHealthCheckXHttp2HealthCheck(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOST_FIELD_NUMBER: builtins.int
    PORT_FIELD_NUMBER: builtins.int
    PORT_NAME_FIELD_NUMBER: builtins.int
    PORT_SPECIFICATION_FIELD_NUMBER: builtins.int
    PROXY_HEADER_FIELD_NUMBER: builtins.int
    REQUEST_PATH_FIELD_NUMBER: builtins.int
    RESPONSE_FIELD_NUMBER: builtins.int
    host: builtins.str
    port: builtins.float
    port_name: builtins.str
    port_specification: builtins.str
    proxy_header: builtins.str
    request_path: builtins.str
    response: builtins.str
    def __init__(
        self,
        *,
        host: builtins.str = ...,
        port: builtins.float = ...,
        port_name: builtins.str = ...,
        port_specification: builtins.str = ...,
        proxy_header: builtins.str = ...,
        request_path: builtins.str = ...,
        response: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["host", b"host", "port", b"port", "port_name", b"port_name", "port_specification", b"port_specification", "proxy_header", b"proxy_header", "request_path", b"request_path", "response", b"response"]) -> None: ...

global___ComputeHealthCheckXHttp2HealthCheck = ComputeHealthCheckXHttp2HealthCheck

@typing_extensions.final
class ComputeHealthCheckXHttpHealthCheck(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOST_FIELD_NUMBER: builtins.int
    PORT_FIELD_NUMBER: builtins.int
    PORT_NAME_FIELD_NUMBER: builtins.int
    PORT_SPECIFICATION_FIELD_NUMBER: builtins.int
    PROXY_HEADER_FIELD_NUMBER: builtins.int
    REQUEST_PATH_FIELD_NUMBER: builtins.int
    RESPONSE_FIELD_NUMBER: builtins.int
    host: builtins.str
    port: builtins.float
    port_name: builtins.str
    port_specification: builtins.str
    proxy_header: builtins.str
    request_path: builtins.str
    response: builtins.str
    def __init__(
        self,
        *,
        host: builtins.str = ...,
        port: builtins.float = ...,
        port_name: builtins.str = ...,
        port_specification: builtins.str = ...,
        proxy_header: builtins.str = ...,
        request_path: builtins.str = ...,
        response: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["host", b"host", "port", b"port", "port_name", b"port_name", "port_specification", b"port_specification", "proxy_header", b"proxy_header", "request_path", b"request_path", "response", b"response"]) -> None: ...

global___ComputeHealthCheckXHttpHealthCheck = ComputeHealthCheckXHttpHealthCheck

@typing_extensions.final
class ComputeHealthCheckXHttpsHealthCheck(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOST_FIELD_NUMBER: builtins.int
    PORT_FIELD_NUMBER: builtins.int
    PORT_NAME_FIELD_NUMBER: builtins.int
    PORT_SPECIFICATION_FIELD_NUMBER: builtins.int
    PROXY_HEADER_FIELD_NUMBER: builtins.int
    REQUEST_PATH_FIELD_NUMBER: builtins.int
    RESPONSE_FIELD_NUMBER: builtins.int
    host: builtins.str
    port: builtins.float
    port_name: builtins.str
    port_specification: builtins.str
    proxy_header: builtins.str
    request_path: builtins.str
    response: builtins.str
    def __init__(
        self,
        *,
        host: builtins.str = ...,
        port: builtins.float = ...,
        port_name: builtins.str = ...,
        port_specification: builtins.str = ...,
        proxy_header: builtins.str = ...,
        request_path: builtins.str = ...,
        response: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["host", b"host", "port", b"port", "port_name", b"port_name", "port_specification", b"port_specification", "proxy_header", b"proxy_header", "request_path", b"request_path", "response", b"response"]) -> None: ...

global___ComputeHealthCheckXHttpsHealthCheck = ComputeHealthCheckXHttpsHealthCheck

@typing_extensions.final
class ComputeHealthCheckXLogConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLE_FIELD_NUMBER: builtins.int
    enable: builtins.bool
    def __init__(
        self,
        *,
        enable: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["enable", b"enable"]) -> None: ...

global___ComputeHealthCheckXLogConfig = ComputeHealthCheckXLogConfig

@typing_extensions.final
class ComputeHealthCheckXSslHealthCheck(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PORT_FIELD_NUMBER: builtins.int
    PORT_NAME_FIELD_NUMBER: builtins.int
    PORT_SPECIFICATION_FIELD_NUMBER: builtins.int
    PROXY_HEADER_FIELD_NUMBER: builtins.int
    REQUEST_FIELD_NUMBER: builtins.int
    RESPONSE_FIELD_NUMBER: builtins.int
    port: builtins.float
    port_name: builtins.str
    port_specification: builtins.str
    proxy_header: builtins.str
    request: builtins.str
    response: builtins.str
    def __init__(
        self,
        *,
        port: builtins.float = ...,
        port_name: builtins.str = ...,
        port_specification: builtins.str = ...,
        proxy_header: builtins.str = ...,
        request: builtins.str = ...,
        response: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["port", b"port", "port_name", b"port_name", "port_specification", b"port_specification", "proxy_header", b"proxy_header", "request", b"request", "response", b"response"]) -> None: ...

global___ComputeHealthCheckXSslHealthCheck = ComputeHealthCheckXSslHealthCheck

@typing_extensions.final
class ComputeHealthCheckXTcpHealthCheck(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PORT_FIELD_NUMBER: builtins.int
    PORT_NAME_FIELD_NUMBER: builtins.int
    PORT_SPECIFICATION_FIELD_NUMBER: builtins.int
    PROXY_HEADER_FIELD_NUMBER: builtins.int
    REQUEST_FIELD_NUMBER: builtins.int
    RESPONSE_FIELD_NUMBER: builtins.int
    port: builtins.float
    port_name: builtins.str
    port_specification: builtins.str
    proxy_header: builtins.str
    request: builtins.str
    response: builtins.str
    def __init__(
        self,
        *,
        port: builtins.float = ...,
        port_name: builtins.str = ...,
        port_specification: builtins.str = ...,
        proxy_header: builtins.str = ...,
        request: builtins.str = ...,
        response: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["port", b"port", "port_name", b"port_name", "port_specification", b"port_specification", "proxy_header", b"proxy_header", "request", b"request", "response", b"response"]) -> None: ...

global___ComputeHealthCheckXTcpHealthCheck = ComputeHealthCheckXTcpHealthCheck

@typing_extensions.final
class ComputeHealthCheckXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___ComputeHealthCheckXTimeouts = ComputeHealthCheckXTimeouts

@typing_extensions.final
class ComputeHealthCheck(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHECK_INTERVAL_SEC_FIELD_NUMBER: builtins.int
    CREATION_TIMESTAMP_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    HEALTHY_THRESHOLD_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    SELF_LINK_FIELD_NUMBER: builtins.int
    TIMEOUT_SEC_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    UNHEALTHY_THRESHOLD_FIELD_NUMBER: builtins.int
    GRPC_HEALTH_CHECK_FIELD_NUMBER: builtins.int
    HTTP2_HEALTH_CHECK_FIELD_NUMBER: builtins.int
    HTTP_HEALTH_CHECK_FIELD_NUMBER: builtins.int
    HTTPS_HEALTH_CHECK_FIELD_NUMBER: builtins.int
    LOG_CONFIG_FIELD_NUMBER: builtins.int
    SSL_HEALTH_CHECK_FIELD_NUMBER: builtins.int
    TCP_HEALTH_CHECK_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    check_interval_sec: builtins.float
    creation_timestamp: builtins.str
    description: builtins.str
    healthy_threshold: builtins.float
    id: builtins.str
    name: builtins.str
    project: builtins.str
    self_link: builtins.str
    timeout_sec: builtins.float
    type: builtins.str
    unhealthy_threshold: builtins.float
    @property
    def grpc_health_check(self) -> global___ComputeHealthCheckXGrpcHealthCheck: ...
    @property
    def http2_health_check(self) -> global___ComputeHealthCheckXHttp2HealthCheck: ...
    @property
    def http_health_check(self) -> global___ComputeHealthCheckXHttpHealthCheck: ...
    @property
    def https_health_check(self) -> global___ComputeHealthCheckXHttpsHealthCheck: ...
    @property
    def log_config(self) -> global___ComputeHealthCheckXLogConfig: ...
    @property
    def ssl_health_check(self) -> global___ComputeHealthCheckXSslHealthCheck: ...
    @property
    def tcp_health_check(self) -> global___ComputeHealthCheckXTcpHealthCheck: ...
    @property
    def timeouts(self) -> global___ComputeHealthCheckXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        check_interval_sec: builtins.float = ...,
        creation_timestamp: builtins.str = ...,
        description: builtins.str = ...,
        healthy_threshold: builtins.float = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        self_link: builtins.str = ...,
        timeout_sec: builtins.float = ...,
        type: builtins.str = ...,
        unhealthy_threshold: builtins.float = ...,
        grpc_health_check: global___ComputeHealthCheckXGrpcHealthCheck | None = ...,
        http2_health_check: global___ComputeHealthCheckXHttp2HealthCheck | None = ...,
        http_health_check: global___ComputeHealthCheckXHttpHealthCheck | None = ...,
        https_health_check: global___ComputeHealthCheckXHttpsHealthCheck | None = ...,
        log_config: global___ComputeHealthCheckXLogConfig | None = ...,
        ssl_health_check: global___ComputeHealthCheckXSslHealthCheck | None = ...,
        tcp_health_check: global___ComputeHealthCheckXTcpHealthCheck | None = ...,
        timeouts: global___ComputeHealthCheckXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["grpc_health_check", b"grpc_health_check", "http2_health_check", b"http2_health_check", "http_health_check", b"http_health_check", "https_health_check", b"https_health_check", "log_config", b"log_config", "resource_info", b"resource_info", "ssl_health_check", b"ssl_health_check", "tcp_health_check", b"tcp_health_check", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["check_interval_sec", b"check_interval_sec", "creation_timestamp", b"creation_timestamp", "description", b"description", "grpc_health_check", b"grpc_health_check", "healthy_threshold", b"healthy_threshold", "http2_health_check", b"http2_health_check", "http_health_check", b"http_health_check", "https_health_check", b"https_health_check", "id", b"id", "log_config", b"log_config", "name", b"name", "project", b"project", "resource_info", b"resource_info", "self_link", b"self_link", "ssl_health_check", b"ssl_health_check", "tcp_health_check", b"tcp_health_check", "timeout_sec", b"timeout_sec", "timeouts", b"timeouts", "type", b"type", "unhealthy_threshold", b"unhealthy_threshold"]) -> None: ...

global___ComputeHealthCheck = ComputeHealthCheck
