"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import gcp.gcp_app_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class GoogleAppEngine(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APP_ENGINE_APPLICATION_FIELD_NUMBER: builtins.int
    APP_ENGINE_APPLICATION_URL_DISPATCH_RULES_FIELD_NUMBER: builtins.int
    APP_ENGINE_DOMAIN_MAPPING_FIELD_NUMBER: builtins.int
    APP_ENGINE_FIREWALL_RULE_FIELD_NUMBER: builtins.int
    APP_ENGINE_FLEXIBLE_APP_VERSION_FIELD_NUMBER: builtins.int
    APP_ENGINE_SERVICE_NETWORK_SETTINGS_FIELD_NUMBER: builtins.int
    APP_ENGINE_SERVICE_SPLIT_TRAFFIC_FIELD_NUMBER: builtins.int
    APP_ENGINE_STANDARD_APP_VERSION_FIELD_NUMBER: builtins.int
    @property
    def app_engine_application(self) -> gcp.gcp_app_pb2.AppEngineApplication: ...
    @property
    def app_engine_application_url_dispatch_rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[gcp.gcp_app_pb2.AppEngineApplicationUrlDispatchRules]: ...
    @property
    def app_engine_domain_mapping(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[gcp.gcp_app_pb2.AppEngineDomainMapping]: ...
    @property
    def app_engine_firewall_rule(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[gcp.gcp_app_pb2.AppEngineFirewallRule]: ...
    @property
    def app_engine_flexible_app_version(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[gcp.gcp_app_pb2.AppEngineFlexibleAppVersion]: ...
    @property
    def app_engine_service_network_settings(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[gcp.gcp_app_pb2.AppEngineServiceNetworkSettings]: ...
    @property
    def app_engine_service_split_traffic(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[gcp.gcp_app_pb2.AppEngineServiceSplitTraffic]: ...
    @property
    def app_engine_standard_app_version(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[gcp.gcp_app_pb2.AppEngineStandardAppVersion]: ...
    def __init__(
        self,
        *,
        app_engine_application: gcp.gcp_app_pb2.AppEngineApplication | None = ...,
        app_engine_application_url_dispatch_rules: collections.abc.Iterable[gcp.gcp_app_pb2.AppEngineApplicationUrlDispatchRules] | None = ...,
        app_engine_domain_mapping: collections.abc.Iterable[gcp.gcp_app_pb2.AppEngineDomainMapping] | None = ...,
        app_engine_firewall_rule: collections.abc.Iterable[gcp.gcp_app_pb2.AppEngineFirewallRule] | None = ...,
        app_engine_flexible_app_version: collections.abc.Iterable[gcp.gcp_app_pb2.AppEngineFlexibleAppVersion] | None = ...,
        app_engine_service_network_settings: collections.abc.Iterable[gcp.gcp_app_pb2.AppEngineServiceNetworkSettings] | None = ...,
        app_engine_service_split_traffic: collections.abc.Iterable[gcp.gcp_app_pb2.AppEngineServiceSplitTraffic] | None = ...,
        app_engine_standard_app_version: collections.abc.Iterable[gcp.gcp_app_pb2.AppEngineStandardAppVersion] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["app_engine_application", b"app_engine_application"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["app_engine_application", b"app_engine_application", "app_engine_application_url_dispatch_rules", b"app_engine_application_url_dispatch_rules", "app_engine_domain_mapping", b"app_engine_domain_mapping", "app_engine_firewall_rule", b"app_engine_firewall_rule", "app_engine_flexible_app_version", b"app_engine_flexible_app_version", "app_engine_service_network_settings", b"app_engine_service_network_settings", "app_engine_service_split_traffic", b"app_engine_service_split_traffic", "app_engine_standard_app_version", b"app_engine_standard_app_version"]) -> None: ...

global___GoogleAppEngine = GoogleAppEngine
