# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_network.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15gcp/gcp_network.proto\x12\x17oak9.tython.gcp.network\x1a\x13shared/shared.proto\"Q\n\x1fNetworkConnectivityHubXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xb1\x04\n\x16NetworkConnectivityHub\x12\x13\n\x0b\x63reate_time\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12K\n\x06labels\x18\x04 \x03(\x0b\x32;.oak9.tython.gcp.network.NetworkConnectivityHub.LabelsEntry\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x0f\n\x07project\x18\x06 \x01(\t\x12V\n\x0crouting_vpcs\x18\x07 \x03(\x0b\x32@.oak9.tython.gcp.network.NetworkConnectivityHub.RoutingVpcsEntry\x12\r\n\x05state\x18\x08 \x01(\t\x12\x11\n\tunique_id\x18\t \x01(\t\x12\x13\n\x0bupdate_time\x18\n \x01(\t\x12J\n\x08timeouts\x18\x0b \x01(\x0b\x32\x38.oak9.tython.gcp.network.NetworkConnectivityHubXTimeouts\x12\x37\n\rresource_info\x18\x0c \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x32\n\x10RoutingVpcsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"j\n6NetworkConnectivitySpokeXLinkedInterconnectAttachments\x12\"\n\x1asite_to_site_data_transfer\x18\x01 \x01(\x08\x12\x0c\n\x04uris\x18\x02 \x03(\t\"p\nANetworkConnectivitySpokeXLinkedRouterApplianceInstancesXInstances\x12\x12\n\nip_address\x18\x01 \x01(\t\x12\x17\n\x0fvirtual_machine\x18\x02 \x01(\t\"\xcc\x01\n7NetworkConnectivitySpokeXLinkedRouterApplianceInstances\x12\"\n\x1asite_to_site_data_transfer\x18\x01 \x01(\x08\x12m\n\tinstances\x18\x02 \x03(\x0b\x32Z.oak9.tython.gcp.network.NetworkConnectivitySpokeXLinkedRouterApplianceInstancesXInstances\"]\n)NetworkConnectivitySpokeXLinkedVpnTunnels\x12\"\n\x1asite_to_site_data_transfer\x18\x01 \x01(\x08\x12\x0c\n\x04uris\x18\x02 \x03(\t\"S\n!NetworkConnectivitySpokeXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xa1\x06\n\x18NetworkConnectivitySpoke\x12\x13\n\x0b\x63reate_time\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0b\n\x03hub\x18\x03 \x01(\t\x12\n\n\x02id\x18\x04 \x01(\t\x12M\n\x06labels\x18\x05 \x03(\x0b\x32=.oak9.tython.gcp.network.NetworkConnectivitySpoke.LabelsEntry\x12\x10\n\x08location\x18\x06 \x01(\t\x12\x0c\n\x04name\x18\x07 \x01(\t\x12\x0f\n\x07project\x18\x08 \x01(\t\x12\r\n\x05state\x18\t \x01(\t\x12\x11\n\tunique_id\x18\n \x01(\t\x12\x13\n\x0bupdate_time\x18\x0b \x01(\t\x12x\n\x1flinked_interconnect_attachments\x18\x0c \x01(\x0b\x32O.oak9.tython.gcp.network.NetworkConnectivitySpokeXLinkedInterconnectAttachments\x12{\n!linked_router_appliance_instances\x18\r \x01(\x0b\x32P.oak9.tython.gcp.network.NetworkConnectivitySpokeXLinkedRouterApplianceInstances\x12^\n\x12linked_vpn_tunnels\x18\x0e \x01(\x0b\x32\x42.oak9.tython.gcp.network.NetworkConnectivitySpokeXLinkedVpnTunnels\x12L\n\x08timeouts\x18\x0f \x01(\x0b\x32:.oak9.tython.gcp.network.NetworkConnectivitySpokeXTimeouts\x12\x37\n\rresource_info\x18\x10 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x88\x01\n-NetworkManagementConnectivityTestXDestination\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x12\n\nip_address\x18\x02 \x01(\t\x12\x0f\n\x07network\x18\x03 \x01(\t\x12\x0c\n\x04port\x18\x04 \x01(\x01\x12\x12\n\nproject_id\x18\x05 \x01(\t\"\x99\x01\n(NetworkManagementConnectivityTestXSource\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x12\n\nip_address\x18\x02 \x01(\t\x12\x0f\n\x07network\x18\x03 \x01(\t\x12\x14\n\x0cnetwork_type\x18\x04 \x01(\t\x12\x0c\n\x04port\x18\x05 \x01(\x01\x12\x12\n\nproject_id\x18\x06 \x01(\t\"\\\n*NetworkManagementConnectivityTestXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xd6\x04\n!NetworkManagementConnectivityTest\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12V\n\x06labels\x18\x03 \x03(\x0b\x32\x46.oak9.tython.gcp.network.NetworkManagementConnectivityTest.LabelsEntry\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x10\n\x08protocol\x18\x06 \x01(\t\x12\x18\n\x10related_projects\x18\x07 \x03(\t\x12[\n\x0b\x64\x65stination\x18\x08 \x01(\x0b\x32\x46.oak9.tython.gcp.network.NetworkManagementConnectivityTestXDestination\x12Q\n\x06source\x18\t \x01(\x0b\x32\x41.oak9.tython.gcp.network.NetworkManagementConnectivityTestXSource\x12U\n\x08timeouts\x18\n \x01(\x0b\x32\x43.oak9.tython.gcp.network.NetworkManagementConnectivityTestXTimeouts\x12\x37\n\rresource_info\x18\x0b \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"E\n(NetworkServicesEdgeCacheKeysetXPublicKey\x12\n\n\x02id\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"Y\n\'NetworkServicesEdgeCacheKeysetXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xc8\x03\n\x1eNetworkServicesEdgeCacheKeyset\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12S\n\x06labels\x18\x03 \x03(\x0b\x32\x43.oak9.tython.gcp.network.NetworkServicesEdgeCacheKeyset.LabelsEntry\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12U\n\npublic_key\x18\x06 \x03(\x0b\x32\x41.oak9.tython.gcp.network.NetworkServicesEdgeCacheKeysetXPublicKey\x12R\n\x08timeouts\x18\x07 \x01(\x0b\x32@.oak9.tython.gcp.network.NetworkServicesEdgeCacheKeysetXTimeouts\x12\x37\n\rresource_info\x18\x08 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x8f\x01\n&NetworkServicesEdgeCacheOriginXTimeout\x12\x17\n\x0f\x63onnect_timeout\x18\x01 \x01(\t\x12\x1c\n\x14max_attempts_timeout\x18\x02 \x01(\t\x12\x14\n\x0cread_timeout\x18\x03 \x01(\t\x12\x18\n\x10response_timeout\x18\x04 \x01(\t\"Y\n\'NetworkServicesEdgeCacheOriginXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xc4\x04\n\x1eNetworkServicesEdgeCacheOrigin\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x17\n\x0f\x66\x61ilover_origin\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12S\n\x06labels\x18\x04 \x03(\x0b\x32\x43.oak9.tython.gcp.network.NetworkServicesEdgeCacheOrigin.LabelsEntry\x12\x14\n\x0cmax_attempts\x18\x05 \x01(\x01\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x16\n\x0eorigin_address\x18\x07 \x01(\t\x12\x0c\n\x04port\x18\x08 \x01(\x01\x12\x0f\n\x07project\x18\t \x01(\t\x12\x10\n\x08protocol\x18\n \x01(\t\x12\x18\n\x10retry_conditions\x18\x0b \x03(\t\x12P\n\x07timeout\x18\x0c \x01(\x0b\x32?.oak9.tython.gcp.network.NetworkServicesEdgeCacheOriginXTimeout\x12R\n\x08timeouts\x18\r \x01(\x0b\x32@.oak9.tython.gcp.network.NetworkServicesEdgeCacheOriginXTimeouts\x12\x37\n\rresource_info\x18\x0e \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"P\n)NetworkServicesEdgeCacheServiceXLogConfig\x12\x0e\n\x06\x65nable\x18\x01 \x01(\x08\x12\x13\n\x0bsample_rate\x18\x02 \x01(\x01\"l\n0NetworkServicesEdgeCacheServiceXRoutingXHostRule\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\r\n\x05hosts\x18\x02 \x03(\t\x12\x14\n\x0cpath_matcher\x18\x03 \x01(\t\"\x9b\x01\n]NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXHeaderActionXRequestHeaderToAdd\x12\x13\n\x0bheader_name\x18\x01 \x01(\t\x12\x14\n\x0cheader_value\x18\x02 \x01(\t\x12\x0f\n\x07replace\x18\x03 \x01(\x08\"w\n`NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXHeaderActionXRequestHeaderToRemove\x12\x13\n\x0bheader_name\x18\x01 \x01(\t\"\x9c\x01\n^NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXHeaderActionXResponseHeaderToAdd\x12\x13\n\x0bheader_name\x18\x01 \x01(\t\x12\x14\n\x0cheader_value\x18\x02 \x01(\t\x12\x0f\n\x07replace\x18\x03 \x01(\x08\"x\naNetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXHeaderActionXResponseHeaderToRemove\x12\x13\n\x0bheader_name\x18\x01 \x01(\t\"\xbc\x05\nJNetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXHeaderAction\x12\x95\x01\n\x15request_header_to_add\x18\x01 \x03(\x0b\x32v.oak9.tython.gcp.network.NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXHeaderActionXRequestHeaderToAdd\x12\x9b\x01\n\x18request_header_to_remove\x18\x02 \x03(\x0b\x32y.oak9.tython.gcp.network.NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXHeaderActionXRequestHeaderToRemove\x12\x97\x01\n\x16response_header_to_add\x18\x03 \x03(\x0b\x32w.oak9.tython.gcp.network.NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXHeaderActionXResponseHeaderToAdd\x12\x9d\x01\n\x19response_header_to_remove\x18\x04 \x03(\x0b\x32z.oak9.tython.gcp.network.NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXHeaderActionXResponseHeaderToRemove\"\xd8\x01\nSNetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXMatchRuleXHeaderMatch\x12\x13\n\x0b\x65xact_match\x18\x01 \x01(\t\x12\x13\n\x0bheader_name\x18\x02 \x01(\t\x12\x14\n\x0cinvert_match\x18\x03 \x01(\x08\x12\x14\n\x0cprefix_match\x18\x04 \x01(\t\x12\x15\n\rpresent_match\x18\x05 \x01(\x08\x12\x14\n\x0csuffix_match\x18\x06 \x01(\t\"\x97\x01\n[NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXMatchRuleXQueryParameterMatch\x12\x13\n\x0b\x65xact_match\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x15\n\rpresent_match\x18\x03 \x01(\x08\"\xc5\x03\nGNetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXMatchRule\x12\x17\n\x0f\x66ull_path_match\x18\x01 \x01(\t\x12\x13\n\x0bignore_case\x18\x02 \x01(\x08\x12\x1b\n\x13path_template_match\x18\x03 \x01(\t\x12\x14\n\x0cprefix_match\x18\x04 \x01(\t\x12\x82\x01\n\x0cheader_match\x18\x05 \x03(\x0b\x32l.oak9.tython.gcp.network.NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXMatchRuleXHeaderMatch\x12\x93\x01\n\x15query_parameter_match\x18\x06 \x03(\x0b\x32t.oak9.tython.gcp.network.NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXMatchRuleXQueryParameterMatch\"\xb6\x02\nbNetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXRouteActionXCdnPolicyXCacheKeyPolicy\x12\x14\n\x0c\x65xclude_host\x18\x01 \x01(\x08\x12\x1c\n\x14\x65xclude_query_string\x18\x02 \x01(\x08\x12!\n\x19\x65xcluded_query_parameters\x18\x03 \x03(\t\x12\x18\n\x10include_protocol\x18\x04 \x01(\x08\x12\x1d\n\x15included_cookie_names\x18\x05 \x03(\t\x12\x1d\n\x15included_header_names\x18\x06 \x03(\t\x12!\n\x19included_query_parameters\x18\x07 \x03(\t\"\xfb\x04\nSNetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXRouteActionXCdnPolicy\x12\x12\n\ncache_mode\x18\x01 \x01(\t\x12\x12\n\nclient_ttl\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65\x66\x61ult_ttl\x18\x03 \x01(\t\x12\x0f\n\x07max_ttl\x18\x04 \x01(\t\x12\x18\n\x10negative_caching\x18\x05 \x01(\x08\x12\xa9\x01\n\x17negative_caching_policy\x18\x06 \x03(\x0b\x32\x87\x01.oak9.tython.gcp.network.NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXRouteActionXCdnPolicy.NegativeCachingPolicyEntry\x12\x1d\n\x15signed_request_keyset\x18\x07 \x01(\t\x12\x1b\n\x13signed_request_mode\x18\x08 \x01(\t\x12\x95\x01\n\x10\x63\x61\x63he_key_policy\x18\t \x01(\x0b\x32{.oak9.tython.gcp.network.NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXRouteActionXCdnPolicyXCacheKeyPolicy\x1a<\n\x1aNegativeCachingPolicyEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xf1\x01\nTNetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXRouteActionXCorsPolicy\x12\x19\n\x11\x61llow_credentials\x18\x01 \x01(\x08\x12\x15\n\rallow_headers\x18\x02 \x03(\t\x12\x15\n\rallow_methods\x18\x03 \x03(\t\x12\x15\n\rallow_origins\x18\x04 \x03(\t\x12\x10\n\x08\x64isabled\x18\x05 \x01(\x08\x12\x16\n\x0e\x65xpose_headers\x18\x06 \x03(\t\x12\x0f\n\x07max_age\x18\x07 \x01(\t\"\xa8\x01\nTNetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXRouteActionXUrlRewrite\x12\x14\n\x0chost_rewrite\x18\x01 \x01(\t\x12\x1b\n\x13path_prefix_rewrite\x18\x02 \x01(\t\x12\x1d\n\x15path_template_rewrite\x18\x03 \x01(\t\"\xd8\x03\nINetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXRouteAction\x12\x80\x01\n\ncdn_policy\x18\x01 \x01(\x0b\x32l.oak9.tython.gcp.network.NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXRouteActionXCdnPolicy\x12\x82\x01\n\x0b\x63ors_policy\x18\x02 \x01(\x0b\x32m.oak9.tython.gcp.network.NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXRouteActionXCorsPolicy\x12\x82\x01\n\x0burl_rewrite\x18\x03 \x01(\x0b\x32m.oak9.tython.gcp.network.NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXRouteActionXUrlRewrite\"\xdf\x01\nINetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXUrlRedirect\x12\x15\n\rhost_redirect\x18\x01 \x01(\t\x12\x16\n\x0ehttps_redirect\x18\x02 \x01(\x08\x12\x15\n\rpath_redirect\x18\x03 \x01(\t\x12\x17\n\x0fprefix_redirect\x18\x04 \x01(\t\x12\x1e\n\x16redirect_response_code\x18\x05 \x01(\t\x12\x13\n\x0bstrip_query\x18\x06 \x01(\x08\"\xdc\x04\n=NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRule\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x0e\n\x06origin\x18\x02 \x01(\t\x12\x10\n\x08priority\x18\x03 \x01(\t\x12z\n\rheader_action\x18\x04 \x01(\x0b\x32\x63.oak9.tython.gcp.network.NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXHeaderAction\x12t\n\nmatch_rule\x18\x05 \x03(\x0b\x32`.oak9.tython.gcp.network.NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXMatchRule\x12x\n\x0croute_action\x18\x06 \x01(\x0b\x32\x62.oak9.tython.gcp.network.NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXRouteAction\x12x\n\x0curl_redirect\x18\x07 \x01(\x0b\x32\x62.oak9.tython.gcp.network.NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXUrlRedirect\"\xc4\x01\n3NetworkServicesEdgeCacheServiceXRoutingXPathMatcher\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12j\n\nroute_rule\x18\x03 \x03(\x0b\x32V.oak9.tython.gcp.network.NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRule\"\xeb\x01\n\'NetworkServicesEdgeCacheServiceXRouting\x12\\\n\thost_rule\x18\x01 \x03(\x0b\x32I.oak9.tython.gcp.network.NetworkServicesEdgeCacheServiceXRoutingXHostRule\x12\x62\n\x0cpath_matcher\x18\x02 \x03(\x0b\x32L.oak9.tython.gcp.network.NetworkServicesEdgeCacheServiceXRoutingXPathMatcher\"Z\n(NetworkServicesEdgeCacheServiceXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xe2\x05\n\x1fNetworkServicesEdgeCacheService\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x15\n\rdisable_http2\x18\x02 \x01(\x08\x12\x14\n\x0c\x64isable_quic\x18\x03 \x01(\x08\x12\x1c\n\x14\x65\x64ge_security_policy\x18\x04 \x01(\t\x12\x1d\n\x15\x65\x64ge_ssl_certificates\x18\x05 \x03(\t\x12\n\n\x02id\x18\x06 \x01(\t\x12\x16\n\x0eipv4_addresses\x18\x07 \x03(\t\x12\x16\n\x0eipv6_addresses\x18\x08 \x03(\t\x12T\n\x06labels\x18\t \x03(\x0b\x32\x44.oak9.tython.gcp.network.NetworkServicesEdgeCacheService.LabelsEntry\x12\x0c\n\x04name\x18\n \x01(\t\x12\x0f\n\x07project\x18\x0b \x01(\t\x12\x13\n\x0brequire_tls\x18\x0c \x01(\x08\x12\x12\n\nssl_policy\x18\r \x01(\t\x12V\n\nlog_config\x18\x0e \x01(\x0b\x32\x42.oak9.tython.gcp.network.NetworkServicesEdgeCacheServiceXLogConfig\x12Q\n\x07routing\x18\x0f \x01(\x0b\x32@.oak9.tython.gcp.network.NetworkServicesEdgeCacheServiceXRouting\x12S\n\x08timeouts\x18\x10 \x01(\x0b\x32\x41.oak9.tython.gcp.network.NetworkServicesEdgeCacheServiceXTimeouts\x12\x37\n\rresource_info\x18\x11 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_network_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _NETWORKCONNECTIVITYHUB_LABELSENTRY._options = None
  _NETWORKCONNECTIVITYHUB_LABELSENTRY._serialized_options = b'8\001'
  _NETWORKCONNECTIVITYHUB_ROUTINGVPCSENTRY._options = None
  _NETWORKCONNECTIVITYHUB_ROUTINGVPCSENTRY._serialized_options = b'8\001'
  _NETWORKCONNECTIVITYSPOKE_LABELSENTRY._options = None
  _NETWORKCONNECTIVITYSPOKE_LABELSENTRY._serialized_options = b'8\001'
  _NETWORKMANAGEMENTCONNECTIVITYTEST_LABELSENTRY._options = None
  _NETWORKMANAGEMENTCONNECTIVITYTEST_LABELSENTRY._serialized_options = b'8\001'
  _NETWORKSERVICESEDGECACHEKEYSET_LABELSENTRY._options = None
  _NETWORKSERVICESEDGECACHEKEYSET_LABELSENTRY._serialized_options = b'8\001'
  _NETWORKSERVICESEDGECACHEORIGIN_LABELSENTRY._options = None
  _NETWORKSERVICESEDGECACHEORIGIN_LABELSENTRY._serialized_options = b'8\001'
  _NETWORKSERVICESEDGECACHESERVICEXROUTINGXPATHMATCHERXROUTERULEXROUTEACTIONXCDNPOLICY_NEGATIVECACHINGPOLICYENTRY._options = None
  _NETWORKSERVICESEDGECACHESERVICEXROUTINGXPATHMATCHERXROUTERULEXROUTEACTIONXCDNPOLICY_NEGATIVECACHINGPOLICYENTRY._serialized_options = b'8\001'
  _NETWORKSERVICESEDGECACHESERVICE_LABELSENTRY._options = None
  _NETWORKSERVICESEDGECACHESERVICE_LABELSENTRY._serialized_options = b'8\001'
  _NETWORKCONNECTIVITYHUBXTIMEOUTS._serialized_start=71
  _NETWORKCONNECTIVITYHUBXTIMEOUTS._serialized_end=152
  _NETWORKCONNECTIVITYHUB._serialized_start=155
  _NETWORKCONNECTIVITYHUB._serialized_end=716
  _NETWORKCONNECTIVITYHUB_LABELSENTRY._serialized_start=619
  _NETWORKCONNECTIVITYHUB_LABELSENTRY._serialized_end=664
  _NETWORKCONNECTIVITYHUB_ROUTINGVPCSENTRY._serialized_start=666
  _NETWORKCONNECTIVITYHUB_ROUTINGVPCSENTRY._serialized_end=716
  _NETWORKCONNECTIVITYSPOKEXLINKEDINTERCONNECTATTACHMENTS._serialized_start=718
  _NETWORKCONNECTIVITYSPOKEXLINKEDINTERCONNECTATTACHMENTS._serialized_end=824
  _NETWORKCONNECTIVITYSPOKEXLINKEDROUTERAPPLIANCEINSTANCESXINSTANCES._serialized_start=826
  _NETWORKCONNECTIVITYSPOKEXLINKEDROUTERAPPLIANCEINSTANCESXINSTANCES._serialized_end=938
  _NETWORKCONNECTIVITYSPOKEXLINKEDROUTERAPPLIANCEINSTANCES._serialized_start=941
  _NETWORKCONNECTIVITYSPOKEXLINKEDROUTERAPPLIANCEINSTANCES._serialized_end=1145
  _NETWORKCONNECTIVITYSPOKEXLINKEDVPNTUNNELS._serialized_start=1147
  _NETWORKCONNECTIVITYSPOKEXLINKEDVPNTUNNELS._serialized_end=1240
  _NETWORKCONNECTIVITYSPOKEXTIMEOUTS._serialized_start=1242
  _NETWORKCONNECTIVITYSPOKEXTIMEOUTS._serialized_end=1325
  _NETWORKCONNECTIVITYSPOKE._serialized_start=1328
  _NETWORKCONNECTIVITYSPOKE._serialized_end=2129
  _NETWORKCONNECTIVITYSPOKE_LABELSENTRY._serialized_start=619
  _NETWORKCONNECTIVITYSPOKE_LABELSENTRY._serialized_end=664
  _NETWORKMANAGEMENTCONNECTIVITYTESTXDESTINATION._serialized_start=2132
  _NETWORKMANAGEMENTCONNECTIVITYTESTXDESTINATION._serialized_end=2268
  _NETWORKMANAGEMENTCONNECTIVITYTESTXSOURCE._serialized_start=2271
  _NETWORKMANAGEMENTCONNECTIVITYTESTXSOURCE._serialized_end=2424
  _NETWORKMANAGEMENTCONNECTIVITYTESTXTIMEOUTS._serialized_start=2426
  _NETWORKMANAGEMENTCONNECTIVITYTESTXTIMEOUTS._serialized_end=2518
  _NETWORKMANAGEMENTCONNECTIVITYTEST._serialized_start=2521
  _NETWORKMANAGEMENTCONNECTIVITYTEST._serialized_end=3119
  _NETWORKMANAGEMENTCONNECTIVITYTEST_LABELSENTRY._serialized_start=619
  _NETWORKMANAGEMENTCONNECTIVITYTEST_LABELSENTRY._serialized_end=664
  _NETWORKSERVICESEDGECACHEKEYSETXPUBLICKEY._serialized_start=3121
  _NETWORKSERVICESEDGECACHEKEYSETXPUBLICKEY._serialized_end=3190
  _NETWORKSERVICESEDGECACHEKEYSETXTIMEOUTS._serialized_start=3192
  _NETWORKSERVICESEDGECACHEKEYSETXTIMEOUTS._serialized_end=3281
  _NETWORKSERVICESEDGECACHEKEYSET._serialized_start=3284
  _NETWORKSERVICESEDGECACHEKEYSET._serialized_end=3740
  _NETWORKSERVICESEDGECACHEKEYSET_LABELSENTRY._serialized_start=619
  _NETWORKSERVICESEDGECACHEKEYSET_LABELSENTRY._serialized_end=664
  _NETWORKSERVICESEDGECACHEORIGINXTIMEOUT._serialized_start=3743
  _NETWORKSERVICESEDGECACHEORIGINXTIMEOUT._serialized_end=3886
  _NETWORKSERVICESEDGECACHEORIGINXTIMEOUTS._serialized_start=3888
  _NETWORKSERVICESEDGECACHEORIGINXTIMEOUTS._serialized_end=3977
  _NETWORKSERVICESEDGECACHEORIGIN._serialized_start=3980
  _NETWORKSERVICESEDGECACHEORIGIN._serialized_end=4560
  _NETWORKSERVICESEDGECACHEORIGIN_LABELSENTRY._serialized_start=619
  _NETWORKSERVICESEDGECACHEORIGIN_LABELSENTRY._serialized_end=664
  _NETWORKSERVICESEDGECACHESERVICEXLOGCONFIG._serialized_start=4562
  _NETWORKSERVICESEDGECACHESERVICEXLOGCONFIG._serialized_end=4642
  _NETWORKSERVICESEDGECACHESERVICEXROUTINGXHOSTRULE._serialized_start=4644
  _NETWORKSERVICESEDGECACHESERVICEXROUTINGXHOSTRULE._serialized_end=4752
  _NETWORKSERVICESEDGECACHESERVICEXROUTINGXPATHMATCHERXROUTERULEXHEADERACTIONXREQUESTHEADERTOADD._serialized_start=4755
  _NETWORKSERVICESEDGECACHESERVICEXROUTINGXPATHMATCHERXROUTERULEXHEADERACTIONXREQUESTHEADERTOADD._serialized_end=4910
  _NETWORKSERVICESEDGECACHESERVICEXROUTINGXPATHMATCHERXROUTERULEXHEADERACTIONXREQUESTHEADERTOREMOVE._serialized_start=4912
  _NETWORKSERVICESEDGECACHESERVICEXROUTINGXPATHMATCHERXROUTERULEXHEADERACTIONXREQUESTHEADERTOREMOVE._serialized_end=5031
  _NETWORKSERVICESEDGECACHESERVICEXROUTINGXPATHMATCHERXROUTERULEXHEADERACTIONXRESPONSEHEADERTOADD._serialized_start=5034
  _NETWORKSERVICESEDGECACHESERVICEXROUTINGXPATHMATCHERXROUTERULEXHEADERACTIONXRESPONSEHEADERTOADD._serialized_end=5190
  _NETWORKSERVICESEDGECACHESERVICEXROUTINGXPATHMATCHERXROUTERULEXHEADERACTIONXRESPONSEHEADERTOREMOVE._serialized_start=5192
  _NETWORKSERVICESEDGECACHESERVICEXROUTINGXPATHMATCHERXROUTERULEXHEADERACTIONXRESPONSEHEADERTOREMOVE._serialized_end=5312
  _NETWORKSERVICESEDGECACHESERVICEXROUTINGXPATHMATCHERXROUTERULEXHEADERACTION._serialized_start=5315
  _NETWORKSERVICESEDGECACHESERVICEXROUTINGXPATHMATCHERXROUTERULEXHEADERACTION._serialized_end=6015
  _NETWORKSERVICESEDGECACHESERVICEXROUTINGXPATHMATCHERXROUTERULEXMATCHRULEXHEADERMATCH._serialized_start=6018
  _NETWORKSERVICESEDGECACHESERVICEXROUTINGXPATHMATCHERXROUTERULEXMATCHRULEXHEADERMATCH._serialized_end=6234
  _NETWORKSERVICESEDGECACHESERVICEXROUTINGXPATHMATCHERXROUTERULEXMATCHRULEXQUERYPARAMETERMATCH._serialized_start=6237
  _NETWORKSERVICESEDGECACHESERVICEXROUTINGXPATHMATCHERXROUTERULEXMATCHRULEXQUERYPARAMETERMATCH._serialized_end=6388
  _NETWORKSERVICESEDGECACHESERVICEXROUTINGXPATHMATCHERXROUTERULEXMATCHRULE._serialized_start=6391
  _NETWORKSERVICESEDGECACHESERVICEXROUTINGXPATHMATCHERXROUTERULEXMATCHRULE._serialized_end=6844
  _NETWORKSERVICESEDGECACHESERVICEXROUTINGXPATHMATCHERXROUTERULEXROUTEACTIONXCDNPOLICYXCACHEKEYPOLICY._serialized_start=6847
  _NETWORKSERVICESEDGECACHESERVICEXROUTINGXPATHMATCHERXROUTERULEXROUTEACTIONXCDNPOLICYXCACHEKEYPOLICY._serialized_end=7157
  _NETWORKSERVICESEDGECACHESERVICEXROUTINGXPATHMATCHERXROUTERULEXROUTEACTIONXCDNPOLICY._serialized_start=7160
  _NETWORKSERVICESEDGECACHESERVICEXROUTINGXPATHMATCHERXROUTERULEXROUTEACTIONXCDNPOLICY._serialized_end=7795
  _NETWORKSERVICESEDGECACHESERVICEXROUTINGXPATHMATCHERXROUTERULEXROUTEACTIONXCDNPOLICY_NEGATIVECACHINGPOLICYENTRY._serialized_start=7735
  _NETWORKSERVICESEDGECACHESERVICEXROUTINGXPATHMATCHERXROUTERULEXROUTEACTIONXCDNPOLICY_NEGATIVECACHINGPOLICYENTRY._serialized_end=7795
  _NETWORKSERVICESEDGECACHESERVICEXROUTINGXPATHMATCHERXROUTERULEXROUTEACTIONXCORSPOLICY._serialized_start=7798
  _NETWORKSERVICESEDGECACHESERVICEXROUTINGXPATHMATCHERXROUTERULEXROUTEACTIONXCORSPOLICY._serialized_end=8039
  _NETWORKSERVICESEDGECACHESERVICEXROUTINGXPATHMATCHERXROUTERULEXROUTEACTIONXURLREWRITE._serialized_start=8042
  _NETWORKSERVICESEDGECACHESERVICEXROUTINGXPATHMATCHERXROUTERULEXROUTEACTIONXURLREWRITE._serialized_end=8210
  _NETWORKSERVICESEDGECACHESERVICEXROUTINGXPATHMATCHERXROUTERULEXROUTEACTION._serialized_start=8213
  _NETWORKSERVICESEDGECACHESERVICEXROUTINGXPATHMATCHERXROUTERULEXROUTEACTION._serialized_end=8685
  _NETWORKSERVICESEDGECACHESERVICEXROUTINGXPATHMATCHERXROUTERULEXURLREDIRECT._serialized_start=8688
  _NETWORKSERVICESEDGECACHESERVICEXROUTINGXPATHMATCHERXROUTERULEXURLREDIRECT._serialized_end=8911
  _NETWORKSERVICESEDGECACHESERVICEXROUTINGXPATHMATCHERXROUTERULE._serialized_start=8914
  _NETWORKSERVICESEDGECACHESERVICEXROUTINGXPATHMATCHERXROUTERULE._serialized_end=9518
  _NETWORKSERVICESEDGECACHESERVICEXROUTINGXPATHMATCHER._serialized_start=9521
  _NETWORKSERVICESEDGECACHESERVICEXROUTINGXPATHMATCHER._serialized_end=9717
  _NETWORKSERVICESEDGECACHESERVICEXROUTING._serialized_start=9720
  _NETWORKSERVICESEDGECACHESERVICEXROUTING._serialized_end=9955
  _NETWORKSERVICESEDGECACHESERVICEXTIMEOUTS._serialized_start=9957
  _NETWORKSERVICESEDGECACHESERVICEXTIMEOUTS._serialized_end=10047
  _NETWORKSERVICESEDGECACHESERVICE._serialized_start=10050
  _NETWORKSERVICESEDGECACHESERVICE._serialized_end=10788
  _NETWORKSERVICESEDGECACHESERVICE_LABELSENTRY._serialized_start=619
  _NETWORKSERVICESEDGECACHESERVICE_LABELSENTRY._serialized_end=664
# @@protoc_insertion_point(module_scope)
