"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import gcp.gcp_compute_network_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class GoogleComputeNetwork(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMPUTE_NETWORK_FIELD_NUMBER: builtins.int
    COMPUTE_NETWORK_PEERING_FIELD_NUMBER: builtins.int
    COMPUTE_NETWORK_PEERING_ROUTES_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def compute_network(self) -> gcp.gcp_compute_network_pb2.ComputeNetwork: ...
    @property
    def compute_network_peering(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[gcp.gcp_compute_network_pb2.ComputeNetworkPeering]: ...
    @property
    def compute_network_peering_routes_config(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[gcp.gcp_compute_network_pb2.ComputeNetworkPeeringRoutesConfig]: ...
    def __init__(
        self,
        *,
        compute_network: gcp.gcp_compute_network_pb2.ComputeNetwork | None = ...,
        compute_network_peering: collections.abc.Iterable[gcp.gcp_compute_network_pb2.ComputeNetworkPeering] | None = ...,
        compute_network_peering_routes_config: collections.abc.Iterable[gcp.gcp_compute_network_pb2.ComputeNetworkPeeringRoutesConfig] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["compute_network", b"compute_network"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["compute_network", b"compute_network", "compute_network_peering", b"compute_network_peering", "compute_network_peering_routes_config", b"compute_network_peering_routes_config"]) -> None: ...

global___GoogleComputeNetwork = GoogleComputeNetwork
