# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kubernetes/kubernetes_io.k8s.api.storage.v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2
from oak9.tython.models.kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta import v1_pb2 as kubernetes_dot_kubernetes__io_dot_k8s_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1__pb2
from oak9.tython.models.kubernetes.kubernetes_io.k8s.apimachinery.pkg.api import resource_pb2 as kubernetes_dot_kubernetes__io_dot_k8s_dot_apimachinery_dot_pkg_dot_api_dot_resource__pb2
from oak9.tython.models.kubernetes.kubernetes_io.k8s.api.core import v1_pb2 as kubernetes_dot_kubernetes__io_dot_k8s_dot_api_dot_core_dot_v1__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1kubernetes/kubernetes_io.k8s.api.storage.v1.proto\x12\x1eoak9.tython.k8s.api.storage.v1\x1a\x13shared/shared.proto\x1a@kubernetes/kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1.proto\x1a@kubernetes/kubernetes_io.k8s.apimachinery.pkg.api.resource.proto\x1a.kubernetes/kubernetes_io.k8s.api.core.v1.proto\"\xf1\x01\n\tCSIDriver\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12K\n\x08metadata\x18\x03 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12;\n\x04spec\x18\x04 \x01(\x0b\x32-.oak9.tython.k8s.api.storage.v1.CSIDriverSpec\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xf0\x01\n\rCSIDriverList\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x38\n\x05items\x18\x02 \x03(\x0b\x32).oak9.tython.k8s.api.storage.v1.CSIDriver\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12I\n\x08metadata\x18\x04 \x01(\x0b\x32\x37.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ListMeta\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xc9\x02\n\rCSIDriverSpec\x12\x17\n\x0f\x61ttach_required\x18\x01 \x01(\x08\x12\x17\n\x0f\x66s_group_policy\x18\x02 \x01(\t\x12\x19\n\x11pod_info_on_mount\x18\x03 \x01(\x08\x12\x1a\n\x12requires_republish\x18\x04 \x01(\x08\x12\x16\n\x0ese_linux_mount\x18\x05 \x01(\x08\x12\x18\n\x10storage_capacity\x18\x06 \x01(\x08\x12\x44\n\x0etoken_requests\x18\x07 \x03(\x0b\x32,.oak9.tython.k8s.api.storage.v1.TokenRequest\x12\x1e\n\x16volume_lifecycle_modes\x18\x08 \x03(\t\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xed\x01\n\x07\x43SINode\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12K\n\x08metadata\x18\x03 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12\x39\n\x04spec\x18\x04 \x01(\x0b\x32+.oak9.tython.k8s.api.storage.v1.CSINodeSpec\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xc8\x01\n\rCSINodeDriver\x12H\n\x0b\x61llocatable\x18\x01 \x01(\x0b\x32\x33.oak9.tython.k8s.api.storage.v1.VolumeNodeResources\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07node_id\x18\x03 \x01(\t\x12\x15\n\rtopology_keys\x18\x04 \x03(\t\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xec\x01\n\x0b\x43SINodeList\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x36\n\x05items\x18\x02 \x03(\x0b\x32\'.oak9.tython.k8s.api.storage.v1.CSINode\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12I\n\x08metadata\x18\x04 \x01(\x0b\x32\x37.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ListMeta\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x86\x01\n\x0b\x43SINodeSpec\x12>\n\x07\x64rivers\x18\x01 \x03(\x0b\x32-.oak9.tython.k8s.api.storage.v1.CSINodeDriver\x12\x37\n\rresource_info\x18\x02 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xcf\x03\n\x12\x43SIStorageCapacity\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12I\n\x08\x63\x61pacity\x18\x02 \x01(\x0b\x32\x37.oak9.tython.k8s.apimachinery.pkg.api.resource.Quantity\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12T\n\x13maximum_volume_size\x18\x04 \x01(\x0b\x32\x37.oak9.tython.k8s.apimachinery.pkg.api.resource.Quantity\x12K\n\x08metadata\x18\x05 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12S\n\rnode_topology\x18\x06 \x01(\x0b\x32<.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.LabelSelector\x12\x1a\n\x12storage_class_name\x18\x07 \x01(\t\x12\x37\n\rresource_info\x18\x08 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x82\x02\n\x16\x43SIStorageCapacityList\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x41\n\x05items\x18\x02 \x03(\x0b\x32\x32.oak9.tython.k8s.api.storage.v1.CSIStorageCapacity\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12I\n\x08metadata\x18\x04 \x01(\x0b\x32\x37.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ListMeta\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x8c\x04\n\x0cStorageClass\x12\x1e\n\x16\x61llow_volume_expansion\x18\x01 \x01(\x08\x12M\n\x12\x61llowed_topologies\x18\x02 \x03(\x0b\x32\x31.oak9.tython.k8s.api.core.v1.TopologySelectorTerm\x12\x13\n\x0b\x61pi_version\x18\x03 \x01(\t\x12\x0c\n\x04kind\x18\x04 \x01(\t\x12K\n\x08metadata\x18\x05 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12\x15\n\rmount_options\x18\x06 \x03(\t\x12P\n\nparameters\x18\x07 \x03(\x0b\x32<.oak9.tython.k8s.api.storage.v1.StorageClass.ParametersEntry\x12\x13\n\x0bprovisioner\x18\x08 \x01(\t\x12\x16\n\x0ereclaim_policy\x18\t \x01(\t\x12\x1b\n\x13volume_binding_mode\x18\n \x01(\t\x12\x37\n\rresource_info\x18\x0b \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a\x31\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xf6\x01\n\x10StorageClassList\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12;\n\x05items\x18\x02 \x03(\x0b\x32,.oak9.tython.k8s.api.storage.v1.StorageClass\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12I\n\x08metadata\x18\x04 \x01(\x0b\x32\x37.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ListMeta\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"u\n\x0cTokenRequest\x12\x10\n\x08\x61udience\x18\x01 \x01(\t\x12\x1a\n\x12\x65xpiration_seconds\x18\x02 \x01(\x05\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xc7\x02\n\x10VolumeAttachment\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12K\n\x08metadata\x18\x03 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12\x42\n\x04spec\x18\x04 \x01(\x0b\x32\x34.oak9.tython.k8s.api.storage.v1.VolumeAttachmentSpec\x12\x46\n\x06status\x18\x05 \x01(\x0b\x32\x36.oak9.tython.k8s.api.storage.v1.VolumeAttachmentStatus\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xfe\x01\n\x14VolumeAttachmentList\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12?\n\x05items\x18\x02 \x03(\x0b\x32\x30.oak9.tython.k8s.api.storage.v1.VolumeAttachment\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12I\n\x08metadata\x18\x04 \x01(\x0b\x32\x37.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ListMeta\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xc0\x01\n\x16VolumeAttachmentSource\x12M\n\x12inline_volume_spec\x18\x01 \x01(\x0b\x32\x31.oak9.tython.k8s.api.core.v1.PersistentVolumeSpec\x12\x1e\n\x16persistent_volume_name\x18\x02 \x01(\t\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xbc\x01\n\x14VolumeAttachmentSpec\x12\x10\n\x08\x61ttacher\x18\x01 \x01(\t\x12\x11\n\tnode_name\x18\x02 \x01(\t\x12\x46\n\x06source\x18\x03 \x01(\x0b\x32\x36.oak9.tython.k8s.api.storage.v1.VolumeAttachmentSource\x12\x37\n\rresource_info\x18\x04 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x91\x03\n\x16VolumeAttachmentStatus\x12\x41\n\x0c\x61ttach_error\x18\x01 \x01(\x0b\x32+.oak9.tython.k8s.api.storage.v1.VolumeError\x12\x10\n\x08\x61ttached\x18\x02 \x01(\x08\x12k\n\x13\x61ttachment_metadata\x18\x03 \x03(\x0b\x32N.oak9.tython.k8s.api.storage.v1.VolumeAttachmentStatus.AttachmentMetadataEntry\x12\x41\n\x0c\x64\x65tach_error\x18\x04 \x01(\x0b\x32+.oak9.tython.k8s.api.storage.v1.VolumeError\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a\x39\n\x17\x41ttachmentMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x9a\x01\n\x0bVolumeError\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\x41\n\x04time\x18\x02 \x01(\x0b\x32\x33.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.Time\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"]\n\x13VolumeNodeResources\x12\r\n\x05\x63ount\x18\x01 \x01(\x05\x12\x37\n\rresource_info\x18\x02 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'kubernetes.kubernetes_io.k8s.api.storage.v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _STORAGECLASS_PARAMETERSENTRY._options = None
  _STORAGECLASS_PARAMETERSENTRY._serialized_options = b'8\001'
  _VOLUMEATTACHMENTSTATUS_ATTACHMENTMETADATAENTRY._options = None
  _VOLUMEATTACHMENTSTATUS_ATTACHMENTMETADATAENTRY._serialized_options = b'8\001'
  _CSIDRIVER._serialized_start=287
  _CSIDRIVER._serialized_end=528
  _CSIDRIVERLIST._serialized_start=531
  _CSIDRIVERLIST._serialized_end=771
  _CSIDRIVERSPEC._serialized_start=774
  _CSIDRIVERSPEC._serialized_end=1103
  _CSINODE._serialized_start=1106
  _CSINODE._serialized_end=1343
  _CSINODEDRIVER._serialized_start=1346
  _CSINODEDRIVER._serialized_end=1546
  _CSINODELIST._serialized_start=1549
  _CSINODELIST._serialized_end=1785
  _CSINODESPEC._serialized_start=1788
  _CSINODESPEC._serialized_end=1922
  _CSISTORAGECAPACITY._serialized_start=1925
  _CSISTORAGECAPACITY._serialized_end=2388
  _CSISTORAGECAPACITYLIST._serialized_start=2391
  _CSISTORAGECAPACITYLIST._serialized_end=2649
  _STORAGECLASS._serialized_start=2652
  _STORAGECLASS._serialized_end=3176
  _STORAGECLASS_PARAMETERSENTRY._serialized_start=3127
  _STORAGECLASS_PARAMETERSENTRY._serialized_end=3176
  _STORAGECLASSLIST._serialized_start=3179
  _STORAGECLASSLIST._serialized_end=3425
  _TOKENREQUEST._serialized_start=3427
  _TOKENREQUEST._serialized_end=3544
  _VOLUMEATTACHMENT._serialized_start=3547
  _VOLUMEATTACHMENT._serialized_end=3874
  _VOLUMEATTACHMENTLIST._serialized_start=3877
  _VOLUMEATTACHMENTLIST._serialized_end=4131
  _VOLUMEATTACHMENTSOURCE._serialized_start=4134
  _VOLUMEATTACHMENTSOURCE._serialized_end=4326
  _VOLUMEATTACHMENTSPEC._serialized_start=4329
  _VOLUMEATTACHMENTSPEC._serialized_end=4517
  _VOLUMEATTACHMENTSTATUS._serialized_start=4520
  _VOLUMEATTACHMENTSTATUS._serialized_end=4921
  _VOLUMEATTACHMENTSTATUS_ATTACHMENTMETADATAENTRY._serialized_start=4864
  _VOLUMEATTACHMENTSTATUS_ATTACHMENTMETADATAENTRY._serialized_end=4921
  _VOLUMEERROR._serialized_start=4924
  _VOLUMEERROR._serialized_end=5078
  _VOLUMENODERESOURCES._serialized_start=5080
  _VOLUMENODERESOURCES._serialized_end=5173
# @@protoc_insertion_point(module_scope)
