# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_eks.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11\x61ws/aws_eks.proto\x12\x13oak9.tython.aws.eks\x1a\x13shared/shared.proto\"[\n\x0f\x43lusterProvider\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07key_arn\x18\x02 \x01(\t\"\x9d\x01\n\x17\x43lusterEncryptionConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\tresources\x18\x02 \x03(\t\x12\x36\n\x08provider\x18\x03 \x01(\x0b\x32$.oak9.tython.aws.eks.ClusterProvider\"\xe2\x01\n\x19\x43lusterResourcesVpcConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1a\n\x12security_group_ids\x18\x02 \x03(\t\x12\x12\n\nsubnet_ids\x18\x03 \x03(\t\x12\x1b\n\x13public_access_cidrs\x18\x04 \x03(\t\x12\x1f\n\x17\x65ndpoint_private_access\x18\x05 \x01(\x08\x12\x1e\n\x16\x65ndpoint_public_access\x18\x06 \x01(\x08\"t\n\x1e\x43lusterKubernetesNetworkConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x19\n\x11service_ipv4_cidr\x18\x02 \x01(\t\"\xe2\x02\n\x07\x43luster\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07version\x18\x02 \x01(\t\x12G\n\x11\x65ncryption_config\x18\x03 \x03(\x0b\x32,.oak9.tython.aws.eks.ClusterEncryptionConfig\x12\x10\n\x08role_arn\x18\x04 \x01(\t\x12L\n\x14resources_vpc_config\x18\x05 \x01(\x0b\x32..oak9.tython.aws.eks.ClusterResourcesVpcConfig\x12V\n\x19kubernetes_network_config\x18\x06 \x01(\x0b\x32\x33.oak9.tython.aws.eks.ClusterKubernetesNetworkConfig\x12\x0c\n\x04name\x18\x07 \x01(\t\"\xa5\x01\n\x03\x45KS\x12-\n\x07\x63luster\x18\x01 \x01(\x0b\x32\x1c.oak9.tython.aws.eks.Cluster\x12<\n\x0f\x66\x61rgate_profile\x18\x02 \x03(\x0b\x32#.oak9.tython.aws.eks.FargateProfile\x12\x31\n\tnodegroup\x18\x03 \x03(\x0b\x32\x1e.oak9.tython.aws.eks.Nodegroup\"j\n\x13\x46\x61rgateProfileLabel\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\"\x9e\x01\n\x16\x46\x61rgateProfileSelector\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\tnamespace\x18\x02 \x01(\t\x12\x38\n\x06labels\x18\x03 \x03(\x0b\x32(.oak9.tython.aws.eks.FargateProfileLabel\"\xd8\x02\n\x0e\x46\x61rgateProfile\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0c\x63luster_name\x18\x02 \x01(\t\x12\x1c\n\x14\x66\x61rgate_profile_name\x18\x03 \x01(\t\x12\x1e\n\x16pod_execution_role_arn\x18\x04 \x01(\t\x12\x0f\n\x07subnets\x18\x05 \x03(\t\x12>\n\tselectors\x18\x06 \x03(\x0b\x32+.oak9.tython.aws.eks.FargateProfileSelector\x12;\n\x04tags\x18\x07 \x03(\x0b\x32-.oak9.tython.aws.eks.FargateProfile.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x8b\x01\n\x16NodegroupScalingConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08min_size\x18\x02 \x01(\x01\x12\x14\n\x0c\x64\x65sired_size\x18\x03 \x01(\x01\x12\x10\n\x08max_size\x18\x04 \x01(\x01\"\x8a\x01\n$NodegroupLaunchTemplateSpecification\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\"\x85\x01\n\x15NodegroupRemoteAccess\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1e\n\x16source_security_groups\x18\x02 \x03(\t\x12\x13\n\x0b\x65\x63\x32_ssh_key\x18\x03 \x01(\t\"\xc7\x05\n\tNodegroup\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x43\n\x0escaling_config\x18\x02 \x01(\x0b\x32+.oak9.tython.aws.eks.NodegroupScalingConfig\x12:\n\x06labels\x18\x03 \x03(\x0b\x32*.oak9.tython.aws.eks.Nodegroup.LabelsEntry\x12\x17\n\x0frelease_version\x18\x04 \x01(\t\x12\x16\n\x0enodegroup_name\x18\x05 \x01(\t\x12\x0f\n\x07subnets\x18\x06 \x03(\t\x12\x11\n\tnode_role\x18\x07 \x01(\t\x12\x10\n\x08\x61mi_type\x18\x08 \x01(\t\x12\x1c\n\x14\x66orce_update_enabled\x18\t \x01(\x08\x12\x0f\n\x07version\x18\n \x01(\t\x12R\n\x0flaunch_template\x18\x0b \x01(\x0b\x32\x39.oak9.tython.aws.eks.NodegroupLaunchTemplateSpecification\x12\x41\n\rremote_access\x18\x0c \x01(\x0b\x32*.oak9.tython.aws.eks.NodegroupRemoteAccess\x12\x11\n\tdisk_size\x18\r \x01(\x01\x12\x14\n\x0c\x63luster_name\x18\x0e \x01(\t\x12\x16\n\x0einstance_types\x18\x0f \x03(\t\x12\x36\n\x04tags\x18\x10 \x03(\x0b\x32(.oak9.tython.aws.eks.Nodegroup.TagsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_eks_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _FARGATEPROFILE_TAGSENTRY._options = None
  _FARGATEPROFILE_TAGSENTRY._serialized_options = b'8\001'
  _NODEGROUP_LABELSENTRY._options = None
  _NODEGROUP_LABELSENTRY._serialized_options = b'8\001'
  _NODEGROUP_TAGSENTRY._options = None
  _NODEGROUP_TAGSENTRY._serialized_options = b'8\001'
  _CLUSTERPROVIDER._serialized_start=63
  _CLUSTERPROVIDER._serialized_end=154
  _CLUSTERENCRYPTIONCONFIG._serialized_start=157
  _CLUSTERENCRYPTIONCONFIG._serialized_end=314
  _CLUSTERRESOURCESVPCCONFIG._serialized_start=317
  _CLUSTERRESOURCESVPCCONFIG._serialized_end=543
  _CLUSTERKUBERNETESNETWORKCONFIG._serialized_start=545
  _CLUSTERKUBERNETESNETWORKCONFIG._serialized_end=661
  _CLUSTER._serialized_start=664
  _CLUSTER._serialized_end=1018
  _EKS._serialized_start=1021
  _EKS._serialized_end=1186
  _FARGATEPROFILELABEL._serialized_start=1188
  _FARGATEPROFILELABEL._serialized_end=1294
  _FARGATEPROFILESELECTOR._serialized_start=1297
  _FARGATEPROFILESELECTOR._serialized_end=1455
  _FARGATEPROFILE._serialized_start=1458
  _FARGATEPROFILE._serialized_end=1802
  _FARGATEPROFILE_TAGSENTRY._serialized_start=1759
  _FARGATEPROFILE_TAGSENTRY._serialized_end=1802
  _NODEGROUPSCALINGCONFIG._serialized_start=1805
  _NODEGROUPSCALINGCONFIG._serialized_end=1944
  _NODEGROUPLAUNCHTEMPLATESPECIFICATION._serialized_start=1947
  _NODEGROUPLAUNCHTEMPLATESPECIFICATION._serialized_end=2085
  _NODEGROUPREMOTEACCESS._serialized_start=2088
  _NODEGROUPREMOTEACCESS._serialized_end=2221
  _NODEGROUP._serialized_start=2224
  _NODEGROUP._serialized_end=2935
  _NODEGROUP_LABELSENTRY._serialized_start=2845
  _NODEGROUP_LABELSENTRY._serialized_end=2890
  _NODEGROUP_TAGSENTRY._serialized_start=1759
  _NODEGROUP_TAGSENTRY._serialized_end=1802
# @@protoc_insertion_point(module_scope)
