# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_kinesisanalytics.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x61ws/aws_kinesisanalytics.proto\x12 oak9.tython.aws.kinesisanalytics\x1a\x13shared/shared.proto\"\x83\x01\n\x17\x41pplicationRecordColumn\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07mapping\x18\x02 \x01(\t\x12\x10\n\x08sql_type\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\"t\n ApplicationJSONMappingParameters\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x17\n\x0frecord_row_path\x18\x02 \x01(\t\"\x99\x01\n\x1f\x41pplicationCSVMappingParameters\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1c\n\x14record_row_delimiter\x18\x02 \x01(\t\x12\x1f\n\x17record_column_delimiter\x18\x03 \x01(\t\"\xa0\x02\n\x1c\x41pplicationMappingParameters\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x63\n\x17json_mapping_parameters\x18\x02 \x01(\x0b\x32\x42.oak9.tython.aws.kinesisanalytics.ApplicationJSONMappingParameters\x12\x62\n\x17\x63s_v_mapping_parameters\x18\x03 \x01(\x0b\x32\x41.oak9.tython.aws.kinesisanalytics.ApplicationCSVMappingParameters\"\xca\x01\n\x17\x41pplicationRecordFormat\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12Z\n\x12mapping_parameters\x18\x02 \x01(\x0b\x32>.oak9.tython.aws.kinesisanalytics.ApplicationMappingParameters\x12\x1a\n\x12record_format_type\x18\x03 \x01(\t\"\x8f\x02\n\x16\x41pplicationInputSchema\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x17\n\x0frecord_encoding\x18\x02 \x01(\t\x12Q\n\x0erecord_columns\x18\x03 \x03(\x0b\x32\x39.oak9.tython.aws.kinesisanalytics.ApplicationRecordColumn\x12P\n\rrecord_format\x18\x04 \x01(\x0b\x32\x39.oak9.tython.aws.kinesisanalytics.ApplicationRecordFormat\"\x81\x01\n\x1e\x41pplicationKinesisStreamsInput\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0cresource_arn\x18\x02 \x01(\t\x12\x10\n\x08role_arn\x18\x03 \x01(\t\"\x82\x01\n\x1f\x41pplicationKinesisFirehoseInput\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0cresource_arn\x18\x02 \x01(\t\x12\x10\n\x08role_arn\x18\x03 \x01(\t\"\x82\x01\n\x1f\x41pplicationInputLambdaProcessor\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0cresource_arn\x18\x02 \x01(\t\x12\x10\n\x08role_arn\x18\x03 \x01(\t\"\xc5\x01\n\'ApplicationInputProcessingConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x61\n\x16input_lambda_processor\x18\x02 \x01(\x0b\x32\x41.oak9.tython.aws.kinesisanalytics.ApplicationInputLambdaProcessor\"e\n\x1b\x41pplicationInputParallelism\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\r\n\x05\x63ount\x18\x02 \x01(\x05\"\xc1\x04\n\x10\x41pplicationInput\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0bname_prefix\x18\x02 \x01(\t\x12N\n\x0cinput_schema\x18\x03 \x01(\x0b\x32\x38.oak9.tython.aws.kinesisanalytics.ApplicationInputSchema\x12_\n\x15kinesis_streams_input\x18\x04 \x01(\x0b\x32@.oak9.tython.aws.kinesisanalytics.ApplicationKinesisStreamsInput\x12\x61\n\x16kinesis_firehose_input\x18\x05 \x01(\x0b\x32\x41.oak9.tython.aws.kinesisanalytics.ApplicationKinesisFirehoseInput\x12q\n\x1einput_processing_configuration\x18\x06 \x01(\x0b\x32I.oak9.tython.aws.kinesisanalytics.ApplicationInputProcessingConfiguration\x12X\n\x11input_parallelism\x18\x07 \x01(\x0b\x32=.oak9.tython.aws.kinesisanalytics.ApplicationInputParallelism\"\xdf\x01\n\x0b\x41pplication\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x18\n\x10\x61pplication_name\x18\x02 \x01(\t\x12\x42\n\x06inputs\x18\x03 \x03(\x0b\x32\x32.oak9.tython.aws.kinesisanalytics.ApplicationInput\x12\x1f\n\x17\x61pplication_description\x18\x04 \x01(\t\x12\x18\n\x10\x61pplication_code\x18\x05 \x01(\t\"\x94\x02\n\x10KinesisAnalytics\x12\x42\n\x0b\x61pplication\x18\x01 \x03(\x0b\x32-.oak9.tython.aws.kinesisanalytics.Application\x12O\n\x12\x61pplication_output\x18\x02 \x03(\x0b\x32\x33.oak9.tython.aws.kinesisanalytics.ApplicationOutput\x12k\n!application_reference_data_source\x18\x03 \x03(\x0b\x32@.oak9.tython.aws.kinesisanalytics.ApplicationReferenceDataSource\"y\n\"ApplicationOutputDestinationSchema\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1a\n\x12record_format_type\x18\x02 \x01(\t\"\x80\x01\n\x1d\x41pplicationOutputLambdaOutput\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0cresource_arn\x18\x02 \x01(\t\x12\x10\n\x08role_arn\x18\x03 \x01(\t\"\x89\x01\n&ApplicationOutputKinesisFirehoseOutput\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0cresource_arn\x18\x02 \x01(\t\x12\x10\n\x08role_arn\x18\x03 \x01(\t\"\x88\x01\n%ApplicationOutputKinesisStreamsOutput\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0cresource_arn\x18\x02 \x01(\t\x12\x10\n\x08role_arn\x18\x03 \x01(\t\"\xee\x03\n\x17\x41pplicationOutputOutput\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12`\n\x12\x64\x65stination_schema\x18\x02 \x01(\x0b\x32\x44.oak9.tython.aws.kinesisanalytics.ApplicationOutputDestinationSchema\x12V\n\rlambda_output\x18\x03 \x01(\x0b\x32?.oak9.tython.aws.kinesisanalytics.ApplicationOutputLambdaOutput\x12i\n\x17kinesis_firehose_output\x18\x04 \x01(\x0b\x32H.oak9.tython.aws.kinesisanalytics.ApplicationOutputKinesisFirehoseOutput\x12g\n\x16kinesis_streams_output\x18\x05 \x01(\x0b\x32G.oak9.tython.aws.kinesisanalytics.ApplicationOutputKinesisStreamsOutput\x12\x0c\n\x04name\x18\x06 \x01(\t\"\xb1\x01\n\x11\x41pplicationOutput\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x18\n\x10\x61pplication_name\x18\x02 \x01(\t\x12I\n\x06output\x18\x03 \x01(\x0b\x32\x39.oak9.tython.aws.kinesisanalytics.ApplicationOutputOutput\"\x96\x01\n*ApplicationReferenceDataSourceRecordColumn\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07mapping\x18\x02 \x01(\t\x12\x10\n\x08sql_type\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\"\x87\x01\n3ApplicationReferenceDataSourceJSONMappingParameters\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x17\n\x0frecord_row_path\x18\x02 \x01(\t\"\xac\x01\n2ApplicationReferenceDataSourceCSVMappingParameters\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1c\n\x14record_row_delimiter\x18\x02 \x01(\t\x12\x1f\n\x17record_column_delimiter\x18\x03 \x01(\t\"\xd9\x02\n/ApplicationReferenceDataSourceMappingParameters\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12v\n\x17json_mapping_parameters\x18\x02 \x01(\x0b\x32U.oak9.tython.aws.kinesisanalytics.ApplicationReferenceDataSourceJSONMappingParameters\x12u\n\x17\x63s_v_mapping_parameters\x18\x03 \x01(\x0b\x32T.oak9.tython.aws.kinesisanalytics.ApplicationReferenceDataSourceCSVMappingParameters\"\xf0\x01\n*ApplicationReferenceDataSourceRecordFormat\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12m\n\x12mapping_parameters\x18\x02 \x01(\x0b\x32Q.oak9.tython.aws.kinesisanalytics.ApplicationReferenceDataSourceMappingParameters\x12\x1a\n\x12record_format_type\x18\x03 \x01(\t\"\xcc\x02\n-ApplicationReferenceDataSourceReferenceSchema\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x17\n\x0frecord_encoding\x18\x02 \x01(\t\x12\x64\n\x0erecord_columns\x18\x03 \x03(\x0b\x32L.oak9.tython.aws.kinesisanalytics.ApplicationReferenceDataSourceRecordColumn\x12\x63\n\rrecord_format\x18\x04 \x01(\x0b\x32L.oak9.tython.aws.kinesisanalytics.ApplicationReferenceDataSourceRecordFormat\"\xb0\x01\n3ApplicationReferenceDataSourceS3ReferenceDataSource\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\nbucket_arn\x18\x02 \x01(\t\x12\x10\n\x08\x66ile_key\x18\x03 \x01(\t\x12\x1a\n\x12reference_role_arn\x18\x04 \x01(\t\"\xe4\x02\n1ApplicationReferenceDataSourceReferenceDataSource\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12i\n\x10reference_schema\x18\x02 \x01(\x0b\x32O.oak9.tython.aws.kinesisanalytics.ApplicationReferenceDataSourceReferenceSchema\x12\x12\n\ntable_name\x18\x03 \x01(\t\x12w\n\x18s3_reference_data_source\x18\x04 \x01(\x0b\x32U.oak9.tython.aws.kinesisanalytics.ApplicationReferenceDataSourceS3ReferenceDataSource\"\xe7\x01\n\x1e\x41pplicationReferenceDataSource\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x18\n\x10\x61pplication_name\x18\x02 \x01(\t\x12r\n\x15reference_data_source\x18\x03 \x01(\x0b\x32S.oak9.tython.aws.kinesisanalytics.ApplicationReferenceDataSourceReferenceDataSourceb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_kinesisanalytics_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _APPLICATIONRECORDCOLUMN._serialized_start=90
  _APPLICATIONRECORDCOLUMN._serialized_end=221
  _APPLICATIONJSONMAPPINGPARAMETERS._serialized_start=223
  _APPLICATIONJSONMAPPINGPARAMETERS._serialized_end=339
  _APPLICATIONCSVMAPPINGPARAMETERS._serialized_start=342
  _APPLICATIONCSVMAPPINGPARAMETERS._serialized_end=495
  _APPLICATIONMAPPINGPARAMETERS._serialized_start=498
  _APPLICATIONMAPPINGPARAMETERS._serialized_end=786
  _APPLICATIONRECORDFORMAT._serialized_start=789
  _APPLICATIONRECORDFORMAT._serialized_end=991
  _APPLICATIONINPUTSCHEMA._serialized_start=994
  _APPLICATIONINPUTSCHEMA._serialized_end=1265
  _APPLICATIONKINESISSTREAMSINPUT._serialized_start=1268
  _APPLICATIONKINESISSTREAMSINPUT._serialized_end=1397
  _APPLICATIONKINESISFIREHOSEINPUT._serialized_start=1400
  _APPLICATIONKINESISFIREHOSEINPUT._serialized_end=1530
  _APPLICATIONINPUTLAMBDAPROCESSOR._serialized_start=1533
  _APPLICATIONINPUTLAMBDAPROCESSOR._serialized_end=1663
  _APPLICATIONINPUTPROCESSINGCONFIGURATION._serialized_start=1666
  _APPLICATIONINPUTPROCESSINGCONFIGURATION._serialized_end=1863
  _APPLICATIONINPUTPARALLELISM._serialized_start=1865
  _APPLICATIONINPUTPARALLELISM._serialized_end=1966
  _APPLICATIONINPUT._serialized_start=1969
  _APPLICATIONINPUT._serialized_end=2546
  _APPLICATION._serialized_start=2549
  _APPLICATION._serialized_end=2772
  _KINESISANALYTICS._serialized_start=2775
  _KINESISANALYTICS._serialized_end=3051
  _APPLICATIONOUTPUTDESTINATIONSCHEMA._serialized_start=3053
  _APPLICATIONOUTPUTDESTINATIONSCHEMA._serialized_end=3174
  _APPLICATIONOUTPUTLAMBDAOUTPUT._serialized_start=3177
  _APPLICATIONOUTPUTLAMBDAOUTPUT._serialized_end=3305
  _APPLICATIONOUTPUTKINESISFIREHOSEOUTPUT._serialized_start=3308
  _APPLICATIONOUTPUTKINESISFIREHOSEOUTPUT._serialized_end=3445
  _APPLICATIONOUTPUTKINESISSTREAMSOUTPUT._serialized_start=3448
  _APPLICATIONOUTPUTKINESISSTREAMSOUTPUT._serialized_end=3584
  _APPLICATIONOUTPUTOUTPUT._serialized_start=3587
  _APPLICATIONOUTPUTOUTPUT._serialized_end=4081
  _APPLICATIONOUTPUT._serialized_start=4084
  _APPLICATIONOUTPUT._serialized_end=4261
  _APPLICATIONREFERENCEDATASOURCERECORDCOLUMN._serialized_start=4264
  _APPLICATIONREFERENCEDATASOURCERECORDCOLUMN._serialized_end=4414
  _APPLICATIONREFERENCEDATASOURCEJSONMAPPINGPARAMETERS._serialized_start=4417
  _APPLICATIONREFERENCEDATASOURCEJSONMAPPINGPARAMETERS._serialized_end=4552
  _APPLICATIONREFERENCEDATASOURCECSVMAPPINGPARAMETERS._serialized_start=4555
  _APPLICATIONREFERENCEDATASOURCECSVMAPPINGPARAMETERS._serialized_end=4727
  _APPLICATIONREFERENCEDATASOURCEMAPPINGPARAMETERS._serialized_start=4730
  _APPLICATIONREFERENCEDATASOURCEMAPPINGPARAMETERS._serialized_end=5075
  _APPLICATIONREFERENCEDATASOURCERECORDFORMAT._serialized_start=5078
  _APPLICATIONREFERENCEDATASOURCERECORDFORMAT._serialized_end=5318
  _APPLICATIONREFERENCEDATASOURCEREFERENCESCHEMA._serialized_start=5321
  _APPLICATIONREFERENCEDATASOURCEREFERENCESCHEMA._serialized_end=5653
  _APPLICATIONREFERENCEDATASOURCES3REFERENCEDATASOURCE._serialized_start=5656
  _APPLICATIONREFERENCEDATASOURCES3REFERENCEDATASOURCE._serialized_end=5832
  _APPLICATIONREFERENCEDATASOURCEREFERENCEDATASOURCE._serialized_start=5835
  _APPLICATIONREFERENCEDATASOURCEREFERENCEDATASOURCE._serialized_end=6191
  _APPLICATIONREFERENCEDATASOURCE._serialized_start=6194
  _APPLICATIONREFERENCEDATASOURCE._serialized_end=6425
# @@protoc_insertion_point(module_scope)
