"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class AssuredWorkloadsWorkloadXKmsSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NEXT_ROTATION_TIME_FIELD_NUMBER: builtins.int
    ROTATION_PERIOD_FIELD_NUMBER: builtins.int
    next_rotation_time: builtins.str
    rotation_period: builtins.str
    def __init__(
        self,
        *,
        next_rotation_time: builtins.str = ...,
        rotation_period: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["next_rotation_time", b"next_rotation_time", "rotation_period", b"rotation_period"]) -> None: ...

global___AssuredWorkloadsWorkloadXKmsSettings = AssuredWorkloadsWorkloadXKmsSettings

@typing_extensions.final
class AssuredWorkloadsWorkloadXResourceSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_ID_FIELD_NUMBER: builtins.int
    RESOURCE_TYPE_FIELD_NUMBER: builtins.int
    resource_id: builtins.str
    resource_type: builtins.str
    def __init__(
        self,
        *,
        resource_id: builtins.str = ...,
        resource_type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_id", b"resource_id", "resource_type", b"resource_type"]) -> None: ...

global___AssuredWorkloadsWorkloadXResourceSettings = AssuredWorkloadsWorkloadXResourceSettings

@typing_extensions.final
class AssuredWorkloadsWorkloadXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___AssuredWorkloadsWorkloadXTimeouts = AssuredWorkloadsWorkloadXTimeouts

@typing_extensions.final
class AssuredWorkloadsWorkload(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class ResourcesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    BILLING_ACCOUNT_FIELD_NUMBER: builtins.int
    COMPLIANCE_REGIME_FIELD_NUMBER: builtins.int
    CREATE_TIME_FIELD_NUMBER: builtins.int
    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ORGANIZATION_FIELD_NUMBER: builtins.int
    PROVISIONED_RESOURCES_PARENT_FIELD_NUMBER: builtins.int
    RESOURCES_FIELD_NUMBER: builtins.int
    KMS_SETTINGS_FIELD_NUMBER: builtins.int
    RESOURCE_SETTINGS_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    billing_account: builtins.str
    compliance_regime: builtins.str
    create_time: builtins.str
    display_name: builtins.str
    id: builtins.str
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    location: builtins.str
    name: builtins.str
    organization: builtins.str
    provisioned_resources_parent: builtins.str
    @property
    def resources(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def kms_settings(self) -> global___AssuredWorkloadsWorkloadXKmsSettings: ...
    @property
    def resource_settings(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AssuredWorkloadsWorkloadXResourceSettings]: ...
    @property
    def timeouts(self) -> global___AssuredWorkloadsWorkloadXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        billing_account: builtins.str = ...,
        compliance_regime: builtins.str = ...,
        create_time: builtins.str = ...,
        display_name: builtins.str = ...,
        id: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        organization: builtins.str = ...,
        provisioned_resources_parent: builtins.str = ...,
        resources: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        kms_settings: global___AssuredWorkloadsWorkloadXKmsSettings | None = ...,
        resource_settings: collections.abc.Iterable[global___AssuredWorkloadsWorkloadXResourceSettings] | None = ...,
        timeouts: global___AssuredWorkloadsWorkloadXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["kms_settings", b"kms_settings", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["billing_account", b"billing_account", "compliance_regime", b"compliance_regime", "create_time", b"create_time", "display_name", b"display_name", "id", b"id", "kms_settings", b"kms_settings", "labels", b"labels", "location", b"location", "name", b"name", "organization", b"organization", "provisioned_resources_parent", b"provisioned_resources_parent", "resource_info", b"resource_info", "resource_settings", b"resource_settings", "resources", b"resources", "timeouts", b"timeouts"]) -> None: ...

global___AssuredWorkloadsWorkload = AssuredWorkloadsWorkload
