# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: azure/azure_microsoft_cache.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!azure/azure_microsoft_cache.proto\x12!oak9.tython.azure.microsoft_cache\x1a\x13shared/shared.proto\"\xcb\x02\n\x0fMicrosoft_Cache\x12\x37\n\x05redis\x18\x01 \x01(\x0b\x32(.oak9.tython.azure.microsoft_cache.Redis\x12S\n\x14redis_firewall_rules\x18\x02 \x03(\x0b\x32\x35.oak9.tython.azure.microsoft_cache.RedisFirewallRules\x12S\n\x14redis_linked_servers\x18\x03 \x01(\x0b\x32\x35.oak9.tython.azure.microsoft_cache.RedisLinkedServers\x12U\n\x15redis_patch_schedules\x18\x04 \x01(\x0b\x32\x36.oak9.tython.azure.microsoft_cache.RedisPatchSchedules\"\xc7\x02\n\x1fRedisPrivateEndpointConnections\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12L\n\x10private_endpoint\x18\x03 \x01(\x0b\x32\x32.oak9.tython.azure.microsoft_cache.PrivateEndpoint\x12s\n%private_link_service_connection_state\x18\x04 \x01(\x0b\x32\x44.oak9.tython.azure.microsoft_cache.PrivateLinkServiceConnectionState\x12\x1a\n\x12provisioning_state\x18\x05 \x01(\t\"b\n!PrivateLinkServiceConnectionState\x12\x18\n\x10\x61\x63tions_required\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0e\n\x06status\x18\x03 \x01(\t\"\x1f\n\x0fPrivateEndpoint\x12\x0c\n\x04name\x18\x01 \x01(\t\"\xa8\x01\n\x13RedisPatchSchedules\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12J\n\x10schedule_entries\x18\x03 \x03(\x0b\x32\x30.oak9.tython.azure.microsoft_cache.ScheduleEntry\"X\n\rScheduleEntry\x12\x13\n\x0b\x64\x61y_of_week\x18\x01 \x01(\t\x12\x1a\n\x12maintenance_window\x18\x02 \x01(\t\x12\x16\n\x0estart_hour_utc\x18\x03 \x01(\x05\"\xb4\x01\n\x12RedisLinkedServers\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x1d\n\x15linked_redis_cache_id\x18\x03 \x01(\t\x12#\n\x1blinked_redis_cache_location\x18\x04 \x01(\t\x12\x13\n\x0bserver_role\x18\x05 \x01(\t\"}\n\x12RedisFirewallRules\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0e\n\x06\x65nd_ip\x18\x03 \x01(\t\x12\x10\n\x08start_ip\x18\x04 \x01(\t\"\xad\x07\n\x05Redis\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12K\n\x08identity\x18\x02 \x01(\x0b\x32\x39.oak9.tython.azure.microsoft_cache.ManagedServiceIdentity\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x1b\n\x13\x65nable_non_ssl_port\x18\x05 \x01(\x08\x12\x1b\n\x13minimum_tls_version\x18\x06 \x01(\t\x12\x1d\n\x15public_network_access\x18\x07 \x01(\t\x12g\n\x13redis_configuration\x18\x08 \x01(\x0b\x32J.oak9.tython.azure.microsoft_cache.RedisCommonPropertiesRedisConfiguration\x12\x15\n\rredis_version\x18\t \x01(\t\x12\x1b\n\x13replicas_per_master\x18\n \x01(\x05\x12\x1c\n\x14replicas_per_primary\x18\x0b \x01(\x05\x12\x13\n\x0bshard_count\x18\x0c \x01(\x05\x12\x33\n\x03sku\x18\r \x01(\x0b\x32&.oak9.tython.azure.microsoft_cache.Sku\x12\x11\n\tstatic_ip\x18\x0e \x01(\t\x12\x11\n\tsubnet_id\x18\x0f \x01(\t\x12U\n\x0ftenant_settings\x18\x10 \x03(\x0b\x32<.oak9.tython.azure.microsoft_cache.Redis.TenantSettingsEntry\x12@\n\x04tags\x18\x11 \x03(\x0b\x32\x32.oak9.tython.azure.microsoft_cache.Redis.TagsEntry\x12\r\n\x05zones\x18\x12 \x03(\t\x12n\n\"redis_private_endpoint_connections\x18\x13 \x03(\x0b\x32\x42.oak9.tython.azure.microsoft_cache.RedisPrivateEndpointConnections\x1a\x35\n\x13TenantSettingsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"5\n\x03Sku\x12\x10\n\x08\x63\x61pacity\x18\x01 \x01(\x05\x12\x0e\n\x06\x66\x61mily\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\"\xbe\x04\n\'RedisCommonPropertiesRedisConfiguration\x12\x83\x01\n\x15\x61\x64\x64itional_properties\x18\x01 \x03(\x0b\x32\x64.oak9.tython.azure.microsoft_cache.RedisCommonPropertiesRedisConfiguration.AdditionalPropertiesEntry\x12\'\n\x1f\x61of_storage_connection_string_0\x18\x02 \x01(\t\x12\'\n\x1f\x61of_storage_connection_string_1\x18\x03 \x01(\t\x12\'\n\x1fmaxfragmentationmemory_reserved\x18\x04 \x01(\t\x12\x17\n\x0fmaxmemory_delta\x18\x05 \x01(\t\x12\x18\n\x10maxmemory_policy\x18\x06 \x01(\t\x12\x1a\n\x12maxmemory_reserved\x18\x07 \x01(\t\x12\x1a\n\x12rdb_backup_enabled\x18\x08 \x01(\t\x12\x1c\n\x14rdb_backup_frequency\x18\t \x01(\t\x12%\n\x1drdb_backup_max_snapshot_count\x18\n \x01(\t\x12%\n\x1drdb_storage_connection_string\x18\x0b \x01(\t\x1a;\n\x19\x41\x64\x64itionalPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xde\x01\n\x16ManagedServiceIdentity\x12\x0c\n\x04type\x18\x01 \x01(\t\x12w\n\x18user_assigned_identities\x18\x02 \x03(\x0b\x32U.oak9.tython.azure.microsoft_cache.ManagedServiceIdentity.UserAssignedIdentitiesEntry\x1a=\n\x1bUserAssignedIdentitiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'azure.azure_microsoft_cache_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _REDIS_TENANTSETTINGSENTRY._options = None
  _REDIS_TENANTSETTINGSENTRY._serialized_options = b'8\001'
  _REDIS_TAGSENTRY._options = None
  _REDIS_TAGSENTRY._serialized_options = b'8\001'
  _REDISCOMMONPROPERTIESREDISCONFIGURATION_ADDITIONALPROPERTIESENTRY._options = None
  _REDISCOMMONPROPERTIESREDISCONFIGURATION_ADDITIONALPROPERTIESENTRY._serialized_options = b'8\001'
  _MANAGEDSERVICEIDENTITY_USERASSIGNEDIDENTITIESENTRY._options = None
  _MANAGEDSERVICEIDENTITY_USERASSIGNEDIDENTITIESENTRY._serialized_options = b'8\001'
  _MICROSOFT_CACHE._serialized_start=94
  _MICROSOFT_CACHE._serialized_end=425
  _REDISPRIVATEENDPOINTCONNECTIONS._serialized_start=428
  _REDISPRIVATEENDPOINTCONNECTIONS._serialized_end=755
  _PRIVATELINKSERVICECONNECTIONSTATE._serialized_start=757
  _PRIVATELINKSERVICECONNECTIONSTATE._serialized_end=855
  _PRIVATEENDPOINT._serialized_start=857
  _PRIVATEENDPOINT._serialized_end=888
  _REDISPATCHSCHEDULES._serialized_start=891
  _REDISPATCHSCHEDULES._serialized_end=1059
  _SCHEDULEENTRY._serialized_start=1061
  _SCHEDULEENTRY._serialized_end=1149
  _REDISLINKEDSERVERS._serialized_start=1152
  _REDISLINKEDSERVERS._serialized_end=1332
  _REDISFIREWALLRULES._serialized_start=1334
  _REDISFIREWALLRULES._serialized_end=1459
  _REDIS._serialized_start=1462
  _REDIS._serialized_end=2403
  _REDIS_TENANTSETTINGSENTRY._serialized_start=2305
  _REDIS_TENANTSETTINGSENTRY._serialized_end=2358
  _REDIS_TAGSENTRY._serialized_start=2360
  _REDIS_TAGSENTRY._serialized_end=2403
  _SKU._serialized_start=2405
  _SKU._serialized_end=2458
  _REDISCOMMONPROPERTIESREDISCONFIGURATION._serialized_start=2461
  _REDISCOMMONPROPERTIESREDISCONFIGURATION._serialized_end=3035
  _REDISCOMMONPROPERTIESREDISCONFIGURATION_ADDITIONALPROPERTIESENTRY._serialized_start=2976
  _REDISCOMMONPROPERTIESREDISCONFIGURATION_ADDITIONALPROPERTIESENTRY._serialized_end=3035
  _MANAGEDSERVICEIDENTITY._serialized_start=3038
  _MANAGEDSERVICEIDENTITY._serialized_end=3260
  _MANAGEDSERVICEIDENTITY_USERASSIGNEDIDENTITIESENTRY._serialized_start=3199
  _MANAGEDSERVICEIDENTITY_USERASSIGNEDIDENTITIESENTRY._serialized_end=3260
# @@protoc_insertion_point(module_scope)
