# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_compute_interconnect.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"gcp/gcp_compute_interconnect.proto\x12$oak9.tython.gcp.compute_interconnect\x1a\x13shared/shared.proto\"X\n&ComputeInterconnectAttachmentXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\x8d\x07\n\x1d\x43omputeInterconnectAttachment\x12\x15\n\radmin_enabled\x18\x01 \x01(\x08\x12\x11\n\tbandwidth\x18\x02 \x01(\t\x12\x19\n\x11\x63\x61ndidate_subnets\x18\x03 \x03(\t\x12\x1f\n\x17\x63loud_router_ip_address\x18\x04 \x01(\t\x12\x1a\n\x12\x63reation_timestamp\x18\x05 \x01(\t\x12\"\n\x1a\x63ustomer_router_ip_address\x18\x06 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x07 \x01(\t\x12 \n\x18\x65\x64ge_availability_domain\x18\x08 \x01(\t\x12\x12\n\nencryption\x18\t \x01(\t\x12\x1b\n\x13google_reference_id\x18\n \x01(\t\x12\n\n\x02id\x18\x0b \x01(\t\x12\x14\n\x0cinterconnect\x18\x0c \x01(\t\x12 \n\x18ipsec_internal_addresses\x18\r \x03(\t\x12\x0b\n\x03mtu\x18\x0e \x01(\t\x12\x0c\n\x04name\x18\x0f \x01(\t\x12\x13\n\x0bpairing_key\x18\x10 \x01(\t\x12\x13\n\x0bpartner_asn\x18\x11 \x01(\t\x12\x83\x01\n\x19private_interconnect_info\x18\x12 \x03(\x0b\x32`.oak9.tython.gcp.compute_interconnect.ComputeInterconnectAttachment.PrivateInterconnectInfoEntry\x12\x0f\n\x07project\x18\x13 \x01(\t\x12\x0e\n\x06region\x18\x14 \x01(\t\x12\x0e\n\x06router\x18\x15 \x01(\t\x12\x11\n\tself_link\x18\x16 \x01(\t\x12\r\n\x05state\x18\x17 \x01(\t\x12\x0c\n\x04type\x18\x18 \x01(\t\x12\x15\n\rvlan_tag8021q\x18\x19 \x01(\x01\x12^\n\x08timeouts\x18\x1a \x01(\x0b\x32L.oak9.tython.gcp.compute_interconnect.ComputeInterconnectAttachmentXTimeouts\x12\x37\n\rresource_info\x18\x1b \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a>\n\x1cPrivateInterconnectInfoEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_compute_interconnect_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMPUTEINTERCONNECTATTACHMENT_PRIVATEINTERCONNECTINFOENTRY._options = None
  _COMPUTEINTERCONNECTATTACHMENT_PRIVATEINTERCONNECTINFOENTRY._serialized_options = b'8\001'
  _COMPUTEINTERCONNECTATTACHMENTXTIMEOUTS._serialized_start=97
  _COMPUTEINTERCONNECTATTACHMENTXTIMEOUTS._serialized_end=185
  _COMPUTEINTERCONNECTATTACHMENT._serialized_start=188
  _COMPUTEINTERCONNECTATTACHMENT._serialized_end=1097
  _COMPUTEINTERCONNECTATTACHMENT_PRIVATEINTERCONNECTINFOENTRY._serialized_start=1035
  _COMPUTEINTERCONNECTATTACHMENT_PRIVATEINTERCONNECTINFOENTRY._serialized_end=1097
# @@protoc_insertion_point(module_scope)
