# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kubernetes/kubernetes_io.k8s.api.resource.v1alpha1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2
from oak9.tython.models.kubernetes.kubernetes_io.k8s.api.core import v1_pb2 as kubernetes_dot_kubernetes__io_dot_k8s_dot_api_dot_core_dot_v1__pb2
from oak9.tython.models.kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta import v1_pb2 as kubernetes_dot_kubernetes__io_dot_k8s_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n8kubernetes/kubernetes_io.k8s.api.resource.v1alpha1.proto\x12%oak9.tython.k8s.api.resource.v1alpha1\x1a\x13shared/shared.proto\x1a.kubernetes/kubernetes_io.k8s.api.core.v1.proto\x1a@kubernetes/kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1.proto\"\xbe\x01\n\x10\x41llocationResult\x12\x45\n\x12\x61vailable_on_nodes\x18\x01 \x01(\x0b\x32).oak9.tython.k8s.api.core.v1.NodeSelector\x12\x17\n\x0fresource_handle\x18\x02 \x01(\t\x12\x11\n\tshareable\x18\x03 \x01(\x08\x12\x37\n\rresource_info\x18\x04 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xcc\x02\n\rPodScheduling\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12K\n\x08metadata\x18\x03 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12\x46\n\x04spec\x18\x04 \x01(\x0b\x32\x38.oak9.tython.k8s.api.resource.v1alpha1.PodSchedulingSpec\x12J\n\x06status\x18\x05 \x01(\x0b\x32:.oak9.tython.k8s.api.resource.v1alpha1.PodSchedulingStatus\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xff\x01\n\x11PodSchedulingList\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x43\n\x05items\x18\x02 \x03(\x0b\x32\x34.oak9.tython.k8s.api.resource.v1alpha1.PodScheduling\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12I\n\x08metadata\x18\x04 \x01(\x0b\x32\x37.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ListMeta\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"|\n\x11PodSchedulingSpec\x12\x17\n\x0fpotential_nodes\x18\x01 \x03(\t\x12\x15\n\rselected_node\x18\x02 \x01(\t\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xad\x01\n\x13PodSchedulingStatus\x12]\n\x0fresource_claims\x18\x01 \x03(\x0b\x32\x44.oak9.tython.k8s.api.resource.v1alpha1.ResourceClaimSchedulingStatus\x12\x37\n\rresource_info\x18\x02 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xcc\x02\n\rResourceClaim\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12K\n\x08metadata\x18\x03 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12\x46\n\x04spec\x18\x04 \x01(\x0b\x32\x38.oak9.tython.k8s.api.resource.v1alpha1.ResourceClaimSpec\x12J\n\x06status\x18\x05 \x01(\x0b\x32:.oak9.tython.k8s.api.resource.v1alpha1.ResourceClaimStatus\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x99\x01\n\x1eResourceClaimConsumerReference\x12\x11\n\tapi_group\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08resource\x18\x03 \x01(\t\x12\x0b\n\x03uid\x18\x04 \x01(\t\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xff\x01\n\x11ResourceClaimList\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x43\n\x05items\x18\x02 \x03(\x0b\x32\x34.oak9.tython.k8s.api.resource.v1alpha1.ResourceClaim\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12I\n\x08metadata\x18\x04 \x01(\x0b\x32\x37.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ListMeta\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x8a\x01\n ResourceClaimParametersReference\x12\x11\n\tapi_group\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x37\n\rresource_info\x18\x04 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x80\x01\n\x1dResourceClaimSchedulingStatus\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x18\n\x10unsuitable_nodes\x18\x02 \x03(\t\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xe3\x01\n\x11ResourceClaimSpec\x12\x17\n\x0f\x61llocation_mode\x18\x01 \x01(\t\x12_\n\x0eparameters_ref\x18\x02 \x01(\x0b\x32G.oak9.tython.k8s.api.resource.v1alpha1.ResourceClaimParametersReference\x12\x1b\n\x13resource_class_name\x18\x03 \x01(\t\x12\x37\n\rresource_info\x18\x04 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xad\x02\n\x13ResourceClaimStatus\x12K\n\nallocation\x18\x01 \x01(\x0b\x32\x37.oak9.tython.k8s.api.resource.v1alpha1.AllocationResult\x12\x1e\n\x16\x64\x65\x61llocation_requested\x18\x02 \x01(\x08\x12\x13\n\x0b\x64river_name\x18\x03 \x01(\t\x12[\n\x0creserved_for\x18\x04 \x03(\x0b\x32\x45.oak9.tython.k8s.api.resource.v1alpha1.ResourceClaimConsumerReference\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x90\x02\n\x15ResourceClaimTemplate\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12K\n\x08metadata\x18\x03 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12N\n\x04spec\x18\x04 \x01(\x0b\x32@.oak9.tython.k8s.api.resource.v1alpha1.ResourceClaimTemplateSpec\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x8f\x02\n\x19ResourceClaimTemplateList\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12K\n\x05items\x18\x02 \x03(\x0b\x32<.oak9.tython.k8s.api.resource.v1alpha1.ResourceClaimTemplate\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12I\n\x08metadata\x18\x04 \x01(\x0b\x32\x37.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ListMeta\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xe9\x01\n\x19ResourceClaimTemplateSpec\x12K\n\x08metadata\x18\x01 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12\x46\n\x04spec\x18\x02 \x01(\x0b\x32\x38.oak9.tython.k8s.api.resource.v1alpha1.ResourceClaimSpec\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xf1\x02\n\rResourceClass\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x13\n\x0b\x64river_name\x18\x02 \x01(\t\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12K\n\x08metadata\x18\x04 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12_\n\x0eparameters_ref\x18\x05 \x01(\x0b\x32G.oak9.tython.k8s.api.resource.v1alpha1.ResourceClassParametersReference\x12\x41\n\x0esuitable_nodes\x18\x06 \x01(\x0b\x32).oak9.tython.k8s.api.core.v1.NodeSelector\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xff\x01\n\x11ResourceClassList\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x43\n\x05items\x18\x02 \x03(\x0b\x32\x34.oak9.tython.k8s.api.resource.v1alpha1.ResourceClass\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12I\n\x08metadata\x18\x04 \x01(\x0b\x32\x37.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ListMeta\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x9d\x01\n ResourceClassParametersReference\x12\x11\n\tapi_group\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x11\n\tnamespace\x18\x04 \x01(\t\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'kubernetes.kubernetes_io.k8s.api.resource.v1alpha1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ALLOCATIONRESULT._serialized_start=235
  _ALLOCATIONRESULT._serialized_end=425
  _PODSCHEDULING._serialized_start=428
  _PODSCHEDULING._serialized_end=760
  _PODSCHEDULINGLIST._serialized_start=763
  _PODSCHEDULINGLIST._serialized_end=1018
  _PODSCHEDULINGSPEC._serialized_start=1020
  _PODSCHEDULINGSPEC._serialized_end=1144
  _PODSCHEDULINGSTATUS._serialized_start=1147
  _PODSCHEDULINGSTATUS._serialized_end=1320
  _RESOURCECLAIM._serialized_start=1323
  _RESOURCECLAIM._serialized_end=1655
  _RESOURCECLAIMCONSUMERREFERENCE._serialized_start=1658
  _RESOURCECLAIMCONSUMERREFERENCE._serialized_end=1811
  _RESOURCECLAIMLIST._serialized_start=1814
  _RESOURCECLAIMLIST._serialized_end=2069
  _RESOURCECLAIMPARAMETERSREFERENCE._serialized_start=2072
  _RESOURCECLAIMPARAMETERSREFERENCE._serialized_end=2210
  _RESOURCECLAIMSCHEDULINGSTATUS._serialized_start=2213
  _RESOURCECLAIMSCHEDULINGSTATUS._serialized_end=2341
  _RESOURCECLAIMSPEC._serialized_start=2344
  _RESOURCECLAIMSPEC._serialized_end=2571
  _RESOURCECLAIMSTATUS._serialized_start=2574
  _RESOURCECLAIMSTATUS._serialized_end=2875
  _RESOURCECLAIMTEMPLATE._serialized_start=2878
  _RESOURCECLAIMTEMPLATE._serialized_end=3150
  _RESOURCECLAIMTEMPLATELIST._serialized_start=3153
  _RESOURCECLAIMTEMPLATELIST._serialized_end=3424
  _RESOURCECLAIMTEMPLATESPEC._serialized_start=3427
  _RESOURCECLAIMTEMPLATESPEC._serialized_end=3660
  _RESOURCECLASS._serialized_start=3663
  _RESOURCECLASS._serialized_end=4032
  _RESOURCECLASSLIST._serialized_start=4035
  _RESOURCECLASSLIST._serialized_end=4290
  _RESOURCECLASSPARAMETERSREFERENCE._serialized_start=4293
  _RESOURCECLASSPARAMETERSREFERENCE._serialized_end=4450
# @@protoc_insertion_point(module_scope)
