"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ComputeServiceAttachmentXConsumerAcceptLists(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONNECTION_LIMIT_FIELD_NUMBER: builtins.int
    PROJECT_ID_OR_NUM_FIELD_NUMBER: builtins.int
    connection_limit: builtins.float
    project_id_or_num: builtins.str
    def __init__(
        self,
        *,
        connection_limit: builtins.float = ...,
        project_id_or_num: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["connection_limit", b"connection_limit", "project_id_or_num", b"project_id_or_num"]) -> None: ...

global___ComputeServiceAttachmentXConsumerAcceptLists = ComputeServiceAttachmentXConsumerAcceptLists

@typing_extensions.final
class ComputeServiceAttachmentXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___ComputeServiceAttachmentXTimeouts = ComputeServiceAttachmentXTimeouts

@typing_extensions.final
class ComputeServiceAttachment(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class ConnectedEndpointsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    CONNECTED_ENDPOINTS_FIELD_NUMBER: builtins.int
    CONNECTION_PREFERENCE_FIELD_NUMBER: builtins.int
    CONSUMER_REJECT_LISTS_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    DOMAIN_NAMES_FIELD_NUMBER: builtins.int
    ENABLE_PROXY_PROTOCOL_FIELD_NUMBER: builtins.int
    FINGERPRINT_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    NAT_SUBNETS_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    SELF_LINK_FIELD_NUMBER: builtins.int
    TARGET_SERVICE_FIELD_NUMBER: builtins.int
    CONSUMER_ACCEPT_LISTS_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def connected_endpoints(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    connection_preference: builtins.str
    @property
    def consumer_reject_lists(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    description: builtins.str
    @property
    def domain_names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    enable_proxy_protocol: builtins.bool
    fingerprint: builtins.str
    id: builtins.str
    name: builtins.str
    @property
    def nat_subnets(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    project: builtins.str
    region: builtins.str
    self_link: builtins.str
    target_service: builtins.str
    @property
    def consumer_accept_lists(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeServiceAttachmentXConsumerAcceptLists]: ...
    @property
    def timeouts(self) -> global___ComputeServiceAttachmentXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        connected_endpoints: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        connection_preference: builtins.str = ...,
        consumer_reject_lists: collections.abc.Iterable[builtins.str] | None = ...,
        description: builtins.str = ...,
        domain_names: collections.abc.Iterable[builtins.str] | None = ...,
        enable_proxy_protocol: builtins.bool = ...,
        fingerprint: builtins.str = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        nat_subnets: collections.abc.Iterable[builtins.str] | None = ...,
        project: builtins.str = ...,
        region: builtins.str = ...,
        self_link: builtins.str = ...,
        target_service: builtins.str = ...,
        consumer_accept_lists: collections.abc.Iterable[global___ComputeServiceAttachmentXConsumerAcceptLists] | None = ...,
        timeouts: global___ComputeServiceAttachmentXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["connected_endpoints", b"connected_endpoints", "connection_preference", b"connection_preference", "consumer_accept_lists", b"consumer_accept_lists", "consumer_reject_lists", b"consumer_reject_lists", "description", b"description", "domain_names", b"domain_names", "enable_proxy_protocol", b"enable_proxy_protocol", "fingerprint", b"fingerprint", "id", b"id", "name", b"name", "nat_subnets", b"nat_subnets", "project", b"project", "region", b"region", "resource_info", b"resource_info", "self_link", b"self_link", "target_service", b"target_service", "timeouts", b"timeouts"]) -> None: ...

global___ComputeServiceAttachment = ComputeServiceAttachment
