# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_backup.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14\x61ws/aws_backup.proto\x12\x16oak9.tython.aws.backup\x1a\x13shared/shared.proto\"\x9e\x01\n\x1f\x42\x61\x63kupPlanLifecycleResourceType\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x19\n\x11\x64\x65lete_after_days\x18\x02 \x01(\x01\x12\'\n\x1fmove_to_cold_storage_after_days\x18\x03 \x01(\x01\"\xcd\x01\n BackupPlanCopyActionResourceType\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12J\n\tlifecycle\x18\x02 \x01(\x0b\x32\x37.oak9.tython.aws.backup.BackupPlanLifecycleResourceType\x12$\n\x1c\x64\x65stination_backup_vault_arn\x18\x03 \x01(\t\"\xad\x04\n BackupPlanBackupRuleResourceType\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12!\n\x19\x63ompletion_window_minutes\x18\x02 \x01(\x01\x12\x1b\n\x13schedule_expression\x18\x03 \x01(\t\x12l\n\x13recovery_point_tags\x18\x04 \x03(\x0b\x32O.oak9.tython.aws.backup.BackupPlanBackupRuleResourceType.RecoveryPointTagsEntry\x12N\n\x0c\x63opy_actions\x18\x05 \x03(\x0b\x32\x38.oak9.tython.aws.backup.BackupPlanCopyActionResourceType\x12J\n\tlifecycle\x18\x06 \x01(\x0b\x32\x37.oak9.tython.aws.backup.BackupPlanLifecycleResourceType\x12\x1b\n\x13target_backup_vault\x18\x07 \x01(\t\x12\x1c\n\x14start_window_minutes\x18\x08 \x01(\x01\x12\x11\n\trule_name\x18\t \x01(\t\x1a\x38\n\x16RecoveryPointTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xc9\x01\n BackupPlanBackupPlanResourceType\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x18\n\x10\x62\x61\x63kup_plan_name\x18\x02 \x01(\t\x12R\n\x10\x62\x61\x63kup_plan_rule\x18\x03 \x03(\x0b\x32\x38.oak9.tython.aws.backup.BackupPlanBackupRuleResourceType\"\x9d\x02\n\nBackupPlan\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12M\n\x0b\x62\x61\x63kup_plan\x18\x02 \x01(\x0b\x32\x38.oak9.tython.aws.backup.BackupPlanBackupPlanResourceType\x12P\n\x10\x62\x61\x63kup_plan_tags\x18\x03 \x03(\x0b\x32\x36.oak9.tython.aws.backup.BackupPlan.BackupPlanTagsEntry\x1a\x35\n\x13\x42\x61\x63kupPlanTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xbf\x01\n\x06\x42\x61\x63kup\x12\x37\n\x0b\x62\x61\x63kup_plan\x18\x01 \x03(\x0b\x32\".oak9.tython.aws.backup.BackupPlan\x12\x41\n\x10\x62\x61\x63kup_selection\x18\x02 \x03(\x0b\x32\'.oak9.tython.aws.backup.BackupSelection\x12\x39\n\x0c\x62\x61\x63kup_vault\x18\x03 \x03(\x0b\x32#.oak9.tython.aws.backup.BackupVault\"\xa7\x01\n$BackupSelectionConditionResourceType\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x17\n\x0f\x63ondition_value\x18\x02 \x01(\t\x12\x15\n\rcondition_key\x18\x03 \x01(\t\x12\x16\n\x0e\x63ondition_type\x18\x04 \x01(\t\"\xfa\x01\n*BackupSelectionBackupSelectionResourceType\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12R\n\x0clist_of_tags\x18\x02 \x03(\x0b\x32<.oak9.tython.aws.backup.BackupSelectionConditionResourceType\x12\x16\n\x0eselection_name\x18\x03 \x01(\t\x12\x14\n\x0ciam_role_arn\x18\x04 \x01(\t\x12\x11\n\tresources\x18\x05 \x03(\t\"\xc0\x01\n\x0f\x42\x61\x63kupSelection\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\\\n\x10\x62\x61\x63kup_selection\x18\x02 \x01(\x0b\x32\x42.oak9.tython.aws.backup.BackupSelectionBackupSelectionResourceType\x12\x16\n\x0e\x62\x61\x63kup_plan_id\x18\x03 \x01(\t\"\x90\x01\n!BackupVaultNotificationObjectType\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rsns_topic_arn\x18\x02 \x01(\t\x12\x1b\n\x13\x62\x61\x63kup_vault_events\x18\x03 \x03(\t\"\xdf\x03\n\x0b\x42\x61\x63kupVault\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12S\n\x11\x62\x61\x63kup_vault_tags\x18\x02 \x03(\x0b\x32\x38.oak9.tython.aws.backup.BackupVault.BackupVaultTagsEntry\x12\x19\n\x11\x62\x61\x63kup_vault_name\x18\x03 \x01(\t\x12\x1a\n\x12\x65ncryption_key_arn\x18\x04 \x01(\t\x12P\n\rnotifications\x18\x05 \x01(\x0b\x32\x39.oak9.tython.aws.backup.BackupVaultNotificationObjectType\x12L\n\raccess_policy\x18\x06 \x03(\x0b\x32\x35.oak9.tython.aws.backup.BackupVault.AccessPolicyEntry\x1a\x36\n\x14\x42\x61\x63kupVaultTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x33\n\x11\x41\x63\x63\x65ssPolicyEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_backup_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _BACKUPPLANBACKUPRULERESOURCETYPE_RECOVERYPOINTTAGSENTRY._options = None
  _BACKUPPLANBACKUPRULERESOURCETYPE_RECOVERYPOINTTAGSENTRY._serialized_options = b'8\001'
  _BACKUPPLAN_BACKUPPLANTAGSENTRY._options = None
  _BACKUPPLAN_BACKUPPLANTAGSENTRY._serialized_options = b'8\001'
  _BACKUPVAULT_BACKUPVAULTTAGSENTRY._options = None
  _BACKUPVAULT_BACKUPVAULTTAGSENTRY._serialized_options = b'8\001'
  _BACKUPVAULT_ACCESSPOLICYENTRY._options = None
  _BACKUPVAULT_ACCESSPOLICYENTRY._serialized_options = b'8\001'
  _BACKUPPLANLIFECYCLERESOURCETYPE._serialized_start=70
  _BACKUPPLANLIFECYCLERESOURCETYPE._serialized_end=228
  _BACKUPPLANCOPYACTIONRESOURCETYPE._serialized_start=231
  _BACKUPPLANCOPYACTIONRESOURCETYPE._serialized_end=436
  _BACKUPPLANBACKUPRULERESOURCETYPE._serialized_start=439
  _BACKUPPLANBACKUPRULERESOURCETYPE._serialized_end=996
  _BACKUPPLANBACKUPRULERESOURCETYPE_RECOVERYPOINTTAGSENTRY._serialized_start=940
  _BACKUPPLANBACKUPRULERESOURCETYPE_RECOVERYPOINTTAGSENTRY._serialized_end=996
  _BACKUPPLANBACKUPPLANRESOURCETYPE._serialized_start=999
  _BACKUPPLANBACKUPPLANRESOURCETYPE._serialized_end=1200
  _BACKUPPLAN._serialized_start=1203
  _BACKUPPLAN._serialized_end=1488
  _BACKUPPLAN_BACKUPPLANTAGSENTRY._serialized_start=1435
  _BACKUPPLAN_BACKUPPLANTAGSENTRY._serialized_end=1488
  _BACKUP._serialized_start=1491
  _BACKUP._serialized_end=1682
  _BACKUPSELECTIONCONDITIONRESOURCETYPE._serialized_start=1685
  _BACKUPSELECTIONCONDITIONRESOURCETYPE._serialized_end=1852
  _BACKUPSELECTIONBACKUPSELECTIONRESOURCETYPE._serialized_start=1855
  _BACKUPSELECTIONBACKUPSELECTIONRESOURCETYPE._serialized_end=2105
  _BACKUPSELECTION._serialized_start=2108
  _BACKUPSELECTION._serialized_end=2300
  _BACKUPVAULTNOTIFICATIONOBJECTTYPE._serialized_start=2303
  _BACKUPVAULTNOTIFICATIONOBJECTTYPE._serialized_end=2447
  _BACKUPVAULT._serialized_start=2450
  _BACKUPVAULT._serialized_end=2929
  _BACKUPVAULT_BACKUPVAULTTAGSENTRY._serialized_start=2822
  _BACKUPVAULT_BACKUPVAULTTAGSENTRY._serialized_end=2876
  _BACKUPVAULT_ACCESSPOLICYENTRY._serialized_start=2878
  _BACKUPVAULT_ACCESSPOLICYENTRY._serialized_end=2929
# @@protoc_insertion_point(module_scope)
