# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_ec2_securitygroup.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x61ws/aws_ec2_securitygroup.proto\x12!oak9.tython.aws.ec2_securitygroup\x1a\x13shared/shared.proto\"P\n\x13SecurityGroupEgress\x12\x39\n\x06\x65gress\x18\x01 \x01(\x0b\x32).oak9.tython.aws.ec2_securitygroup.Egress\"S\n\x14SecurityGroupIngress\x12;\n\x07ingress\x18\x01 \x01(\x0b\x32*.oak9.tython.aws.ec2_securitygroup.Ingress\"\xae\x03\n\rSecurityGroup\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x19\n\x11group_description\x18\x02 \x01(\t\x12\x12\n\ngroup_name\x18\x03 \x01(\t\x12U\n\x15security_group_egress\x18\x04 \x03(\x0b\x32\x36.oak9.tython.aws.ec2_securitygroup.SecurityGroupEgress\x12W\n\x16security_group_ingress\x18\x05 \x03(\x0b\x32\x37.oak9.tython.aws.ec2_securitygroup.SecurityGroupIngress\x12H\n\x04tags\x18\x06 \x03(\x0b\x32:.oak9.tython.aws.ec2_securitygroup.SecurityGroup.TagsEntry\x12\x0e\n\x06vpc_id\x18\x07 \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xfe\x01\n\x06\x45gress\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07\x63idr_ip\x18\x02 \x01(\t\x12\x11\n\tcidr_ipv6\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\"\n\x1a\x64\x65stination_prefix_list_id\x18\x05 \x01(\t\x12%\n\x1d\x64\x65stination_security_group_id\x18\x06 \x01(\t\x12\x11\n\tfrom_port\x18\x07 \x01(\x05\x12\x13\n\x0bip_protocol\x18\x08 \x01(\t\x12\x0f\n\x07to_port\x18\t \x01(\x05\"\xc1\x02\n\x07Ingress\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07\x63idr_ip\x18\x02 \x01(\t\x12\x11\n\tcidr_ipv6\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x1d\n\x15source_prefix_list_id\x18\x05 \x01(\t\x12 \n\x18source_security_group_id\x18\x06 \x01(\t\x12\"\n\x1asource_security_group_name\x18\x07 \x01(\t\x12&\n\x1esource_security_group_owner_id\x18\x08 \x01(\t\x12\x11\n\tfrom_port\x18\t \x01(\x05\x12\x13\n\x0bip_protocol\x18\n \x01(\t\x12\x0f\n\x07to_port\x18\x0b \x01(\x05\"]\n\x11\x45\x43\x32_SecurityGroup\x12H\n\x0esecurity_group\x18\x01 \x01(\x0b\x32\x30.oak9.tython.aws.ec2_securitygroup.SecurityGroupb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_ec2_securitygroup_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SECURITYGROUP_TAGSENTRY._options = None
  _SECURITYGROUP_TAGSENTRY._serialized_options = b'8\001'
  _SECURITYGROUPEGRESS._serialized_start=91
  _SECURITYGROUPEGRESS._serialized_end=171
  _SECURITYGROUPINGRESS._serialized_start=173
  _SECURITYGROUPINGRESS._serialized_end=256
  _SECURITYGROUP._serialized_start=259
  _SECURITYGROUP._serialized_end=689
  _SECURITYGROUP_TAGSENTRY._serialized_start=646
  _SECURITYGROUP_TAGSENTRY._serialized_end=689
  _EGRESS._serialized_start=692
  _EGRESS._serialized_end=946
  _INGRESS._serialized_start=949
  _INGRESS._serialized_end=1270
  _EC2_SECURITYGROUP._serialized_start=1272
  _EC2_SECURITYGROUP._serialized_end=1365
# @@protoc_insertion_point(module_scope)
