"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ComputeReservationXShareSettingsXProjectMap(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    PROJECT_ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    project_id: builtins.str
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        project_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "project_id", b"project_id"]) -> None: ...

global___ComputeReservationXShareSettingsXProjectMap = ComputeReservationXShareSettingsXProjectMap

@typing_extensions.final
class ComputeReservationXShareSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SHARE_TYPE_FIELD_NUMBER: builtins.int
    PROJECT_MAP_FIELD_NUMBER: builtins.int
    share_type: builtins.str
    @property
    def project_map(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeReservationXShareSettingsXProjectMap]: ...
    def __init__(
        self,
        *,
        share_type: builtins.str = ...,
        project_map: collections.abc.Iterable[global___ComputeReservationXShareSettingsXProjectMap] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["project_map", b"project_map", "share_type", b"share_type"]) -> None: ...

global___ComputeReservationXShareSettings = ComputeReservationXShareSettings

@typing_extensions.final
class ComputeReservationXSpecificReservationXInstancePropertiesXGuestAccelerators(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACCELERATOR_COUNT_FIELD_NUMBER: builtins.int
    ACCELERATOR_TYPE_FIELD_NUMBER: builtins.int
    accelerator_count: builtins.float
    accelerator_type: builtins.str
    def __init__(
        self,
        *,
        accelerator_count: builtins.float = ...,
        accelerator_type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["accelerator_count", b"accelerator_count", "accelerator_type", b"accelerator_type"]) -> None: ...

global___ComputeReservationXSpecificReservationXInstancePropertiesXGuestAccelerators = ComputeReservationXSpecificReservationXInstancePropertiesXGuestAccelerators

@typing_extensions.final
class ComputeReservationXSpecificReservationXInstancePropertiesXLocalSsds(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISK_SIZE_GB_FIELD_NUMBER: builtins.int
    INTERFACE_FIELD_NUMBER: builtins.int
    disk_size_gb: builtins.float
    interface: builtins.str
    def __init__(
        self,
        *,
        disk_size_gb: builtins.float = ...,
        interface: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["disk_size_gb", b"disk_size_gb", "interface", b"interface"]) -> None: ...

global___ComputeReservationXSpecificReservationXInstancePropertiesXLocalSsds = ComputeReservationXSpecificReservationXInstancePropertiesXLocalSsds

@typing_extensions.final
class ComputeReservationXSpecificReservationXInstanceProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MACHINE_TYPE_FIELD_NUMBER: builtins.int
    MIN_CPU_PLATFORM_FIELD_NUMBER: builtins.int
    GUEST_ACCELERATORS_FIELD_NUMBER: builtins.int
    LOCAL_SSDS_FIELD_NUMBER: builtins.int
    machine_type: builtins.str
    min_cpu_platform: builtins.str
    @property
    def guest_accelerators(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeReservationXSpecificReservationXInstancePropertiesXGuestAccelerators]: ...
    @property
    def local_ssds(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeReservationXSpecificReservationXInstancePropertiesXLocalSsds]: ...
    def __init__(
        self,
        *,
        machine_type: builtins.str = ...,
        min_cpu_platform: builtins.str = ...,
        guest_accelerators: collections.abc.Iterable[global___ComputeReservationXSpecificReservationXInstancePropertiesXGuestAccelerators] | None = ...,
        local_ssds: collections.abc.Iterable[global___ComputeReservationXSpecificReservationXInstancePropertiesXLocalSsds] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["guest_accelerators", b"guest_accelerators", "local_ssds", b"local_ssds", "machine_type", b"machine_type", "min_cpu_platform", b"min_cpu_platform"]) -> None: ...

global___ComputeReservationXSpecificReservationXInstanceProperties = ComputeReservationXSpecificReservationXInstanceProperties

@typing_extensions.final
class ComputeReservationXSpecificReservation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COUNT_FIELD_NUMBER: builtins.int
    IN_USE_COUNT_FIELD_NUMBER: builtins.int
    INSTANCE_PROPERTIES_FIELD_NUMBER: builtins.int
    count: builtins.float
    in_use_count: builtins.float
    @property
    def instance_properties(self) -> global___ComputeReservationXSpecificReservationXInstanceProperties: ...
    def __init__(
        self,
        *,
        count: builtins.float = ...,
        in_use_count: builtins.float = ...,
        instance_properties: global___ComputeReservationXSpecificReservationXInstanceProperties | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["instance_properties", b"instance_properties"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["count", b"count", "in_use_count", b"in_use_count", "instance_properties", b"instance_properties"]) -> None: ...

global___ComputeReservationXSpecificReservation = ComputeReservationXSpecificReservation

@typing_extensions.final
class ComputeReservationXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___ComputeReservationXTimeouts = ComputeReservationXTimeouts

@typing_extensions.final
class ComputeReservation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMMITMENT_FIELD_NUMBER: builtins.int
    CREATION_TIMESTAMP_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    SELF_LINK_FIELD_NUMBER: builtins.int
    SPECIFIC_RESERVATION_REQUIRED_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    ZONE_FIELD_NUMBER: builtins.int
    SHARE_SETTINGS_FIELD_NUMBER: builtins.int
    SPECIFIC_RESERVATION_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    commitment: builtins.str
    creation_timestamp: builtins.str
    description: builtins.str
    id: builtins.str
    name: builtins.str
    project: builtins.str
    self_link: builtins.str
    specific_reservation_required: builtins.bool
    status: builtins.str
    zone: builtins.str
    @property
    def share_settings(self) -> global___ComputeReservationXShareSettings: ...
    @property
    def specific_reservation(self) -> global___ComputeReservationXSpecificReservation: ...
    @property
    def timeouts(self) -> global___ComputeReservationXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        commitment: builtins.str = ...,
        creation_timestamp: builtins.str = ...,
        description: builtins.str = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        self_link: builtins.str = ...,
        specific_reservation_required: builtins.bool = ...,
        status: builtins.str = ...,
        zone: builtins.str = ...,
        share_settings: global___ComputeReservationXShareSettings | None = ...,
        specific_reservation: global___ComputeReservationXSpecificReservation | None = ...,
        timeouts: global___ComputeReservationXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "share_settings", b"share_settings", "specific_reservation", b"specific_reservation", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["commitment", b"commitment", "creation_timestamp", b"creation_timestamp", "description", b"description", "id", b"id", "name", b"name", "project", b"project", "resource_info", b"resource_info", "self_link", b"self_link", "share_settings", b"share_settings", "specific_reservation", b"specific_reservation", "specific_reservation_required", b"specific_reservation_required", "status", b"status", "timeouts", b"timeouts", "zone", b"zone"]) -> None: ...

global___ComputeReservation = ComputeReservation
