"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class CloudiotDeviceXCredentialsXPublicKey(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FORMAT_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    format: builtins.str
    key: builtins.str
    def __init__(
        self,
        *,
        format: builtins.str = ...,
        key: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["format", b"format", "key", b"key"]) -> None: ...

global___CloudiotDeviceXCredentialsXPublicKey = CloudiotDeviceXCredentialsXPublicKey

@typing_extensions.final
class CloudiotDeviceXCredentials(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXPIRATION_TIME_FIELD_NUMBER: builtins.int
    PUBLIC_KEY_FIELD_NUMBER: builtins.int
    expiration_time: builtins.str
    @property
    def public_key(self) -> global___CloudiotDeviceXCredentialsXPublicKey: ...
    def __init__(
        self,
        *,
        expiration_time: builtins.str = ...,
        public_key: global___CloudiotDeviceXCredentialsXPublicKey | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["public_key", b"public_key"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["expiration_time", b"expiration_time", "public_key", b"public_key"]) -> None: ...

global___CloudiotDeviceXCredentials = CloudiotDeviceXCredentials

@typing_extensions.final
class CloudiotDeviceXGatewayConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GATEWAY_AUTH_METHOD_FIELD_NUMBER: builtins.int
    GATEWAY_TYPE_FIELD_NUMBER: builtins.int
    LAST_ACCESSED_GATEWAY_ID_FIELD_NUMBER: builtins.int
    LAST_ACCESSED_GATEWAY_TIME_FIELD_NUMBER: builtins.int
    gateway_auth_method: builtins.str
    gateway_type: builtins.str
    last_accessed_gateway_id: builtins.str
    last_accessed_gateway_time: builtins.str
    def __init__(
        self,
        *,
        gateway_auth_method: builtins.str = ...,
        gateway_type: builtins.str = ...,
        last_accessed_gateway_id: builtins.str = ...,
        last_accessed_gateway_time: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["gateway_auth_method", b"gateway_auth_method", "gateway_type", b"gateway_type", "last_accessed_gateway_id", b"last_accessed_gateway_id", "last_accessed_gateway_time", b"last_accessed_gateway_time"]) -> None: ...

global___CloudiotDeviceXGatewayConfig = CloudiotDeviceXGatewayConfig

@typing_extensions.final
class CloudiotDeviceXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___CloudiotDeviceXTimeouts = CloudiotDeviceXTimeouts

@typing_extensions.final
class CloudiotDevice(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class ConfigEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class LastErrorStatusEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class MetadataEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class StateEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    BLOCKED_FIELD_NUMBER: builtins.int
    CONFIG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LAST_CONFIG_ACK_TIME_FIELD_NUMBER: builtins.int
    LAST_CONFIG_SEND_TIME_FIELD_NUMBER: builtins.int
    LAST_ERROR_STATUS_FIELD_NUMBER: builtins.int
    LAST_ERROR_TIME_FIELD_NUMBER: builtins.int
    LAST_EVENT_TIME_FIELD_NUMBER: builtins.int
    LAST_HEARTBEAT_TIME_FIELD_NUMBER: builtins.int
    LAST_STATE_TIME_FIELD_NUMBER: builtins.int
    LOG_LEVEL_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    NUM_ID_FIELD_NUMBER: builtins.int
    REGISTRY_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    CREDENTIALS_FIELD_NUMBER: builtins.int
    GATEWAY_CONFIG_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    blocked: builtins.bool
    @property
    def config(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    id: builtins.str
    last_config_ack_time: builtins.str
    last_config_send_time: builtins.str
    @property
    def last_error_status(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    last_error_time: builtins.str
    last_event_time: builtins.str
    last_heartbeat_time: builtins.str
    last_state_time: builtins.str
    log_level: builtins.str
    @property
    def metadata(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    name: builtins.str
    num_id: builtins.str
    registry: builtins.str
    @property
    def state(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def credentials(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CloudiotDeviceXCredentials]: ...
    @property
    def gateway_config(self) -> global___CloudiotDeviceXGatewayConfig: ...
    @property
    def timeouts(self) -> global___CloudiotDeviceXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        blocked: builtins.bool = ...,
        config: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        id: builtins.str = ...,
        last_config_ack_time: builtins.str = ...,
        last_config_send_time: builtins.str = ...,
        last_error_status: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        last_error_time: builtins.str = ...,
        last_event_time: builtins.str = ...,
        last_heartbeat_time: builtins.str = ...,
        last_state_time: builtins.str = ...,
        log_level: builtins.str = ...,
        metadata: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        name: builtins.str = ...,
        num_id: builtins.str = ...,
        registry: builtins.str = ...,
        state: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        credentials: collections.abc.Iterable[global___CloudiotDeviceXCredentials] | None = ...,
        gateway_config: global___CloudiotDeviceXGatewayConfig | None = ...,
        timeouts: global___CloudiotDeviceXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["gateway_config", b"gateway_config", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["blocked", b"blocked", "config", b"config", "credentials", b"credentials", "gateway_config", b"gateway_config", "id", b"id", "last_config_ack_time", b"last_config_ack_time", "last_config_send_time", b"last_config_send_time", "last_error_status", b"last_error_status", "last_error_time", b"last_error_time", "last_event_time", b"last_event_time", "last_heartbeat_time", b"last_heartbeat_time", "last_state_time", b"last_state_time", "log_level", b"log_level", "metadata", b"metadata", "name", b"name", "num_id", b"num_id", "registry", b"registry", "resource_info", b"resource_info", "state", b"state", "timeouts", b"timeouts"]) -> None: ...

global___CloudiotDevice = CloudiotDevice

@typing_extensions.final
class CloudiotRegistryXCredentials(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class PublicKeyCertificateEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    PUBLIC_KEY_CERTIFICATE_FIELD_NUMBER: builtins.int
    @property
    def public_key_certificate(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        public_key_certificate: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["public_key_certificate", b"public_key_certificate"]) -> None: ...

global___CloudiotRegistryXCredentials = CloudiotRegistryXCredentials

@typing_extensions.final
class CloudiotRegistryXEventNotificationConfigs(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PUBSUB_TOPIC_NAME_FIELD_NUMBER: builtins.int
    SUBFOLDER_MATCHES_FIELD_NUMBER: builtins.int
    pubsub_topic_name: builtins.str
    subfolder_matches: builtins.str
    def __init__(
        self,
        *,
        pubsub_topic_name: builtins.str = ...,
        subfolder_matches: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["pubsub_topic_name", b"pubsub_topic_name", "subfolder_matches", b"subfolder_matches"]) -> None: ...

global___CloudiotRegistryXEventNotificationConfigs = CloudiotRegistryXEventNotificationConfigs

@typing_extensions.final
class CloudiotRegistryXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___CloudiotRegistryXTimeouts = CloudiotRegistryXTimeouts

@typing_extensions.final
class CloudiotRegistry(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class HttpConfigEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class MqttConfigEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class StateNotificationConfigEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    HTTP_CONFIG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LOG_LEVEL_FIELD_NUMBER: builtins.int
    MQTT_CONFIG_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    STATE_NOTIFICATION_CONFIG_FIELD_NUMBER: builtins.int
    CREDENTIALS_FIELD_NUMBER: builtins.int
    EVENT_NOTIFICATION_CONFIGS_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def http_config(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    id: builtins.str
    log_level: builtins.str
    @property
    def mqtt_config(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    name: builtins.str
    project: builtins.str
    region: builtins.str
    @property
    def state_notification_config(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def credentials(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CloudiotRegistryXCredentials]: ...
    @property
    def event_notification_configs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CloudiotRegistryXEventNotificationConfigs]: ...
    @property
    def timeouts(self) -> global___CloudiotRegistryXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        http_config: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        id: builtins.str = ...,
        log_level: builtins.str = ...,
        mqtt_config: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        region: builtins.str = ...,
        state_notification_config: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        credentials: collections.abc.Iterable[global___CloudiotRegistryXCredentials] | None = ...,
        event_notification_configs: collections.abc.Iterable[global___CloudiotRegistryXEventNotificationConfigs] | None = ...,
        timeouts: global___CloudiotRegistryXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["credentials", b"credentials", "event_notification_configs", b"event_notification_configs", "http_config", b"http_config", "id", b"id", "log_level", b"log_level", "mqtt_config", b"mqtt_config", "name", b"name", "project", b"project", "region", b"region", "resource_info", b"resource_info", "state_notification_config", b"state_notification_config", "timeouts", b"timeouts"]) -> None: ...

global___CloudiotRegistry = CloudiotRegistry

@typing_extensions.final
class CloudiotRegistryIamBindingXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___CloudiotRegistryIamBindingXCondition = CloudiotRegistryIamBindingXCondition

@typing_extensions.final
class CloudiotRegistryIamBinding(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    MEMBERS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    @property
    def members(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    name: builtins.str
    project: builtins.str
    region: builtins.str
    role: builtins.str
    @property
    def condition(self) -> global___CloudiotRegistryIamBindingXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        members: collections.abc.Iterable[builtins.str] | None = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        region: builtins.str = ...,
        role: builtins.str = ...,
        condition: global___CloudiotRegistryIamBindingXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "etag", b"etag", "id", b"id", "members", b"members", "name", b"name", "project", b"project", "region", b"region", "resource_info", b"resource_info", "role", b"role"]) -> None: ...

global___CloudiotRegistryIamBinding = CloudiotRegistryIamBinding

@typing_extensions.final
class CloudiotRegistryIamMemberXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___CloudiotRegistryIamMemberXCondition = CloudiotRegistryIamMemberXCondition

@typing_extensions.final
class CloudiotRegistryIamMember(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    MEMBER_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    member: builtins.str
    name: builtins.str
    project: builtins.str
    region: builtins.str
    role: builtins.str
    @property
    def condition(self) -> global___CloudiotRegistryIamMemberXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        member: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        region: builtins.str = ...,
        role: builtins.str = ...,
        condition: global___CloudiotRegistryIamMemberXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "etag", b"etag", "id", b"id", "member", b"member", "name", b"name", "project", b"project", "region", b"region", "resource_info", b"resource_info", "role", b"role"]) -> None: ...

global___CloudiotRegistryIamMember = CloudiotRegistryIamMember

@typing_extensions.final
class CloudiotRegistryIamPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    POLICY_DATA_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    name: builtins.str
    policy_data: builtins.str
    project: builtins.str
    region: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        policy_data: builtins.str = ...,
        project: builtins.str = ...,
        region: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["etag", b"etag", "id", b"id", "name", b"name", "policy_data", b"policy_data", "project", b"project", "region", b"region", "resource_info", b"resource_info"]) -> None: ...

global___CloudiotRegistryIamPolicy = CloudiotRegistryIamPolicy
