# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_google_compute_subnetwork_bundle.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2
from oak9.tython.models.gcp import gcp_compute_subnetwork_pb2 as gcp_dot_gcp__compute__subnetwork__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.gcp/gcp_google_compute_subnetwork_bundle.proto\x12\x30oak9.tython.gcp.google_compute_subnetwork_bundle\x1a\x13shared/shared.proto\x1a gcp/gcp_compute_subnetwork.proto\"\xa3\x03\n\x17GoogleComputeSubnetwork\x12Q\n\x12\x63ompute_subnetwork\x18\x01 \x01(\x0b\x32\x35.oak9.tython.gcp.compute_subnetwork.ComputeSubnetwork\x12g\n\x1e\x63ompute_subnetwork_iam_binding\x18\x02 \x03(\x0b\x32?.oak9.tython.gcp.compute_subnetwork.ComputeSubnetworkIamBinding\x12\x65\n\x1d\x63ompute_subnetwork_iam_member\x18\x03 \x03(\x0b\x32>.oak9.tython.gcp.compute_subnetwork.ComputeSubnetworkIamMember\x12\x65\n\x1d\x63ompute_subnetwork_iam_policy\x18\x04 \x03(\x0b\x32>.oak9.tython.gcp.compute_subnetwork.ComputeSubnetworkIamPolicyb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_google_compute_subnetwork_bundle_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GOOGLECOMPUTESUBNETWORK._serialized_start=156
  _GOOGLECOMPUTESUBNETWORK._serialized_end=575
# @@protoc_insertion_point(module_scope)
