"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class DeploymentManagerDeploymentXLabels(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    key: builtins.str
    value: builtins.str
    def __init__(
        self,
        *,
        key: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

global___DeploymentManagerDeploymentXLabels = DeploymentManagerDeploymentXLabels

@typing_extensions.final
class DeploymentManagerDeploymentXTargetXConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTENT_FIELD_NUMBER: builtins.int
    content: builtins.str
    def __init__(
        self,
        *,
        content: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["content", b"content"]) -> None: ...

global___DeploymentManagerDeploymentXTargetXConfig = DeploymentManagerDeploymentXTargetXConfig

@typing_extensions.final
class DeploymentManagerDeploymentXTargetXImports(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTENT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    content: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        content: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["content", b"content", "name", b"name"]) -> None: ...

global___DeploymentManagerDeploymentXTargetXImports = DeploymentManagerDeploymentXTargetXImports

@typing_extensions.final
class DeploymentManagerDeploymentXTarget(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONFIG_FIELD_NUMBER: builtins.int
    IMPORTS_FIELD_NUMBER: builtins.int
    @property
    def config(self) -> global___DeploymentManagerDeploymentXTargetXConfig: ...
    @property
    def imports(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DeploymentManagerDeploymentXTargetXImports]: ...
    def __init__(
        self,
        *,
        config: global___DeploymentManagerDeploymentXTargetXConfig | None = ...,
        imports: collections.abc.Iterable[global___DeploymentManagerDeploymentXTargetXImports] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["config", b"config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["config", b"config", "imports", b"imports"]) -> None: ...

global___DeploymentManagerDeploymentXTarget = DeploymentManagerDeploymentXTarget

@typing_extensions.final
class DeploymentManagerDeploymentXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___DeploymentManagerDeploymentXTimeouts = DeploymentManagerDeploymentXTimeouts

@typing_extensions.final
class DeploymentManagerDeployment(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_POLICY_FIELD_NUMBER: builtins.int
    DELETE_POLICY_FIELD_NUMBER: builtins.int
    DEPLOYMENT_ID_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    MANIFEST_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PREVIEW_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    SELF_LINK_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    TARGET_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    create_policy: builtins.str
    delete_policy: builtins.str
    deployment_id: builtins.str
    description: builtins.str
    id: builtins.str
    manifest: builtins.str
    name: builtins.str
    preview: builtins.bool
    project: builtins.str
    self_link: builtins.str
    @property
    def labels(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DeploymentManagerDeploymentXLabels]: ...
    @property
    def target(self) -> global___DeploymentManagerDeploymentXTarget: ...
    @property
    def timeouts(self) -> global___DeploymentManagerDeploymentXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        create_policy: builtins.str = ...,
        delete_policy: builtins.str = ...,
        deployment_id: builtins.str = ...,
        description: builtins.str = ...,
        id: builtins.str = ...,
        manifest: builtins.str = ...,
        name: builtins.str = ...,
        preview: builtins.bool = ...,
        project: builtins.str = ...,
        self_link: builtins.str = ...,
        labels: collections.abc.Iterable[global___DeploymentManagerDeploymentXLabels] | None = ...,
        target: global___DeploymentManagerDeploymentXTarget | None = ...,
        timeouts: global___DeploymentManagerDeploymentXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "target", b"target", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["create_policy", b"create_policy", "delete_policy", b"delete_policy", "deployment_id", b"deployment_id", "description", b"description", "id", b"id", "labels", b"labels", "manifest", b"manifest", "name", b"name", "preview", b"preview", "project", b"project", "resource_info", b"resource_info", "self_link", b"self_link", "target", b"target", "timeouts", b"timeouts"]) -> None: ...

global___DeploymentManagerDeployment = DeploymentManagerDeployment
