# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_codecommit.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18\x61ws/aws_codecommit.proto\x12\x1aoak9.tython.aws.codecommit\x1a\x13shared/shared.proto\"\xb4\x01\n\x1bRepositoryRepositoryTrigger\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06\x65vents\x18\x02 \x03(\t\x12\x10\n\x08\x62ranches\x18\x03 \x03(\t\x12\x13\n\x0b\x63ustom_data\x18\x04 \x01(\t\x12\x17\n\x0f\x64\x65stination_arn\x18\x05 \x01(\t\x12\x0c\n\x04name\x18\x06 \x01(\t\"|\n\x0cRepositoryS3\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0eobject_version\x18\x02 \x01(\t\x12\x0e\n\x06\x62ucket\x18\x03 \x01(\t\x12\x0b\n\x03key\x18\x04 \x01(\t\"\x94\x01\n\x0eRepositoryCode\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x34\n\x02s3\x18\x02 \x01(\x0b\x32(.oak9.tython.aws.codecommit.RepositoryS3\x12\x13\n\x0b\x62ranch_name\x18\x03 \x01(\t\"\xf0\x02\n\nRepository\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x17\n\x0frepository_name\x18\x02 \x01(\t\x12I\n\x08triggers\x18\x03 \x03(\x0b\x32\x37.oak9.tython.aws.codecommit.RepositoryRepositoryTrigger\x12\x38\n\x04\x63ode\x18\x04 \x01(\x0b\x32*.oak9.tython.aws.codecommit.RepositoryCode\x12\x1e\n\x16repository_description\x18\x05 \x01(\t\x12>\n\x04tags\x18\x06 \x03(\x0b\x32\x30.oak9.tython.aws.codecommit.Repository.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"H\n\nCodeCommit\x12:\n\nrepository\x18\x01 \x03(\x0b\x32&.oak9.tython.aws.codecommit.Repositoryb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_codecommit_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _REPOSITORY_TAGSENTRY._options = None
  _REPOSITORY_TAGSENTRY._serialized_options = b'8\001'
  _REPOSITORYREPOSITORYTRIGGER._serialized_start=78
  _REPOSITORYREPOSITORYTRIGGER._serialized_end=258
  _REPOSITORYS3._serialized_start=260
  _REPOSITORYS3._serialized_end=384
  _REPOSITORYCODE._serialized_start=387
  _REPOSITORYCODE._serialized_end=535
  _REPOSITORY._serialized_start=538
  _REPOSITORY._serialized_end=906
  _REPOSITORY_TAGSENTRY._serialized_start=863
  _REPOSITORY_TAGSENTRY._serialized_end=906
  _CODECOMMIT._serialized_start=908
  _CODECOMMIT._serialized_end=980
# @@protoc_insertion_point(module_scope)
