# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kubernetes/kubernetes_io.k8s.api.admissionregistration.v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2
from oak9.tython.models.kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta import v1_pb2 as kubernetes_dot_kubernetes__io_dot_k8s_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?kubernetes/kubernetes_io.k8s.api.admissionregistration.v1.proto\x12,oak9.tython.k8s.api.admissionregistration.v1\x1a\x13shared/shared.proto\x1a@kubernetes/kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1.proto\"\xd1\x04\n\x0fMutatingWebhook\x12!\n\x19\x61\x64mission_review_versions\x18\x01 \x03(\t\x12X\n\rclient_config\x18\x02 \x01(\x0b\x32\x41.oak9.tython.k8s.api.admissionregistration.v1.WebhookClientConfig\x12\x16\n\x0e\x66\x61ilure_policy\x18\x03 \x01(\t\x12\x14\n\x0cmatch_policy\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12X\n\x12namespace_selector\x18\x06 \x01(\x0b\x32<.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.LabelSelector\x12U\n\x0fobject_selector\x18\x07 \x01(\x0b\x32<.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.LabelSelector\x12\x1b\n\x13reinvocation_policy\x18\x08 \x01(\t\x12O\n\x05rules\x18\t \x03(\x0b\x32@.oak9.tython.k8s.api.admissionregistration.v1.RuleWithOperations\x12\x14\n\x0cside_effects\x18\n \x01(\t\x12\x17\n\x0ftimeout_seconds\x18\x0b \x01(\x05\x12\x37\n\rresource_info\x18\x0c \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x98\x02\n\x1cMutatingWebhookConfiguration\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12K\n\x08metadata\x18\x03 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12O\n\x08webhooks\x18\x04 \x03(\x0b\x32=.oak9.tython.k8s.api.admissionregistration.v1.MutatingWebhook\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xa4\x02\n MutatingWebhookConfigurationList\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12Y\n\x05items\x18\x02 \x03(\x0b\x32J.oak9.tython.k8s.api.admissionregistration.v1.MutatingWebhookConfiguration\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12I\n\x08metadata\x18\x04 \x01(\x0b\x32\x37.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ListMeta\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xad\x01\n\x12RuleWithOperations\x12\x12\n\napi_groups\x18\x01 \x03(\t\x12\x14\n\x0c\x61pi_versions\x18\x02 \x03(\t\x12\x12\n\noperations\x18\x03 \x03(\t\x12\x11\n\tresources\x18\x04 \x03(\t\x12\r\n\x05scope\x18\x05 \x01(\t\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x88\x01\n\x10ServiceReference\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\tnamespace\x18\x02 \x01(\t\x12\x0c\n\x04path\x18\x03 \x01(\t\x12\x0c\n\x04port\x18\x04 \x01(\x05\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xb6\x04\n\x11ValidatingWebhook\x12!\n\x19\x61\x64mission_review_versions\x18\x01 \x03(\t\x12X\n\rclient_config\x18\x02 \x01(\x0b\x32\x41.oak9.tython.k8s.api.admissionregistration.v1.WebhookClientConfig\x12\x16\n\x0e\x66\x61ilure_policy\x18\x03 \x01(\t\x12\x14\n\x0cmatch_policy\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12X\n\x12namespace_selector\x18\x06 \x01(\x0b\x32<.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.LabelSelector\x12U\n\x0fobject_selector\x18\x07 \x01(\x0b\x32<.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.LabelSelector\x12O\n\x05rules\x18\x08 \x03(\x0b\x32@.oak9.tython.k8s.api.admissionregistration.v1.RuleWithOperations\x12\x14\n\x0cside_effects\x18\t \x01(\t\x12\x17\n\x0ftimeout_seconds\x18\n \x01(\x05\x12\x37\n\rresource_info\x18\x0b \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x9c\x02\n\x1eValidatingWebhookConfiguration\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12K\n\x08metadata\x18\x03 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12Q\n\x08webhooks\x18\x04 \x03(\x0b\x32?.oak9.tython.k8s.api.admissionregistration.v1.ValidatingWebhook\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xa8\x02\n\"ValidatingWebhookConfigurationList\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12[\n\x05items\x18\x02 \x03(\x0b\x32L.oak9.tython.k8s.api.admissionregistration.v1.ValidatingWebhookConfiguration\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12I\n\x08metadata\x18\x04 \x01(\x0b\x32\x37.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ListMeta\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xbf\x01\n\x13WebhookClientConfig\x12\x11\n\tca_bundle\x18\x01 \x01(\t\x12O\n\x07service\x18\x02 \x01(\x0b\x32>.oak9.tython.k8s.api.admissionregistration.v1.ServiceReference\x12\x0b\n\x03url\x18\x03 \x01(\t\x12\x37\n\rresource_info\x18\x04 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'kubernetes.kubernetes_io.k8s.api.admissionregistration.v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _MUTATINGWEBHOOK._serialized_start=201
  _MUTATINGWEBHOOK._serialized_end=794
  _MUTATINGWEBHOOKCONFIGURATION._serialized_start=797
  _MUTATINGWEBHOOKCONFIGURATION._serialized_end=1077
  _MUTATINGWEBHOOKCONFIGURATIONLIST._serialized_start=1080
  _MUTATINGWEBHOOKCONFIGURATIONLIST._serialized_end=1372
  _RULEWITHOPERATIONS._serialized_start=1375
  _RULEWITHOPERATIONS._serialized_end=1548
  _SERVICEREFERENCE._serialized_start=1551
  _SERVICEREFERENCE._serialized_end=1687
  _VALIDATINGWEBHOOK._serialized_start=1690
  _VALIDATINGWEBHOOK._serialized_end=2256
  _VALIDATINGWEBHOOKCONFIGURATION._serialized_start=2259
  _VALIDATINGWEBHOOKCONFIGURATION._serialized_end=2543
  _VALIDATINGWEBHOOKCONFIGURATIONLIST._serialized_start=2546
  _VALIDATINGWEBHOOKCONFIGURATIONLIST._serialized_end=2842
  _WEBHOOKCLIENTCONFIG._serialized_start=2845
  _WEBHOOKCLIENTCONFIG._serialized_end=3036
# @@protoc_insertion_point(module_scope)
