# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_ec2_route.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17\x61ws/aws_ec2_route.proto\x12\x19oak9.tython.aws.ec2_route\x1a\x13shared/shared.proto\"\xe4\x02\n\x05Route\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1e\n\x16\x64\x65stination_cidr_block\x18\x02 \x01(\t\x12#\n\x1b\x64\x65stination_ipv6_cidr_block\x18\x03 \x01(\t\x12\'\n\x1f\x65gress_only_internet_gateway_id\x18\x04 \x01(\t\x12\x12\n\ngateway_id\x18\x05 \x01(\t\x12\x13\n\x0binstance_id\x18\x06 \x01(\t\x12\x16\n\x0enat_gateway_id\x18\x07 \x01(\t\x12\x1c\n\x14network_interface_id\x18\x08 \x01(\t\x12\x16\n\x0eroute_table_id\x18\t \x01(\t\x12\x1a\n\x12transit_gateway_id\x18\n \x01(\t\x12!\n\x19vpc_peering_connection_id\x18\x0b \x01(\t\"x\n\tEC2_Route\x12/\n\x05route\x18\x01 \x03(\x0b\x32 .oak9.tython.aws.ec2_route.Route\x12:\n\x0broute_table\x18\x02 \x01(\x0b\x32%.oak9.tython.aws.ec2_route.RouteTable\"\xc1\x01\n\nRouteTable\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12=\n\x04tags\x18\x02 \x03(\x0b\x32/.oak9.tython.aws.ec2_route.RouteTable.TagsEntry\x12\x0e\n\x06vpc_id\x18\x03 \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_ec2_route_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ROUTETABLE_TAGSENTRY._options = None
  _ROUTETABLE_TAGSENTRY._serialized_options = b'8\001'
  _ROUTE._serialized_start=76
  _ROUTE._serialized_end=432
  _EC2_ROUTE._serialized_start=434
  _EC2_ROUTE._serialized_end=554
  _ROUTETABLE._serialized_start=557
  _ROUTETABLE._serialized_end=750
  _ROUTETABLE_TAGSENTRY._serialized_start=707
  _ROUTETABLE_TAGSENTRY._serialized_end=750
# @@protoc_insertion_point(module_scope)
