"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ComputePacketMirroringXCollectorIlb(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    URL_FIELD_NUMBER: builtins.int
    url: builtins.str
    def __init__(
        self,
        *,
        url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["url", b"url"]) -> None: ...

global___ComputePacketMirroringXCollectorIlb = ComputePacketMirroringXCollectorIlb

@typing_extensions.final
class ComputePacketMirroringXFilter(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CIDR_RANGES_FIELD_NUMBER: builtins.int
    DIRECTION_FIELD_NUMBER: builtins.int
    IP_PROTOCOLS_FIELD_NUMBER: builtins.int
    @property
    def cidr_ranges(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    direction: builtins.str
    @property
    def ip_protocols(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        cidr_ranges: collections.abc.Iterable[builtins.str] | None = ...,
        direction: builtins.str = ...,
        ip_protocols: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cidr_ranges", b"cidr_ranges", "direction", b"direction", "ip_protocols", b"ip_protocols"]) -> None: ...

global___ComputePacketMirroringXFilter = ComputePacketMirroringXFilter

@typing_extensions.final
class ComputePacketMirroringXMirroredResourcesXInstances(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    URL_FIELD_NUMBER: builtins.int
    url: builtins.str
    def __init__(
        self,
        *,
        url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["url", b"url"]) -> None: ...

global___ComputePacketMirroringXMirroredResourcesXInstances = ComputePacketMirroringXMirroredResourcesXInstances

@typing_extensions.final
class ComputePacketMirroringXMirroredResourcesXSubnetworks(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    URL_FIELD_NUMBER: builtins.int
    url: builtins.str
    def __init__(
        self,
        *,
        url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["url", b"url"]) -> None: ...

global___ComputePacketMirroringXMirroredResourcesXSubnetworks = ComputePacketMirroringXMirroredResourcesXSubnetworks

@typing_extensions.final
class ComputePacketMirroringXMirroredResources(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TAGS_FIELD_NUMBER: builtins.int
    INSTANCES_FIELD_NUMBER: builtins.int
    SUBNETWORKS_FIELD_NUMBER: builtins.int
    @property
    def tags(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def instances(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputePacketMirroringXMirroredResourcesXInstances]: ...
    @property
    def subnetworks(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputePacketMirroringXMirroredResourcesXSubnetworks]: ...
    def __init__(
        self,
        *,
        tags: collections.abc.Iterable[builtins.str] | None = ...,
        instances: collections.abc.Iterable[global___ComputePacketMirroringXMirroredResourcesXInstances] | None = ...,
        subnetworks: collections.abc.Iterable[global___ComputePacketMirroringXMirroredResourcesXSubnetworks] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["instances", b"instances", "subnetworks", b"subnetworks", "tags", b"tags"]) -> None: ...

global___ComputePacketMirroringXMirroredResources = ComputePacketMirroringXMirroredResources

@typing_extensions.final
class ComputePacketMirroringXNetwork(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    URL_FIELD_NUMBER: builtins.int
    url: builtins.str
    def __init__(
        self,
        *,
        url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["url", b"url"]) -> None: ...

global___ComputePacketMirroringXNetwork = ComputePacketMirroringXNetwork

@typing_extensions.final
class ComputePacketMirroringXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___ComputePacketMirroringXTimeouts = ComputePacketMirroringXTimeouts

@typing_extensions.final
class ComputePacketMirroring(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PRIORITY_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    COLLECTOR_ILB_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    MIRRORED_RESOURCES_FIELD_NUMBER: builtins.int
    NETWORK_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    description: builtins.str
    id: builtins.str
    name: builtins.str
    priority: builtins.float
    project: builtins.str
    region: builtins.str
    @property
    def collector_ilb(self) -> global___ComputePacketMirroringXCollectorIlb: ...
    @property
    def filter(self) -> global___ComputePacketMirroringXFilter: ...
    @property
    def mirrored_resources(self) -> global___ComputePacketMirroringXMirroredResources: ...
    @property
    def network(self) -> global___ComputePacketMirroringXNetwork: ...
    @property
    def timeouts(self) -> global___ComputePacketMirroringXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        priority: builtins.float = ...,
        project: builtins.str = ...,
        region: builtins.str = ...,
        collector_ilb: global___ComputePacketMirroringXCollectorIlb | None = ...,
        filter: global___ComputePacketMirroringXFilter | None = ...,
        mirrored_resources: global___ComputePacketMirroringXMirroredResources | None = ...,
        network: global___ComputePacketMirroringXNetwork | None = ...,
        timeouts: global___ComputePacketMirroringXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["collector_ilb", b"collector_ilb", "filter", b"filter", "mirrored_resources", b"mirrored_resources", "network", b"network", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["collector_ilb", b"collector_ilb", "description", b"description", "filter", b"filter", "id", b"id", "mirrored_resources", b"mirrored_resources", "name", b"name", "network", b"network", "priority", b"priority", "project", b"project", "region", b"region", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> None: ...

global___ComputePacketMirroring = ComputePacketMirroring
