"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class AssessmentTarget(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ASSESSMENT_TARGET_NAME_FIELD_NUMBER: builtins.int
    RESOURCE_GROUP_ARN_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    assessment_target_name: builtins.str
    resource_group_arn: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        assessment_target_name: builtins.str = ...,
        resource_group_arn: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["assessment_target_name", b"assessment_target_name", "resource_group_arn", b"resource_group_arn", "resource_info", b"resource_info"]) -> None: ...

global___AssessmentTarget = AssessmentTarget

@typing_extensions.final
class Inspector(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ASSESSMENT_TARGET_FIELD_NUMBER: builtins.int
    ASSESSMENT_TEMPLATE_FIELD_NUMBER: builtins.int
    RESOURCE_GROUP_FIELD_NUMBER: builtins.int
    @property
    def assessment_target(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AssessmentTarget]: ...
    @property
    def assessment_template(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AssessmentTemplate]: ...
    @property
    def resource_group(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ResourceGroup]: ...
    def __init__(
        self,
        *,
        assessment_target: collections.abc.Iterable[global___AssessmentTarget] | None = ...,
        assessment_template: collections.abc.Iterable[global___AssessmentTemplate] | None = ...,
        resource_group: collections.abc.Iterable[global___ResourceGroup] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["assessment_target", b"assessment_target", "assessment_template", b"assessment_template", "resource_group", b"resource_group"]) -> None: ...

global___Inspector = Inspector

@typing_extensions.final
class AssessmentTemplate(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class UserAttributesForFindingsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ASSESSMENT_TARGET_ARN_FIELD_NUMBER: builtins.int
    DURATION_IN_SECONDS_FIELD_NUMBER: builtins.int
    ASSESSMENT_TEMPLATE_NAME_FIELD_NUMBER: builtins.int
    RULES_PACKAGE_ARNS_FIELD_NUMBER: builtins.int
    USER_ATTRIBUTES_FOR_FINDINGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    assessment_target_arn: builtins.str
    duration_in_seconds: builtins.int
    assessment_template_name: builtins.str
    @property
    def rules_package_arns(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def user_attributes_for_findings(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        assessment_target_arn: builtins.str = ...,
        duration_in_seconds: builtins.int = ...,
        assessment_template_name: builtins.str = ...,
        rules_package_arns: collections.abc.Iterable[builtins.str] | None = ...,
        user_attributes_for_findings: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["assessment_target_arn", b"assessment_target_arn", "assessment_template_name", b"assessment_template_name", "duration_in_seconds", b"duration_in_seconds", "resource_info", b"resource_info", "rules_package_arns", b"rules_package_arns", "user_attributes_for_findings", b"user_attributes_for_findings"]) -> None: ...

global___AssessmentTemplate = AssessmentTemplate

@typing_extensions.final
class ResourceGroup(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class ResourceGroupTagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    RESOURCE_GROUP_TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def resource_group_tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        resource_group_tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_group_tags", b"resource_group_tags", "resource_info", b"resource_info"]) -> None: ...

global___ResourceGroup = ResourceGroup
