# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: azure/azure_microsoft_eventgrid.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%azure/azure_microsoft_eventgrid.proto\x12%oak9.tython.azure.microsoft_eventgrid\x1a\x13shared/shared.proto\"\xd1\x03\n\x13Microsoft_EventGrid\x12?\n\x07\x64omains\x18\x01 \x01(\x0b\x32..oak9.tython.azure.microsoft_eventgrid.Domains\x12v\n$domains_private_endpoint_connections\x18\x02 \x03(\x0b\x32H.oak9.tython.azure.microsoft_eventgrid.DomainsPrivateEndpointConnections\x12L\n\x0e\x64omains_topics\x18\x03 \x03(\x0b\x32\x34.oak9.tython.azure.microsoft_eventgrid.DomainsTopics\x12=\n\x06topics\x18\x04 \x01(\x0b\x32-.oak9.tython.azure.microsoft_eventgrid.Topics\x12t\n#topics_private_endpoint_connections\x18\x05 \x03(\x0b\x32G.oak9.tython.azure.microsoft_eventgrid.TopicsPrivateEndpointConnections\"\xd1\x02\n TopicsPrivateEndpointConnections\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x11\n\tgroup_ids\x18\x03 \x03(\t\x12P\n\x10private_endpoint\x18\x04 \x01(\x0b\x32\x36.oak9.tython.azure.microsoft_eventgrid.PrivateEndpoint\x12\x65\n%private_link_service_connection_state\x18\x05 \x01(\x0b\x32\x36.oak9.tython.azure.microsoft_eventgrid.ConnectionState\x12\x1a\n\x12provisioning_state\x18\x06 \x01(\t\"\x96\x04\n\x06Topics\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x45\n\x08identity\x18\x02 \x01(\x0b\x32\x33.oak9.tython.azure.microsoft_eventgrid.IdentityInfo\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x1a\n\x12\x64isable_local_auth\x18\x05 \x01(\x08\x12N\n\x10inbound_ip_rules\x18\x06 \x03(\x0b\x32\x34.oak9.tython.azure.microsoft_eventgrid.InboundIpRule\x12\x14\n\x0cinput_schema\x18\x07 \x01(\t\x12W\n\x14input_schema_mapping\x18\x08 \x01(\x0b\x32\x39.oak9.tython.azure.microsoft_eventgrid.InputSchemaMapping\x12\x1d\n\x15public_network_access\x18\t \x01(\t\x12\x45\n\x04tags\x18\n \x03(\x0b\x32\x37.oak9.tython.azure.microsoft_eventgrid.Topics.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xe7\x05\n\x1eSystemTopicsEventSubscriptions\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12]\n\x17\x64\x65\x61\x64_letter_destination\x18\x03 \x01(\x0b\x32<.oak9.tython.azure.microsoft_eventgrid.DeadLetterDestination\x12q\n\"dead_letter_with_resource_identity\x18\x04 \x01(\x0b\x32\x45.oak9.tython.azure.microsoft_eventgrid.DeadLetterWithResourceIdentity\x12l\n\x1f\x64\x65livery_with_resource_identity\x18\x05 \x01(\x0b\x32\x43.oak9.tython.azure.microsoft_eventgrid.DeliveryWithResourceIdentity\x12X\n\x0b\x64\x65stination\x18\x06 \x01(\x0b\x32\x43.oak9.tython.azure.microsoft_eventgrid.EventSubscriptionDestination\x12\x1d\n\x15\x65vent_delivery_schema\x18\x07 \x01(\t\x12\x1b\n\x13\x65xpiration_time_utc\x18\x08 \x01(\t\x12N\n\x06\x66ilter\x18\t \x01(\x0b\x32>.oak9.tython.azure.microsoft_eventgrid.EventSubscriptionFilter\x12\x0e\n\x06labels\x18\n \x03(\t\x12H\n\x0cretry_policy\x18\x0b \x01(\x0b\x32\x32.oak9.tython.azure.microsoft_eventgrid.RetryPolicy\"S\n\x0bRetryPolicy\x12%\n\x1d\x65vent_time_to_live_in_minutes\x18\x01 \x01(\x05\x12\x1d\n\x15max_delivery_attempts\x18\x02 \x01(\x05\"\x90\x02\n\x17\x45ventSubscriptionFilter\x12O\n\x10\x61\x64vanced_filters\x18\x01 \x03(\x0b\x32\x35.oak9.tython.azure.microsoft_eventgrid.AdvancedFilter\x12+\n#enable_advanced_filtering_on_arrays\x18\x02 \x01(\x08\x12\x1c\n\x14included_event_types\x18\x03 \x03(\t\x12!\n\x19is_subject_case_sensitive\x18\x04 \x01(\x08\x12\x1b\n\x13subject_begins_with\x18\x05 \x01(\t\x12\x19\n\x11subject_ends_with\x18\x06 \x01(\t\"\x1d\n\x0e\x41\x64vancedFilter\x12\x0b\n\x03key\x18\x01 \x01(\t\"\xcc\x01\n\x1c\x44\x65liveryWithResourceIdentity\x12X\n\x0b\x64\x65stination\x18\x01 \x01(\x0b\x32\x43.oak9.tython.azure.microsoft_eventgrid.EventSubscriptionDestination\x12R\n\x08identity\x18\x02 \x01(\x0b\x32@.oak9.tython.azure.microsoft_eventgrid.EventSubscriptionIdentity\",\n\x1c\x45ventSubscriptionDestination\x12\x0c\n\x04name\x18\x01 \x01(\t\"\xd3\x01\n\x1e\x44\x65\x61\x64LetterWithResourceIdentity\x12]\n\x17\x64\x65\x61\x64_letter_destination\x18\x01 \x01(\x0b\x32<.oak9.tython.azure.microsoft_eventgrid.DeadLetterDestination\x12R\n\x08identity\x18\x02 \x01(\x0b\x32@.oak9.tython.azure.microsoft_eventgrid.EventSubscriptionIdentity\"I\n\x19\x45ventSubscriptionIdentity\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x1e\n\x16user_assigned_identity\x18\x02 \x01(\t\"%\n\x15\x44\x65\x61\x64LetterDestination\x12\x0c\n\x04name\x18\x01 \x01(\t\"\xbe\x03\n\x0cSystemTopics\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x45\n\x08identity\x18\x02 \x01(\x0b\x32\x33.oak9.tython.azure.microsoft_eventgrid.IdentityInfo\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0e\n\x06source\x18\x05 \x01(\t\x12\x12\n\ntopic_type\x18\x06 \x01(\t\x12K\n\x04tags\x18\x07 \x03(\x0b\x32=.oak9.tython.azure.microsoft_eventgrid.SystemTopics.TagsEntry\x12p\n!system_topics_event_subscriptions\x18\x08 \x03(\x0b\x32\x45.oak9.tython.azure.microsoft_eventgrid.SystemTopicsEventSubscriptions\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"V\n\rDomainsTopics\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\"\xd2\x02\n!DomainsPrivateEndpointConnections\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x11\n\tgroup_ids\x18\x03 \x03(\t\x12P\n\x10private_endpoint\x18\x04 \x01(\x0b\x32\x36.oak9.tython.azure.microsoft_eventgrid.PrivateEndpoint\x12\x65\n%private_link_service_connection_state\x18\x05 \x01(\x0b\x32\x36.oak9.tython.azure.microsoft_eventgrid.ConnectionState\x12\x1a\n\x12provisioning_state\x18\x06 \x01(\t\"P\n\x0f\x43onnectionState\x12\x18\n\x10\x61\x63tions_required\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0e\n\x06status\x18\x03 \x01(\t\"\x1d\n\x0fPrivateEndpoint\x12\n\n\x02id\x18\x01 \x01(\t\"\xfd\x04\n\x07\x44omains\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x45\n\x08identity\x18\x02 \x01(\x0b\x32\x33.oak9.tython.azure.microsoft_eventgrid.IdentityInfo\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x31\n)auto_create_topic_with_first_subscription\x18\x05 \x01(\x08\x12\x30\n(auto_delete_topic_with_last_subscription\x18\x06 \x01(\x08\x12\x1a\n\x12\x64isable_local_auth\x18\x07 \x01(\x08\x12N\n\x10inbound_ip_rules\x18\x08 \x03(\x0b\x32\x34.oak9.tython.azure.microsoft_eventgrid.InboundIpRule\x12\x14\n\x0cinput_schema\x18\t \x01(\t\x12W\n\x14input_schema_mapping\x18\n \x01(\x0b\x32\x39.oak9.tython.azure.microsoft_eventgrid.InputSchemaMapping\x12\x1d\n\x15public_network_access\x18\x0b \x01(\t\x12\x46\n\x04tags\x18\x0c \x03(\x0b\x32\x38.oak9.tython.azure.microsoft_eventgrid.Domains.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\"\n\x12InputSchemaMapping\x12\x0c\n\x04name\x18\x01 \x01(\t\"0\n\rInboundIpRule\x12\x0e\n\x06\x61\x63tion\x18\x01 \x01(\t\x12\x0f\n\x07ip_mask\x18\x02 \x01(\t\"\xf7\x01\n\x0cIdentityInfo\x12\x14\n\x0cprincipal_id\x18\x01 \x01(\t\x12\x11\n\ttenant_id\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\x12q\n\x18user_assigned_identities\x18\x04 \x03(\x0b\x32O.oak9.tython.azure.microsoft_eventgrid.IdentityInfo.UserAssignedIdentitiesEntry\x1a=\n\x1bUserAssignedIdentitiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'azure.azure_microsoft_eventgrid_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _TOPICS_TAGSENTRY._options = None
  _TOPICS_TAGSENTRY._serialized_options = b'8\001'
  _SYSTEMTOPICS_TAGSENTRY._options = None
  _SYSTEMTOPICS_TAGSENTRY._serialized_options = b'8\001'
  _DOMAINS_TAGSENTRY._options = None
  _DOMAINS_TAGSENTRY._serialized_options = b'8\001'
  _IDENTITYINFO_USERASSIGNEDIDENTITIESENTRY._options = None
  _IDENTITYINFO_USERASSIGNEDIDENTITIESENTRY._serialized_options = b'8\001'
  _MICROSOFT_EVENTGRID._serialized_start=102
  _MICROSOFT_EVENTGRID._serialized_end=567
  _TOPICSPRIVATEENDPOINTCONNECTIONS._serialized_start=570
  _TOPICSPRIVATEENDPOINTCONNECTIONS._serialized_end=907
  _TOPICS._serialized_start=910
  _TOPICS._serialized_end=1444
  _TOPICS_TAGSENTRY._serialized_start=1401
  _TOPICS_TAGSENTRY._serialized_end=1444
  _SYSTEMTOPICSEVENTSUBSCRIPTIONS._serialized_start=1447
  _SYSTEMTOPICSEVENTSUBSCRIPTIONS._serialized_end=2190
  _RETRYPOLICY._serialized_start=2192
  _RETRYPOLICY._serialized_end=2275
  _EVENTSUBSCRIPTIONFILTER._serialized_start=2278
  _EVENTSUBSCRIPTIONFILTER._serialized_end=2550
  _ADVANCEDFILTER._serialized_start=2552
  _ADVANCEDFILTER._serialized_end=2581
  _DELIVERYWITHRESOURCEIDENTITY._serialized_start=2584
  _DELIVERYWITHRESOURCEIDENTITY._serialized_end=2788
  _EVENTSUBSCRIPTIONDESTINATION._serialized_start=2790
  _EVENTSUBSCRIPTIONDESTINATION._serialized_end=2834
  _DEADLETTERWITHRESOURCEIDENTITY._serialized_start=2837
  _DEADLETTERWITHRESOURCEIDENTITY._serialized_end=3048
  _EVENTSUBSCRIPTIONIDENTITY._serialized_start=3050
  _EVENTSUBSCRIPTIONIDENTITY._serialized_end=3123
  _DEADLETTERDESTINATION._serialized_start=3125
  _DEADLETTERDESTINATION._serialized_end=3162
  _SYSTEMTOPICS._serialized_start=3165
  _SYSTEMTOPICS._serialized_end=3611
  _SYSTEMTOPICS_TAGSENTRY._serialized_start=1401
  _SYSTEMTOPICS_TAGSENTRY._serialized_end=1444
  _DOMAINSTOPICS._serialized_start=3613
  _DOMAINSTOPICS._serialized_end=3699
  _DOMAINSPRIVATEENDPOINTCONNECTIONS._serialized_start=3702
  _DOMAINSPRIVATEENDPOINTCONNECTIONS._serialized_end=4040
  _CONNECTIONSTATE._serialized_start=4042
  _CONNECTIONSTATE._serialized_end=4122
  _PRIVATEENDPOINT._serialized_start=4124
  _PRIVATEENDPOINT._serialized_end=4153
  _DOMAINS._serialized_start=4156
  _DOMAINS._serialized_end=4793
  _DOMAINS_TAGSENTRY._serialized_start=1401
  _DOMAINS_TAGSENTRY._serialized_end=1444
  _INPUTSCHEMAMAPPING._serialized_start=4795
  _INPUTSCHEMAMAPPING._serialized_end=4829
  _INBOUNDIPRULE._serialized_start=4831
  _INBOUNDIPRULE._serialized_end=4879
  _IDENTITYINFO._serialized_start=4882
  _IDENTITYINFO._serialized_end=5129
  _IDENTITYINFO_USERASSIGNEDIDENTITIESENTRY._serialized_start=5068
  _IDENTITYINFO_USERASSIGNEDIDENTITIESENTRY._serialized_end=5129
# @@protoc_insertion_point(module_scope)
