# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_efs.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11\x61ws/aws_efs.proto\x12\x13oak9.tython.aws.efs\x1a\x13shared/shared.proto\"p\n\x19\x41\x63\x63\x65ssPointAccessPointTag\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\"\x81\x01\n\x14\x41\x63\x63\x65ssPointPosixUser\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0b\n\x03uid\x18\x02 \x01(\t\x12\x0b\n\x03gid\x18\x03 \x01(\t\x12\x16\n\x0esecondary_gids\x18\x04 \x03(\t\"\x8d\x01\n\x17\x41\x63\x63\x65ssPointCreationInfo\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\towner_uid\x18\x02 \x01(\t\x12\x11\n\towner_gid\x18\x03 \x01(\t\x12\x13\n\x0bpermissions\x18\x04 \x01(\t\"\xa6\x01\n\x18\x41\x63\x63\x65ssPointRootDirectory\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x43\n\rcreation_info\x18\x03 \x01(\x0b\x32,.oak9.tython.aws.efs.AccessPointCreationInfo\"\xc5\x02\n\x0b\x41\x63\x63\x65ssPoint\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0c\x63lient_token\x18\x02 \x01(\t\x12I\n\x11\x61\x63\x63\x65ss_point_tags\x18\x03 \x03(\x0b\x32..oak9.tython.aws.efs.AccessPointAccessPointTag\x12\x16\n\x0e\x66ile_system_id\x18\x04 \x01(\t\x12=\n\nposix_user\x18\x05 \x01(\x0b\x32).oak9.tython.aws.efs.AccessPointPosixUser\x12\x45\n\x0eroot_directory\x18\x06 \x01(\x0b\x32-.oak9.tython.aws.efs.AccessPointRootDirectory\"\xab\x01\n\x03\x45\x46S\x12\x36\n\x0c\x61\x63\x63\x65ss_point\x18\x01 \x03(\x0b\x32 .oak9.tython.aws.efs.AccessPoint\x12\x34\n\x0b\x66ile_system\x18\x02 \x03(\x0b\x32\x1f.oak9.tython.aws.efs.FileSystem\x12\x36\n\x0cmount_target\x18\x03 \x03(\x0b\x32 .oak9.tython.aws.efs.MountTarget\"u\n\x1e\x46ileSystemElasticFileSystemTag\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\"o\n\x19\x46ileSystemLifecyclePolicy\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x19\n\x11transition_to_i_a\x18\x02 \x01(\t\"a\n\x16\x46ileSystemBackupPolicy\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06status\x18\x02 \x01(\t\"\xb3\x04\n\nFileSystem\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\tencrypted\x18\x02 \x01(\x08\x12M\n\x10\x66ile_system_tags\x18\x03 \x03(\x0b\x32\x33.oak9.tython.aws.efs.FileSystemElasticFileSystemTag\x12\x12\n\nkms_key_id\x18\x04 \x01(\t\x12J\n\x12lifecycle_policies\x18\x05 \x03(\x0b\x32..oak9.tython.aws.efs.FileSystemLifecyclePolicy\x12\x18\n\x10performance_mode\x18\x06 \x01(\t\x12\'\n\x1fprovisioned_throughput_in_mibps\x18\x07 \x01(\x01\x12\x17\n\x0fthroughput_mode\x18\x08 \x01(\t\x12Q\n\x12\x66ile_system_policy\x18\t \x03(\x0b\x32\x35.oak9.tython.aws.efs.FileSystem.FileSystemPolicyEntry\x12\x42\n\rbackup_policy\x18\n \x01(\x0b\x32+.oak9.tython.aws.efs.FileSystemBackupPolicy\x1a\x37\n\x15\x46ileSystemPolicyEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x9e\x01\n\x0bMountTarget\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0e\x66ile_system_id\x18\x02 \x01(\t\x12\x12\n\nip_address\x18\x03 \x01(\t\x12\x17\n\x0fsecurity_groups\x18\x04 \x03(\t\x12\x11\n\tsubnet_id\x18\x05 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_efs_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _FILESYSTEM_FILESYSTEMPOLICYENTRY._options = None
  _FILESYSTEM_FILESYSTEMPOLICYENTRY._serialized_options = b'8\001'
  _ACCESSPOINTACCESSPOINTTAG._serialized_start=63
  _ACCESSPOINTACCESSPOINTTAG._serialized_end=175
  _ACCESSPOINTPOSIXUSER._serialized_start=178
  _ACCESSPOINTPOSIXUSER._serialized_end=307
  _ACCESSPOINTCREATIONINFO._serialized_start=310
  _ACCESSPOINTCREATIONINFO._serialized_end=451
  _ACCESSPOINTROOTDIRECTORY._serialized_start=454
  _ACCESSPOINTROOTDIRECTORY._serialized_end=620
  _ACCESSPOINT._serialized_start=623
  _ACCESSPOINT._serialized_end=948
  _EFS._serialized_start=951
  _EFS._serialized_end=1122
  _FILESYSTEMELASTICFILESYSTEMTAG._serialized_start=1124
  _FILESYSTEMELASTICFILESYSTEMTAG._serialized_end=1241
  _FILESYSTEMLIFECYCLEPOLICY._serialized_start=1243
  _FILESYSTEMLIFECYCLEPOLICY._serialized_end=1354
  _FILESYSTEMBACKUPPOLICY._serialized_start=1356
  _FILESYSTEMBACKUPPOLICY._serialized_end=1453
  _FILESYSTEM._serialized_start=1456
  _FILESYSTEM._serialized_end=2019
  _FILESYSTEM_FILESYSTEMPOLICYENTRY._serialized_start=1964
  _FILESYSTEM_FILESYSTEMPOLICYENTRY._serialized_end=2019
  _MOUNTTARGET._serialized_start=2022
  _MOUNTTARGET._serialized_end=2180
# @@protoc_insertion_point(module_scope)
