# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_s3.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10\x61ws/aws_s3.proto\x12\x12oak9.tython.aws.s3\x1a\x13shared/shared.proto\"f\n\x1b\x41\x63\x63\x65ssPointVpcConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06vpc_id\x18\x02 \x01(\t\"\xd9\x01\n)AccessPointPublicAccessBlockConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x19\n\x11\x62lock_public_acls\x18\x02 \x01(\x08\x12\x1a\n\x12ignore_public_acls\x18\x03 \x01(\x08\x12\x1b\n\x13\x62lock_public_policy\x18\x04 \x01(\x08\x12\x1f\n\x17restrict_public_buckets\x18\x05 \x01(\x08\"\xb4\x04\n\x0b\x41\x63\x63\x65ssPoint\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0e\n\x06\x62ucket\x18\x03 \x01(\t\x12J\n\x11vpc_configuration\x18\x04 \x01(\x0b\x32/.oak9.tython.aws.s3.AccessPointVpcConfiguration\x12h\n!public_access_block_configuration\x18\x05 \x01(\x0b\x32=.oak9.tython.aws.s3.AccessPointPublicAccessBlockConfiguration\x12;\n\x06policy\x18\x06 \x03(\x0b\x32+.oak9.tython.aws.s3.AccessPoint.PolicyEntry\x12H\n\rpolicy_status\x18\x07 \x03(\x0b\x32\x31.oak9.tython.aws.s3.AccessPoint.PolicyStatusEntry\x12\x16\n\x0enetwork_origin\x18\x08 \x01(\t\x12\x15\n\rcreation_date\x18\t \x01(\t\x1a-\n\x0bPolicyEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x33\n\x11PolicyStatusEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa0\x01\n\x02S3\x12\x35\n\x0c\x61\x63\x63\x65ss_point\x18\x01 \x01(\x0b\x32\x1f.oak9.tython.aws.s3.AccessPoint\x12*\n\x06\x62ucket\x18\x02 \x01(\x0b\x32\x1a.oak9.tython.aws.s3.Bucket\x12\x37\n\rbucket_policy\x18\x03 \x01(\x0b\x32 .oak9.tython.aws.s3.BucketPolicy\"u\n\x1d\x42ucketAccelerateConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1b\n\x13\x61\x63\x63\x65leration_status\x18\x02 \x01(\t\"\x9b\x01\n\x11\x42ucketDestination\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x19\n\x11\x62ucket_account_id\x18\x02 \x01(\t\x12\x12\n\nbucket_arn\x18\x03 \x01(\t\x12\x0e\n\x06\x66ormat\x18\x04 \x01(\t\x12\x0e\n\x06prefix\x18\x05 \x01(\t\"\xa6\x01\n\x10\x42ucketDataExport\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12:\n\x0b\x64\x65stination\x18\x02 \x01(\x0b\x32%.oak9.tython.aws.s3.BucketDestination\x12\x1d\n\x15output_schema_version\x18\x03 \x01(\t\"\x90\x01\n\x1a\x42ucketStorageClassAnalysis\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x39\n\x0b\x64\x61ta_export\x18\x02 \x01(\x0b\x32$.oak9.tython.aws.s3.BucketDataExport\"f\n\x0f\x42ucketTagFilter\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\"\xfd\x01\n\x1c\x42ucketAnalyticsConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0e\n\x06prefix\x18\x03 \x01(\t\x12N\n\x16storage_class_analysis\x18\x04 \x01(\x0b\x32..oak9.tython.aws.s3.BucketStorageClassAnalysis\x12\x38\n\x0btag_filters\x18\x05 \x03(\x0b\x32#.oak9.tython.aws.s3.BucketTagFilter\"\x90\x01\n#BucketServerSideEncryptionByDefault\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x19\n\x11kms_master_key_id\x18\x02 \x01(\t\x12\x15\n\rsse_algorithm\x18\x03 \x01(\t\"\xbd\x01\n\x1e\x42ucketServerSideEncryptionRule\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x62\n!server_side_encryption_by_default\x18\x02 \x01(\x0b\x32\x37.oak9.tython.aws.s3.BucketServerSideEncryptionByDefault\"\xb3\x01\n\x16\x42ucketBucketEncryption\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12`\n$server_side_encryption_configuration\x18\x02 \x03(\x0b\x32\x32.oak9.tython.aws.s3.BucketServerSideEncryptionRule\"\xca\x01\n\x0e\x42ucketCorsRule\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x17\n\x0f\x61llowed_headers\x18\x02 \x03(\t\x12\x17\n\x0f\x61llowed_methods\x18\x03 \x03(\t\x12\x17\n\x0f\x61llowed_origins\x18\x04 \x03(\t\x12\x17\n\x0f\x65xposed_headers\x18\x05 \x03(\t\x12\n\n\x02id\x18\x06 \x01(\t\x12\x0f\n\x07max_age\x18\x07 \x01(\x05\"\x8a\x01\n\x17\x42ucketCorsConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x36\n\ncors_rules\x18\x02 \x03(\x0b\x32\".oak9.tython.aws.s3.BucketCorsRule\"\x97\x02\n\x1c\x42ucketInventoryConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12:\n\x0b\x64\x65stination\x18\x02 \x01(\x0b\x32%.oak9.tython.aws.s3.BucketDestination\x12\x0f\n\x07\x65nabled\x18\x03 \x01(\x08\x12\n\n\x02id\x18\x04 \x01(\t\x12 \n\x18included_object_versions\x18\x05 \x01(\t\x12\x17\n\x0foptional_fields\x18\x06 \x03(\t\x12\x0e\n\x06prefix\x18\x07 \x01(\t\x12\x1a\n\x12schedule_frequency\x18\x08 \x01(\t\"~\n$BucketAbortIncompleteMultipartUpload\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1d\n\x15\x64\x61ys_after_initiation\x18\x02 \x01(\x05\"\x8f\x01\n!BucketNoncurrentVersionTransition\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rstorage_class\x18\x02 \x01(\t\x12\x1a\n\x12transition_in_days\x18\x03 \x01(\x05\"\x97\x01\n\x10\x42ucketTransition\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rstorage_class\x18\x02 \x01(\t\x12\x17\n\x0ftransition_date\x18\x03 \x01(\t\x12\x1a\n\x12transition_in_days\x18\x04 \x01(\x05\"\xa6\x05\n\nBucketRule\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x63\n!abort_incomplete_multipart_upload\x18\x02 \x01(\x0b\x32\x38.oak9.tython.aws.s3.BucketAbortIncompleteMultipartUpload\x12\x17\n\x0f\x65xpiration_date\x18\x03 \x01(\t\x12\x1a\n\x12\x65xpiration_in_days\x18\x04 \x01(\x05\x12\n\n\x02id\x18\x05 \x01(\t\x12-\n%noncurrent_version_expiration_in_days\x18\x06 \x01(\x05\x12\\\n\x1dnoncurrent_version_transition\x18\x07 \x01(\x0b\x32\x35.oak9.tython.aws.s3.BucketNoncurrentVersionTransition\x12]\n\x1enoncurrent_version_transitions\x18\x08 \x03(\x0b\x32\x35.oak9.tython.aws.s3.BucketNoncurrentVersionTransition\x12\x0e\n\x06prefix\x18\t \x01(\t\x12\x0e\n\x06status\x18\n \x01(\t\x12\x38\n\x0btag_filters\x18\x0b \x03(\x0b\x32#.oak9.tython.aws.s3.BucketTagFilter\x12\x38\n\ntransition\x18\x0c \x01(\x0b\x32$.oak9.tython.aws.s3.BucketTransition\x12\x39\n\x0btransitions\x18\r \x03(\x0b\x32$.oak9.tython.aws.s3.BucketTransition\"\x86\x01\n\x1c\x42ucketLifecycleConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12-\n\x05rules\x18\x02 \x03(\x0b\x32\x1e.oak9.tython.aws.s3.BucketRule\"\x8f\x01\n\x1a\x42ucketLoggingConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1f\n\x17\x64\x65stination_bucket_name\x18\x02 \x01(\t\x12\x17\n\x0flog_file_prefix\x18\x03 \x01(\t\"\xab\x01\n\x1a\x42ucketMetricsConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0e\n\x06prefix\x18\x03 \x01(\t\x12\x38\n\x0btag_filters\x18\x04 \x03(\x0b\x32#.oak9.tython.aws.s3.BucketTagFilter\"h\n\x10\x42ucketFilterRule\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\"\x81\x01\n\x11\x42ucketS3KeyFilter\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x33\n\x05rules\x18\x02 \x03(\x0b\x32$.oak9.tython.aws.s3.BucketFilterRule\"\x8a\x01\n\x18\x42ucketNotificationFilter\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x35\n\x06s3_key\x18\x02 \x01(\x0b\x32%.oak9.tython.aws.s3.BucketS3KeyFilter\"\xb3\x01\n\x19\x42ucketLambdaConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\r\n\x05\x65vent\x18\x02 \x01(\t\x12<\n\x06\x66ilter\x18\x03 \x01(\x0b\x32,.oak9.tython.aws.s3.BucketNotificationFilter\x12\x10\n\x08\x66unction\x18\x04 \x01(\t\"\xaf\x01\n\x18\x42ucketQueueConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\r\n\x05\x65vent\x18\x02 \x01(\t\x12<\n\x06\x66ilter\x18\x03 \x01(\x0b\x32,.oak9.tython.aws.s3.BucketNotificationFilter\x12\r\n\x05queue\x18\x04 \x01(\t\"\xaf\x01\n\x18\x42ucketTopicConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\r\n\x05\x65vent\x18\x02 \x01(\t\x12<\n\x06\x66ilter\x18\x03 \x01(\x0b\x32,.oak9.tython.aws.s3.BucketNotificationFilter\x12\r\n\x05topic\x18\x04 \x01(\t\"\xc0\x02\n\x1f\x42ucketNotificationConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12L\n\x15lambda_configurations\x18\x02 \x03(\x0b\x32-.oak9.tython.aws.s3.BucketLambdaConfiguration\x12J\n\x14queue_configurations\x18\x03 \x03(\x0b\x32,.oak9.tython.aws.s3.BucketQueueConfiguration\x12J\n\x14topic_configurations\x18\x04 \x03(\x0b\x32,.oak9.tython.aws.s3.BucketTopicConfiguration\"|\n\x16\x42ucketDefaultRetention\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04\x64\x61ys\x18\x02 \x01(\x05\x12\x0c\n\x04mode\x18\x03 \x01(\t\x12\r\n\x05years\x18\x04 \x01(\x05\"\x96\x01\n\x14\x42ucketObjectLockRule\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x45\n\x11\x64\x65\x66\x61ult_retention\x18\x02 \x01(\x0b\x32*.oak9.tython.aws.s3.BucketDefaultRetention\"\xad\x01\n\x1d\x42ucketObjectLockConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1b\n\x13object_lock_enabled\x18\x02 \x01(\t\x12\x36\n\x04rule\x18\x03 \x01(\x0b\x32(.oak9.tython.aws.s3.BucketObjectLockRule\"\xd4\x01\n$BucketPublicAccessBlockConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x19\n\x11\x62lock_public_acls\x18\x02 \x01(\x08\x12\x1b\n\x13\x62lock_public_policy\x18\x03 \x01(\x08\x12\x1a\n\x12ignore_public_acls\x18\x04 \x01(\x08\x12\x1f\n\x17restrict_public_buckets\x18\x05 \x01(\x08\"h\n\x1d\x42ucketDeleteMarkerReplication\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06status\x18\x02 \x01(\t\"h\n\x1e\x42ucketAccessControlTranslation\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\r\n\x05owner\x18\x02 \x01(\t\"t\n\x1d\x42ucketEncryptionConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1a\n\x12replica_kms_key_id\x18\x02 \x01(\t\"f\n\x1a\x42ucketReplicationTimeValue\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07minutes\x18\x02 \x01(\x05\"\xa1\x01\n\rBucketMetrics\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12G\n\x0f\x65vent_threshold\x18\x02 \x01(\x0b\x32..oak9.tython.aws.s3.BucketReplicationTimeValue\x12\x0e\n\x06status\x18\x03 \x01(\t\"\x9e\x01\n\x15\x42ucketReplicationTime\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06status\x18\x02 \x01(\t\x12<\n\x04time\x18\x03 \x01(\x0b\x32..oak9.tython.aws.s3.BucketReplicationTimeValue\"\xb5\x03\n\x1c\x42ucketReplicationDestination\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12V\n\x1a\x61\x63\x63\x65ss_control_translation\x18\x02 \x01(\x0b\x32\x32.oak9.tython.aws.s3.BucketAccessControlTranslation\x12\x0f\n\x07\x61\x63\x63ount\x18\x03 \x01(\t\x12\x0e\n\x06\x62ucket\x18\x04 \x01(\t\x12S\n\x18\x65ncryption_configuration\x18\x05 \x01(\x0b\x32\x31.oak9.tython.aws.s3.BucketEncryptionConfiguration\x12\x32\n\x07metrics\x18\x06 \x01(\x0b\x32!.oak9.tython.aws.s3.BucketMetrics\x12\x43\n\x10replication_time\x18\x07 \x01(\x0b\x32).oak9.tython.aws.s3.BucketReplicationTime\x12\x15\n\rstorage_class\x18\x08 \x01(\t\"\xa5\x01\n BucketReplicationRuleAndOperator\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06prefix\x18\x02 \x01(\t\x12\x38\n\x0btag_filters\x18\x03 \x03(\x0b\x32#.oak9.tython.aws.s3.BucketTagFilter\"\xe2\x01\n\x1b\x42ucketReplicationRuleFilter\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x41\n\x03\x61nd\x18\x02 \x01(\x0b\x32\x34.oak9.tython.aws.s3.BucketReplicationRuleAndOperator\x12\x0e\n\x06prefix\x18\x03 \x01(\t\x12\x37\n\ntag_filter\x18\x04 \x01(\x0b\x32#.oak9.tython.aws.s3.BucketTagFilter\"g\n\x1c\x42ucketSseKmsEncryptedObjects\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06status\x18\x02 \x01(\t\"\xad\x01\n\x1d\x42ucketSourceSelectionCriteria\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12S\n\x19sse_kms_encrypted_objects\x18\x02 \x01(\x0b\x32\x30.oak9.tython.aws.s3.BucketSseKmsEncryptedObjects\"\xc2\x03\n\x15\x42ucketReplicationRule\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12T\n\x19\x64\x65lete_marker_replication\x18\x02 \x01(\x0b\x32\x31.oak9.tython.aws.s3.BucketDeleteMarkerReplication\x12\x45\n\x0b\x64\x65stination\x18\x03 \x01(\x0b\x32\x30.oak9.tython.aws.s3.BucketReplicationDestination\x12?\n\x06\x66ilter\x18\x04 \x01(\x0b\x32/.oak9.tython.aws.s3.BucketReplicationRuleFilter\x12\n\n\x02id\x18\x05 \x01(\t\x12\x0e\n\x06prefix\x18\x06 \x01(\t\x12\x10\n\x08priority\x18\x07 \x01(\x05\x12T\n\x19source_selection_criteria\x18\x08 \x01(\x0b\x32\x31.oak9.tython.aws.s3.BucketSourceSelectionCriteria\x12\x0e\n\x06status\x18\t \x01(\t\"\xa1\x01\n\x1e\x42ucketReplicationConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04role\x18\x02 \x01(\t\x12\x38\n\x05rules\x18\x03 \x03(\x0b\x32).oak9.tython.aws.s3.BucketReplicationRule\"h\n\x1d\x42ucketVersioningConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06status\x18\x02 \x01(\t\"{\n\x1b\x42ucketRedirectAllRequestsTo\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\thost_name\x18\x02 \x01(\t\x12\x10\n\x08protocol\x18\x03 \x01(\t\"\xc9\x01\n\x12\x42ucketRedirectRule\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\thost_name\x18\x02 \x01(\t\x12\x1a\n\x12http_redirect_code\x18\x03 \x01(\t\x12\x10\n\x08protocol\x18\x04 \x01(\t\x12\x1f\n\x17replace_key_prefix_with\x18\x05 \x01(\t\x12\x18\n\x10replace_key_with\x18\x06 \x01(\t\"\x99\x01\n\x1a\x42ucketRoutingRuleCondition\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\'\n\x1fhttp_error_code_returned_equals\x18\x02 \x01(\t\x12\x19\n\x11key_prefix_equals\x18\x03 \x01(\t\"\xdb\x01\n\x11\x42ucketRoutingRule\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12=\n\rredirect_rule\x18\x02 \x01(\x0b\x32&.oak9.tython.aws.s3.BucketRedirectRule\x12N\n\x16routing_rule_condition\x18\x03 \x01(\x0b\x32..oak9.tython.aws.s3.BucketRoutingRuleCondition\"\x96\x02\n\x1a\x42ucketWebsiteConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0e\x65rror_document\x18\x02 \x01(\t\x12\x16\n\x0eindex_document\x18\x03 \x01(\t\x12Q\n\x18redirect_all_requests_to\x18\x04 \x01(\x0b\x32/.oak9.tython.aws.s3.BucketRedirectAllRequestsTo\x12<\n\rrouting_rules\x18\x05 \x03(\x0b\x32%.oak9.tython.aws.s3.BucketRoutingRule\"\xfd\x0b\n\x06\x42ucket\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12S\n\x18\x61\x63\x63\x65lerate_configuration\x18\x02 \x01(\x0b\x32\x31.oak9.tython.aws.s3.BucketAccelerateConfiguration\x12\x16\n\x0e\x61\x63\x63\x65ss_control\x18\x03 \x01(\t\x12R\n\x18\x61nalytics_configurations\x18\x04 \x03(\x0b\x32\x30.oak9.tython.aws.s3.BucketAnalyticsConfiguration\x12\x45\n\x11\x62ucket_encryption\x18\x05 \x01(\x0b\x32*.oak9.tython.aws.s3.BucketBucketEncryption\x12\x13\n\x0b\x62ucket_name\x18\x06 \x01(\t\x12G\n\x12\x63ors_configuration\x18\x07 \x01(\x0b\x32+.oak9.tython.aws.s3.BucketCorsConfiguration\x12R\n\x18inventory_configurations\x18\x08 \x03(\x0b\x32\x30.oak9.tython.aws.s3.BucketInventoryConfiguration\x12Q\n\x17lifecycle_configuration\x18\t \x01(\x0b\x32\x30.oak9.tython.aws.s3.BucketLifecycleConfiguration\x12M\n\x15logging_configuration\x18\n \x01(\x0b\x32..oak9.tython.aws.s3.BucketLoggingConfiguration\x12N\n\x16metrics_configurations\x18\x0b \x03(\x0b\x32..oak9.tython.aws.s3.BucketMetricsConfiguration\x12W\n\x1anotification_configuration\x18\x0c \x01(\x0b\x32\x33.oak9.tython.aws.s3.BucketNotificationConfiguration\x12T\n\x19object_lock_configuration\x18\r \x01(\x0b\x32\x31.oak9.tython.aws.s3.BucketObjectLockConfiguration\x12\x1b\n\x13object_lock_enabled\x18\x0e \x01(\x08\x12\x63\n!public_access_block_configuration\x18\x0f \x01(\x0b\x32\x38.oak9.tython.aws.s3.BucketPublicAccessBlockConfiguration\x12U\n\x19replication_configuration\x18\x10 \x01(\x0b\x32\x32.oak9.tython.aws.s3.BucketReplicationConfiguration\x12\x32\n\x04tags\x18\x11 \x03(\x0b\x32$.oak9.tython.aws.s3.Bucket.TagsEntry\x12S\n\x18versioning_configuration\x18\x12 \x01(\x0b\x32\x31.oak9.tython.aws.s3.BucketVersioningConfiguration\x12M\n\x15website_configuration\x18\x13 \x01(\x0b\x32..oak9.tython.aws.s3.BucketWebsiteConfiguration\x12\x38\n\nversioning\x18\x14 \x01(\x0b\x32$.oak9.tython.aws.s3.BucketVersioning\x12G\n\x12ownership_controls\x18\x15 \x01(\x0b\x32+.oak9.tython.aws.s3.BucketOwnershipControls\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"#\n\x10\x42ucketVersioning\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\"p\n\x1b\x42ucketOwnershipControlsRule\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x18\n\x10object_ownership\x18\x02 \x01(\t\"\x92\x01\n\x17\x42ucketOwnershipControls\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12>\n\x05rules\x18\x02 \x03(\x0b\x32/.oak9.tython.aws.s3.BucketOwnershipControlsRule\"p\n\x0c\x42ucketPolicy\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06\x62ucket\x18\x02 \x01(\t\x12\x17\n\x0fpolicy_document\x18\x03 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_s3_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ACCESSPOINT_POLICYENTRY._options = None
  _ACCESSPOINT_POLICYENTRY._serialized_options = b'8\001'
  _ACCESSPOINT_POLICYSTATUSENTRY._options = None
  _ACCESSPOINT_POLICYSTATUSENTRY._serialized_options = b'8\001'
  _BUCKET_TAGSENTRY._options = None
  _BUCKET_TAGSENTRY._serialized_options = b'8\001'
  _ACCESSPOINTVPCCONFIGURATION._serialized_start=61
  _ACCESSPOINTVPCCONFIGURATION._serialized_end=163
  _ACCESSPOINTPUBLICACCESSBLOCKCONFIGURATION._serialized_start=166
  _ACCESSPOINTPUBLICACCESSBLOCKCONFIGURATION._serialized_end=383
  _ACCESSPOINT._serialized_start=386
  _ACCESSPOINT._serialized_end=950
  _ACCESSPOINT_POLICYENTRY._serialized_start=852
  _ACCESSPOINT_POLICYENTRY._serialized_end=897
  _ACCESSPOINT_POLICYSTATUSENTRY._serialized_start=899
  _ACCESSPOINT_POLICYSTATUSENTRY._serialized_end=950
  _S3._serialized_start=953
  _S3._serialized_end=1113
  _BUCKETACCELERATECONFIGURATION._serialized_start=1115
  _BUCKETACCELERATECONFIGURATION._serialized_end=1232
  _BUCKETDESTINATION._serialized_start=1235
  _BUCKETDESTINATION._serialized_end=1390
  _BUCKETDATAEXPORT._serialized_start=1393
  _BUCKETDATAEXPORT._serialized_end=1559
  _BUCKETSTORAGECLASSANALYSIS._serialized_start=1562
  _BUCKETSTORAGECLASSANALYSIS._serialized_end=1706
  _BUCKETTAGFILTER._serialized_start=1708
  _BUCKETTAGFILTER._serialized_end=1810
  _BUCKETANALYTICSCONFIGURATION._serialized_start=1813
  _BUCKETANALYTICSCONFIGURATION._serialized_end=2066
  _BUCKETSERVERSIDEENCRYPTIONBYDEFAULT._serialized_start=2069
  _BUCKETSERVERSIDEENCRYPTIONBYDEFAULT._serialized_end=2213
  _BUCKETSERVERSIDEENCRYPTIONRULE._serialized_start=2216
  _BUCKETSERVERSIDEENCRYPTIONRULE._serialized_end=2405
  _BUCKETBUCKETENCRYPTION._serialized_start=2408
  _BUCKETBUCKETENCRYPTION._serialized_end=2587
  _BUCKETCORSRULE._serialized_start=2590
  _BUCKETCORSRULE._serialized_end=2792
  _BUCKETCORSCONFIGURATION._serialized_start=2795
  _BUCKETCORSCONFIGURATION._serialized_end=2933
  _BUCKETINVENTORYCONFIGURATION._serialized_start=2936
  _BUCKETINVENTORYCONFIGURATION._serialized_end=3215
  _BUCKETABORTINCOMPLETEMULTIPARTUPLOAD._serialized_start=3217
  _BUCKETABORTINCOMPLETEMULTIPARTUPLOAD._serialized_end=3343
  _BUCKETNONCURRENTVERSIONTRANSITION._serialized_start=3346
  _BUCKETNONCURRENTVERSIONTRANSITION._serialized_end=3489
  _BUCKETTRANSITION._serialized_start=3492
  _BUCKETTRANSITION._serialized_end=3643
  _BUCKETRULE._serialized_start=3646
  _BUCKETRULE._serialized_end=4324
  _BUCKETLIFECYCLECONFIGURATION._serialized_start=4327
  _BUCKETLIFECYCLECONFIGURATION._serialized_end=4461
  _BUCKETLOGGINGCONFIGURATION._serialized_start=4464
  _BUCKETLOGGINGCONFIGURATION._serialized_end=4607
  _BUCKETMETRICSCONFIGURATION._serialized_start=4610
  _BUCKETMETRICSCONFIGURATION._serialized_end=4781
  _BUCKETFILTERRULE._serialized_start=4783
  _BUCKETFILTERRULE._serialized_end=4887
  _BUCKETS3KEYFILTER._serialized_start=4890
  _BUCKETS3KEYFILTER._serialized_end=5019
  _BUCKETNOTIFICATIONFILTER._serialized_start=5022
  _BUCKETNOTIFICATIONFILTER._serialized_end=5160
  _BUCKETLAMBDACONFIGURATION._serialized_start=5163
  _BUCKETLAMBDACONFIGURATION._serialized_end=5342
  _BUCKETQUEUECONFIGURATION._serialized_start=5345
  _BUCKETQUEUECONFIGURATION._serialized_end=5520
  _BUCKETTOPICCONFIGURATION._serialized_start=5523
  _BUCKETTOPICCONFIGURATION._serialized_end=5698
  _BUCKETNOTIFICATIONCONFIGURATION._serialized_start=5701
  _BUCKETNOTIFICATIONCONFIGURATION._serialized_end=6021
  _BUCKETDEFAULTRETENTION._serialized_start=6023
  _BUCKETDEFAULTRETENTION._serialized_end=6147
  _BUCKETOBJECTLOCKRULE._serialized_start=6150
  _BUCKETOBJECTLOCKRULE._serialized_end=6300
  _BUCKETOBJECTLOCKCONFIGURATION._serialized_start=6303
  _BUCKETOBJECTLOCKCONFIGURATION._serialized_end=6476
  _BUCKETPUBLICACCESSBLOCKCONFIGURATION._serialized_start=6479
  _BUCKETPUBLICACCESSBLOCKCONFIGURATION._serialized_end=6691
  _BUCKETDELETEMARKERREPLICATION._serialized_start=6693
  _BUCKETDELETEMARKERREPLICATION._serialized_end=6797
  _BUCKETACCESSCONTROLTRANSLATION._serialized_start=6799
  _BUCKETACCESSCONTROLTRANSLATION._serialized_end=6903
  _BUCKETENCRYPTIONCONFIGURATION._serialized_start=6905
  _BUCKETENCRYPTIONCONFIGURATION._serialized_end=7021
  _BUCKETREPLICATIONTIMEVALUE._serialized_start=7023
  _BUCKETREPLICATIONTIMEVALUE._serialized_end=7125
  _BUCKETMETRICS._serialized_start=7128
  _BUCKETMETRICS._serialized_end=7289
  _BUCKETREPLICATIONTIME._serialized_start=7292
  _BUCKETREPLICATIONTIME._serialized_end=7450
  _BUCKETREPLICATIONDESTINATION._serialized_start=7453
  _BUCKETREPLICATIONDESTINATION._serialized_end=7890
  _BUCKETREPLICATIONRULEANDOPERATOR._serialized_start=7893
  _BUCKETREPLICATIONRULEANDOPERATOR._serialized_end=8058
  _BUCKETREPLICATIONRULEFILTER._serialized_start=8061
  _BUCKETREPLICATIONRULEFILTER._serialized_end=8287
  _BUCKETSSEKMSENCRYPTEDOBJECTS._serialized_start=8289
  _BUCKETSSEKMSENCRYPTEDOBJECTS._serialized_end=8392
  _BUCKETSOURCESELECTIONCRITERIA._serialized_start=8395
  _BUCKETSOURCESELECTIONCRITERIA._serialized_end=8568
  _BUCKETREPLICATIONRULE._serialized_start=8571
  _BUCKETREPLICATIONRULE._serialized_end=9021
  _BUCKETREPLICATIONCONFIGURATION._serialized_start=9024
  _BUCKETREPLICATIONCONFIGURATION._serialized_end=9185
  _BUCKETVERSIONINGCONFIGURATION._serialized_start=9187
  _BUCKETVERSIONINGCONFIGURATION._serialized_end=9291
  _BUCKETREDIRECTALLREQUESTSTO._serialized_start=9293
  _BUCKETREDIRECTALLREQUESTSTO._serialized_end=9416
  _BUCKETREDIRECTRULE._serialized_start=9419
  _BUCKETREDIRECTRULE._serialized_end=9620
  _BUCKETROUTINGRULECONDITION._serialized_start=9623
  _BUCKETROUTINGRULECONDITION._serialized_end=9776
  _BUCKETROUTINGRULE._serialized_start=9779
  _BUCKETROUTINGRULE._serialized_end=9998
  _BUCKETWEBSITECONFIGURATION._serialized_start=10001
  _BUCKETWEBSITECONFIGURATION._serialized_end=10279
  _BUCKET._serialized_start=10282
  _BUCKET._serialized_end=11815
  _BUCKET_TAGSENTRY._serialized_start=11772
  _BUCKET_TAGSENTRY._serialized_end=11815
  _BUCKETVERSIONING._serialized_start=11817
  _BUCKETVERSIONING._serialized_end=11852
  _BUCKETOWNERSHIPCONTROLSRULE._serialized_start=11854
  _BUCKETOWNERSHIPCONTROLSRULE._serialized_end=11966
  _BUCKETOWNERSHIPCONTROLS._serialized_start=11969
  _BUCKETOWNERSHIPCONTROLS._serialized_end=12115
  _BUCKETPOLICY._serialized_start=12117
  _BUCKETPOLICY._serialized_end=12229
# @@protoc_insertion_point(module_scope)
