# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_google_pubsub_bundle.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2
from oak9.tython.models.gcp import gcp_pubsub_pb2 as gcp_dot_gcp__pubsub__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"gcp/gcp_google_pubsub_bundle.proto\x12$oak9.tython.gcp.google_pubsub_bundle\x1a\x13shared/shared.proto\x1a\x14gcp/gcp_pubsub.proto\"\xd7\x05\n\x0cGooglePubsub\x12;\n\rpubsub_schema\x18\x01 \x01(\x0b\x32$.oak9.tython.gcp.pubsub.PubsubSchema\x12G\n\x13pubsub_subscription\x18\x02 \x03(\x0b\x32*.oak9.tython.gcp.pubsub.PubsubSubscription\x12]\n\x1fpubsub_subscription_iam_binding\x18\x03 \x03(\x0b\x32\x34.oak9.tython.gcp.pubsub.PubsubSubscriptionIamBinding\x12[\n\x1epubsub_subscription_iam_member\x18\x04 \x03(\x0b\x32\x33.oak9.tython.gcp.pubsub.PubsubSubscriptionIamMember\x12[\n\x1epubsub_subscription_iam_policy\x18\x05 \x03(\x0b\x32\x33.oak9.tython.gcp.pubsub.PubsubSubscriptionIamPolicy\x12\x39\n\x0cpubsub_topic\x18\x06 \x01(\x0b\x32#.oak9.tython.gcp.pubsub.PubsubTopic\x12O\n\x18pubsub_topic_iam_binding\x18\x07 \x03(\x0b\x32-.oak9.tython.gcp.pubsub.PubsubTopicIamBinding\x12M\n\x17pubsub_topic_iam_member\x18\x08 \x03(\x0b\x32,.oak9.tython.gcp.pubsub.PubsubTopicIamMember\x12M\n\x17pubsub_topic_iam_policy\x18\t \x03(\x0b\x32,.oak9.tython.gcp.pubsub.PubsubTopicIamPolicyb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_google_pubsub_bundle_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GOOGLEPUBSUB._serialized_start=120
  _GOOGLEPUBSUB._serialized_end=847
# @@protoc_insertion_point(module_scope)
