# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_compute_global.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1cgcp/gcp_compute_global.proto\x12\x1eoak9.tython.gcp.compute_global\x1a\x13shared/shared.proto\"?\n\x1d\x43omputeGlobalAddressXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\"\x83\x03\n\x14\x43omputeGlobalAddress\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x14\n\x0c\x61\x64\x64ress_type\x18\x02 \x01(\t\x12\x1a\n\x12\x63reation_timestamp\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\n\n\x02id\x18\x05 \x01(\t\x12\x12\n\nip_version\x18\x06 \x01(\t\x12\x0c\n\x04name\x18\x07 \x01(\t\x12\x0f\n\x07network\x18\x08 \x01(\t\x12\x15\n\rprefix_length\x18\t \x01(\x01\x12\x0f\n\x07project\x18\n \x01(\t\x12\x0f\n\x07purpose\x18\x0b \x01(\t\x12\x11\n\tself_link\x18\x0c \x01(\t\x12O\n\x08timeouts\x18\r \x01(\x0b\x32=.oak9.tython.gcp.compute_global.ComputeGlobalAddressXTimeouts\x12\x37\n\rresource_info\x18\x0e \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"W\n8ComputeGlobalForwardingRuleXMetadataFiltersXFilterLabels\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"\xbd\x01\n+ComputeGlobalForwardingRuleXMetadataFilters\x12\x1d\n\x15\x66ilter_match_criteria\x18\x01 \x01(\t\x12o\n\rfilter_labels\x18\x02 \x03(\x0b\x32X.oak9.tython.gcp.compute_global.ComputeGlobalForwardingRuleXMetadataFiltersXFilterLabels\"V\n$ComputeGlobalForwardingRuleXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xd6\x05\n\x1b\x43omputeGlobalForwardingRule\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x12\n\nip_address\x18\x03 \x01(\t\x12\x13\n\x0bip_protocol\x18\x04 \x01(\t\x12\x12\n\nip_version\x18\x05 \x01(\t\x12\x19\n\x11label_fingerprint\x18\x06 \x01(\t\x12W\n\x06labels\x18\x07 \x03(\x0b\x32G.oak9.tython.gcp.compute_global.ComputeGlobalForwardingRule.LabelsEntry\x12\x1d\n\x15load_balancing_scheme\x18\x08 \x01(\t\x12\x0c\n\x04name\x18\t \x01(\t\x12\x0f\n\x07network\x18\n \x01(\t\x12\x12\n\nport_range\x18\x0b \x01(\t\x12\x0f\n\x07project\x18\x0c \x01(\t\x12\x19\n\x11psc_connection_id\x18\r \x01(\t\x12\x1d\n\x15psc_connection_status\x18\x0e \x01(\t\x12\x11\n\tself_link\x18\x0f \x01(\t\x12\x0e\n\x06target\x18\x10 \x01(\t\x12\x65\n\x10metadata_filters\x18\x11 \x03(\x0b\x32K.oak9.tython.gcp.compute_global.ComputeGlobalForwardingRuleXMetadataFilters\x12V\n\x08timeouts\x18\x12 \x01(\x0b\x32\x44.oak9.tython.gcp.compute_global.ComputeGlobalForwardingRuleXTimeouts\x12\x37\n\rresource_info\x18\x13 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"G\n%ComputeGlobalNetworkEndpointXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\"\xa4\x02\n\x1c\x43omputeGlobalNetworkEndpoint\x12\x0c\n\x04\x66qdn\x18\x01 \x01(\t\x12%\n\x1dglobal_network_endpoint_group\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x12\n\nip_address\x18\x04 \x01(\t\x12\x0c\n\x04port\x18\x05 \x01(\x01\x12\x0f\n\x07project\x18\x06 \x01(\t\x12W\n\x08timeouts\x18\x07 \x01(\x0b\x32\x45.oak9.tython.gcp.compute_global.ComputeGlobalNetworkEndpointXTimeouts\x12\x37\n\rresource_info\x18\x08 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"L\n*ComputeGlobalNetworkEndpointGroupXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\"\xc2\x02\n!ComputeGlobalNetworkEndpointGroup\x12\x14\n\x0c\x64\x65\x66\x61ult_port\x18\x01 \x01(\x01\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x1d\n\x15network_endpoint_type\x18\x05 \x01(\t\x12\x0f\n\x07project\x18\x06 \x01(\t\x12\x11\n\tself_link\x18\x07 \x01(\t\x12\\\n\x08timeouts\x18\x08 \x01(\x0b\x32J.oak9.tython.gcp.compute_global.ComputeGlobalNetworkEndpointGroupXTimeouts\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_compute_global_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMPUTEGLOBALFORWARDINGRULE_LABELSENTRY._options = None
  _COMPUTEGLOBALFORWARDINGRULE_LABELSENTRY._serialized_options = b'8\001'
  _COMPUTEGLOBALADDRESSXTIMEOUTS._serialized_start=85
  _COMPUTEGLOBALADDRESSXTIMEOUTS._serialized_end=148
  _COMPUTEGLOBALADDRESS._serialized_start=151
  _COMPUTEGLOBALADDRESS._serialized_end=538
  _COMPUTEGLOBALFORWARDINGRULEXMETADATAFILTERSXFILTERLABELS._serialized_start=540
  _COMPUTEGLOBALFORWARDINGRULEXMETADATAFILTERSXFILTERLABELS._serialized_end=627
  _COMPUTEGLOBALFORWARDINGRULEXMETADATAFILTERS._serialized_start=630
  _COMPUTEGLOBALFORWARDINGRULEXMETADATAFILTERS._serialized_end=819
  _COMPUTEGLOBALFORWARDINGRULEXTIMEOUTS._serialized_start=821
  _COMPUTEGLOBALFORWARDINGRULEXTIMEOUTS._serialized_end=907
  _COMPUTEGLOBALFORWARDINGRULE._serialized_start=910
  _COMPUTEGLOBALFORWARDINGRULE._serialized_end=1636
  _COMPUTEGLOBALFORWARDINGRULE_LABELSENTRY._serialized_start=1591
  _COMPUTEGLOBALFORWARDINGRULE_LABELSENTRY._serialized_end=1636
  _COMPUTEGLOBALNETWORKENDPOINTXTIMEOUTS._serialized_start=1638
  _COMPUTEGLOBALNETWORKENDPOINTXTIMEOUTS._serialized_end=1709
  _COMPUTEGLOBALNETWORKENDPOINT._serialized_start=1712
  _COMPUTEGLOBALNETWORKENDPOINT._serialized_end=2004
  _COMPUTEGLOBALNETWORKENDPOINTGROUPXTIMEOUTS._serialized_start=2006
  _COMPUTEGLOBALNETWORKENDPOINTGROUPXTIMEOUTS._serialized_end=2082
  _COMPUTEGLOBALNETWORKENDPOINTGROUP._serialized_start=2085
  _COMPUTEGLOBALNETWORKENDPOINTGROUP._serialized_end=2407
# @@protoc_insertion_point(module_scope)
