# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: azure/azure_microsoft_network_applicationgateways.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7azure/azure_microsoft_network_applicationgateways.proto\x12\x37oak9.tython.azure.microsoft_network_applicationgateways\x1a\x13shared/shared.proto\"\x93\x01\n%Microsoft_Network_applicationGateways\x12j\n\x14\x61pplication_gateways\x18\x01 \x01(\x0b\x32L.oak9.tython.azure.microsoft_network_applicationgateways.ApplicationGateways\"\x1a\n\x0cHttpListener\x12\n\n\x02id\x18\x01 \x01(\t\"!\n\x13\x42\x61\x63kendHttpSettings\x12\n\n\x02id\x18\x01 \x01(\t\" \n\x12\x42\x61\x63kendAddressPool\x12\n\n\x02id\x18\x01 \x01(\t\"\x1a\n\x0c\x46rontendPort\x12\n\n\x02id\x18\x01 \x01(\t\"%\n\x17\x46rontendIPConfiguration\x12\n\n\x02id\x18\x01 \x01(\t\"\x14\n\x06Subnet\x12\n\n\x02id\x18\x01 \x01(\t\"\x1d\n\x0fPublicIpAddress\x12\n\n\x02id\x18\x01 \x01(\t\"\x82\x02\n-ApplicationGatewaysPrivateEndpointConnections\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x89\x01\n%private_link_service_connection_state\x18\x03 \x01(\x0b\x32Z.oak9.tython.azure.microsoft_network_applicationgateways.PrivateLinkServiceConnectionState\"b\n!PrivateLinkServiceConnectionState\x12\x0e\n\x06status\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x18\n\x10\x61\x63tions_required\x18\x03 \x01(\t\"\xb6\x1a\n\x13\x41pplicationGateways\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x64\n\x04tags\x18\x04 \x03(\x0b\x32V.oak9.tython.azure.microsoft_network_applicationgateways.ApplicationGateways.TagsEntry\x12[\n\x03sku\x18\x05 \x01(\x0b\x32N.oak9.tython.azure.microsoft_network_applicationgateways.ApplicationGatewaySku\x12h\n\nssl_policy\x18\x06 \x01(\x0b\x32T.oak9.tython.azure.microsoft_network_applicationgateways.ApplicationGatewaySslPolicy\x12}\n\x19gateway_ip_configurations\x18\x07 \x03(\x0b\x32Z.oak9.tython.azure.microsoft_network_applicationgateways.ApplicationGatewayIPConfiguration\x12\x89\x01\n\x1b\x61uthentication_certificates\x18\x08 \x03(\x0b\x32\x64.oak9.tython.azure.microsoft_network_applicationgateways.ApplicationGatewayAuthenticationCertificate\x12\x84\x01\n\x19trusted_root_certificates\x18\t \x03(\x0b\x32\x61.oak9.tython.azure.microsoft_network_applicationgateways.ApplicationGatewayTrustedRootCertificate\x12\x88\x01\n\x1btrusted_client_certificates\x18\n \x03(\x0b\x32\x63.oak9.tython.azure.microsoft_network_applicationgateways.ApplicationGatewayTrustedClientCertificate\x12s\n\x10ssl_certificates\x18\x0b \x03(\x0b\x32Y.oak9.tython.azure.microsoft_network_applicationgateways.ApplicationGatewaySslCertificate\x12\x86\x01\n\x1a\x66rontend_ip_configurations\x18\x0c \x03(\x0b\x32\x62.oak9.tython.azure.microsoft_network_applicationgateways.ApplicationGatewayFrontendIPConfiguration\x12o\n\x0e\x66rontend_ports\x18\r \x03(\x0b\x32W.oak9.tython.azure.microsoft_network_applicationgateways.ApplicationGatewayFrontendPort\x12`\n\x06probes\x18\x0e \x03(\x0b\x32P.oak9.tython.azure.microsoft_network_applicationgateways.ApplicationGatewayProbe\x12|\n\x15\x62\x61\x63kend_address_pools\x18\x0f \x03(\x0b\x32].oak9.tython.azure.microsoft_network_applicationgateways.ApplicationGatewayBackendAddressPool\x12\x88\x01\n backend_http_settings_collection\x18\x10 \x03(\x0b\x32^.oak9.tython.azure.microsoft_network_applicationgateways.ApplicationGatewayBackendHttpSettings\x12o\n\x0ehttp_listeners\x18\x11 \x03(\x0b\x32W.oak9.tython.azure.microsoft_network_applicationgateways.ApplicationGatewayHttpListener\x12k\n\x0cssl_profiles\x18\x12 \x03(\x0b\x32U.oak9.tython.azure.microsoft_network_applicationgateways.ApplicationGatewaySslProfile\x12l\n\rurl_path_maps\x18\x13 \x03(\x0b\x32U.oak9.tython.azure.microsoft_network_applicationgateways.ApplicationGatewayUrlPathMap\x12|\n\x15request_routing_rules\x18\x14 \x03(\x0b\x32].oak9.tython.azure.microsoft_network_applicationgateways.ApplicationGatewayRequestRoutingRule\x12t\n\x11rewrite_rule_sets\x18\x15 \x03(\x0b\x32Y.oak9.tython.azure.microsoft_network_applicationgateways.ApplicationGatewayRewriteRuleSet\x12\x81\x01\n\x17redirect_configurations\x18\x16 \x03(\x0b\x32`.oak9.tython.azure.microsoft_network_applicationgateways.ApplicationGatewayRedirectConfiguration\x12\x9e\x01\n&web_application_firewall_configuration\x18\x17 \x01(\x0b\x32n.oak9.tython.azure.microsoft_network_applicationgateways.ApplicationGatewayWebApplicationFirewallConfiguration\x12\x17\n\x0f\x66irewall_policy\x18\x18 \x01(\t\x12\x14\n\x0c\x65nable_http2\x18\x19 \x01(\x08\x12\x13\n\x0b\x65nable_fips\x18\x1a \x01(\x08\x12\x82\x01\n\x17\x61utoscale_configuration\x18\x1b \x01(\x0b\x32\x61.oak9.tython.azure.microsoft_network_applicationgateways.ApplicationGatewayAutoscaleConfiguration\x12\x88\x01\n\x1bprivate_link_configurations\x18\x1c \x03(\x0b\x32\x63.oak9.tython.azure.microsoft_network_applicationgateways.ApplicationGatewayPrivateLinkConfiguration\x12{\n\x1b\x63ustom_error_configurations\x18\x1d \x03(\x0b\x32V.oak9.tython.azure.microsoft_network_applicationgateways.ApplicationGatewayCustomError\x12)\n!force_firewall_policy_association\x18\x1e \x01(\x08\x12\r\n\x05zones\x18\x1f \x03(\t\x12\x61\n\x08identity\x18  \x01(\x0b\x32O.oak9.tython.azure.microsoft_network_applicationgateways.ManagedServiceIdentity\x12\xa1\x01\n1application_gateways_private_endpoint_connections\x18! \x03(\x0b\x32\x66.oak9.tython.azure.microsoft_network_applicationgateways.ApplicationGatewaysPrivateEndpointConnections\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xf5\x01\n\x16ManagedServiceIdentity\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x8d\x01\n\x18user_assigned_identities\x18\x02 \x03(\x0b\x32k.oak9.tython.azure.microsoft_network_applicationgateways.ManagedServiceIdentity.UserAssignedIdentitiesEntry\x1a=\n\x1bUserAssignedIdentitiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xbd\x01\n*ApplicationGatewayPrivateLinkConfiguration\x12\x80\x01\n\x11ip_configurations\x18\x01 \x03(\x0b\x32\x65.oak9.tython.azure.microsoft_network_applicationgateways.ApplicationGatewayPrivateLinkIpConfiguration\x12\x0c\n\x04name\x18\x02 \x01(\t\"\xe0\x01\n,ApplicationGatewayPrivateLinkIpConfiguration\x12\x1a\n\x12private_ip_address\x18\x01 \x01(\t\x12$\n\x1cprivate_ip_allocation_method\x18\x02 \x01(\t\x12O\n\x06subnet\x18\x03 \x01(\x0b\x32?.oak9.tython.azure.microsoft_network_applicationgateways.Subnet\x12\x0f\n\x07primary\x18\x04 \x01(\x08\x12\x0c\n\x04name\x18\x05 \x01(\t\"V\n(ApplicationGatewayAutoscaleConfiguration\x12\x14\n\x0cmin_capacity\x18\x01 \x01(\x05\x12\x14\n\x0cmax_capacity\x18\x02 \x01(\x05\"\x88\x04\n5ApplicationGatewayWebApplicationFirewallConfiguration\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x15\n\rfirewall_mode\x18\x02 \x01(\t\x12\x15\n\rrule_set_type\x18\x03 \x01(\t\x12\x18\n\x10rule_set_version\x18\x04 \x01(\t\x12\x82\x01\n\x14\x64isabled_rule_groups\x18\x05 \x03(\x0b\x32\x64.oak9.tython.azure.microsoft_network_applicationgateways.ApplicationGatewayFirewallDisabledRuleGroup\x12\x1a\n\x12request_body_check\x18\x06 \x01(\x08\x12\x1d\n\x15max_request_body_size\x18\x07 \x01(\x05\x12#\n\x1bmax_request_body_size_in_kb\x18\x08 \x01(\x05\x12\x1f\n\x17\x66ile_upload_limit_in_mb\x18\t \x01(\x05\x12p\n\nexclusions\x18\n \x03(\x0b\x32\\.oak9.tython.azure.microsoft_network_applicationgateways.ApplicationGatewayFirewallExclusion\"p\n#ApplicationGatewayFirewallExclusion\x12\x16\n\x0ematch_variable\x18\x01 \x01(\t\x12\x1f\n\x17selector_match_operator\x18\x02 \x01(\t\x12\x10\n\x08selector\x18\x03 \x01(\t\"U\n+ApplicationGatewayFirewallDisabledRuleGroup\x12\x17\n\x0frule_group_name\x18\x01 \x01(\t\x12\r\n\x05rules\x18\x02 \x03(\x05\"\xf9\x01\n\'ApplicationGatewayRedirectConfiguration\x12\x15\n\rredirect_type\x18\x01 \x01(\t\x12\x17\n\x0ftarget_listener\x18\x02 \x01(\t\x12\x12\n\ntarget_url\x18\x03 \x01(\t\x12\x14\n\x0cinclude_path\x18\x04 \x01(\x08\x12\x1c\n\x14include_query_string\x18\x05 \x01(\x08\x12\x1d\n\x15request_routing_rules\x18\x06 \x03(\t\x12\x15\n\rurl_path_maps\x18\x07 \x03(\t\x12\x12\n\npath_rules\x18\x08 \x03(\t\x12\x0c\n\x04name\x18\t \x01(\t\"\x9f\x01\n ApplicationGatewayRewriteRuleSet\x12m\n\rrewrite_rules\x18\x01 \x03(\x0b\x32V.oak9.tython.azure.microsoft_network_applicationgateways.ApplicationGatewayRewriteRule\x12\x0c\n\x04name\x18\x02 \x01(\t\"\xae\x02\n\x1d\x41pplicationGatewayRewriteRule\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x15\n\rrule_sequence\x18\x02 \x01(\x05\x12s\n\nconditions\x18\x03 \x03(\x0b\x32_.oak9.tython.azure.microsoft_network_applicationgateways.ApplicationGatewayRewriteRuleCondition\x12s\n\naction_set\x18\x04 \x01(\x0b\x32_.oak9.tython.azure.microsoft_network_applicationgateways.ApplicationGatewayRewriteRuleActionSet\"\xb1\x03\n&ApplicationGatewayRewriteRuleActionSet\x12\x85\x01\n\x1drequest_header_configurations\x18\x01 \x03(\x0b\x32^.oak9.tython.azure.microsoft_network_applicationgateways.ApplicationGatewayHeaderConfiguration\x12\x86\x01\n\x1eresponse_header_configurations\x18\x02 \x03(\x0b\x32^.oak9.tython.azure.microsoft_network_applicationgateways.ApplicationGatewayHeaderConfiguration\x12v\n\x11url_configuration\x18\x03 \x01(\x0b\x32[.oak9.tython.azure.microsoft_network_applicationgateways.ApplicationGatewayUrlConfiguration\"k\n\"ApplicationGatewayUrlConfiguration\x12\x15\n\rmodified_path\x18\x01 \x01(\t\x12\x1d\n\x15modified_query_string\x18\x02 \x01(\t\x12\x0f\n\x07reroute\x18\x03 \x01(\x08\"R\n%ApplicationGatewayHeaderConfiguration\x12\x13\n\x0bheader_name\x18\x01 \x01(\t\x12\x14\n\x0cheader_value\x18\x02 \x01(\t\"p\n&ApplicationGatewayRewriteRuleCondition\x12\x10\n\x08variable\x18\x01 \x01(\t\x12\x0f\n\x07pattern\x18\x02 \x01(\t\x12\x13\n\x0bignore_case\x18\x03 \x01(\x08\x12\x0e\n\x06negate\x18\x04 \x01(\x08\"\xdf\x03\n$ApplicationGatewayRequestRoutingRule\x12\x11\n\trule_type\x18\x01 \x01(\t\x12\x10\n\x08priority\x18\x02 \x01(\x05\x12i\n\x14\x62\x61\x63kend_address_pool\x18\x03 \x01(\x0b\x32K.oak9.tython.azure.microsoft_network_applicationgateways.BackendAddressPool\x12k\n\x15\x62\x61\x63kend_http_settings\x18\x04 \x01(\x0b\x32L.oak9.tython.azure.microsoft_network_applicationgateways.BackendHttpSettings\x12\\\n\rhttp_listener\x18\x05 \x01(\x0b\x32\x45.oak9.tython.azure.microsoft_network_applicationgateways.HttpListener\x12\x14\n\x0curl_path_map\x18\x06 \x01(\t\x12\x18\n\x10rewrite_rule_set\x18\x07 \x01(\t\x12\x1e\n\x16redirect_configuration\x18\x08 \x01(\t\x12\x0c\n\x04name\x18\t \x01(\t\"\xac\x02\n\x1c\x41pplicationGatewayUrlPathMap\x12$\n\x1c\x64\x65\x66\x61ult_backend_address_pool\x18\x01 \x01(\t\x12%\n\x1d\x64\x65\x66\x61ult_backend_http_settings\x18\x02 \x01(\t\x12 \n\x18\x64\x65\x66\x61ult_rewrite_rule_set\x18\x03 \x01(\t\x12&\n\x1e\x64\x65\x66\x61ult_redirect_configuration\x18\x04 \x01(\t\x12g\n\npath_rules\x18\x05 \x03(\x0b\x32S.oak9.tython.azure.microsoft_network_applicationgateways.ApplicationGatewayPathRule\x12\x0c\n\x04name\x18\x06 \x01(\t\"\xe4\x02\n\x1a\x41pplicationGatewayPathRule\x12\r\n\x05paths\x18\x01 \x03(\t\x12i\n\x14\x62\x61\x63kend_address_pool\x18\x02 \x01(\x0b\x32K.oak9.tython.azure.microsoft_network_applicationgateways.BackendAddressPool\x12k\n\x15\x62\x61\x63kend_http_settings\x18\x03 \x01(\x0b\x32L.oak9.tython.azure.microsoft_network_applicationgateways.BackendHttpSettings\x12\x1e\n\x16redirect_configuration\x18\x04 \x01(\t\x12\x18\n\x10rewrite_rule_set\x18\x05 \x01(\t\x12\x17\n\x0f\x66irewall_policy\x18\x06 \x01(\t\x12\x0c\n\x04name\x18\x07 \x01(\t\"\xc3\x02\n\x1c\x41pplicationGatewaySslProfile\x12#\n\x1btrusted_client_certificates\x18\x01 \x03(\t\x12h\n\nssl_policy\x18\x02 \x01(\x0b\x32T.oak9.tython.azure.microsoft_network_applicationgateways.ApplicationGatewaySslPolicy\x12\x85\x01\n\x19\x63lient_auth_configuration\x18\x03 \x01(\x0b\x32\x62.oak9.tython.azure.microsoft_network_applicationgateways.ApplicationGatewayClientAuthConfiguration\x12\x0c\n\x04name\x18\x04 \x01(\t\"R\n)ApplicationGatewayClientAuthConfiguration\x12%\n\x1dverify_client_cert_issuer_d_n\x18\x01 \x01(\x08\"\xa6\x04\n\x1e\x41pplicationGatewayHttpListener\x12s\n\x19\x66rontend_ip_configuration\x18\x01 \x01(\x0b\x32P.oak9.tython.azure.microsoft_network_applicationgateways.FrontendIPConfiguration\x12\\\n\rfrontend_port\x18\x02 \x01(\x0b\x32\x45.oak9.tython.azure.microsoft_network_applicationgateways.FrontendPort\x12\x10\n\x08protocol\x18\x03 \x01(\t\x12\x11\n\thost_name\x18\x04 \x01(\t\x12\x17\n\x0fssl_certificate\x18\x05 \x01(\t\x12\x13\n\x0bssl_profile\x18\x06 \x01(\t\x12&\n\x1erequire_server_name_indication\x18\x07 \x01(\x08\x12{\n\x1b\x63ustom_error_configurations\x18\x08 \x03(\x0b\x32V.oak9.tython.azure.microsoft_network_applicationgateways.ApplicationGatewayCustomError\x12\x17\n\x0f\x66irewall_policy\x18\t \x01(\t\x12\x12\n\nhost_names\x18\n \x03(\t\x12\x0c\n\x04name\x18\x0b \x01(\t\"S\n\x1d\x41pplicationGatewayCustomError\x12\x13\n\x0bstatus_code\x18\x01 \x01(\t\x12\x1d\n\x15\x63ustom_error_page_url\x18\x02 \x01(\t\"\xe3\x03\n%ApplicationGatewayBackendHttpSettings\x12\x0c\n\x04port\x18\x01 \x01(\x05\x12\x10\n\x08protocol\x18\x02 \x01(\t\x12\x1d\n\x15\x63ookie_based_affinity\x18\x03 \x01(\t\x12\x17\n\x0frequest_timeout\x18\x04 \x01(\x05\x12\r\n\x05probe\x18\x05 \x01(\t\x12#\n\x1b\x61uthentication_certificates\x18\x06 \x03(\t\x12!\n\x19trusted_root_certificates\x18\x07 \x03(\t\x12z\n\x13\x63onnection_draining\x18\x08 \x01(\x0b\x32].oak9.tython.azure.microsoft_network_applicationgateways.ApplicationGatewayConnectionDraining\x12\x11\n\thost_name\x18\t \x01(\t\x12+\n#pick_host_name_from_backend_address\x18\n \x01(\x08\x12\x1c\n\x14\x61\x66\x66inity_cookie_name\x18\x0b \x01(\t\x12\x15\n\rprobe_enabled\x18\x0c \x01(\x08\x12\x0c\n\x04path\x18\r \x01(\t\x12\x0c\n\x04name\x18\x0e \x01(\t\"U\n$ApplicationGatewayConnectionDraining\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x1c\n\x14\x64rain_timeout_in_sec\x18\x02 \x01(\x05\"\xaa\x01\n$ApplicationGatewayBackendAddressPool\x12t\n\x11\x62\x61\x63kend_addresses\x18\x01 \x03(\x0b\x32Y.oak9.tython.azure.microsoft_network_applicationgateways.ApplicationGatewayBackendAddress\x12\x0c\n\x04name\x18\x02 \x01(\t\"D\n ApplicationGatewayBackendAddress\x12\x0c\n\x04\x66qdn\x18\x01 \x01(\t\x12\x12\n\nip_address\x18\x02 \x01(\t\"\xdf\x02\n\x17\x41pplicationGatewayProbe\x12\x10\n\x08protocol\x18\x01 \x01(\t\x12\x0c\n\x04host\x18\x02 \x01(\t\x12\x0c\n\x04path\x18\x03 \x01(\t\x12\x10\n\x08interval\x18\x04 \x01(\x05\x12\x0f\n\x07timeout\x18\x05 \x01(\x05\x12\x1b\n\x13unhealthy_threshold\x18\x06 \x01(\x05\x12\x31\n)pick_host_name_from_backend_http_settings\x18\x07 \x01(\x08\x12\x13\n\x0bmin_servers\x18\x08 \x01(\x05\x12r\n\x05match\x18\t \x01(\x0b\x32\x63.oak9.tython.azure.microsoft_network_applicationgateways.ApplicationGatewayProbeHealthResponseMatch\x12\x0c\n\x04port\x18\n \x01(\x05\x12\x0c\n\x04name\x18\x0b \x01(\t\"P\n*ApplicationGatewayProbeHealthResponseMatch\x12\x0c\n\x04\x62ody\x18\x01 \x01(\t\x12\x14\n\x0cstatus_codes\x18\x02 \x03(\t\"<\n\x1e\x41pplicationGatewayFrontendPort\x12\x0c\n\x04port\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\"\xd5\x02\n)ApplicationGatewayFrontendIPConfiguration\x12\x1a\n\x12private_ip_address\x18\x01 \x01(\t\x12$\n\x1cprivate_ip_allocation_method\x18\x02 \x01(\t\x12O\n\x06subnet\x18\x03 \x01(\x0b\x32?.oak9.tython.azure.microsoft_network_applicationgateways.Subnet\x12\"\n\x1aprivate_link_configuration\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x63\n\x11public_ip_address\x18\x06 \x01(\x0b\x32H.oak9.tython.azure.microsoft_network_applicationgateways.PublicIpAddress\"m\n ApplicationGatewaySslCertificate\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\x12\x1b\n\x13key_vault_secret_id\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\"H\n*ApplicationGatewayTrustedClientCertificate\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"c\n(ApplicationGatewayTrustedRootCertificate\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\t\x12\x1b\n\x13key_vault_secret_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\"I\n+ApplicationGatewayAuthenticationCertificate\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x82\x01\n!ApplicationGatewayIPConfiguration\x12O\n\x06subnet\x18\x01 \x01(\x0b\x32?.oak9.tython.azure.microsoft_network_applicationgateways.Subnet\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x9c\x01\n\x1b\x41pplicationGatewaySslPolicy\x12\x1e\n\x16\x64isabled_ssl_protocols\x18\x01 \x03(\t\x12\x13\n\x0bpolicy_type\x18\x02 \x01(\t\x12\x13\n\x0bpolicy_name\x18\x03 \x01(\t\x12\x15\n\rcipher_suites\x18\x04 \x03(\t\x12\x1c\n\x14min_protocol_version\x18\x05 \x01(\t\"E\n\x15\x41pplicationGatewaySku\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04tier\x18\x02 \x01(\t\x12\x10\n\x08\x63\x61pacity\x18\x03 \x01(\x05\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'azure.azure_microsoft_network_applicationgateways_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _APPLICATIONGATEWAYS_TAGSENTRY._options = None
  _APPLICATIONGATEWAYS_TAGSENTRY._serialized_options = b'8\001'
  _MANAGEDSERVICEIDENTITY_USERASSIGNEDIDENTITIESENTRY._options = None
  _MANAGEDSERVICEIDENTITY_USERASSIGNEDIDENTITIESENTRY._serialized_options = b'8\001'
  _MICROSOFT_NETWORK_APPLICATIONGATEWAYS._serialized_start=138
  _MICROSOFT_NETWORK_APPLICATIONGATEWAYS._serialized_end=285
  _HTTPLISTENER._serialized_start=287
  _HTTPLISTENER._serialized_end=313
  _BACKENDHTTPSETTINGS._serialized_start=315
  _BACKENDHTTPSETTINGS._serialized_end=348
  _BACKENDADDRESSPOOL._serialized_start=350
  _BACKENDADDRESSPOOL._serialized_end=382
  _FRONTENDPORT._serialized_start=384
  _FRONTENDPORT._serialized_end=410
  _FRONTENDIPCONFIGURATION._serialized_start=412
  _FRONTENDIPCONFIGURATION._serialized_end=449
  _SUBNET._serialized_start=451
  _SUBNET._serialized_end=471
  _PUBLICIPADDRESS._serialized_start=473
  _PUBLICIPADDRESS._serialized_end=502
  _APPLICATIONGATEWAYSPRIVATEENDPOINTCONNECTIONS._serialized_start=505
  _APPLICATIONGATEWAYSPRIVATEENDPOINTCONNECTIONS._serialized_end=763
  _PRIVATELINKSERVICECONNECTIONSTATE._serialized_start=765
  _PRIVATELINKSERVICECONNECTIONSTATE._serialized_end=863
  _APPLICATIONGATEWAYS._serialized_start=866
  _APPLICATIONGATEWAYS._serialized_end=4248
  _APPLICATIONGATEWAYS_TAGSENTRY._serialized_start=4205
  _APPLICATIONGATEWAYS_TAGSENTRY._serialized_end=4248
  _MANAGEDSERVICEIDENTITY._serialized_start=4251
  _MANAGEDSERVICEIDENTITY._serialized_end=4496
  _MANAGEDSERVICEIDENTITY_USERASSIGNEDIDENTITIESENTRY._serialized_start=4435
  _MANAGEDSERVICEIDENTITY_USERASSIGNEDIDENTITIESENTRY._serialized_end=4496
  _APPLICATIONGATEWAYPRIVATELINKCONFIGURATION._serialized_start=4499
  _APPLICATIONGATEWAYPRIVATELINKCONFIGURATION._serialized_end=4688
  _APPLICATIONGATEWAYPRIVATELINKIPCONFIGURATION._serialized_start=4691
  _APPLICATIONGATEWAYPRIVATELINKIPCONFIGURATION._serialized_end=4915
  _APPLICATIONGATEWAYAUTOSCALECONFIGURATION._serialized_start=4917
  _APPLICATIONGATEWAYAUTOSCALECONFIGURATION._serialized_end=5003
  _APPLICATIONGATEWAYWEBAPPLICATIONFIREWALLCONFIGURATION._serialized_start=5006
  _APPLICATIONGATEWAYWEBAPPLICATIONFIREWALLCONFIGURATION._serialized_end=5526
  _APPLICATIONGATEWAYFIREWALLEXCLUSION._serialized_start=5528
  _APPLICATIONGATEWAYFIREWALLEXCLUSION._serialized_end=5640
  _APPLICATIONGATEWAYFIREWALLDISABLEDRULEGROUP._serialized_start=5642
  _APPLICATIONGATEWAYFIREWALLDISABLEDRULEGROUP._serialized_end=5727
  _APPLICATIONGATEWAYREDIRECTCONFIGURATION._serialized_start=5730
  _APPLICATIONGATEWAYREDIRECTCONFIGURATION._serialized_end=5979
  _APPLICATIONGATEWAYREWRITERULESET._serialized_start=5982
  _APPLICATIONGATEWAYREWRITERULESET._serialized_end=6141
  _APPLICATIONGATEWAYREWRITERULE._serialized_start=6144
  _APPLICATIONGATEWAYREWRITERULE._serialized_end=6446
  _APPLICATIONGATEWAYREWRITERULEACTIONSET._serialized_start=6449
  _APPLICATIONGATEWAYREWRITERULEACTIONSET._serialized_end=6882
  _APPLICATIONGATEWAYURLCONFIGURATION._serialized_start=6884
  _APPLICATIONGATEWAYURLCONFIGURATION._serialized_end=6991
  _APPLICATIONGATEWAYHEADERCONFIGURATION._serialized_start=6993
  _APPLICATIONGATEWAYHEADERCONFIGURATION._serialized_end=7075
  _APPLICATIONGATEWAYREWRITERULECONDITION._serialized_start=7077
  _APPLICATIONGATEWAYREWRITERULECONDITION._serialized_end=7189
  _APPLICATIONGATEWAYREQUESTROUTINGRULE._serialized_start=7192
  _APPLICATIONGATEWAYREQUESTROUTINGRULE._serialized_end=7671
  _APPLICATIONGATEWAYURLPATHMAP._serialized_start=7674
  _APPLICATIONGATEWAYURLPATHMAP._serialized_end=7974
  _APPLICATIONGATEWAYPATHRULE._serialized_start=7977
  _APPLICATIONGATEWAYPATHRULE._serialized_end=8333
  _APPLICATIONGATEWAYSSLPROFILE._serialized_start=8336
  _APPLICATIONGATEWAYSSLPROFILE._serialized_end=8659
  _APPLICATIONGATEWAYCLIENTAUTHCONFIGURATION._serialized_start=8661
  _APPLICATIONGATEWAYCLIENTAUTHCONFIGURATION._serialized_end=8743
  _APPLICATIONGATEWAYHTTPLISTENER._serialized_start=8746
  _APPLICATIONGATEWAYHTTPLISTENER._serialized_end=9296
  _APPLICATIONGATEWAYCUSTOMERROR._serialized_start=9298
  _APPLICATIONGATEWAYCUSTOMERROR._serialized_end=9381
  _APPLICATIONGATEWAYBACKENDHTTPSETTINGS._serialized_start=9384
  _APPLICATIONGATEWAYBACKENDHTTPSETTINGS._serialized_end=9867
  _APPLICATIONGATEWAYCONNECTIONDRAINING._serialized_start=9869
  _APPLICATIONGATEWAYCONNECTIONDRAINING._serialized_end=9954
  _APPLICATIONGATEWAYBACKENDADDRESSPOOL._serialized_start=9957
  _APPLICATIONGATEWAYBACKENDADDRESSPOOL._serialized_end=10127
  _APPLICATIONGATEWAYBACKENDADDRESS._serialized_start=10129
  _APPLICATIONGATEWAYBACKENDADDRESS._serialized_end=10197
  _APPLICATIONGATEWAYPROBE._serialized_start=10200
  _APPLICATIONGATEWAYPROBE._serialized_end=10551
  _APPLICATIONGATEWAYPROBEHEALTHRESPONSEMATCH._serialized_start=10553
  _APPLICATIONGATEWAYPROBEHEALTHRESPONSEMATCH._serialized_end=10633
  _APPLICATIONGATEWAYFRONTENDPORT._serialized_start=10635
  _APPLICATIONGATEWAYFRONTENDPORT._serialized_end=10695
  _APPLICATIONGATEWAYFRONTENDIPCONFIGURATION._serialized_start=10698
  _APPLICATIONGATEWAYFRONTENDIPCONFIGURATION._serialized_end=11039
  _APPLICATIONGATEWAYSSLCERTIFICATE._serialized_start=11041
  _APPLICATIONGATEWAYSSLCERTIFICATE._serialized_end=11150
  _APPLICATIONGATEWAYTRUSTEDCLIENTCERTIFICATE._serialized_start=11152
  _APPLICATIONGATEWAYTRUSTEDCLIENTCERTIFICATE._serialized_end=11224
  _APPLICATIONGATEWAYTRUSTEDROOTCERTIFICATE._serialized_start=11226
  _APPLICATIONGATEWAYTRUSTEDROOTCERTIFICATE._serialized_end=11325
  _APPLICATIONGATEWAYAUTHENTICATIONCERTIFICATE._serialized_start=11327
  _APPLICATIONGATEWAYAUTHENTICATIONCERTIFICATE._serialized_end=11400
  _APPLICATIONGATEWAYIPCONFIGURATION._serialized_start=11403
  _APPLICATIONGATEWAYIPCONFIGURATION._serialized_end=11533
  _APPLICATIONGATEWAYSSLPOLICY._serialized_start=11536
  _APPLICATIONGATEWAYSSLPOLICY._serialized_end=11692
  _APPLICATIONGATEWAYSKU._serialized_start=11694
  _APPLICATIONGATEWAYSKU._serialized_end=11763
# @@protoc_insertion_point(module_scope)
