# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_opsworks.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16\x61ws/aws_opsworks.proto\x12\x18oak9.tython.aws.opsworks\x1a\x13shared/shared.proto\"\x98\x01\n\tAppSource\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08password\x18\x02 \x01(\t\x12\x10\n\x08revision\x18\x03 \x01(\t\x12\x0f\n\x07ssh_key\x18\x04 \x01(\t\x12\x0b\n\x03url\x18\x05 \x01(\t\x12\x10\n\x08username\x18\x06 \x01(\t\"l\n\rAppDataSource\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0b\n\x03\x61rn\x18\x02 \x01(\t\x12\x15\n\rdatabase_name\x18\x03 \x01(\t\"}\n\x16\x41ppEnvironmentVariable\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\x0e\n\x06secure\x18\x03 \x01(\x08\x12\r\n\x05value\x18\x04 \x01(\t\"\x87\x01\n\x13\x41ppSslConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x63\x65rtificate\x18\x02 \x01(\t\x12\r\n\x05\x63hain\x18\x03 \x01(\t\x12\x13\n\x0bprivate_key\x18\x04 \x01(\t\"\xb8\x04\n\x03\x41pp\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x37\n\napp_source\x18\x02 \x01(\x0b\x32#.oak9.tython.aws.opsworks.AppSource\x12\x41\n\nattributes\x18\x03 \x03(\x0b\x32-.oak9.tython.aws.opsworks.App.AttributesEntry\x12=\n\x0c\x64\x61ta_sources\x18\x04 \x03(\x0b\x32\'.oak9.tython.aws.opsworks.AppDataSource\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12\x0f\n\x07\x64omains\x18\x06 \x03(\t\x12\x12\n\nenable_ssl\x18\x07 \x01(\x08\x12\x45\n\x0b\x65nvironment\x18\x08 \x03(\x0b\x32\x30.oak9.tython.aws.opsworks.AppEnvironmentVariable\x12\x0c\n\x04name\x18\t \x01(\t\x12\x11\n\tshortname\x18\n \x01(\t\x12H\n\x11ssl_configuration\x18\x0b \x01(\x0b\x32-.oak9.tython.aws.opsworks.AppSslConfiguration\x12\x10\n\x08stack_id\x18\x0c \x01(\t\x12\x0c\n\x04type\x18\r \x01(\t\x1a\x31\n\x0f\x41ttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x9e\x03\n\x08OpsWorks\x12*\n\x03\x61pp\x18\x01 \x03(\x0b\x32\x1d.oak9.tython.aws.opsworks.App\x12\x61\n elastic_load_balancer_attachment\x18\x02 \x03(\x0b\x32\x37.oak9.tython.aws.opsworks.ElasticLoadBalancerAttachment\x12\x34\n\x08instance\x18\x03 \x03(\x0b\x32\".oak9.tython.aws.opsworks.Instance\x12.\n\x05layer\x18\x04 \x03(\x0b\x32\x1f.oak9.tython.aws.opsworks.Layer\x12.\n\x05stack\x18\x05 \x03(\x0b\x32\x1f.oak9.tython.aws.opsworks.Stack\x12;\n\x0cuser_profile\x18\x06 \x03(\x0b\x32%.oak9.tython.aws.opsworks.UserProfile\x12\x30\n\x06volume\x18\x07 \x03(\x0b\x32 .oak9.tython.aws.opsworks.Volume\"\x8e\x01\n\x1d\x45lasticLoadBalancerAttachment\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\"\n\x1a\x65lastic_load_balancer_name\x18\x02 \x01(\t\x12\x10\n\x08layer_id\x18\x03 \x01(\t\"\xbd\x01\n\x16InstanceEbsBlockDevice\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1d\n\x15\x64\x65lete_on_termination\x18\x02 \x01(\x08\x12\x0c\n\x04iops\x18\x03 \x01(\x05\x12\x13\n\x0bsnapshot_id\x18\x04 \x01(\t\x12\x13\n\x0bvolume_size\x18\x05 \x01(\x05\x12\x13\n\x0bvolume_type\x18\x06 \x01(\t\"\xd2\x01\n\x1aInstanceBlockDeviceMapping\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65vice_name\x18\x02 \x01(\t\x12=\n\x03\x65\x62s\x18\x03 \x01(\x0b\x32\x30.oak9.tython.aws.opsworks.InstanceEbsBlockDevice\x12\x11\n\tno_device\x18\x04 \x01(\t\x12\x14\n\x0cvirtual_name\x18\x05 \x01(\t\"\x84\x08\n\x1cInstanceTimeBasedAutoScaling\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12R\n\x06\x66riday\x18\x02 \x03(\x0b\x32\x42.oak9.tython.aws.opsworks.InstanceTimeBasedAutoScaling.FridayEntry\x12R\n\x06monday\x18\x03 \x03(\x0b\x32\x42.oak9.tython.aws.opsworks.InstanceTimeBasedAutoScaling.MondayEntry\x12V\n\x08saturday\x18\x04 \x03(\x0b\x32\x44.oak9.tython.aws.opsworks.InstanceTimeBasedAutoScaling.SaturdayEntry\x12R\n\x06sunday\x18\x05 \x03(\x0b\x32\x42.oak9.tython.aws.opsworks.InstanceTimeBasedAutoScaling.SundayEntry\x12V\n\x08thursday\x18\x06 \x03(\x0b\x32\x44.oak9.tython.aws.opsworks.InstanceTimeBasedAutoScaling.ThursdayEntry\x12T\n\x07tuesday\x18\x07 \x03(\x0b\x32\x43.oak9.tython.aws.opsworks.InstanceTimeBasedAutoScaling.TuesdayEntry\x12X\n\twednesday\x18\x08 \x03(\x0b\x32\x45.oak9.tython.aws.opsworks.InstanceTimeBasedAutoScaling.WednesdayEntry\x1a-\n\x0b\x46ridayEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a-\n\x0bMondayEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a/\n\rSaturdayEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a-\n\x0bSundayEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a/\n\rThursdayEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a.\n\x0cTuesdayEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x30\n\x0eWednesdayEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x8d\x05\n\x08Instance\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\ragent_version\x18\x02 \x01(\t\x12\x0e\n\x06\x61mi_id\x18\x03 \x01(\t\x12\x14\n\x0c\x61rchitecture\x18\x04 \x01(\t\x12\x19\n\x11\x61uto_scaling_type\x18\x05 \x01(\t\x12\x19\n\x11\x61vailability_zone\x18\x06 \x01(\t\x12S\n\x15\x62lock_device_mappings\x18\x07 \x03(\x0b\x32\x34.oak9.tython.aws.opsworks.InstanceBlockDeviceMapping\x12\x15\n\rebs_optimized\x18\x08 \x01(\x08\x12\x13\n\x0b\x65lastic_ips\x18\t \x03(\t\x12\x10\n\x08hostname\x18\n \x01(\t\x12\x1f\n\x17install_updates_on_boot\x18\x0b \x01(\x08\x12\x15\n\rinstance_type\x18\x0c \x01(\t\x12\x11\n\tlayer_ids\x18\r \x03(\t\x12\n\n\x02os\x18\x0e \x01(\t\x12\x18\n\x10root_device_type\x18\x0f \x01(\t\x12\x14\n\x0cssh_key_name\x18\x10 \x01(\t\x12\x10\n\x08stack_id\x18\x11 \x01(\t\x12\x11\n\tsubnet_id\x18\x12 \x01(\t\x12\x0f\n\x07tenancy\x18\x13 \x01(\t\x12W\n\x17time_based_auto_scaling\x18\x14 \x01(\x0b\x32\x36.oak9.tython.aws.opsworks.InstanceTimeBasedAutoScaling\x12\x1b\n\x13virtualization_type\x18\x15 \x01(\t\x12\x0f\n\x07volumes\x18\x16 \x03(\t\"\x9d\x01\n\x0cLayerRecipes\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\tconfigure\x18\x02 \x03(\t\x12\x0e\n\x06\x64\x65ploy\x18\x03 \x03(\t\x12\r\n\x05setup\x18\x04 \x03(\t\x12\x10\n\x08shutdown\x18\x05 \x03(\t\x12\x10\n\x08undeploy\x18\x06 \x03(\t\"\xa2\x01\n\x1fLayerShutdownEventConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12+\n#delay_until_elb_connections_drained\x18\x02 \x01(\x08\x12\x19\n\x11\x65xecution_timeout\x18\x03 \x01(\x05\"\xbc\x01\n LayerLifecycleEventConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12_\n\x1cshutdown_event_configuration\x18\x02 \x01(\x0b\x32\x39.oak9.tython.aws.opsworks.LayerShutdownEventConfiguration\"\xf1\x01\n\x1aLayerAutoScalingThresholds\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rcpu_threshold\x18\x02 \x01(\x01\x12\x1b\n\x13ignore_metrics_time\x18\x03 \x01(\x05\x12\x16\n\x0einstance_count\x18\x04 \x01(\x05\x12\x16\n\x0eload_threshold\x18\x05 \x01(\x01\x12\x18\n\x10memory_threshold\x18\x06 \x01(\x01\x12\x1c\n\x14thresholds_wait_time\x18\x07 \x01(\x05\"\xfa\x01\n\x19LayerLoadBasedAutoScaling\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12J\n\x0c\x64own_scaling\x18\x02 \x01(\x0b\x32\x34.oak9.tython.aws.opsworks.LayerAutoScalingThresholds\x12\x0e\n\x06\x65nable\x18\x03 \x01(\x08\x12H\n\nup_scaling\x18\x04 \x01(\x0b\x32\x34.oak9.tython.aws.opsworks.LayerAutoScalingThresholds\"\xd9\x01\n\x18LayerVolumeConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\tencrypted\x18\x02 \x01(\x08\x12\x0c\n\x04iops\x18\x03 \x01(\x05\x12\x13\n\x0bmount_point\x18\x04 \x01(\t\x12\x17\n\x0fnumber_of_disks\x18\x05 \x01(\x05\x12\x12\n\nraid_level\x18\x06 \x01(\x05\x12\x0c\n\x04size\x18\x07 \x01(\x05\x12\x13\n\x0bvolume_type\x18\x08 \x01(\t\"\xa2\x08\n\x05Layer\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x43\n\nattributes\x18\x02 \x03(\x0b\x32/.oak9.tython.aws.opsworks.Layer.AttributesEntry\x12\x1f\n\x17\x61uto_assign_elastic_ips\x18\x03 \x01(\x08\x12\x1e\n\x16\x61uto_assign_public_ips\x18\x04 \x01(\x08\x12#\n\x1b\x63ustom_instance_profile_arn\x18\x05 \x01(\t\x12\x44\n\x0b\x63ustom_json\x18\x06 \x03(\x0b\x32/.oak9.tython.aws.opsworks.Layer.CustomJsonEntry\x12>\n\x0e\x63ustom_recipes\x18\x07 \x01(\x0b\x32&.oak9.tython.aws.opsworks.LayerRecipes\x12!\n\x19\x63ustom_security_group_ids\x18\x08 \x03(\t\x12\x1b\n\x13\x65nable_auto_healing\x18\t \x01(\x08\x12\x1f\n\x17install_updates_on_boot\x18\n \x01(\x08\x12\x61\n\x1dlifecycle_event_configuration\x18\x0b \x01(\x0b\x32:.oak9.tython.aws.opsworks.LayerLifecycleEventConfiguration\x12T\n\x17load_based_auto_scaling\x18\x0c \x01(\x0b\x32\x33.oak9.tython.aws.opsworks.LayerLoadBasedAutoScaling\x12\x0c\n\x04name\x18\r \x01(\t\x12\x10\n\x08packages\x18\x0e \x03(\t\x12\x11\n\tshortname\x18\x0f \x01(\t\x12\x10\n\x08stack_id\x18\x10 \x01(\t\x12\x37\n\x04tags\x18\x11 \x03(\x0b\x32).oak9.tython.aws.opsworks.Layer.TagsEntry\x12\x0c\n\x04type\x18\x12 \x01(\t\x12#\n\x1buse_ebs_optimized_instances\x18\x13 \x01(\x08\x12Q\n\x15volume_configurations\x18\x14 \x03(\x0b\x32\x32.oak9.tython.aws.opsworks.LayerVolumeConfiguration\x1a\x31\n\x0f\x41ttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x31\n\x0f\x43ustomJsonEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x86\x01\n\x16StackChefConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x19\n\x11\x62\x65rkshelf_version\x18\x02 \x01(\t\x12\x18\n\x10manage_berkshelf\x18\x03 \x01(\x08\"x\n\x1eStackStackConfigurationManager\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\t\"\x9a\x01\n\x0bStackSource\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08password\x18\x02 \x01(\t\x12\x10\n\x08revision\x18\x03 \x01(\t\x12\x0f\n\x07ssh_key\x18\x04 \x01(\t\x12\x0b\n\x03url\x18\x05 \x01(\t\x12\x10\n\x08username\x18\x06 \x01(\t\"c\n\x0eStackElasticIp\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\n\n\x02ip\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\"\x90\x01\n\x12StackRdsDbInstance\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x62_password\x18\x02 \x01(\t\x12\x0f\n\x07\x64\x62_user\x18\x03 \x01(\t\x12\x1b\n\x13rds_db_instance_arn\x18\x04 \x01(\t\"\xd4\t\n\x05Stack\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\ragent_version\x18\x02 \x01(\t\x12\x43\n\nattributes\x18\x03 \x03(\x0b\x32/.oak9.tython.aws.opsworks.Stack.AttributesEntry\x12L\n\x12\x63hef_configuration\x18\x04 \x01(\x0b\x32\x30.oak9.tython.aws.opsworks.StackChefConfiguration\x12\x15\n\rclone_app_ids\x18\x05 \x03(\t\x12\x19\n\x11\x63lone_permissions\x18\x06 \x01(\x08\x12W\n\x15\x63onfiguration_manager\x18\x07 \x01(\x0b\x32\x38.oak9.tython.aws.opsworks.StackStackConfigurationManager\x12\x46\n\x17\x63ustom_cookbooks_source\x18\x08 \x01(\x0b\x32%.oak9.tython.aws.opsworks.StackSource\x12\x44\n\x0b\x63ustom_json\x18\t \x03(\x0b\x32/.oak9.tython.aws.opsworks.Stack.CustomJsonEntry\x12!\n\x19\x64\x65\x66\x61ult_availability_zone\x18\n \x01(\t\x12$\n\x1c\x64\x65\x66\x61ult_instance_profile_arn\x18\x0b \x01(\t\x12\x12\n\ndefault_os\x18\x0c \x01(\t\x12 \n\x18\x64\x65\x66\x61ult_root_device_type\x18\r \x01(\t\x12\x1c\n\x14\x64\x65\x66\x61ult_ssh_key_name\x18\x0e \x01(\t\x12\x19\n\x11\x64\x65\x66\x61ult_subnet_id\x18\x0f \x01(\t\x12\x17\n\x0f\x65\x63s_cluster_arn\x18\x10 \x01(\t\x12=\n\x0b\x65lastic_ips\x18\x11 \x03(\x0b\x32(.oak9.tython.aws.opsworks.StackElasticIp\x12\x16\n\x0ehostname_theme\x18\x12 \x01(\t\x12\x0c\n\x04name\x18\x13 \x01(\t\x12\x46\n\x10rds_db_instances\x18\x14 \x03(\x0b\x32,.oak9.tython.aws.opsworks.StackRdsDbInstance\x12\x18\n\x10service_role_arn\x18\x15 \x01(\t\x12\x17\n\x0fsource_stack_id\x18\x16 \x01(\t\x12\x37\n\x04tags\x18\x17 \x03(\x0b\x32).oak9.tython.aws.opsworks.Stack.TagsEntry\x12\x1c\n\x14use_custom_cookbooks\x18\x18 \x01(\x08\x12$\n\x1cuse_opsworks_security_groups\x18\x19 \x01(\x08\x12\x0e\n\x06vpc_id\x18\x1a \x01(\t\x1a\x31\n\x0f\x41ttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x31\n\x0f\x43ustomJsonEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa9\x01\n\x0bUserProfile\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1d\n\x15\x61llow_self_management\x18\x02 \x01(\x08\x12\x14\n\x0ciam_user_arn\x18\x03 \x01(\t\x12\x16\n\x0essh_public_key\x18\x04 \x01(\t\x12\x14\n\x0cssh_username\x18\x05 \x01(\t\"\x8d\x01\n\x06Volume\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rec2_volume_id\x18\x02 \x01(\t\x12\x13\n\x0bmount_point\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x10\n\x08stack_id\x18\x05 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_opsworks_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _APP_ATTRIBUTESENTRY._options = None
  _APP_ATTRIBUTESENTRY._serialized_options = b'8\001'
  _INSTANCETIMEBASEDAUTOSCALING_FRIDAYENTRY._options = None
  _INSTANCETIMEBASEDAUTOSCALING_FRIDAYENTRY._serialized_options = b'8\001'
  _INSTANCETIMEBASEDAUTOSCALING_MONDAYENTRY._options = None
  _INSTANCETIMEBASEDAUTOSCALING_MONDAYENTRY._serialized_options = b'8\001'
  _INSTANCETIMEBASEDAUTOSCALING_SATURDAYENTRY._options = None
  _INSTANCETIMEBASEDAUTOSCALING_SATURDAYENTRY._serialized_options = b'8\001'
  _INSTANCETIMEBASEDAUTOSCALING_SUNDAYENTRY._options = None
  _INSTANCETIMEBASEDAUTOSCALING_SUNDAYENTRY._serialized_options = b'8\001'
  _INSTANCETIMEBASEDAUTOSCALING_THURSDAYENTRY._options = None
  _INSTANCETIMEBASEDAUTOSCALING_THURSDAYENTRY._serialized_options = b'8\001'
  _INSTANCETIMEBASEDAUTOSCALING_TUESDAYENTRY._options = None
  _INSTANCETIMEBASEDAUTOSCALING_TUESDAYENTRY._serialized_options = b'8\001'
  _INSTANCETIMEBASEDAUTOSCALING_WEDNESDAYENTRY._options = None
  _INSTANCETIMEBASEDAUTOSCALING_WEDNESDAYENTRY._serialized_options = b'8\001'
  _LAYER_ATTRIBUTESENTRY._options = None
  _LAYER_ATTRIBUTESENTRY._serialized_options = b'8\001'
  _LAYER_CUSTOMJSONENTRY._options = None
  _LAYER_CUSTOMJSONENTRY._serialized_options = b'8\001'
  _LAYER_TAGSENTRY._options = None
  _LAYER_TAGSENTRY._serialized_options = b'8\001'
  _STACK_ATTRIBUTESENTRY._options = None
  _STACK_ATTRIBUTESENTRY._serialized_options = b'8\001'
  _STACK_CUSTOMJSONENTRY._options = None
  _STACK_CUSTOMJSONENTRY._serialized_options = b'8\001'
  _STACK_TAGSENTRY._options = None
  _STACK_TAGSENTRY._serialized_options = b'8\001'
  _APPSOURCE._serialized_start=74
  _APPSOURCE._serialized_end=226
  _APPDATASOURCE._serialized_start=228
  _APPDATASOURCE._serialized_end=336
  _APPENVIRONMENTVARIABLE._serialized_start=338
  _APPENVIRONMENTVARIABLE._serialized_end=463
  _APPSSLCONFIGURATION._serialized_start=466
  _APPSSLCONFIGURATION._serialized_end=601
  _APP._serialized_start=604
  _APP._serialized_end=1172
  _APP_ATTRIBUTESENTRY._serialized_start=1123
  _APP_ATTRIBUTESENTRY._serialized_end=1172
  _OPSWORKS._serialized_start=1175
  _OPSWORKS._serialized_end=1589
  _ELASTICLOADBALANCERATTACHMENT._serialized_start=1592
  _ELASTICLOADBALANCERATTACHMENT._serialized_end=1734
  _INSTANCEEBSBLOCKDEVICE._serialized_start=1737
  _INSTANCEEBSBLOCKDEVICE._serialized_end=1926
  _INSTANCEBLOCKDEVICEMAPPING._serialized_start=1929
  _INSTANCEBLOCKDEVICEMAPPING._serialized_end=2139
  _INSTANCETIMEBASEDAUTOSCALING._serialized_start=2142
  _INSTANCETIMEBASEDAUTOSCALING._serialized_end=3170
  _INSTANCETIMEBASEDAUTOSCALING_FRIDAYENTRY._serialized_start=2835
  _INSTANCETIMEBASEDAUTOSCALING_FRIDAYENTRY._serialized_end=2880
  _INSTANCETIMEBASEDAUTOSCALING_MONDAYENTRY._serialized_start=2882
  _INSTANCETIMEBASEDAUTOSCALING_MONDAYENTRY._serialized_end=2927
  _INSTANCETIMEBASEDAUTOSCALING_SATURDAYENTRY._serialized_start=2929
  _INSTANCETIMEBASEDAUTOSCALING_SATURDAYENTRY._serialized_end=2976
  _INSTANCETIMEBASEDAUTOSCALING_SUNDAYENTRY._serialized_start=2978
  _INSTANCETIMEBASEDAUTOSCALING_SUNDAYENTRY._serialized_end=3023
  _INSTANCETIMEBASEDAUTOSCALING_THURSDAYENTRY._serialized_start=3025
  _INSTANCETIMEBASEDAUTOSCALING_THURSDAYENTRY._serialized_end=3072
  _INSTANCETIMEBASEDAUTOSCALING_TUESDAYENTRY._serialized_start=3074
  _INSTANCETIMEBASEDAUTOSCALING_TUESDAYENTRY._serialized_end=3120
  _INSTANCETIMEBASEDAUTOSCALING_WEDNESDAYENTRY._serialized_start=3122
  _INSTANCETIMEBASEDAUTOSCALING_WEDNESDAYENTRY._serialized_end=3170
  _INSTANCE._serialized_start=3173
  _INSTANCE._serialized_end=3826
  _LAYERRECIPES._serialized_start=3829
  _LAYERRECIPES._serialized_end=3986
  _LAYERSHUTDOWNEVENTCONFIGURATION._serialized_start=3989
  _LAYERSHUTDOWNEVENTCONFIGURATION._serialized_end=4151
  _LAYERLIFECYCLEEVENTCONFIGURATION._serialized_start=4154
  _LAYERLIFECYCLEEVENTCONFIGURATION._serialized_end=4342
  _LAYERAUTOSCALINGTHRESHOLDS._serialized_start=4345
  _LAYERAUTOSCALINGTHRESHOLDS._serialized_end=4586
  _LAYERLOADBASEDAUTOSCALING._serialized_start=4589
  _LAYERLOADBASEDAUTOSCALING._serialized_end=4839
  _LAYERVOLUMECONFIGURATION._serialized_start=4842
  _LAYERVOLUMECONFIGURATION._serialized_end=5059
  _LAYER._serialized_start=5062
  _LAYER._serialized_end=6120
  _LAYER_ATTRIBUTESENTRY._serialized_start=1123
  _LAYER_ATTRIBUTESENTRY._serialized_end=1172
  _LAYER_CUSTOMJSONENTRY._serialized_start=6026
  _LAYER_CUSTOMJSONENTRY._serialized_end=6075
  _LAYER_TAGSENTRY._serialized_start=6077
  _LAYER_TAGSENTRY._serialized_end=6120
  _STACKCHEFCONFIGURATION._serialized_start=6123
  _STACKCHEFCONFIGURATION._serialized_end=6257
  _STACKSTACKCONFIGURATIONMANAGER._serialized_start=6259
  _STACKSTACKCONFIGURATIONMANAGER._serialized_end=6379
  _STACKSOURCE._serialized_start=6382
  _STACKSOURCE._serialized_end=6536
  _STACKELASTICIP._serialized_start=6538
  _STACKELASTICIP._serialized_end=6637
  _STACKRDSDBINSTANCE._serialized_start=6640
  _STACKRDSDBINSTANCE._serialized_end=6784
  _STACK._serialized_start=6787
  _STACK._serialized_end=8023
  _STACK_ATTRIBUTESENTRY._serialized_start=1123
  _STACK_ATTRIBUTESENTRY._serialized_end=1172
  _STACK_CUSTOMJSONENTRY._serialized_start=6026
  _STACK_CUSTOMJSONENTRY._serialized_end=6075
  _STACK_TAGSENTRY._serialized_start=6077
  _STACK_TAGSENTRY._serialized_end=6120
  _USERPROFILE._serialized_start=8026
  _USERPROFILE._serialized_end=8195
  _VOLUME._serialized_start=8198
  _VOLUME._serialized_end=8339
# @@protoc_insertion_point(module_scope)
