"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Microsoft_EventGrid(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DOMAINS_FIELD_NUMBER: builtins.int
    DOMAINS_PRIVATE_ENDPOINT_CONNECTIONS_FIELD_NUMBER: builtins.int
    DOMAINS_TOPICS_FIELD_NUMBER: builtins.int
    TOPICS_FIELD_NUMBER: builtins.int
    TOPICS_PRIVATE_ENDPOINT_CONNECTIONS_FIELD_NUMBER: builtins.int
    @property
    def domains(self) -> global___Domains: ...
    @property
    def domains_private_endpoint_connections(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DomainsPrivateEndpointConnections]: ...
    @property
    def domains_topics(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DomainsTopics]: ...
    @property
    def topics(self) -> global___Topics: ...
    @property
    def topics_private_endpoint_connections(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TopicsPrivateEndpointConnections]: ...
    def __init__(
        self,
        *,
        domains: global___Domains | None = ...,
        domains_private_endpoint_connections: collections.abc.Iterable[global___DomainsPrivateEndpointConnections] | None = ...,
        domains_topics: collections.abc.Iterable[global___DomainsTopics] | None = ...,
        topics: global___Topics | None = ...,
        topics_private_endpoint_connections: collections.abc.Iterable[global___TopicsPrivateEndpointConnections] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["domains", b"domains", "topics", b"topics"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["domains", b"domains", "domains_private_endpoint_connections", b"domains_private_endpoint_connections", "domains_topics", b"domains_topics", "topics", b"topics", "topics_private_endpoint_connections", b"topics_private_endpoint_connections"]) -> None: ...

global___Microsoft_EventGrid = Microsoft_EventGrid

@typing_extensions.final
class TopicsPrivateEndpointConnections(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    GROUP_IDS_FIELD_NUMBER: builtins.int
    PRIVATE_ENDPOINT_FIELD_NUMBER: builtins.int
    PRIVATE_LINK_SERVICE_CONNECTION_STATE_FIELD_NUMBER: builtins.int
    PROVISIONING_STATE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def group_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def private_endpoint(self) -> global___PrivateEndpoint: ...
    @property
    def private_link_service_connection_state(self) -> global___ConnectionState: ...
    provisioning_state: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        group_ids: collections.abc.Iterable[builtins.str] | None = ...,
        private_endpoint: global___PrivateEndpoint | None = ...,
        private_link_service_connection_state: global___ConnectionState | None = ...,
        provisioning_state: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["private_endpoint", b"private_endpoint", "private_link_service_connection_state", b"private_link_service_connection_state", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["group_ids", b"group_ids", "name", b"name", "private_endpoint", b"private_endpoint", "private_link_service_connection_state", b"private_link_service_connection_state", "provisioning_state", b"provisioning_state", "resource_info", b"resource_info"]) -> None: ...

global___TopicsPrivateEndpointConnections = TopicsPrivateEndpointConnections

@typing_extensions.final
class Topics(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    IDENTITY_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DISABLE_LOCAL_AUTH_FIELD_NUMBER: builtins.int
    INBOUND_IP_RULES_FIELD_NUMBER: builtins.int
    INPUT_SCHEMA_FIELD_NUMBER: builtins.int
    INPUT_SCHEMA_MAPPING_FIELD_NUMBER: builtins.int
    PUBLIC_NETWORK_ACCESS_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def identity(self) -> global___IdentityInfo: ...
    location: builtins.str
    name: builtins.str
    disable_local_auth: builtins.bool
    @property
    def inbound_ip_rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___InboundIpRule]: ...
    input_schema: builtins.str
    @property
    def input_schema_mapping(self) -> global___InputSchemaMapping: ...
    public_network_access: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        identity: global___IdentityInfo | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        disable_local_auth: builtins.bool = ...,
        inbound_ip_rules: collections.abc.Iterable[global___InboundIpRule] | None = ...,
        input_schema: builtins.str = ...,
        input_schema_mapping: global___InputSchemaMapping | None = ...,
        public_network_access: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["identity", b"identity", "input_schema_mapping", b"input_schema_mapping", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["disable_local_auth", b"disable_local_auth", "identity", b"identity", "inbound_ip_rules", b"inbound_ip_rules", "input_schema", b"input_schema", "input_schema_mapping", b"input_schema_mapping", "location", b"location", "name", b"name", "public_network_access", b"public_network_access", "resource_info", b"resource_info", "tags", b"tags"]) -> None: ...

global___Topics = Topics

@typing_extensions.final
class SystemTopicsEventSubscriptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DEAD_LETTER_DESTINATION_FIELD_NUMBER: builtins.int
    DEAD_LETTER_WITH_RESOURCE_IDENTITY_FIELD_NUMBER: builtins.int
    DELIVERY_WITH_RESOURCE_IDENTITY_FIELD_NUMBER: builtins.int
    DESTINATION_FIELD_NUMBER: builtins.int
    EVENT_DELIVERY_SCHEMA_FIELD_NUMBER: builtins.int
    EXPIRATION_TIME_UTC_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    RETRY_POLICY_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def dead_letter_destination(self) -> global___DeadLetterDestination: ...
    @property
    def dead_letter_with_resource_identity(self) -> global___DeadLetterWithResourceIdentity: ...
    @property
    def delivery_with_resource_identity(self) -> global___DeliveryWithResourceIdentity: ...
    @property
    def destination(self) -> global___EventSubscriptionDestination: ...
    event_delivery_schema: builtins.str
    expiration_time_utc: builtins.str
    @property
    def filter(self) -> global___EventSubscriptionFilter: ...
    @property
    def labels(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def retry_policy(self) -> global___RetryPolicy: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        dead_letter_destination: global___DeadLetterDestination | None = ...,
        dead_letter_with_resource_identity: global___DeadLetterWithResourceIdentity | None = ...,
        delivery_with_resource_identity: global___DeliveryWithResourceIdentity | None = ...,
        destination: global___EventSubscriptionDestination | None = ...,
        event_delivery_schema: builtins.str = ...,
        expiration_time_utc: builtins.str = ...,
        filter: global___EventSubscriptionFilter | None = ...,
        labels: collections.abc.Iterable[builtins.str] | None = ...,
        retry_policy: global___RetryPolicy | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["dead_letter_destination", b"dead_letter_destination", "dead_letter_with_resource_identity", b"dead_letter_with_resource_identity", "delivery_with_resource_identity", b"delivery_with_resource_identity", "destination", b"destination", "filter", b"filter", "resource_info", b"resource_info", "retry_policy", b"retry_policy"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["dead_letter_destination", b"dead_letter_destination", "dead_letter_with_resource_identity", b"dead_letter_with_resource_identity", "delivery_with_resource_identity", b"delivery_with_resource_identity", "destination", b"destination", "event_delivery_schema", b"event_delivery_schema", "expiration_time_utc", b"expiration_time_utc", "filter", b"filter", "labels", b"labels", "name", b"name", "resource_info", b"resource_info", "retry_policy", b"retry_policy"]) -> None: ...

global___SystemTopicsEventSubscriptions = SystemTopicsEventSubscriptions

@typing_extensions.final
class RetryPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EVENT_TIME_TO_LIVE_IN_MINUTES_FIELD_NUMBER: builtins.int
    MAX_DELIVERY_ATTEMPTS_FIELD_NUMBER: builtins.int
    event_time_to_live_in_minutes: builtins.int
    max_delivery_attempts: builtins.int
    def __init__(
        self,
        *,
        event_time_to_live_in_minutes: builtins.int = ...,
        max_delivery_attempts: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["event_time_to_live_in_minutes", b"event_time_to_live_in_minutes", "max_delivery_attempts", b"max_delivery_attempts"]) -> None: ...

global___RetryPolicy = RetryPolicy

@typing_extensions.final
class EventSubscriptionFilter(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADVANCED_FILTERS_FIELD_NUMBER: builtins.int
    ENABLE_ADVANCED_FILTERING_ON_ARRAYS_FIELD_NUMBER: builtins.int
    INCLUDED_EVENT_TYPES_FIELD_NUMBER: builtins.int
    IS_SUBJECT_CASE_SENSITIVE_FIELD_NUMBER: builtins.int
    SUBJECT_BEGINS_WITH_FIELD_NUMBER: builtins.int
    SUBJECT_ENDS_WITH_FIELD_NUMBER: builtins.int
    @property
    def advanced_filters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AdvancedFilter]: ...
    enable_advanced_filtering_on_arrays: builtins.bool
    @property
    def included_event_types(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    is_subject_case_sensitive: builtins.bool
    subject_begins_with: builtins.str
    subject_ends_with: builtins.str
    def __init__(
        self,
        *,
        advanced_filters: collections.abc.Iterable[global___AdvancedFilter] | None = ...,
        enable_advanced_filtering_on_arrays: builtins.bool = ...,
        included_event_types: collections.abc.Iterable[builtins.str] | None = ...,
        is_subject_case_sensitive: builtins.bool = ...,
        subject_begins_with: builtins.str = ...,
        subject_ends_with: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["advanced_filters", b"advanced_filters", "enable_advanced_filtering_on_arrays", b"enable_advanced_filtering_on_arrays", "included_event_types", b"included_event_types", "is_subject_case_sensitive", b"is_subject_case_sensitive", "subject_begins_with", b"subject_begins_with", "subject_ends_with", b"subject_ends_with"]) -> None: ...

global___EventSubscriptionFilter = EventSubscriptionFilter

@typing_extensions.final
class AdvancedFilter(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_FIELD_NUMBER: builtins.int
    key: builtins.str
    def __init__(
        self,
        *,
        key: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key"]) -> None: ...

global___AdvancedFilter = AdvancedFilter

@typing_extensions.final
class DeliveryWithResourceIdentity(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESTINATION_FIELD_NUMBER: builtins.int
    IDENTITY_FIELD_NUMBER: builtins.int
    @property
    def destination(self) -> global___EventSubscriptionDestination: ...
    @property
    def identity(self) -> global___EventSubscriptionIdentity: ...
    def __init__(
        self,
        *,
        destination: global___EventSubscriptionDestination | None = ...,
        identity: global___EventSubscriptionIdentity | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["destination", b"destination", "identity", b"identity"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["destination", b"destination", "identity", b"identity"]) -> None: ...

global___DeliveryWithResourceIdentity = DeliveryWithResourceIdentity

@typing_extensions.final
class EventSubscriptionDestination(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___EventSubscriptionDestination = EventSubscriptionDestination

@typing_extensions.final
class DeadLetterWithResourceIdentity(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEAD_LETTER_DESTINATION_FIELD_NUMBER: builtins.int
    IDENTITY_FIELD_NUMBER: builtins.int
    @property
    def dead_letter_destination(self) -> global___DeadLetterDestination: ...
    @property
    def identity(self) -> global___EventSubscriptionIdentity: ...
    def __init__(
        self,
        *,
        dead_letter_destination: global___DeadLetterDestination | None = ...,
        identity: global___EventSubscriptionIdentity | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["dead_letter_destination", b"dead_letter_destination", "identity", b"identity"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["dead_letter_destination", b"dead_letter_destination", "identity", b"identity"]) -> None: ...

global___DeadLetterWithResourceIdentity = DeadLetterWithResourceIdentity

@typing_extensions.final
class EventSubscriptionIdentity(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    USER_ASSIGNED_IDENTITY_FIELD_NUMBER: builtins.int
    type: builtins.str
    user_assigned_identity: builtins.str
    def __init__(
        self,
        *,
        type: builtins.str = ...,
        user_assigned_identity: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["type", b"type", "user_assigned_identity", b"user_assigned_identity"]) -> None: ...

global___EventSubscriptionIdentity = EventSubscriptionIdentity

@typing_extensions.final
class DeadLetterDestination(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___DeadLetterDestination = DeadLetterDestination

@typing_extensions.final
class SystemTopics(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    IDENTITY_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    TOPIC_TYPE_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    SYSTEM_TOPICS_EVENT_SUBSCRIPTIONS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def identity(self) -> global___IdentityInfo: ...
    location: builtins.str
    name: builtins.str
    source: builtins.str
    topic_type: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def system_topics_event_subscriptions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SystemTopicsEventSubscriptions]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        identity: global___IdentityInfo | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        source: builtins.str = ...,
        topic_type: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        system_topics_event_subscriptions: collections.abc.Iterable[global___SystemTopicsEventSubscriptions] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["identity", b"identity", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["identity", b"identity", "location", b"location", "name", b"name", "resource_info", b"resource_info", "source", b"source", "system_topics_event_subscriptions", b"system_topics_event_subscriptions", "tags", b"tags", "topic_type", b"topic_type"]) -> None: ...

global___SystemTopics = SystemTopics

@typing_extensions.final
class DomainsTopics(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___DomainsTopics = DomainsTopics

@typing_extensions.final
class DomainsPrivateEndpointConnections(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    GROUP_IDS_FIELD_NUMBER: builtins.int
    PRIVATE_ENDPOINT_FIELD_NUMBER: builtins.int
    PRIVATE_LINK_SERVICE_CONNECTION_STATE_FIELD_NUMBER: builtins.int
    PROVISIONING_STATE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def group_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def private_endpoint(self) -> global___PrivateEndpoint: ...
    @property
    def private_link_service_connection_state(self) -> global___ConnectionState: ...
    provisioning_state: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        group_ids: collections.abc.Iterable[builtins.str] | None = ...,
        private_endpoint: global___PrivateEndpoint | None = ...,
        private_link_service_connection_state: global___ConnectionState | None = ...,
        provisioning_state: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["private_endpoint", b"private_endpoint", "private_link_service_connection_state", b"private_link_service_connection_state", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["group_ids", b"group_ids", "name", b"name", "private_endpoint", b"private_endpoint", "private_link_service_connection_state", b"private_link_service_connection_state", "provisioning_state", b"provisioning_state", "resource_info", b"resource_info"]) -> None: ...

global___DomainsPrivateEndpointConnections = DomainsPrivateEndpointConnections

@typing_extensions.final
class ConnectionState(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACTIONS_REQUIRED_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    actions_required: builtins.str
    description: builtins.str
    status: builtins.str
    def __init__(
        self,
        *,
        actions_required: builtins.str = ...,
        description: builtins.str = ...,
        status: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["actions_required", b"actions_required", "description", b"description", "status", b"status"]) -> None: ...

global___ConnectionState = ConnectionState

@typing_extensions.final
class PrivateEndpoint(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    def __init__(
        self,
        *,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id"]) -> None: ...

global___PrivateEndpoint = PrivateEndpoint

@typing_extensions.final
class Domains(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    IDENTITY_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    AUTO_CREATE_TOPIC_WITH_FIRST_SUBSCRIPTION_FIELD_NUMBER: builtins.int
    AUTO_DELETE_TOPIC_WITH_LAST_SUBSCRIPTION_FIELD_NUMBER: builtins.int
    DISABLE_LOCAL_AUTH_FIELD_NUMBER: builtins.int
    INBOUND_IP_RULES_FIELD_NUMBER: builtins.int
    INPUT_SCHEMA_FIELD_NUMBER: builtins.int
    INPUT_SCHEMA_MAPPING_FIELD_NUMBER: builtins.int
    PUBLIC_NETWORK_ACCESS_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def identity(self) -> global___IdentityInfo: ...
    location: builtins.str
    name: builtins.str
    auto_create_topic_with_first_subscription: builtins.bool
    auto_delete_topic_with_last_subscription: builtins.bool
    disable_local_auth: builtins.bool
    @property
    def inbound_ip_rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___InboundIpRule]: ...
    input_schema: builtins.str
    @property
    def input_schema_mapping(self) -> global___InputSchemaMapping: ...
    public_network_access: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        identity: global___IdentityInfo | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        auto_create_topic_with_first_subscription: builtins.bool = ...,
        auto_delete_topic_with_last_subscription: builtins.bool = ...,
        disable_local_auth: builtins.bool = ...,
        inbound_ip_rules: collections.abc.Iterable[global___InboundIpRule] | None = ...,
        input_schema: builtins.str = ...,
        input_schema_mapping: global___InputSchemaMapping | None = ...,
        public_network_access: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["identity", b"identity", "input_schema_mapping", b"input_schema_mapping", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auto_create_topic_with_first_subscription", b"auto_create_topic_with_first_subscription", "auto_delete_topic_with_last_subscription", b"auto_delete_topic_with_last_subscription", "disable_local_auth", b"disable_local_auth", "identity", b"identity", "inbound_ip_rules", b"inbound_ip_rules", "input_schema", b"input_schema", "input_schema_mapping", b"input_schema_mapping", "location", b"location", "name", b"name", "public_network_access", b"public_network_access", "resource_info", b"resource_info", "tags", b"tags"]) -> None: ...

global___Domains = Domains

@typing_extensions.final
class InputSchemaMapping(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___InputSchemaMapping = InputSchemaMapping

@typing_extensions.final
class InboundIpRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACTION_FIELD_NUMBER: builtins.int
    IP_MASK_FIELD_NUMBER: builtins.int
    action: builtins.str
    ip_mask: builtins.str
    def __init__(
        self,
        *,
        action: builtins.str = ...,
        ip_mask: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["action", b"action", "ip_mask", b"ip_mask"]) -> None: ...

global___InboundIpRule = InboundIpRule

@typing_extensions.final
class IdentityInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class UserAssignedIdentitiesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    PRINCIPAL_ID_FIELD_NUMBER: builtins.int
    TENANT_ID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    USER_ASSIGNED_IDENTITIES_FIELD_NUMBER: builtins.int
    principal_id: builtins.str
    tenant_id: builtins.str
    type: builtins.str
    @property
    def user_assigned_identities(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        principal_id: builtins.str = ...,
        tenant_id: builtins.str = ...,
        type: builtins.str = ...,
        user_assigned_identities: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["principal_id", b"principal_id", "tenant_id", b"tenant_id", "type", b"type", "user_assigned_identities", b"user_assigned_identities"]) -> None: ...

global___IdentityInfo = IdentityInfo
