# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_iotanalytics.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1a\x61ws/aws_iotanalytics.proto\x12\x1coak9.tython.aws.iotanalytics\x1a\x13shared/shared.proto\"\x89\x01\n\x18\x43hannelCustomerManagedS3\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06\x62ucket\x18\x02 \x01(\t\x12\x10\n\x08role_arn\x18\x03 \x01(\t\x12\x12\n\nkey_prefix\x18\x04 \x01(\t\"R\n\x17\x43hannelServiceManagedS3\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xf8\x01\n\x15\x43hannelChannelStorage\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12S\n\x13\x63ustomer_managed_s3\x18\x02 \x01(\x0b\x32\x36.oak9.tython.aws.iotanalytics.ChannelCustomerManagedS3\x12Q\n\x12service_managed_s3\x18\x03 \x01(\x0b\x32\x35.oak9.tython.aws.iotanalytics.ChannelServiceManagedS3\"|\n\x16\x43hannelRetentionPeriod\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0enumber_of_days\x18\x02 \x01(\x05\x12\x11\n\tunlimited\x18\x03 \x01(\x08\"\xe2\x02\n\x07\x43hannel\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12L\n\x0f\x63hannel_storage\x18\x03 \x01(\x0b\x32\x33.oak9.tython.aws.iotanalytics.ChannelChannelStorage\x12N\n\x10retention_period\x18\x04 \x01(\x0b\x32\x34.oak9.tython.aws.iotanalytics.ChannelRetentionPeriod\x12=\n\x04tags\x18\x05 \x03(\x0b\x32/.oak9.tython.aws.iotanalytics.Channel.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xf4\x01\n\x0cIoTAnalytics\x12\x36\n\x07\x63hannel\x18\x01 \x03(\x0b\x32%.oak9.tython.aws.iotanalytics.Channel\x12\x36\n\x07\x64\x61taset\x18\x02 \x03(\x0b\x32%.oak9.tython.aws.iotanalytics.Dataset\x12:\n\tdatastore\x18\x03 \x03(\x0b\x32\'.oak9.tython.aws.iotanalytics.Datastore\x12\x38\n\x08pipeline\x18\x04 \x03(\x0b\x32&.oak9.tython.aws.iotanalytics.Pipeline\"r\n!DatasetDatasetContentVersionValue\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0c\x64\x61taset_name\x18\x02 \x01(\t\"g\n\x19\x44\x61tasetOutputFileUriValue\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\tfile_name\x18\x02 \x01(\t\"\xcd\x02\n\x0f\x44\x61tasetVariable\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x66\n\x1d\x64\x61taset_content_version_value\x18\x02 \x01(\x0b\x32?.oak9.tython.aws.iotanalytics.DatasetDatasetContentVersionValue\x12\x14\n\x0c\x64ouble_value\x18\x03 \x01(\x01\x12V\n\x15output_file_uri_value\x18\x04 \x01(\x0b\x32\x37.oak9.tython.aws.iotanalytics.DatasetOutputFileUriValue\x12\x15\n\rvariable_name\x18\x05 \x01(\t\x12\x14\n\x0cstring_value\x18\x06 \x01(\t\"\x88\x01\n\x1c\x44\x61tasetResourceConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x19\n\x11volume_size_in_gb\x18\x02 \x01(\x05\x12\x14\n\x0c\x63ompute_type\x18\x03 \x01(\t\"\x9a\x02\n\x16\x44\x61tasetContainerAction\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12@\n\tvariables\x18\x02 \x03(\x0b\x32-.oak9.tython.aws.iotanalytics.DatasetVariable\x12\x1a\n\x12\x65xecution_role_arn\x18\x03 \x01(\t\x12\r\n\x05image\x18\x04 \x01(\t\x12Z\n\x16resource_configuration\x18\x05 \x01(\x0b\x32:.oak9.tython.aws.iotanalytics.DatasetResourceConfiguration\"|\n\x10\x44\x61tasetDeltaTime\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x17\n\x0ftime_expression\x18\x02 \x01(\t\x12\x16\n\x0eoffset_seconds\x18\x03 \x01(\x05\"\x8c\x01\n\rDatasetFilter\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x42\n\ndelta_time\x18\x02 \x01(\x0b\x32..oak9.tython.aws.iotanalytics.DatasetDeltaTime\"\x9e\x01\n\x12\x44\x61tasetQueryAction\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12<\n\x07\x66ilters\x18\x02 \x03(\x0b\x32+.oak9.tython.aws.iotanalytics.DatasetFilter\x12\x11\n\tsql_query\x18\x03 \x01(\t\"\xf5\x01\n\rDatasetAction\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x61\x63tion_name\x18\x02 \x01(\t\x12N\n\x10\x63ontainer_action\x18\x03 \x01(\x0b\x32\x34.oak9.tython.aws.iotanalytics.DatasetContainerAction\x12\x46\n\x0cquery_action\x18\x04 \x01(\x0b\x32\x30.oak9.tython.aws.iotanalytics.DatasetQueryAction\"\x89\x01\n(DatasetIotEventsDestinationConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\ninput_name\x18\x02 \x01(\t\x12\x10\n\x08role_arn\x18\x03 \x01(\t\"~\n\x18\x44\x61tasetGlueConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\ntable_name\x18\x02 \x01(\t\x12\x15\n\rdatabase_name\x18\x03 \x01(\t\"\xdf\x01\n!DatasetS3DestinationConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12R\n\x12glue_configuration\x18\x02 \x01(\x0b\x32\x36.oak9.tython.aws.iotanalytics.DatasetGlueConfiguration\x12\x0e\n\x06\x62ucket\x18\x03 \x01(\t\x12\x0b\n\x03key\x18\x04 \x01(\t\x12\x10\n\x08role_arn\x18\x05 \x01(\t\"\xc4\x02\n,DatasetDatasetContentDeliveryRuleDestination\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12t\n$iot_events_destination_configuration\x18\x02 \x01(\x0b\x32\x46.oak9.tython.aws.iotanalytics.DatasetIotEventsDestinationConfiguration\x12\x65\n\x1cs3_destination_configuration\x18\x03 \x01(\x0b\x32?.oak9.tython.aws.iotanalytics.DatasetS3DestinationConfiguration\"\xd1\x01\n!DatasetDatasetContentDeliveryRule\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12_\n\x0b\x64\x65stination\x18\x02 \x01(\x0b\x32J.oak9.tython.aws.iotanalytics.DatasetDatasetContentDeliveryRuleDestination\x12\x12\n\nentry_name\x18\x03 \x01(\t\"g\n\x0f\x44\x61tasetSchedule\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1b\n\x13schedule_expression\x18\x02 \x01(\t\"i\n\x18\x44\x61tasetTriggeringDataset\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0c\x64\x61taset_name\x18\x02 \x01(\t\"\xde\x01\n\x0e\x44\x61tasetTrigger\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12?\n\x08schedule\x18\x02 \x01(\x0b\x32-.oak9.tython.aws.iotanalytics.DatasetSchedule\x12R\n\x12triggering_dataset\x18\x03 \x01(\x0b\x32\x36.oak9.tython.aws.iotanalytics.DatasetTriggeringDataset\"\x82\x01\n\x1e\x44\x61tasetVersioningConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0cmax_versions\x18\x02 \x01(\x05\x12\x11\n\tunlimited\x18\x03 \x01(\x08\"|\n\x16\x44\x61tasetRetentionPeriod\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0enumber_of_days\x18\x02 \x01(\x05\x12\x11\n\tunlimited\x18\x03 \x01(\x08\"\xd3\x04\n\x07\x44\x61taset\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12<\n\x07\x61\x63tions\x18\x02 \x03(\x0b\x32+.oak9.tython.aws.iotanalytics.DatasetAction\x12\x14\n\x0c\x64\x61taset_name\x18\x03 \x01(\t\x12_\n\x16\x63ontent_delivery_rules\x18\x04 \x03(\x0b\x32?.oak9.tython.aws.iotanalytics.DatasetDatasetContentDeliveryRule\x12>\n\x08triggers\x18\x05 \x03(\x0b\x32,.oak9.tython.aws.iotanalytics.DatasetTrigger\x12^\n\x18versioning_configuration\x18\x06 \x01(\x0b\x32<.oak9.tython.aws.iotanalytics.DatasetVersioningConfiguration\x12N\n\x10retention_period\x18\x07 \x01(\x0b\x32\x34.oak9.tython.aws.iotanalytics.DatasetRetentionPeriod\x12=\n\x04tags\x18\x08 \x03(\x0b\x32/.oak9.tython.aws.iotanalytics.Dataset.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x8b\x01\n\x1a\x44\x61tastoreCustomerManagedS3\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06\x62ucket\x18\x02 \x01(\t\x12\x10\n\x08role_arn\x18\x03 \x01(\t\x12\x12\n\nkey_prefix\x18\x04 \x01(\t\"T\n\x19\x44\x61tastoreServiceManagedS3\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x80\x02\n\x19\x44\x61tastoreDatastoreStorage\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12U\n\x13\x63ustomer_managed_s3\x18\x02 \x01(\x0b\x32\x38.oak9.tython.aws.iotanalytics.DatastoreCustomerManagedS3\x12S\n\x12service_managed_s3\x18\x03 \x01(\x0b\x32\x37.oak9.tython.aws.iotanalytics.DatastoreServiceManagedS3\"~\n\x18\x44\x61tastoreRetentionPeriod\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0enumber_of_days\x18\x02 \x01(\x05\x12\x11\n\tunlimited\x18\x03 \x01(\x08\"\xf0\x02\n\tDatastore\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12R\n\x11\x64\x61tastore_storage\x18\x02 \x01(\x0b\x32\x37.oak9.tython.aws.iotanalytics.DatastoreDatastoreStorage\x12\x16\n\x0e\x64\x61tastore_name\x18\x03 \x01(\t\x12P\n\x10retention_period\x18\x04 \x01(\x0b\x32\x36.oak9.tython.aws.iotanalytics.DatastoreRetentionPeriod\x12?\n\x04tags\x18\x05 \x03(\x0b\x32\x31.oak9.tython.aws.iotanalytics.Datastore.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x83\x01\n\x18PipelineSelectAttributes\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04next\x18\x02 \x01(\t\x12\x12\n\nattributes\x18\x03 \x03(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\"r\n\x11PipelineDatastore\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0e\x64\x61tastore_name\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\"u\n\x0ePipelineFilter\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06\x66ilter\x18\x02 \x01(\t\x12\x0c\n\x04next\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\"\xf8\x01\n\x15PipelineAddAttributes\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04next\x18\x02 \x01(\t\x12W\n\nattributes\x18\x03 \x03(\x0b\x32\x43.oak9.tython.aws.iotanalytics.PipelineAddAttributes.AttributesEntry\x12\x0c\n\x04name\x18\x04 \x01(\t\x1a\x31\n\x0f\x41ttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"|\n\x0fPipelineChannel\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x0c\n\x04next\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\"\xaa\x01\n\x1aPipelineDeviceShadowEnrich\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\tattribute\x18\x02 \x01(\t\x12\x0c\n\x04next\x18\x03 \x01(\t\x12\x12\n\nthing_name\x18\x04 \x01(\t\x12\x10\n\x08role_arn\x18\x05 \x01(\t\x12\x0c\n\x04name\x18\x06 \x01(\t\"\x84\x01\n\x0cPipelineMath\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\tattribute\x18\x02 \x01(\t\x12\x0c\n\x04next\x18\x03 \x01(\t\x12\x0c\n\x04math\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\"\x8e\x01\n\x0ePipelineLambda\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\nbatch_size\x18\x02 \x01(\x05\x12\x0c\n\x04next\x18\x03 \x01(\t\x12\x13\n\x0blambda_name\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\"\xac\x01\n\x1cPipelineDeviceRegistryEnrich\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\tattribute\x18\x02 \x01(\t\x12\x0c\n\x04next\x18\x03 \x01(\t\x12\x12\n\nthing_name\x18\x04 \x01(\t\x12\x10\n\x08role_arn\x18\x05 \x01(\t\x12\x0c\n\x04name\x18\x06 \x01(\t\"\x83\x01\n\x18PipelineRemoveAttributes\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04next\x18\x02 \x01(\t\x12\x12\n\nattributes\x18\x03 \x03(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\"\xac\x06\n\x10PipelineActivity\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12Q\n\x11select_attributes\x18\x02 \x01(\x0b\x32\x36.oak9.tython.aws.iotanalytics.PipelineSelectAttributes\x12\x42\n\tdatastore\x18\x03 \x01(\x0b\x32/.oak9.tython.aws.iotanalytics.PipelineDatastore\x12<\n\x06\x66ilter\x18\x04 \x01(\x0b\x32,.oak9.tython.aws.iotanalytics.PipelineFilter\x12K\n\x0e\x61\x64\x64_attributes\x18\x05 \x01(\x0b\x32\x33.oak9.tython.aws.iotanalytics.PipelineAddAttributes\x12>\n\x07\x63hannel\x18\x06 \x01(\x0b\x32-.oak9.tython.aws.iotanalytics.PipelineChannel\x12V\n\x14\x64\x65vice_shadow_enrich\x18\x07 \x01(\x0b\x32\x38.oak9.tython.aws.iotanalytics.PipelineDeviceShadowEnrich\x12\x38\n\x04math\x18\x08 \x01(\x0b\x32*.oak9.tython.aws.iotanalytics.PipelineMath\x12<\n\x06lambda\x18\t \x01(\x0b\x32,.oak9.tython.aws.iotanalytics.PipelineLambda\x12Z\n\x16\x64\x65vice_registry_enrich\x18\n \x01(\x0b\x32:.oak9.tython.aws.iotanalytics.PipelineDeviceRegistryEnrich\x12Q\n\x11remove_attributes\x18\x0b \x01(\x0b\x32\x36.oak9.tython.aws.iotanalytics.PipelineRemoveAttributes\"\x94\x02\n\x08Pipeline\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rpipeline_name\x18\x02 \x01(\t\x12>\n\x04tags\x18\x03 \x03(\x0b\x32\x30.oak9.tython.aws.iotanalytics.Pipeline.TagsEntry\x12K\n\x13pipeline_activities\x18\x04 \x03(\x0b\x32..oak9.tython.aws.iotanalytics.PipelineActivity\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_iotanalytics_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CHANNEL_TAGSENTRY._options = None
  _CHANNEL_TAGSENTRY._serialized_options = b'8\001'
  _DATASET_TAGSENTRY._options = None
  _DATASET_TAGSENTRY._serialized_options = b'8\001'
  _DATASTORE_TAGSENTRY._options = None
  _DATASTORE_TAGSENTRY._serialized_options = b'8\001'
  _PIPELINEADDATTRIBUTES_ATTRIBUTESENTRY._options = None
  _PIPELINEADDATTRIBUTES_ATTRIBUTESENTRY._serialized_options = b'8\001'
  _PIPELINE_TAGSENTRY._options = None
  _PIPELINE_TAGSENTRY._serialized_options = b'8\001'
  _CHANNELCUSTOMERMANAGEDS3._serialized_start=82
  _CHANNELCUSTOMERMANAGEDS3._serialized_end=219
  _CHANNELSERVICEMANAGEDS3._serialized_start=221
  _CHANNELSERVICEMANAGEDS3._serialized_end=303
  _CHANNELCHANNELSTORAGE._serialized_start=306
  _CHANNELCHANNELSTORAGE._serialized_end=554
  _CHANNELRETENTIONPERIOD._serialized_start=556
  _CHANNELRETENTIONPERIOD._serialized_end=680
  _CHANNEL._serialized_start=683
  _CHANNEL._serialized_end=1037
  _CHANNEL_TAGSENTRY._serialized_start=994
  _CHANNEL_TAGSENTRY._serialized_end=1037
  _IOTANALYTICS._serialized_start=1040
  _IOTANALYTICS._serialized_end=1284
  _DATASETDATASETCONTENTVERSIONVALUE._serialized_start=1286
  _DATASETDATASETCONTENTVERSIONVALUE._serialized_end=1400
  _DATASETOUTPUTFILEURIVALUE._serialized_start=1402
  _DATASETOUTPUTFILEURIVALUE._serialized_end=1505
  _DATASETVARIABLE._serialized_start=1508
  _DATASETVARIABLE._serialized_end=1841
  _DATASETRESOURCECONFIGURATION._serialized_start=1844
  _DATASETRESOURCECONFIGURATION._serialized_end=1980
  _DATASETCONTAINERACTION._serialized_start=1983
  _DATASETCONTAINERACTION._serialized_end=2265
  _DATASETDELTATIME._serialized_start=2267
  _DATASETDELTATIME._serialized_end=2391
  _DATASETFILTER._serialized_start=2394
  _DATASETFILTER._serialized_end=2534
  _DATASETQUERYACTION._serialized_start=2537
  _DATASETQUERYACTION._serialized_end=2695
  _DATASETACTION._serialized_start=2698
  _DATASETACTION._serialized_end=2943
  _DATASETIOTEVENTSDESTINATIONCONFIGURATION._serialized_start=2946
  _DATASETIOTEVENTSDESTINATIONCONFIGURATION._serialized_end=3083
  _DATASETGLUECONFIGURATION._serialized_start=3085
  _DATASETGLUECONFIGURATION._serialized_end=3211
  _DATASETS3DESTINATIONCONFIGURATION._serialized_start=3214
  _DATASETS3DESTINATIONCONFIGURATION._serialized_end=3437
  _DATASETDATASETCONTENTDELIVERYRULEDESTINATION._serialized_start=3440
  _DATASETDATASETCONTENTDELIVERYRULEDESTINATION._serialized_end=3764
  _DATASETDATASETCONTENTDELIVERYRULE._serialized_start=3767
  _DATASETDATASETCONTENTDELIVERYRULE._serialized_end=3976
  _DATASETSCHEDULE._serialized_start=3978
  _DATASETSCHEDULE._serialized_end=4081
  _DATASETTRIGGERINGDATASET._serialized_start=4083
  _DATASETTRIGGERINGDATASET._serialized_end=4188
  _DATASETTRIGGER._serialized_start=4191
  _DATASETTRIGGER._serialized_end=4413
  _DATASETVERSIONINGCONFIGURATION._serialized_start=4416
  _DATASETVERSIONINGCONFIGURATION._serialized_end=4546
  _DATASETRETENTIONPERIOD._serialized_start=4548
  _DATASETRETENTIONPERIOD._serialized_end=4672
  _DATASET._serialized_start=4675
  _DATASET._serialized_end=5270
  _DATASET_TAGSENTRY._serialized_start=994
  _DATASET_TAGSENTRY._serialized_end=1037
  _DATASTORECUSTOMERMANAGEDS3._serialized_start=5273
  _DATASTORECUSTOMERMANAGEDS3._serialized_end=5412
  _DATASTORESERVICEMANAGEDS3._serialized_start=5414
  _DATASTORESERVICEMANAGEDS3._serialized_end=5498
  _DATASTOREDATASTORESTORAGE._serialized_start=5501
  _DATASTOREDATASTORESTORAGE._serialized_end=5757
  _DATASTORERETENTIONPERIOD._serialized_start=5759
  _DATASTORERETENTIONPERIOD._serialized_end=5885
  _DATASTORE._serialized_start=5888
  _DATASTORE._serialized_end=6256
  _DATASTORE_TAGSENTRY._serialized_start=994
  _DATASTORE_TAGSENTRY._serialized_end=1037
  _PIPELINESELECTATTRIBUTES._serialized_start=6259
  _PIPELINESELECTATTRIBUTES._serialized_end=6390
  _PIPELINEDATASTORE._serialized_start=6392
  _PIPELINEDATASTORE._serialized_end=6506
  _PIPELINEFILTER._serialized_start=6508
  _PIPELINEFILTER._serialized_end=6625
  _PIPELINEADDATTRIBUTES._serialized_start=6628
  _PIPELINEADDATTRIBUTES._serialized_end=6876
  _PIPELINEADDATTRIBUTES_ATTRIBUTESENTRY._serialized_start=6827
  _PIPELINEADDATTRIBUTES_ATTRIBUTESENTRY._serialized_end=6876
  _PIPELINECHANNEL._serialized_start=6878
  _PIPELINECHANNEL._serialized_end=7002
  _PIPELINEDEVICESHADOWENRICH._serialized_start=7005
  _PIPELINEDEVICESHADOWENRICH._serialized_end=7175
  _PIPELINEMATH._serialized_start=7178
  _PIPELINEMATH._serialized_end=7310
  _PIPELINELAMBDA._serialized_start=7313
  _PIPELINELAMBDA._serialized_end=7455
  _PIPELINEDEVICEREGISTRYENRICH._serialized_start=7458
  _PIPELINEDEVICEREGISTRYENRICH._serialized_end=7630
  _PIPELINEREMOVEATTRIBUTES._serialized_start=7633
  _PIPELINEREMOVEATTRIBUTES._serialized_end=7764
  _PIPELINEACTIVITY._serialized_start=7767
  _PIPELINEACTIVITY._serialized_end=8579
  _PIPELINE._serialized_start=8582
  _PIPELINE._serialized_end=8858
  _PIPELINE_TAGSENTRY._serialized_start=994
  _PIPELINE_TAGSENTRY._serialized_end=1037
# @@protoc_insertion_point(module_scope)
