# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_google_cloudfunctions_bundle.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2
from oak9.tython.models.gcp import gcp_cloudfunctions_pb2 as gcp_dot_gcp__cloudfunctions__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*gcp/gcp_google_cloudfunctions_bundle.proto\x12,oak9.tython.gcp.google_cloudfunctions_bundle\x1a\x13shared/shared.proto\x1a\x1cgcp/gcp_cloudfunctions.proto\"\xb8\x03\n\x14GoogleCloudfunctions\x12W\n\x17\x63loudfunctions_function\x18\x01 \x01(\x0b\x32\x36.oak9.tython.gcp.cloudfunctions.CloudfunctionsFunction\x12m\n#cloudfunctions_function_iam_binding\x18\x02 \x03(\x0b\x32@.oak9.tython.gcp.cloudfunctions.CloudfunctionsFunctionIamBinding\x12k\n\"cloudfunctions_function_iam_member\x18\x03 \x03(\x0b\x32?.oak9.tython.gcp.cloudfunctions.CloudfunctionsFunctionIamMember\x12k\n\"cloudfunctions_function_iam_policy\x18\x04 \x03(\x0b\x32?.oak9.tython.gcp.cloudfunctions.CloudfunctionsFunctionIamPolicyb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_google_cloudfunctions_bundle_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GOOGLECLOUDFUNCTIONS._serialized_start=144
  _GOOGLECLOUDFUNCTIONS._serialized_end=584
# @@protoc_insertion_point(module_scope)
