# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kubernetes/kubernetes_io.k8s.api.authentication.v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2
from oak9.tython.models.kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta import v1_pb2 as kubernetes_dot_kubernetes__io_dot_k8s_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n8kubernetes/kubernetes_io.k8s.api.authentication.v1.proto\x12%oak9.tython.k8s.api.authentication.v1\x1a\x13shared/shared.proto\x1a@kubernetes/kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1.proto\"\x8d\x01\n\x14\x42oundObjectReference\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0b\n\x03uid\x18\x04 \x01(\t\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xc9\x02\n\x0cTokenRequest\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12K\n\x08metadata\x18\x03 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12\x45\n\x04spec\x18\x04 \x01(\x0b\x32\x37.oak9.tython.k8s.api.authentication.v1.TokenRequestSpec\x12I\n\x06status\x18\x05 \x01(\x0b\x32\x39.oak9.tython.k8s.api.authentication.v1.TokenRequestStatus\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xd1\x01\n\x10TokenRequestSpec\x12\x11\n\taudiences\x18\x01 \x03(\t\x12U\n\x10\x62ound_object_ref\x18\x02 \x01(\x0b\x32;.oak9.tython.k8s.api.authentication.v1.BoundObjectReference\x12\x1a\n\x12\x65xpiration_seconds\x18\x03 \x01(\x05\x12\x37\n\rresource_info\x18\x04 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xaf\x01\n\x12TokenRequestStatus\x12Q\n\x14\x65xpiration_timestamp\x18\x01 \x01(\x0b\x32\x33.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.Time\x12\r\n\x05token\x18\x02 \x01(\t\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xc6\x02\n\x0bTokenReview\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12K\n\x08metadata\x18\x03 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12\x44\n\x04spec\x18\x04 \x01(\x0b\x32\x36.oak9.tython.k8s.api.authentication.v1.TokenReviewSpec\x12H\n\x06status\x18\x05 \x01(\x0b\x32\x38.oak9.tython.k8s.api.authentication.v1.TokenReviewStatus\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"l\n\x0fTokenReviewSpec\x12\x11\n\taudiences\x18\x01 \x03(\t\x12\r\n\x05token\x18\x02 \x01(\t\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xc4\x01\n\x11TokenReviewStatus\x12\x11\n\taudiences\x18\x01 \x03(\t\x12\x15\n\rauthenticated\x18\x02 \x01(\x08\x12\r\n\x05\x65rror\x18\x03 \x01(\t\x12=\n\x04user\x18\x04 \x01(\x0b\x32/.oak9.tython.k8s.api.authentication.v1.UserInfo\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xeb\x01\n\x08UserInfo\x12I\n\x05\x65xtra\x18\x01 \x03(\x0b\x32:.oak9.tython.k8s.api.authentication.v1.UserInfo.ExtraEntry\x12\x0e\n\x06groups\x18\x02 \x03(\t\x12\x0b\n\x03uid\x18\x03 \x01(\t\x12\x10\n\x08username\x18\x04 \x01(\t\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a,\n\nExtraEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'kubernetes.kubernetes_io.k8s.api.authentication.v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _USERINFO_EXTRAENTRY._options = None
  _USERINFO_EXTRAENTRY._serialized_options = b'8\001'
  _BOUNDOBJECTREFERENCE._serialized_start=187
  _BOUNDOBJECTREFERENCE._serialized_end=328
  _TOKENREQUEST._serialized_start=331
  _TOKENREQUEST._serialized_end=660
  _TOKENREQUESTSPEC._serialized_start=663
  _TOKENREQUESTSPEC._serialized_end=872
  _TOKENREQUESTSTATUS._serialized_start=875
  _TOKENREQUESTSTATUS._serialized_end=1050
  _TOKENREVIEW._serialized_start=1053
  _TOKENREVIEW._serialized_end=1379
  _TOKENREVIEWSPEC._serialized_start=1381
  _TOKENREVIEWSPEC._serialized_end=1489
  _TOKENREVIEWSTATUS._serialized_start=1492
  _TOKENREVIEWSTATUS._serialized_end=1688
  _USERINFO._serialized_start=1691
  _USERINFO._serialized_end=1926
  _USERINFO_EXTRAENTRY._serialized_start=1882
  _USERINFO_EXTRAENTRY._serialized_end=1926
# @@protoc_insertion_point(module_scope)
