# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_compute_router.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1cgcp/gcp_compute_router.proto\x12\x1eoak9.tython.gcp.compute_router\x1a\x13shared/shared.proto\"J\n$ComputeRouterXBgpXAdvertisedIpRanges\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\r\n\x05range\x18\x02 \x01(\t\"\xd3\x01\n\x11\x43omputeRouterXBgp\x12\x16\n\x0e\x61\x64vertise_mode\x18\x01 \x01(\t\x12\x19\n\x11\x61\x64vertised_groups\x18\x02 \x03(\t\x12\x0b\n\x03\x61sn\x18\x03 \x01(\x01\x12\x1a\n\x12keepalive_interval\x18\x04 \x01(\x01\x12\x62\n\x14\x61\x64vertised_ip_ranges\x18\x05 \x03(\x0b\x32\x44.oak9.tython.gcp.compute_router.ComputeRouterXBgpXAdvertisedIpRanges\"H\n\x16\x43omputeRouterXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\x89\x03\n\rComputeRouter\x12\x1a\n\x12\x63reation_timestamp\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12%\n\x1d\x65ncrypted_interconnect_router\x18\x03 \x01(\x08\x12\n\n\x02id\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x0f\n\x07network\x18\x06 \x01(\t\x12\x0f\n\x07project\x18\x07 \x01(\t\x12\x0e\n\x06region\x18\x08 \x01(\t\x12\x11\n\tself_link\x18\t \x01(\t\x12>\n\x03\x62gp\x18\n \x01(\x0b\x32\x31.oak9.tython.gcp.compute_router.ComputeRouterXBgp\x12H\n\x08timeouts\x18\x0b \x01(\x0b\x32\x36.oak9.tython.gcp.compute_router.ComputeRouterXTimeouts\x12\x37\n\rresource_info\x18\x0c \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"A\n\x1f\x43omputeRouterInterfaceXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\"\xb6\x02\n\x16\x43omputeRouterInterface\x12\n\n\x02id\x18\x01 \x01(\t\x12\x1f\n\x17interconnect_attachment\x18\x02 \x01(\t\x12\x10\n\x08ip_range\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x0e\n\x06region\x18\x06 \x01(\t\x12\x0e\n\x06router\x18\x07 \x01(\t\x12\x12\n\nvpn_tunnel\x18\x08 \x01(\t\x12Q\n\x08timeouts\x18\t \x01(\x0b\x32?.oak9.tython.gcp.compute_router.ComputeRouterInterfaceXTimeouts\x12\x37\n\rresource_info\x18\n \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"<\n\x1a\x43omputeRouterNatXLogConfig\x12\x0e\n\x06\x65nable\x18\x01 \x01(\x08\x12\x0e\n\x06\x66ilter\x18\x02 \x01(\t\"n\n\x1b\x43omputeRouterNatXSubnetwork\x12\x0c\n\x04name\x18\x01 \x01(\t\x12 \n\x18secondary_ip_range_names\x18\x02 \x03(\t\x12\x1f\n\x17source_ip_ranges_to_nat\x18\x03 \x03(\t\"K\n\x19\x43omputeRouterNatXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\x91\x06\n\x10\x43omputeRouterNat\x12\x15\n\rdrain_nat_ips\x18\x01 \x03(\t\x12&\n\x1e\x65nable_dynamic_port_allocation\x18\x02 \x01(\x08\x12+\n#enable_endpoint_independent_mapping\x18\x03 \x01(\x08\x12\x1d\n\x15icmp_idle_timeout_sec\x18\x04 \x01(\x01\x12\n\n\x02id\x18\x05 \x01(\t\x12\x18\n\x10max_ports_per_vm\x18\x06 \x01(\x01\x12\x18\n\x10min_ports_per_vm\x18\x07 \x01(\x01\x12\x0c\n\x04name\x18\x08 \x01(\t\x12\x1e\n\x16nat_ip_allocate_option\x18\t \x01(\t\x12\x0f\n\x07nat_ips\x18\n \x03(\t\x12\x0f\n\x07project\x18\x0b \x01(\t\x12\x0e\n\x06region\x18\x0c \x01(\t\x12\x0e\n\x06router\x18\r \x01(\t\x12*\n\"source_subnetwork_ip_ranges_to_nat\x18\x0e \x01(\t\x12(\n tcp_established_idle_timeout_sec\x18\x0f \x01(\x01\x12\'\n\x1ftcp_transitory_idle_timeout_sec\x18\x10 \x01(\x01\x12\x1c\n\x14udp_idle_timeout_sec\x18\x11 \x01(\x01\x12N\n\nlog_config\x18\x12 \x01(\x0b\x32:.oak9.tython.gcp.compute_router.ComputeRouterNatXLogConfig\x12O\n\nsubnetwork\x18\x13 \x03(\x0b\x32;.oak9.tython.gcp.compute_router.ComputeRouterNatXSubnetwork\x12K\n\x08timeouts\x18\x14 \x01(\x0b\x32\x39.oak9.tython.gcp.compute_router.ComputeRouterNatXTimeouts\x12\x37\n\rresource_info\x18\x15 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"J\n$ComputeRouterPeerXAdvertisedIpRanges\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\r\n\x05range\x18\x02 \x01(\t\"\x8d\x01\n\x15\x43omputeRouterPeerXBfd\x12\x1c\n\x14min_receive_interval\x18\x01 \x01(\x01\x12\x1d\n\x15min_transmit_interval\x18\x02 \x01(\x01\x12\x12\n\nmultiplier\x18\x03 \x01(\x01\x12#\n\x1bsession_initialization_mode\x18\x04 \x01(\t\"L\n\x1a\x43omputeRouterPeerXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xde\x04\n\x11\x43omputeRouterPeer\x12\x16\n\x0e\x61\x64vertise_mode\x18\x01 \x01(\t\x12\x19\n\x11\x61\x64vertised_groups\x18\x02 \x03(\t\x12!\n\x19\x61\x64vertised_route_priority\x18\x03 \x01(\x01\x12\x0e\n\x06\x65nable\x18\x04 \x01(\x08\x12\n\n\x02id\x18\x05 \x01(\t\x12\x11\n\tinterface\x18\x06 \x01(\t\x12\x12\n\nip_address\x18\x07 \x01(\t\x12\x17\n\x0fmanagement_type\x18\x08 \x01(\t\x12\x0c\n\x04name\x18\t \x01(\t\x12\x10\n\x08peer_asn\x18\n \x01(\x01\x12\x17\n\x0fpeer_ip_address\x18\x0b \x01(\t\x12\x0f\n\x07project\x18\x0c \x01(\t\x12\x0e\n\x06region\x18\r \x01(\t\x12\x0e\n\x06router\x18\x0e \x01(\t\x12\x62\n\x14\x61\x64vertised_ip_ranges\x18\x0f \x03(\x0b\x32\x44.oak9.tython.gcp.compute_router.ComputeRouterPeerXAdvertisedIpRanges\x12\x42\n\x03\x62\x66\x64\x18\x10 \x01(\x0b\x32\x35.oak9.tython.gcp.compute_router.ComputeRouterPeerXBfd\x12L\n\x08timeouts\x18\x11 \x01(\x0b\x32:.oak9.tython.gcp.compute_router.ComputeRouterPeerXTimeouts\x12\x37\n\rresource_info\x18\x12 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_compute_router_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMPUTEROUTERXBGPXADVERTISEDIPRANGES._serialized_start=85
  _COMPUTEROUTERXBGPXADVERTISEDIPRANGES._serialized_end=159
  _COMPUTEROUTERXBGP._serialized_start=162
  _COMPUTEROUTERXBGP._serialized_end=373
  _COMPUTEROUTERXTIMEOUTS._serialized_start=375
  _COMPUTEROUTERXTIMEOUTS._serialized_end=447
  _COMPUTEROUTER._serialized_start=450
  _COMPUTEROUTER._serialized_end=843
  _COMPUTEROUTERINTERFACEXTIMEOUTS._serialized_start=845
  _COMPUTEROUTERINTERFACEXTIMEOUTS._serialized_end=910
  _COMPUTEROUTERINTERFACE._serialized_start=913
  _COMPUTEROUTERINTERFACE._serialized_end=1223
  _COMPUTEROUTERNATXLOGCONFIG._serialized_start=1225
  _COMPUTEROUTERNATXLOGCONFIG._serialized_end=1285
  _COMPUTEROUTERNATXSUBNETWORK._serialized_start=1287
  _COMPUTEROUTERNATXSUBNETWORK._serialized_end=1397
  _COMPUTEROUTERNATXTIMEOUTS._serialized_start=1399
  _COMPUTEROUTERNATXTIMEOUTS._serialized_end=1474
  _COMPUTEROUTERNAT._serialized_start=1477
  _COMPUTEROUTERNAT._serialized_end=2262
  _COMPUTEROUTERPEERXADVERTISEDIPRANGES._serialized_start=2264
  _COMPUTEROUTERPEERXADVERTISEDIPRANGES._serialized_end=2338
  _COMPUTEROUTERPEERXBFD._serialized_start=2341
  _COMPUTEROUTERPEERXBFD._serialized_end=2482
  _COMPUTEROUTERPEERXTIMEOUTS._serialized_start=2484
  _COMPUTEROUTERPEERXTIMEOUTS._serialized_end=2560
  _COMPUTEROUTERPEER._serialized_start=2563
  _COMPUTEROUTERPEER._serialized_end=3169
# @@protoc_insertion_point(module_scope)
