"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class AssociationTarget(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    VALUES_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    key: builtins.str
    @property
    def values(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        key: builtins.str = ...,
        values: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "resource_info", b"resource_info", "values", b"values"]) -> None: ...

global___AssociationTarget = AssociationTarget

@typing_extensions.final
class AssociationS3OutputLocation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    OUTPUT_S3_REGION_FIELD_NUMBER: builtins.int
    OUTPUT_S3_BUCKET_NAME_FIELD_NUMBER: builtins.int
    OUTPUT_S3_KEY_PREFIX_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    output_s3_region: builtins.str
    output_s3_bucket_name: builtins.str
    output_s3_key_prefix: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        output_s3_region: builtins.str = ...,
        output_s3_bucket_name: builtins.str = ...,
        output_s3_key_prefix: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["output_s3_bucket_name", b"output_s3_bucket_name", "output_s3_key_prefix", b"output_s3_key_prefix", "output_s3_region", b"output_s3_region", "resource_info", b"resource_info"]) -> None: ...

global___AssociationS3OutputLocation = AssociationS3OutputLocation

@typing_extensions.final
class AssociationInstanceAssociationOutputLocation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    S3_LOCATION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def s3_location(self) -> global___AssociationS3OutputLocation: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        s3_location: global___AssociationS3OutputLocation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "s3_location", b"s3_location"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "s3_location", b"s3_location"]) -> None: ...

global___AssociationInstanceAssociationOutputLocation = AssociationInstanceAssociationOutputLocation

@typing_extensions.final
class Association(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class ParametersEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ASSOCIATION_NAME_FIELD_NUMBER: builtins.int
    DOCUMENT_VERSION_FIELD_NUMBER: builtins.int
    INSTANCE_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PARAMETERS_FIELD_NUMBER: builtins.int
    SCHEDULE_EXPRESSION_FIELD_NUMBER: builtins.int
    TARGETS_FIELD_NUMBER: builtins.int
    OUTPUT_LOCATION_FIELD_NUMBER: builtins.int
    AUTOMATION_TARGET_PARAMETER_NAME_FIELD_NUMBER: builtins.int
    MAX_ERRORS_FIELD_NUMBER: builtins.int
    MAX_CONCURRENCY_FIELD_NUMBER: builtins.int
    COMPLIANCE_SEVERITY_FIELD_NUMBER: builtins.int
    SYNC_COMPLIANCE_FIELD_NUMBER: builtins.int
    WAIT_FOR_SUCCESS_TIMEOUT_SECONDS_FIELD_NUMBER: builtins.int
    APPLY_ONLY_AT_CRON_INTERVAL_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    association_name: builtins.str
    document_version: builtins.str
    instance_id: builtins.str
    name: builtins.str
    @property
    def parameters(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    schedule_expression: builtins.str
    @property
    def targets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AssociationTarget]: ...
    @property
    def output_location(self) -> global___AssociationInstanceAssociationOutputLocation: ...
    automation_target_parameter_name: builtins.str
    max_errors: builtins.str
    max_concurrency: builtins.str
    compliance_severity: builtins.str
    sync_compliance: builtins.str
    wait_for_success_timeout_seconds: builtins.int
    apply_only_at_cron_interval: builtins.bool
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        association_name: builtins.str = ...,
        document_version: builtins.str = ...,
        instance_id: builtins.str = ...,
        name: builtins.str = ...,
        parameters: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        schedule_expression: builtins.str = ...,
        targets: collections.abc.Iterable[global___AssociationTarget] | None = ...,
        output_location: global___AssociationInstanceAssociationOutputLocation | None = ...,
        automation_target_parameter_name: builtins.str = ...,
        max_errors: builtins.str = ...,
        max_concurrency: builtins.str = ...,
        compliance_severity: builtins.str = ...,
        sync_compliance: builtins.str = ...,
        wait_for_success_timeout_seconds: builtins.int = ...,
        apply_only_at_cron_interval: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["output_location", b"output_location", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["apply_only_at_cron_interval", b"apply_only_at_cron_interval", "association_name", b"association_name", "automation_target_parameter_name", b"automation_target_parameter_name", "compliance_severity", b"compliance_severity", "document_version", b"document_version", "instance_id", b"instance_id", "max_concurrency", b"max_concurrency", "max_errors", b"max_errors", "name", b"name", "output_location", b"output_location", "parameters", b"parameters", "resource_info", b"resource_info", "schedule_expression", b"schedule_expression", "sync_compliance", b"sync_compliance", "targets", b"targets", "wait_for_success_timeout_seconds", b"wait_for_success_timeout_seconds"]) -> None: ...

global___Association = Association

@typing_extensions.final
class SSM(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ASSOCIATION_FIELD_NUMBER: builtins.int
    DOCUMENT_FIELD_NUMBER: builtins.int
    MAINTENANCE_WINDOW_FIELD_NUMBER: builtins.int
    MAINTENANCE_WINDOW_TARGET_FIELD_NUMBER: builtins.int
    MAINTENANCE_WINDOW_TASK_FIELD_NUMBER: builtins.int
    PARAMETER_FIELD_NUMBER: builtins.int
    PATCH_BASELINE_FIELD_NUMBER: builtins.int
    RESOURCE_DATA_SYNC_FIELD_NUMBER: builtins.int
    ASSOCIATION_PARAMETER_VALUES_FIELD_NUMBER: builtins.int
    @property
    def association(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Association]: ...
    @property
    def document(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Document]: ...
    @property
    def maintenance_window(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MaintenanceWindow]: ...
    @property
    def maintenance_window_target(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MaintenanceWindowTarget]: ...
    @property
    def maintenance_window_task(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MaintenanceWindowTask]: ...
    @property
    def parameter(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Parameter]: ...
    @property
    def patch_baseline(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PatchBaseline]: ...
    @property
    def resource_data_sync(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ResourceDataSync]: ...
    @property
    def association_parameter_values(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AssociationParameterValues]: ...
    def __init__(
        self,
        *,
        association: collections.abc.Iterable[global___Association] | None = ...,
        document: collections.abc.Iterable[global___Document] | None = ...,
        maintenance_window: collections.abc.Iterable[global___MaintenanceWindow] | None = ...,
        maintenance_window_target: collections.abc.Iterable[global___MaintenanceWindowTarget] | None = ...,
        maintenance_window_task: collections.abc.Iterable[global___MaintenanceWindowTask] | None = ...,
        parameter: collections.abc.Iterable[global___Parameter] | None = ...,
        patch_baseline: collections.abc.Iterable[global___PatchBaseline] | None = ...,
        resource_data_sync: collections.abc.Iterable[global___ResourceDataSync] | None = ...,
        association_parameter_values: collections.abc.Iterable[global___AssociationParameterValues] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["association", b"association", "association_parameter_values", b"association_parameter_values", "document", b"document", "maintenance_window", b"maintenance_window", "maintenance_window_target", b"maintenance_window_target", "maintenance_window_task", b"maintenance_window_task", "parameter", b"parameter", "patch_baseline", b"patch_baseline", "resource_data_sync", b"resource_data_sync"]) -> None: ...

global___SSM = SSM

@typing_extensions.final
class Document(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class ContentEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    DOCUMENT_TYPE_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def content(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    document_type: builtins.str
    name: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        content: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        document_type: builtins.str = ...,
        name: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["content", b"content", "document_type", b"document_type", "name", b"name", "resource_info", b"resource_info", "tags", b"tags"]) -> None: ...

global___Document = Document

@typing_extensions.final
class MaintenanceWindow(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    START_DATE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ALLOW_UNASSOCIATED_TARGETS_FIELD_NUMBER: builtins.int
    CUTOFF_FIELD_NUMBER: builtins.int
    SCHEDULE_FIELD_NUMBER: builtins.int
    DURATION_FIELD_NUMBER: builtins.int
    SCHEDULE_OFFSET_FIELD_NUMBER: builtins.int
    END_DATE_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    SCHEDULE_TIMEZONE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    start_date: builtins.str
    description: builtins.str
    allow_unassociated_targets: builtins.bool
    cutoff: builtins.int
    schedule: builtins.str
    duration: builtins.int
    schedule_offset: builtins.int
    end_date: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    name: builtins.str
    schedule_timezone: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        start_date: builtins.str = ...,
        description: builtins.str = ...,
        allow_unassociated_targets: builtins.bool = ...,
        cutoff: builtins.int = ...,
        schedule: builtins.str = ...,
        duration: builtins.int = ...,
        schedule_offset: builtins.int = ...,
        end_date: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        name: builtins.str = ...,
        schedule_timezone: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["allow_unassociated_targets", b"allow_unassociated_targets", "cutoff", b"cutoff", "description", b"description", "duration", b"duration", "end_date", b"end_date", "name", b"name", "resource_info", b"resource_info", "schedule", b"schedule", "schedule_offset", b"schedule_offset", "schedule_timezone", b"schedule_timezone", "start_date", b"start_date", "tags", b"tags"]) -> None: ...

global___MaintenanceWindow = MaintenanceWindow

@typing_extensions.final
class MaintenanceWindowTargetTargets(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    VALUES_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def values(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    key: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        values: collections.abc.Iterable[builtins.str] | None = ...,
        key: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "resource_info", b"resource_info", "values", b"values"]) -> None: ...

global___MaintenanceWindowTargetTargets = MaintenanceWindowTargetTargets

@typing_extensions.final
class MaintenanceWindowTarget(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    OWNER_INFORMATION_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    WINDOW_ID_FIELD_NUMBER: builtins.int
    RESOURCE_TYPE_FIELD_NUMBER: builtins.int
    TARGETS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    owner_information: builtins.str
    description: builtins.str
    window_id: builtins.str
    resource_type: builtins.str
    @property
    def targets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MaintenanceWindowTargetTargets]: ...
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        owner_information: builtins.str = ...,
        description: builtins.str = ...,
        window_id: builtins.str = ...,
        resource_type: builtins.str = ...,
        targets: collections.abc.Iterable[global___MaintenanceWindowTargetTargets] | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "name", b"name", "owner_information", b"owner_information", "resource_info", b"resource_info", "resource_type", b"resource_type", "targets", b"targets", "window_id", b"window_id"]) -> None: ...

global___MaintenanceWindowTarget = MaintenanceWindowTarget

@typing_extensions.final
class MaintenanceWindowTaskTarget(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    VALUES_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def values(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    key: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        values: collections.abc.Iterable[builtins.str] | None = ...,
        key: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "resource_info", b"resource_info", "values", b"values"]) -> None: ...

global___MaintenanceWindowTaskTarget = MaintenanceWindowTaskTarget

@typing_extensions.final
class MaintenanceWindowTaskNotificationConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NOTIFICATION_ARN_FIELD_NUMBER: builtins.int
    NOTIFICATION_TYPE_FIELD_NUMBER: builtins.int
    NOTIFICATION_EVENTS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    notification_arn: builtins.str
    notification_type: builtins.str
    @property
    def notification_events(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        notification_arn: builtins.str = ...,
        notification_type: builtins.str = ...,
        notification_events: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["notification_arn", b"notification_arn", "notification_events", b"notification_events", "notification_type", b"notification_type", "resource_info", b"resource_info"]) -> None: ...

global___MaintenanceWindowTaskNotificationConfig = MaintenanceWindowTaskNotificationConfig

@typing_extensions.final
class MaintenanceWindowTaskMaintenanceWindowRunCommandParameters(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class ParametersEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    TIMEOUT_SECONDS_FIELD_NUMBER: builtins.int
    COMMENT_FIELD_NUMBER: builtins.int
    OUTPUT_S3_KEY_PREFIX_FIELD_NUMBER: builtins.int
    PARAMETERS_FIELD_NUMBER: builtins.int
    DOCUMENT_HASH_TYPE_FIELD_NUMBER: builtins.int
    SERVICE_ROLE_ARN_FIELD_NUMBER: builtins.int
    NOTIFICATION_CONFIG_FIELD_NUMBER: builtins.int
    OUTPUT_S3_BUCKET_NAME_FIELD_NUMBER: builtins.int
    DOCUMENT_HASH_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    timeout_seconds: builtins.int
    comment: builtins.str
    output_s3_key_prefix: builtins.str
    @property
    def parameters(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    document_hash_type: builtins.str
    service_role_arn: builtins.str
    @property
    def notification_config(self) -> global___MaintenanceWindowTaskNotificationConfig: ...
    output_s3_bucket_name: builtins.str
    document_hash: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        timeout_seconds: builtins.int = ...,
        comment: builtins.str = ...,
        output_s3_key_prefix: builtins.str = ...,
        parameters: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        document_hash_type: builtins.str = ...,
        service_role_arn: builtins.str = ...,
        notification_config: global___MaintenanceWindowTaskNotificationConfig | None = ...,
        output_s3_bucket_name: builtins.str = ...,
        document_hash: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["notification_config", b"notification_config", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["comment", b"comment", "document_hash", b"document_hash", "document_hash_type", b"document_hash_type", "notification_config", b"notification_config", "output_s3_bucket_name", b"output_s3_bucket_name", "output_s3_key_prefix", b"output_s3_key_prefix", "parameters", b"parameters", "resource_info", b"resource_info", "service_role_arn", b"service_role_arn", "timeout_seconds", b"timeout_seconds"]) -> None: ...

global___MaintenanceWindowTaskMaintenanceWindowRunCommandParameters = MaintenanceWindowTaskMaintenanceWindowRunCommandParameters

@typing_extensions.final
class MaintenanceWindowTaskMaintenanceWindowAutomationParameters(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class ParametersEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    PARAMETERS_FIELD_NUMBER: builtins.int
    DOCUMENT_VERSION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def parameters(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    document_version: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        parameters: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        document_version: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["document_version", b"document_version", "parameters", b"parameters", "resource_info", b"resource_info"]) -> None: ...

global___MaintenanceWindowTaskMaintenanceWindowAutomationParameters = MaintenanceWindowTaskMaintenanceWindowAutomationParameters

@typing_extensions.final
class MaintenanceWindowTaskMaintenanceWindowStepFunctionsParameters(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    INPUT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    input: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        input: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["input", b"input", "name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___MaintenanceWindowTaskMaintenanceWindowStepFunctionsParameters = MaintenanceWindowTaskMaintenanceWindowStepFunctionsParameters

@typing_extensions.final
class MaintenanceWindowTaskMaintenanceWindowLambdaParameters(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CLIENT_CONTEXT_FIELD_NUMBER: builtins.int
    QUALIFIER_FIELD_NUMBER: builtins.int
    PAYLOAD_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    client_context: builtins.str
    qualifier: builtins.str
    payload: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        client_context: builtins.str = ...,
        qualifier: builtins.str = ...,
        payload: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["client_context", b"client_context", "payload", b"payload", "qualifier", b"qualifier", "resource_info", b"resource_info"]) -> None: ...

global___MaintenanceWindowTaskMaintenanceWindowLambdaParameters = MaintenanceWindowTaskMaintenanceWindowLambdaParameters

@typing_extensions.final
class MaintenanceWindowTaskTaskInvocationParameters(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    MAINTENANCE_WINDOW_RUN_COMMAND_PARAMETERS_FIELD_NUMBER: builtins.int
    MAINTENANCE_WINDOW_AUTOMATION_PARAMETERS_FIELD_NUMBER: builtins.int
    MAINTENANCE_WINDOW_STEP_FUNCTIONS_PARAMETERS_FIELD_NUMBER: builtins.int
    MAINTENANCE_WINDOW_LAMBDA_PARAMETERS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def maintenance_window_run_command_parameters(self) -> global___MaintenanceWindowTaskMaintenanceWindowRunCommandParameters: ...
    @property
    def maintenance_window_automation_parameters(self) -> global___MaintenanceWindowTaskMaintenanceWindowAutomationParameters: ...
    @property
    def maintenance_window_step_functions_parameters(self) -> global___MaintenanceWindowTaskMaintenanceWindowStepFunctionsParameters: ...
    @property
    def maintenance_window_lambda_parameters(self) -> global___MaintenanceWindowTaskMaintenanceWindowLambdaParameters: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        maintenance_window_run_command_parameters: global___MaintenanceWindowTaskMaintenanceWindowRunCommandParameters | None = ...,
        maintenance_window_automation_parameters: global___MaintenanceWindowTaskMaintenanceWindowAutomationParameters | None = ...,
        maintenance_window_step_functions_parameters: global___MaintenanceWindowTaskMaintenanceWindowStepFunctionsParameters | None = ...,
        maintenance_window_lambda_parameters: global___MaintenanceWindowTaskMaintenanceWindowLambdaParameters | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["maintenance_window_automation_parameters", b"maintenance_window_automation_parameters", "maintenance_window_lambda_parameters", b"maintenance_window_lambda_parameters", "maintenance_window_run_command_parameters", b"maintenance_window_run_command_parameters", "maintenance_window_step_functions_parameters", b"maintenance_window_step_functions_parameters", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["maintenance_window_automation_parameters", b"maintenance_window_automation_parameters", "maintenance_window_lambda_parameters", b"maintenance_window_lambda_parameters", "maintenance_window_run_command_parameters", b"maintenance_window_run_command_parameters", "maintenance_window_step_functions_parameters", b"maintenance_window_step_functions_parameters", "resource_info", b"resource_info"]) -> None: ...

global___MaintenanceWindowTaskTaskInvocationParameters = MaintenanceWindowTaskTaskInvocationParameters

@typing_extensions.final
class MaintenanceWindowTaskLoggingInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    S3_BUCKET_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    S3_PREFIX_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    s3_bucket: builtins.str
    region: builtins.str
    s3_prefix: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        s3_bucket: builtins.str = ...,
        region: builtins.str = ...,
        s3_prefix: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["region", b"region", "resource_info", b"resource_info", "s3_bucket", b"s3_bucket", "s3_prefix", b"s3_prefix"]) -> None: ...

global___MaintenanceWindowTaskLoggingInfo = MaintenanceWindowTaskLoggingInfo

@typing_extensions.final
class MaintenanceWindowTask(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TaskParametersEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    MAX_ERRORS_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    SERVICE_ROLE_ARN_FIELD_NUMBER: builtins.int
    PRIORITY_FIELD_NUMBER: builtins.int
    MAX_CONCURRENCY_FIELD_NUMBER: builtins.int
    TARGETS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    TASK_ARN_FIELD_NUMBER: builtins.int
    TASK_INVOCATION_PARAMETERS_FIELD_NUMBER: builtins.int
    WINDOW_ID_FIELD_NUMBER: builtins.int
    TASK_PARAMETERS_FIELD_NUMBER: builtins.int
    TASK_TYPE_FIELD_NUMBER: builtins.int
    LOGGING_INFO_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    max_errors: builtins.str
    description: builtins.str
    service_role_arn: builtins.str
    priority: builtins.int
    max_concurrency: builtins.str
    @property
    def targets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MaintenanceWindowTaskTarget]: ...
    name: builtins.str
    task_arn: builtins.str
    @property
    def task_invocation_parameters(self) -> global___MaintenanceWindowTaskTaskInvocationParameters: ...
    window_id: builtins.str
    @property
    def task_parameters(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    task_type: builtins.str
    @property
    def logging_info(self) -> global___MaintenanceWindowTaskLoggingInfo: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        max_errors: builtins.str = ...,
        description: builtins.str = ...,
        service_role_arn: builtins.str = ...,
        priority: builtins.int = ...,
        max_concurrency: builtins.str = ...,
        targets: collections.abc.Iterable[global___MaintenanceWindowTaskTarget] | None = ...,
        name: builtins.str = ...,
        task_arn: builtins.str = ...,
        task_invocation_parameters: global___MaintenanceWindowTaskTaskInvocationParameters | None = ...,
        window_id: builtins.str = ...,
        task_parameters: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        task_type: builtins.str = ...,
        logging_info: global___MaintenanceWindowTaskLoggingInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["logging_info", b"logging_info", "resource_info", b"resource_info", "task_invocation_parameters", b"task_invocation_parameters"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "logging_info", b"logging_info", "max_concurrency", b"max_concurrency", "max_errors", b"max_errors", "name", b"name", "priority", b"priority", "resource_info", b"resource_info", "service_role_arn", b"service_role_arn", "targets", b"targets", "task_arn", b"task_arn", "task_invocation_parameters", b"task_invocation_parameters", "task_parameters", b"task_parameters", "task_type", b"task_type", "window_id", b"window_id"]) -> None: ...

global___MaintenanceWindowTask = MaintenanceWindowTask

@typing_extensions.final
class Parameter(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    POLICIES_FIELD_NUMBER: builtins.int
    ALLOWED_PATTERN_FIELD_NUMBER: builtins.int
    TIER_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    DATA_TYPE_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    type: builtins.str
    description: builtins.str
    policies: builtins.str
    allowed_pattern: builtins.str
    tier: builtins.str
    value: builtins.str
    data_type: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        type: builtins.str = ...,
        description: builtins.str = ...,
        policies: builtins.str = ...,
        allowed_pattern: builtins.str = ...,
        tier: builtins.str = ...,
        value: builtins.str = ...,
        data_type: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["allowed_pattern", b"allowed_pattern", "data_type", b"data_type", "description", b"description", "name", b"name", "policies", b"policies", "resource_info", b"resource_info", "tags", b"tags", "tier", b"tier", "type", b"type", "value", b"value"]) -> None: ...

global___Parameter = Parameter

@typing_extensions.final
class PatchBaselinePatchStringDate(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> None: ...

global___PatchBaselinePatchStringDate = PatchBaselinePatchStringDate

@typing_extensions.final
class PatchBaselinePatchFilter(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    VALUES_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def values(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    key: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        values: collections.abc.Iterable[builtins.str] | None = ...,
        key: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "resource_info", b"resource_info", "values", b"values"]) -> None: ...

global___PatchBaselinePatchFilter = PatchBaselinePatchFilter

@typing_extensions.final
class PatchBaselinePatchFilterGroup(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    PATCH_FILTERS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def patch_filters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PatchBaselinePatchFilter]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        patch_filters: collections.abc.Iterable[global___PatchBaselinePatchFilter] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["patch_filters", b"patch_filters", "resource_info", b"resource_info"]) -> None: ...

global___PatchBaselinePatchFilterGroup = PatchBaselinePatchFilterGroup

@typing_extensions.final
class PatchBaselineRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    APPROVE_UNTIL_DATE_FIELD_NUMBER: builtins.int
    ENABLE_NON_SECURITY_FIELD_NUMBER: builtins.int
    PATCH_FILTER_GROUP_FIELD_NUMBER: builtins.int
    APPROVE_AFTER_DAYS_FIELD_NUMBER: builtins.int
    COMPLIANCE_LEVEL_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def approve_until_date(self) -> global___PatchBaselinePatchStringDate: ...
    enable_non_security: builtins.bool
    @property
    def patch_filter_group(self) -> global___PatchBaselinePatchFilterGroup: ...
    approve_after_days: builtins.int
    compliance_level: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        approve_until_date: global___PatchBaselinePatchStringDate | None = ...,
        enable_non_security: builtins.bool = ...,
        patch_filter_group: global___PatchBaselinePatchFilterGroup | None = ...,
        approve_after_days: builtins.int = ...,
        compliance_level: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["approve_until_date", b"approve_until_date", "patch_filter_group", b"patch_filter_group", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["approve_after_days", b"approve_after_days", "approve_until_date", b"approve_until_date", "compliance_level", b"compliance_level", "enable_non_security", b"enable_non_security", "patch_filter_group", b"patch_filter_group", "resource_info", b"resource_info"]) -> None: ...

global___PatchBaselineRule = PatchBaselineRule

@typing_extensions.final
class PatchBaselineRuleGroup(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    PATCH_RULES_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def patch_rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PatchBaselineRule]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        patch_rules: collections.abc.Iterable[global___PatchBaselineRule] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["patch_rules", b"patch_rules", "resource_info", b"resource_info"]) -> None: ...

global___PatchBaselineRuleGroup = PatchBaselineRuleGroup

@typing_extensions.final
class PatchBaselinePatchSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    PRODUCTS_FIELD_NUMBER: builtins.int
    CONFIGURATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def products(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    configuration: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        products: collections.abc.Iterable[builtins.str] | None = ...,
        configuration: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["configuration", b"configuration", "name", b"name", "products", b"products", "resource_info", b"resource_info"]) -> None: ...

global___PatchBaselinePatchSource = PatchBaselinePatchSource

@typing_extensions.final
class PatchBaseline(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    OPERATING_SYSTEM_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    APPROVAL_RULES_FIELD_NUMBER: builtins.int
    SOURCES_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    REJECTED_PATCHES_FIELD_NUMBER: builtins.int
    APPROVED_PATCHES_FIELD_NUMBER: builtins.int
    REJECTED_PATCHES_ACTION_FIELD_NUMBER: builtins.int
    PATCH_GROUPS_FIELD_NUMBER: builtins.int
    APPROVED_PATCHES_COMPLIANCE_LEVEL_FIELD_NUMBER: builtins.int
    APPROVED_PATCHES_ENABLE_NON_SECURITY_FIELD_NUMBER: builtins.int
    GLOBAL_FILTERS_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    operating_system: builtins.str
    description: builtins.str
    @property
    def approval_rules(self) -> global___PatchBaselineRuleGroup: ...
    @property
    def sources(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PatchBaselinePatchSource]: ...
    name: builtins.str
    @property
    def rejected_patches(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def approved_patches(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    rejected_patches_action: builtins.str
    @property
    def patch_groups(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    approved_patches_compliance_level: builtins.str
    approved_patches_enable_non_security: builtins.bool
    @property
    def global_filters(self) -> global___PatchBaselinePatchFilterGroup: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        operating_system: builtins.str = ...,
        description: builtins.str = ...,
        approval_rules: global___PatchBaselineRuleGroup | None = ...,
        sources: collections.abc.Iterable[global___PatchBaselinePatchSource] | None = ...,
        name: builtins.str = ...,
        rejected_patches: collections.abc.Iterable[builtins.str] | None = ...,
        approved_patches: collections.abc.Iterable[builtins.str] | None = ...,
        rejected_patches_action: builtins.str = ...,
        patch_groups: collections.abc.Iterable[builtins.str] | None = ...,
        approved_patches_compliance_level: builtins.str = ...,
        approved_patches_enable_non_security: builtins.bool = ...,
        global_filters: global___PatchBaselinePatchFilterGroup | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["approval_rules", b"approval_rules", "global_filters", b"global_filters", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["approval_rules", b"approval_rules", "approved_patches", b"approved_patches", "approved_patches_compliance_level", b"approved_patches_compliance_level", "approved_patches_enable_non_security", b"approved_patches_enable_non_security", "description", b"description", "global_filters", b"global_filters", "name", b"name", "operating_system", b"operating_system", "patch_groups", b"patch_groups", "rejected_patches", b"rejected_patches", "rejected_patches_action", b"rejected_patches_action", "resource_info", b"resource_info", "sources", b"sources", "tags", b"tags"]) -> None: ...

global___PatchBaseline = PatchBaseline

@typing_extensions.final
class ResourceDataSyncS3Destination(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    KMS_KEY_ARN_FIELD_NUMBER: builtins.int
    BUCKET_NAME_FIELD_NUMBER: builtins.int
    BUCKET_REGION_FIELD_NUMBER: builtins.int
    SYNC_FORMAT_FIELD_NUMBER: builtins.int
    BUCKET_PREFIX_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    kms_key_arn: builtins.str
    bucket_name: builtins.str
    bucket_region: builtins.str
    sync_format: builtins.str
    bucket_prefix: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        kms_key_arn: builtins.str = ...,
        bucket_name: builtins.str = ...,
        bucket_region: builtins.str = ...,
        sync_format: builtins.str = ...,
        bucket_prefix: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bucket_name", b"bucket_name", "bucket_prefix", b"bucket_prefix", "bucket_region", b"bucket_region", "kms_key_arn", b"kms_key_arn", "resource_info", b"resource_info", "sync_format", b"sync_format"]) -> None: ...

global___ResourceDataSyncS3Destination = ResourceDataSyncS3Destination

@typing_extensions.final
class ResourceDataSyncAwsOrganizationsSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ORGANIZATION_SOURCE_TYPE_FIELD_NUMBER: builtins.int
    ORGANIZATIONAL_UNITS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    organization_source_type: builtins.str
    @property
    def organizational_units(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        organization_source_type: builtins.str = ...,
        organizational_units: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["organization_source_type", b"organization_source_type", "organizational_units", b"organizational_units", "resource_info", b"resource_info"]) -> None: ...

global___ResourceDataSyncAwsOrganizationsSource = ResourceDataSyncAwsOrganizationsSource

@typing_extensions.final
class ResourceDataSyncSyncSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    SOURCE_TYPE_FIELD_NUMBER: builtins.int
    AWS_ORGANIZATIONS_SOURCE_FIELD_NUMBER: builtins.int
    INCLUDE_FUTURE_REGIONS_FIELD_NUMBER: builtins.int
    SOURCE_REGIONS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    source_type: builtins.str
    @property
    def aws_organizations_source(self) -> global___ResourceDataSyncAwsOrganizationsSource: ...
    include_future_regions: builtins.bool
    @property
    def source_regions(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        source_type: builtins.str = ...,
        aws_organizations_source: global___ResourceDataSyncAwsOrganizationsSource | None = ...,
        include_future_regions: builtins.bool = ...,
        source_regions: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["aws_organizations_source", b"aws_organizations_source", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["aws_organizations_source", b"aws_organizations_source", "include_future_regions", b"include_future_regions", "resource_info", b"resource_info", "source_regions", b"source_regions", "source_type", b"source_type"]) -> None: ...

global___ResourceDataSyncSyncSource = ResourceDataSyncSyncSource

@typing_extensions.final
class ResourceDataSync(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    S3_DESTINATION_FIELD_NUMBER: builtins.int
    KMS_KEY_ARN_FIELD_NUMBER: builtins.int
    SYNC_SOURCE_FIELD_NUMBER: builtins.int
    BUCKET_NAME_FIELD_NUMBER: builtins.int
    BUCKET_REGION_FIELD_NUMBER: builtins.int
    SYNC_FORMAT_FIELD_NUMBER: builtins.int
    SYNC_NAME_FIELD_NUMBER: builtins.int
    SYNC_TYPE_FIELD_NUMBER: builtins.int
    BUCKET_PREFIX_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def s3_destination(self) -> global___ResourceDataSyncS3Destination: ...
    kms_key_arn: builtins.str
    @property
    def sync_source(self) -> global___ResourceDataSyncSyncSource: ...
    bucket_name: builtins.str
    bucket_region: builtins.str
    sync_format: builtins.str
    sync_name: builtins.str
    sync_type: builtins.str
    bucket_prefix: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        s3_destination: global___ResourceDataSyncS3Destination | None = ...,
        kms_key_arn: builtins.str = ...,
        sync_source: global___ResourceDataSyncSyncSource | None = ...,
        bucket_name: builtins.str = ...,
        bucket_region: builtins.str = ...,
        sync_format: builtins.str = ...,
        sync_name: builtins.str = ...,
        sync_type: builtins.str = ...,
        bucket_prefix: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "s3_destination", b"s3_destination", "sync_source", b"sync_source"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bucket_name", b"bucket_name", "bucket_prefix", b"bucket_prefix", "bucket_region", b"bucket_region", "kms_key_arn", b"kms_key_arn", "resource_info", b"resource_info", "s3_destination", b"s3_destination", "sync_format", b"sync_format", "sync_name", b"sync_name", "sync_source", b"sync_source", "sync_type", b"sync_type"]) -> None: ...

global___ResourceDataSync = ResourceDataSync

@typing_extensions.final
class AssociationParameterValues(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    PARAMETER_VALUES_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def parameter_values(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        parameter_values: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["parameter_values", b"parameter_values", "resource_info", b"resource_info"]) -> None: ...

global___AssociationParameterValues = AssociationParameterValues
