# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_access.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14gcp/gcp_access.proto\x12\x16oak9.tython.gcp.access\x1a\x13shared/shared.proto\"\x9b\x01\nKAccessContextManagerAccessLevelXBasicXConditionsXDevicePolicyXOsConstraints\x12\x17\n\x0fminimum_version\x18\x01 \x01(\t\x12\x0f\n\x07os_type\x18\x02 \x01(\t\x12\"\n\x1arequire_verified_chrome_os\x18\x03 \x01(\x08\"\xe4\x02\n=AccessContextManagerAccessLevelXBasicXConditionsXDevicePolicy\x12(\n allowed_device_management_levels\x18\x01 \x03(\t\x12#\n\x1b\x61llowed_encryption_statuses\x18\x02 \x03(\t\x12\x1e\n\x16require_admin_approval\x18\x03 \x01(\x08\x12\x1a\n\x12require_corp_owned\x18\x04 \x01(\x08\x12\x1b\n\x13require_screen_lock\x18\x05 \x01(\x08\x12{\n\x0eos_constraints\x18\x06 \x03(\x0b\x32\x63.oak9.tython.gcp.access.AccessContextManagerAccessLevelXBasicXConditionsXDevicePolicyXOsConstraints\"\x8a\x02\n0AccessContextManagerAccessLevelXBasicXConditions\x12\x16\n\x0eip_subnetworks\x18\x01 \x03(\t\x12\x0f\n\x07members\x18\x02 \x03(\t\x12\x0e\n\x06negate\x18\x03 \x01(\x08\x12\x0f\n\x07regions\x18\x04 \x03(\t\x12\x1e\n\x16required_access_levels\x18\x05 \x03(\t\x12l\n\rdevice_policy\x18\x06 \x01(\x0b\x32U.oak9.tython.gcp.access.AccessContextManagerAccessLevelXBasicXConditionsXDevicePolicy\"\xa1\x01\n%AccessContextManagerAccessLevelXBasic\x12\x1a\n\x12\x63ombining_function\x18\x01 \x01(\t\x12\\\n\nconditions\x18\x02 \x03(\x0b\x32H.oak9.tython.gcp.access.AccessContextManagerAccessLevelXBasicXConditions\"w\n+AccessContextManagerAccessLevelXCustomXExpr\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12\r\n\x05title\x18\x04 \x01(\t\"{\n&AccessContextManagerAccessLevelXCustom\x12Q\n\x04\x65xpr\x18\x01 \x01(\x0b\x32\x43.oak9.tython.gcp.access.AccessContextManagerAccessLevelXCustomXExpr\"Z\n(AccessContextManagerAccessLevelXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\x9a\x03\n\x1f\x41\x63\x63\x65ssContextManagerAccessLevel\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0e\n\x06parent\x18\x04 \x01(\t\x12\r\n\x05title\x18\x05 \x01(\t\x12L\n\x05\x62\x61sic\x18\x06 \x01(\x0b\x32=.oak9.tython.gcp.access.AccessContextManagerAccessLevelXBasic\x12N\n\x06\x63ustom\x18\x07 \x01(\x0b\x32>.oak9.tython.gcp.access.AccessContextManagerAccessLevelXCustom\x12R\n\x08timeouts\x18\x08 \x01(\x0b\x32@.oak9.tython.gcp.access.AccessContextManagerAccessLevelXTimeouts\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"o\nCAccessContextManagerAccessLevelConditionXDevicePolicyXOsConstraints\x12\x17\n\x0fminimum_version\x18\x01 \x01(\t\x12\x0f\n\x07os_type\x18\x02 \x01(\t\"\xd4\x02\n5AccessContextManagerAccessLevelConditionXDevicePolicy\x12(\n allowed_device_management_levels\x18\x01 \x03(\t\x12#\n\x1b\x61llowed_encryption_statuses\x18\x02 \x03(\t\x12\x1e\n\x16require_admin_approval\x18\x03 \x01(\x08\x12\x1a\n\x12require_corp_owned\x18\x04 \x01(\x08\x12\x1b\n\x13require_screen_lock\x18\x05 \x01(\x08\x12s\n\x0eos_constraints\x18\x06 \x03(\x0b\x32[.oak9.tython.gcp.access.AccessContextManagerAccessLevelConditionXDevicePolicyXOsConstraints\"S\n1AccessContextManagerAccessLevelConditionXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\"\xb2\x03\n(AccessContextManagerAccessLevelCondition\x12\x14\n\x0c\x61\x63\x63\x65ss_level\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x16\n\x0eip_subnetworks\x18\x03 \x03(\t\x12\x0f\n\x07members\x18\x04 \x03(\t\x12\x0e\n\x06negate\x18\x05 \x01(\x08\x12\x0f\n\x07regions\x18\x06 \x03(\t\x12\x1e\n\x16required_access_levels\x18\x07 \x03(\t\x12\x64\n\rdevice_policy\x18\x08 \x01(\x0b\x32M.oak9.tython.gcp.access.AccessContextManagerAccessLevelConditionXDevicePolicy\x12[\n\x08timeouts\x18\t \x01(\x0b\x32I.oak9.tython.gcp.access.AccessContextManagerAccessLevelConditionXTimeouts\x12\x37\n\rresource_info\x18\n \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x85\x01\nYAccessContextManagerAccessLevelsXAccessLevelsXBasicXConditionsXDevicePolicyXOsConstraints\x12\x17\n\x0fminimum_version\x18\x01 \x01(\t\x12\x0f\n\x07os_type\x18\x02 \x01(\t\"\x81\x03\nKAccessContextManagerAccessLevelsXAccessLevelsXBasicXConditionsXDevicePolicy\x12(\n allowed_device_management_levels\x18\x01 \x03(\t\x12#\n\x1b\x61llowed_encryption_statuses\x18\x02 \x03(\t\x12\x1e\n\x16require_admin_approval\x18\x03 \x01(\x08\x12\x1a\n\x12require_corp_owned\x18\x04 \x01(\x08\x12\x1b\n\x13require_screen_lock\x18\x05 \x01(\x08\x12\x89\x01\n\x0eos_constraints\x18\x06 \x03(\x0b\x32q.oak9.tython.gcp.access.AccessContextManagerAccessLevelsXAccessLevelsXBasicXConditionsXDevicePolicyXOsConstraints\"\xa6\x02\n>AccessContextManagerAccessLevelsXAccessLevelsXBasicXConditions\x12\x16\n\x0eip_subnetworks\x18\x01 \x03(\t\x12\x0f\n\x07members\x18\x02 \x03(\t\x12\x0e\n\x06negate\x18\x03 \x01(\x08\x12\x0f\n\x07regions\x18\x04 \x03(\t\x12\x1e\n\x16required_access_levels\x18\x05 \x03(\t\x12z\n\rdevice_policy\x18\x06 \x01(\x0b\x32\x63.oak9.tython.gcp.access.AccessContextManagerAccessLevelsXAccessLevelsXBasicXConditionsXDevicePolicy\"\xbd\x01\n3AccessContextManagerAccessLevelsXAccessLevelsXBasic\x12\x1a\n\x12\x63ombining_function\x18\x01 \x01(\t\x12j\n\nconditions\x18\x02 \x03(\x0b\x32V.oak9.tython.gcp.access.AccessContextManagerAccessLevelsXAccessLevelsXBasicXConditions\"\x85\x01\n9AccessContextManagerAccessLevelsXAccessLevelsXCustomXExpr\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12\r\n\x05title\x18\x04 \x01(\t\"\x97\x01\n4AccessContextManagerAccessLevelsXAccessLevelsXCustom\x12_\n\x04\x65xpr\x18\x01 \x01(\x0b\x32Q.oak9.tython.gcp.access.AccessContextManagerAccessLevelsXAccessLevelsXCustomXExpr\"\x9b\x02\n-AccessContextManagerAccessLevelsXAccessLevels\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\x12Z\n\x05\x62\x61sic\x18\x04 \x01(\x0b\x32K.oak9.tython.gcp.access.AccessContextManagerAccessLevelsXAccessLevelsXBasic\x12\\\n\x06\x63ustom\x18\x05 \x01(\x0b\x32L.oak9.tython.gcp.access.AccessContextManagerAccessLevelsXAccessLevelsXCustom\"[\n)AccessContextManagerAccessLevelsXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xaa\x02\n AccessContextManagerAccessLevels\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0e\n\x06parent\x18\x02 \x01(\t\x12\\\n\raccess_levels\x18\x03 \x03(\x0b\x32\x45.oak9.tython.gcp.access.AccessContextManagerAccessLevelsXAccessLevels\x12S\n\x08timeouts\x18\x04 \x01(\x0b\x32\x41.oak9.tython.gcp.access.AccessContextManagerAccessLevelsXTimeouts\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"[\n)AccessContextManagerAccessPolicyXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xa3\x02\n AccessContextManagerAccessPolicy\x12\x13\n\x0b\x63reate_time\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0e\n\x06parent\x18\x04 \x01(\t\x12\x0e\n\x06scopes\x18\x05 \x03(\t\x12\r\n\x05title\x18\x06 \x01(\t\x12\x13\n\x0bupdate_time\x18\x07 \x01(\t\x12S\n\x08timeouts\x18\x08 \x01(\x0b\x32\x41.oak9.tython.gcp.access.AccessContextManagerAccessPolicyXTimeouts\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"n\n4AccessContextManagerAccessPolicyIamBindingXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\x8d\x02\n*AccessContextManagerAccessPolicyIamBinding\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0f\n\x07members\x18\x03 \x03(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0c\n\x04role\x18\x05 \x01(\t\x12_\n\tcondition\x18\x06 \x01(\x0b\x32L.oak9.tython.gcp.access.AccessContextManagerAccessPolicyIamBindingXCondition\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"m\n3AccessContextManagerAccessPolicyIamMemberXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\x8a\x02\n)AccessContextManagerAccessPolicyIamMember\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0e\n\x06member\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0c\n\x04role\x18\x05 \x01(\t\x12^\n\tcondition\x18\x06 \x01(\x0b\x32K.oak9.tython.gcp.access.AccessContextManagerAccessPolicyIamMemberXCondition\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xa1\x01\n)AccessContextManagerAccessPolicyIamPolicy\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0bpolicy_data\x18\x04 \x01(\t\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"c\n1AccessContextManagerGcpUserAccessBindingXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\x9d\x02\n(AccessContextManagerGcpUserAccessBinding\x12\x15\n\raccess_levels\x18\x01 \x03(\t\x12\x11\n\tgroup_key\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x17\n\x0forganization_id\x18\x05 \x01(\t\x12[\n\x08timeouts\x18\x06 \x01(\x0b\x32I.oak9.tython.gcp.access.AccessContextManagerGcpUserAccessBindingXTimeouts\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"p\nCAccessContextManagerServicePerimeterXSpecXEgressPoliciesXEgressFrom\x12\x12\n\nidentities\x18\x01 \x03(\t\x12\x15\n\ridentity_type\x18\x02 \x01(\t\"\x82\x01\n\\AccessContextManagerServicePerimeterXSpecXEgressPoliciesXEgressToXOperationsXMethodSelectors\x12\x0e\n\x06method\x18\x01 \x01(\t\x12\x12\n\npermission\x18\x02 \x01(\t\"\xf5\x01\nLAccessContextManagerServicePerimeterXSpecXEgressPoliciesXEgressToXOperations\x12\x14\n\x0cservice_name\x18\x01 \x01(\t\x12\x8e\x01\n\x10method_selectors\x18\x02 \x03(\x0b\x32t.oak9.tython.gcp.access.AccessContextManagerServicePerimeterXSpecXEgressPoliciesXEgressToXOperationsXMethodSelectors\"\xec\x01\nAAccessContextManagerServicePerimeterXSpecXEgressPoliciesXEgressTo\x12\x1a\n\x12\x65xternal_resources\x18\x01 \x03(\t\x12\x11\n\tresources\x18\x02 \x03(\t\x12x\n\noperations\x18\x03 \x03(\x0b\x32\x64.oak9.tython.gcp.access.AccessContextManagerServicePerimeterXSpecXEgressPoliciesXEgressToXOperations\"\x9a\x02\n8AccessContextManagerServicePerimeterXSpecXEgressPolicies\x12p\n\x0b\x65gress_from\x18\x01 \x01(\x0b\x32[.oak9.tython.gcp.access.AccessContextManagerServicePerimeterXSpecXEgressPoliciesXEgressFrom\x12l\n\tegress_to\x18\x02 \x01(\x0b\x32Y.oak9.tython.gcp.access.AccessContextManagerServicePerimeterXSpecXEgressPoliciesXEgressTo\"w\nMAccessContextManagerServicePerimeterXSpecXIngressPoliciesXIngressFromXSources\x12\x14\n\x0c\x61\x63\x63\x65ss_level\x18\x01 \x01(\t\x12\x10\n\x08resource\x18\x02 \x01(\t\"\xea\x01\nEAccessContextManagerServicePerimeterXSpecXIngressPoliciesXIngressFrom\x12\x12\n\nidentities\x18\x01 \x03(\t\x12\x15\n\ridentity_type\x18\x02 \x01(\t\x12v\n\x07sources\x18\x03 \x03(\x0b\x32\x65.oak9.tython.gcp.access.AccessContextManagerServicePerimeterXSpecXIngressPoliciesXIngressFromXSources\"\x84\x01\n^AccessContextManagerServicePerimeterXSpecXIngressPoliciesXIngressToXOperationsXMethodSelectors\x12\x0e\n\x06method\x18\x01 \x01(\t\x12\x12\n\npermission\x18\x02 \x01(\t\"\xf9\x01\nNAccessContextManagerServicePerimeterXSpecXIngressPoliciesXIngressToXOperations\x12\x14\n\x0cservice_name\x18\x01 \x01(\t\x12\x90\x01\n\x10method_selectors\x18\x02 \x03(\x0b\x32v.oak9.tython.gcp.access.AccessContextManagerServicePerimeterXSpecXIngressPoliciesXIngressToXOperationsXMethodSelectors\"\xd4\x01\nCAccessContextManagerServicePerimeterXSpecXIngressPoliciesXIngressTo\x12\x11\n\tresources\x18\x01 \x03(\t\x12z\n\noperations\x18\x02 \x03(\x0b\x32\x66.oak9.tython.gcp.access.AccessContextManagerServicePerimeterXSpecXIngressPoliciesXIngressToXOperations\"\xa1\x02\n9AccessContextManagerServicePerimeterXSpecXIngressPolicies\x12s\n\x0cingress_from\x18\x01 \x01(\x0b\x32].oak9.tython.gcp.access.AccessContextManagerServicePerimeterXSpecXIngressPoliciesXIngressFrom\x12o\n\ningress_to\x18\x02 \x01(\x0b\x32[.oak9.tython.gcp.access.AccessContextManagerServicePerimeterXSpecXIngressPoliciesXIngressTo\"w\n?AccessContextManagerServicePerimeterXSpecXVpcAccessibleServices\x12\x18\n\x10\x61llowed_services\x18\x01 \x03(\t\x12\x1a\n\x12\x65nable_restriction\x18\x02 \x01(\x08\"\xc4\x03\n)AccessContextManagerServicePerimeterXSpec\x12\x15\n\raccess_levels\x18\x01 \x03(\t\x12\x11\n\tresources\x18\x02 \x03(\t\x12\x1b\n\x13restricted_services\x18\x03 \x03(\t\x12i\n\x0f\x65gress_policies\x18\x04 \x03(\x0b\x32P.oak9.tython.gcp.access.AccessContextManagerServicePerimeterXSpecXEgressPolicies\x12k\n\x10ingress_policies\x18\x05 \x03(\x0b\x32Q.oak9.tython.gcp.access.AccessContextManagerServicePerimeterXSpecXIngressPolicies\x12x\n\x17vpc_accessible_services\x18\x06 \x01(\x0b\x32W.oak9.tython.gcp.access.AccessContextManagerServicePerimeterXSpecXVpcAccessibleServices\"r\nEAccessContextManagerServicePerimeterXStatusXEgressPoliciesXEgressFrom\x12\x12\n\nidentities\x18\x01 \x03(\t\x12\x15\n\ridentity_type\x18\x02 \x01(\t\"\x84\x01\n^AccessContextManagerServicePerimeterXStatusXEgressPoliciesXEgressToXOperationsXMethodSelectors\x12\x0e\n\x06method\x18\x01 \x01(\t\x12\x12\n\npermission\x18\x02 \x01(\t\"\xf9\x01\nNAccessContextManagerServicePerimeterXStatusXEgressPoliciesXEgressToXOperations\x12\x14\n\x0cservice_name\x18\x01 \x01(\t\x12\x90\x01\n\x10method_selectors\x18\x02 \x03(\x0b\x32v.oak9.tython.gcp.access.AccessContextManagerServicePerimeterXStatusXEgressPoliciesXEgressToXOperationsXMethodSelectors\"\xf0\x01\nCAccessContextManagerServicePerimeterXStatusXEgressPoliciesXEgressTo\x12\x1a\n\x12\x65xternal_resources\x18\x01 \x03(\t\x12\x11\n\tresources\x18\x02 \x03(\t\x12z\n\noperations\x18\x03 \x03(\x0b\x32\x66.oak9.tython.gcp.access.AccessContextManagerServicePerimeterXStatusXEgressPoliciesXEgressToXOperations\"\xa0\x02\n:AccessContextManagerServicePerimeterXStatusXEgressPolicies\x12r\n\x0b\x65gress_from\x18\x01 \x01(\x0b\x32].oak9.tython.gcp.access.AccessContextManagerServicePerimeterXStatusXEgressPoliciesXEgressFrom\x12n\n\tegress_to\x18\x02 \x01(\x0b\x32[.oak9.tython.gcp.access.AccessContextManagerServicePerimeterXStatusXEgressPoliciesXEgressTo\"y\nOAccessContextManagerServicePerimeterXStatusXIngressPoliciesXIngressFromXSources\x12\x14\n\x0c\x61\x63\x63\x65ss_level\x18\x01 \x01(\t\x12\x10\n\x08resource\x18\x02 \x01(\t\"\xee\x01\nGAccessContextManagerServicePerimeterXStatusXIngressPoliciesXIngressFrom\x12\x12\n\nidentities\x18\x01 \x03(\t\x12\x15\n\ridentity_type\x18\x02 \x01(\t\x12x\n\x07sources\x18\x03 \x03(\x0b\x32g.oak9.tython.gcp.access.AccessContextManagerServicePerimeterXStatusXIngressPoliciesXIngressFromXSources\"\x86\x01\n`AccessContextManagerServicePerimeterXStatusXIngressPoliciesXIngressToXOperationsXMethodSelectors\x12\x0e\n\x06method\x18\x01 \x01(\t\x12\x12\n\npermission\x18\x02 \x01(\t\"\xfd\x01\nPAccessContextManagerServicePerimeterXStatusXIngressPoliciesXIngressToXOperations\x12\x14\n\x0cservice_name\x18\x01 \x01(\t\x12\x92\x01\n\x10method_selectors\x18\x02 \x03(\x0b\x32x.oak9.tython.gcp.access.AccessContextManagerServicePerimeterXStatusXIngressPoliciesXIngressToXOperationsXMethodSelectors\"\xd8\x01\nEAccessContextManagerServicePerimeterXStatusXIngressPoliciesXIngressTo\x12\x11\n\tresources\x18\x01 \x03(\t\x12|\n\noperations\x18\x02 \x03(\x0b\x32h.oak9.tython.gcp.access.AccessContextManagerServicePerimeterXStatusXIngressPoliciesXIngressToXOperations\"\xa7\x02\n;AccessContextManagerServicePerimeterXStatusXIngressPolicies\x12u\n\x0cingress_from\x18\x01 \x01(\x0b\x32_.oak9.tython.gcp.access.AccessContextManagerServicePerimeterXStatusXIngressPoliciesXIngressFrom\x12q\n\ningress_to\x18\x02 \x01(\x0b\x32].oak9.tython.gcp.access.AccessContextManagerServicePerimeterXStatusXIngressPoliciesXIngressTo\"y\nAAccessContextManagerServicePerimeterXStatusXVpcAccessibleServices\x12\x18\n\x10\x61llowed_services\x18\x01 \x03(\t\x12\x1a\n\x12\x65nable_restriction\x18\x02 \x01(\x08\"\xcc\x03\n+AccessContextManagerServicePerimeterXStatus\x12\x15\n\raccess_levels\x18\x01 \x03(\t\x12\x11\n\tresources\x18\x02 \x03(\t\x12\x1b\n\x13restricted_services\x18\x03 \x03(\t\x12k\n\x0f\x65gress_policies\x18\x04 \x03(\x0b\x32R.oak9.tython.gcp.access.AccessContextManagerServicePerimeterXStatusXEgressPolicies\x12m\n\x10ingress_policies\x18\x05 \x03(\x0b\x32S.oak9.tython.gcp.access.AccessContextManagerServicePerimeterXStatusXIngressPolicies\x12z\n\x17vpc_accessible_services\x18\x06 \x01(\x0b\x32Y.oak9.tython.gcp.access.AccessContextManagerServicePerimeterXStatusXVpcAccessibleServices\"_\n-AccessContextManagerServicePerimeterXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\x91\x04\n$AccessContextManagerServicePerimeter\x12\x13\n\x0b\x63reate_time\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0e\n\x06parent\x18\x05 \x01(\t\x12\x16\n\x0eperimeter_type\x18\x06 \x01(\t\x12\r\n\x05title\x18\x07 \x01(\t\x12\x13\n\x0bupdate_time\x18\x08 \x01(\t\x12!\n\x19use_explicit_dry_run_spec\x18\t \x01(\x08\x12O\n\x04spec\x18\n \x01(\x0b\x32\x41.oak9.tython.gcp.access.AccessContextManagerServicePerimeterXSpec\x12S\n\x06status\x18\x0b \x01(\x0b\x32\x43.oak9.tython.gcp.access.AccessContextManagerServicePerimeterXStatus\x12W\n\x08timeouts\x18\x0c \x01(\x0b\x32\x45.oak9.tython.gcp.access.AccessContextManagerServicePerimeterXTimeouts\x12\x37\n\rresource_info\x18\r \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"W\n5AccessContextManagerServicePerimeterResourceXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\"\xfe\x01\n,AccessContextManagerServicePerimeterResource\x12\n\n\x02id\x18\x01 \x01(\t\x12\x16\n\x0eperimeter_name\x18\x02 \x01(\t\x12\x10\n\x08resource\x18\x03 \x01(\t\x12_\n\x08timeouts\x18\x04 \x01(\x0b\x32M.oak9.tython.gcp.access.AccessContextManagerServicePerimeterResourceXTimeouts\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x83\x01\nVAccessContextManagerServicePerimetersXServicePerimetersXSpecXEgressPoliciesXEgressFrom\x12\x12\n\nidentities\x18\x01 \x03(\t\x12\x15\n\ridentity_type\x18\x02 \x01(\t\"\x95\x01\noAccessContextManagerServicePerimetersXServicePerimetersXSpecXEgressPoliciesXEgressToXOperationsXMethodSelectors\x12\x0e\n\x06method\x18\x01 \x01(\t\x12\x12\n\npermission\x18\x02 \x01(\t\"\x9c\x02\n_AccessContextManagerServicePerimetersXServicePerimetersXSpecXEgressPoliciesXEgressToXOperations\x12\x14\n\x0cservice_name\x18\x01 \x01(\t\x12\xa2\x01\n\x10method_selectors\x18\x02 \x03(\x0b\x32\x87\x01.oak9.tython.gcp.access.AccessContextManagerServicePerimetersXServicePerimetersXSpecXEgressPoliciesXEgressToXOperationsXMethodSelectors\"\x93\x02\nTAccessContextManagerServicePerimetersXServicePerimetersXSpecXEgressPoliciesXEgressTo\x12\x1a\n\x12\x65xternal_resources\x18\x01 \x03(\t\x12\x11\n\tresources\x18\x02 \x03(\t\x12\x8b\x01\n\noperations\x18\x03 \x03(\x0b\x32w.oak9.tython.gcp.access.AccessContextManagerServicePerimetersXServicePerimetersXSpecXEgressPoliciesXEgressToXOperations\"\xd4\x02\nKAccessContextManagerServicePerimetersXServicePerimetersXSpecXEgressPolicies\x12\x83\x01\n\x0b\x65gress_from\x18\x01 \x01(\x0b\x32n.oak9.tython.gcp.access.AccessContextManagerServicePerimetersXServicePerimetersXSpecXEgressPoliciesXEgressFrom\x12\x7f\n\tegress_to\x18\x02 \x01(\x0b\x32l.oak9.tython.gcp.access.AccessContextManagerServicePerimetersXServicePerimetersXSpecXEgressPoliciesXEgressTo\"\x8a\x01\n`AccessContextManagerServicePerimetersXServicePerimetersXSpecXIngressPoliciesXIngressFromXSources\x12\x14\n\x0c\x61\x63\x63\x65ss_level\x18\x01 \x01(\t\x12\x10\n\x08resource\x18\x02 \x01(\t\"\x91\x02\nXAccessContextManagerServicePerimetersXServicePerimetersXSpecXIngressPoliciesXIngressFrom\x12\x12\n\nidentities\x18\x01 \x03(\t\x12\x15\n\ridentity_type\x18\x02 \x01(\t\x12\x89\x01\n\x07sources\x18\x03 \x03(\x0b\x32x.oak9.tython.gcp.access.AccessContextManagerServicePerimetersXServicePerimetersXSpecXIngressPoliciesXIngressFromXSources\"\x97\x01\nqAccessContextManagerServicePerimetersXServicePerimetersXSpecXIngressPoliciesXIngressToXOperationsXMethodSelectors\x12\x0e\n\x06method\x18\x01 \x01(\t\x12\x12\n\npermission\x18\x02 \x01(\t\"\xa0\x02\naAccessContextManagerServicePerimetersXServicePerimetersXSpecXIngressPoliciesXIngressToXOperations\x12\x14\n\x0cservice_name\x18\x01 \x01(\t\x12\xa4\x01\n\x10method_selectors\x18\x02 \x03(\x0b\x32\x89\x01.oak9.tython.gcp.access.AccessContextManagerServicePerimetersXServicePerimetersXSpecXIngressPoliciesXIngressToXOperationsXMethodSelectors\"\xfb\x01\nVAccessContextManagerServicePerimetersXServicePerimetersXSpecXIngressPoliciesXIngressTo\x12\x11\n\tresources\x18\x01 \x03(\t\x12\x8d\x01\n\noperations\x18\x02 \x03(\x0b\x32y.oak9.tython.gcp.access.AccessContextManagerServicePerimetersXServicePerimetersXSpecXIngressPoliciesXIngressToXOperations\"\xdc\x02\nLAccessContextManagerServicePerimetersXServicePerimetersXSpecXIngressPolicies\x12\x86\x01\n\x0cingress_from\x18\x01 \x01(\x0b\x32p.oak9.tython.gcp.access.AccessContextManagerServicePerimetersXServicePerimetersXSpecXIngressPoliciesXIngressFrom\x12\x82\x01\n\ningress_to\x18\x02 \x01(\x0b\x32n.oak9.tython.gcp.access.AccessContextManagerServicePerimetersXServicePerimetersXSpecXIngressPoliciesXIngressTo\"\x8a\x01\nRAccessContextManagerServicePerimetersXServicePerimetersXSpecXVpcAccessibleServices\x12\x18\n\x10\x61llowed_services\x18\x01 \x03(\t\x12\x1a\n\x12\x65nable_restriction\x18\x02 \x01(\x08\"\x91\x04\n<AccessContextManagerServicePerimetersXServicePerimetersXSpec\x12\x15\n\raccess_levels\x18\x01 \x03(\t\x12\x11\n\tresources\x18\x02 \x03(\t\x12\x1b\n\x13restricted_services\x18\x03 \x03(\t\x12|\n\x0f\x65gress_policies\x18\x04 \x03(\x0b\x32\x63.oak9.tython.gcp.access.AccessContextManagerServicePerimetersXServicePerimetersXSpecXEgressPolicies\x12~\n\x10ingress_policies\x18\x05 \x03(\x0b\x32\x64.oak9.tython.gcp.access.AccessContextManagerServicePerimetersXServicePerimetersXSpecXIngressPolicies\x12\x8b\x01\n\x17vpc_accessible_services\x18\x06 \x01(\x0b\x32j.oak9.tython.gcp.access.AccessContextManagerServicePerimetersXServicePerimetersXSpecXVpcAccessibleServices\"\x85\x01\nXAccessContextManagerServicePerimetersXServicePerimetersXStatusXEgressPoliciesXEgressFrom\x12\x12\n\nidentities\x18\x01 \x03(\t\x12\x15\n\ridentity_type\x18\x02 \x01(\t\"\x97\x01\nqAccessContextManagerServicePerimetersXServicePerimetersXStatusXEgressPoliciesXEgressToXOperationsXMethodSelectors\x12\x0e\n\x06method\x18\x01 \x01(\t\x12\x12\n\npermission\x18\x02 \x01(\t\"\xa0\x02\naAccessContextManagerServicePerimetersXServicePerimetersXStatusXEgressPoliciesXEgressToXOperations\x12\x14\n\x0cservice_name\x18\x01 \x01(\t\x12\xa4\x01\n\x10method_selectors\x18\x02 \x03(\x0b\x32\x89\x01.oak9.tython.gcp.access.AccessContextManagerServicePerimetersXServicePerimetersXStatusXEgressPoliciesXEgressToXOperationsXMethodSelectors\"\x97\x02\nVAccessContextManagerServicePerimetersXServicePerimetersXStatusXEgressPoliciesXEgressTo\x12\x1a\n\x12\x65xternal_resources\x18\x01 \x03(\t\x12\x11\n\tresources\x18\x02 \x03(\t\x12\x8d\x01\n\noperations\x18\x03 \x03(\x0b\x32y.oak9.tython.gcp.access.AccessContextManagerServicePerimetersXServicePerimetersXStatusXEgressPoliciesXEgressToXOperations\"\xdb\x02\nMAccessContextManagerServicePerimetersXServicePerimetersXStatusXEgressPolicies\x12\x85\x01\n\x0b\x65gress_from\x18\x01 \x01(\x0b\x32p.oak9.tython.gcp.access.AccessContextManagerServicePerimetersXServicePerimetersXStatusXEgressPoliciesXEgressFrom\x12\x81\x01\n\tegress_to\x18\x02 \x01(\x0b\x32n.oak9.tython.gcp.access.AccessContextManagerServicePerimetersXServicePerimetersXStatusXEgressPoliciesXEgressTo\"\x8c\x01\nbAccessContextManagerServicePerimetersXServicePerimetersXStatusXIngressPoliciesXIngressFromXSources\x12\x14\n\x0c\x61\x63\x63\x65ss_level\x18\x01 \x01(\t\x12\x10\n\x08resource\x18\x02 \x01(\t\"\x95\x02\nZAccessContextManagerServicePerimetersXServicePerimetersXStatusXIngressPoliciesXIngressFrom\x12\x12\n\nidentities\x18\x01 \x03(\t\x12\x15\n\ridentity_type\x18\x02 \x01(\t\x12\x8b\x01\n\x07sources\x18\x03 \x03(\x0b\x32z.oak9.tython.gcp.access.AccessContextManagerServicePerimetersXServicePerimetersXStatusXIngressPoliciesXIngressFromXSources\"\x99\x01\nsAccessContextManagerServicePerimetersXServicePerimetersXStatusXIngressPoliciesXIngressToXOperationsXMethodSelectors\x12\x0e\n\x06method\x18\x01 \x01(\t\x12\x12\n\npermission\x18\x02 \x01(\t\"\xa4\x02\ncAccessContextManagerServicePerimetersXServicePerimetersXStatusXIngressPoliciesXIngressToXOperations\x12\x14\n\x0cservice_name\x18\x01 \x01(\t\x12\xa6\x01\n\x10method_selectors\x18\x02 \x03(\x0b\x32\x8b\x01.oak9.tython.gcp.access.AccessContextManagerServicePerimetersXServicePerimetersXStatusXIngressPoliciesXIngressToXOperationsXMethodSelectors\"\xff\x01\nXAccessContextManagerServicePerimetersXServicePerimetersXStatusXIngressPoliciesXIngressTo\x12\x11\n\tresources\x18\x01 \x03(\t\x12\x8f\x01\n\noperations\x18\x02 \x03(\x0b\x32{.oak9.tython.gcp.access.AccessContextManagerServicePerimetersXServicePerimetersXStatusXIngressPoliciesXIngressToXOperations\"\xe2\x02\nNAccessContextManagerServicePerimetersXServicePerimetersXStatusXIngressPolicies\x12\x88\x01\n\x0cingress_from\x18\x01 \x01(\x0b\x32r.oak9.tython.gcp.access.AccessContextManagerServicePerimetersXServicePerimetersXStatusXIngressPoliciesXIngressFrom\x12\x84\x01\n\ningress_to\x18\x02 \x01(\x0b\x32p.oak9.tython.gcp.access.AccessContextManagerServicePerimetersXServicePerimetersXStatusXIngressPoliciesXIngressTo\"\x8c\x01\nTAccessContextManagerServicePerimetersXServicePerimetersXStatusXVpcAccessibleServices\x12\x18\n\x10\x61llowed_services\x18\x01 \x03(\t\x12\x1a\n\x12\x65nable_restriction\x18\x02 \x01(\x08\"\x9a\x04\n>AccessContextManagerServicePerimetersXServicePerimetersXStatus\x12\x15\n\raccess_levels\x18\x01 \x03(\t\x12\x11\n\tresources\x18\x02 \x03(\t\x12\x1b\n\x13restricted_services\x18\x03 \x03(\t\x12~\n\x0f\x65gress_policies\x18\x04 \x03(\x0b\x32\x65.oak9.tython.gcp.access.AccessContextManagerServicePerimetersXServicePerimetersXStatusXEgressPolicies\x12\x80\x01\n\x10ingress_policies\x18\x05 \x03(\x0b\x32\x66.oak9.tython.gcp.access.AccessContextManagerServicePerimetersXServicePerimetersXStatusXIngressPolicies\x12\x8d\x01\n\x17vpc_accessible_services\x18\x06 \x01(\x0b\x32l.oak9.tython.gcp.access.AccessContextManagerServicePerimetersXServicePerimetersXStatusXVpcAccessibleServices\"\x9c\x03\n7AccessContextManagerServicePerimetersXServicePerimeters\x12\x13\n\x0b\x63reate_time\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x16\n\x0eperimeter_type\x18\x04 \x01(\t\x12\r\n\x05title\x18\x05 \x01(\t\x12\x13\n\x0bupdate_time\x18\x06 \x01(\t\x12!\n\x19use_explicit_dry_run_spec\x18\x07 \x01(\x08\x12\x62\n\x04spec\x18\x08 \x01(\x0b\x32T.oak9.tython.gcp.access.AccessContextManagerServicePerimetersXServicePerimetersXSpec\x12\x66\n\x06status\x18\t \x01(\x0b\x32V.oak9.tython.gcp.access.AccessContextManagerServicePerimetersXServicePerimetersXStatus\"`\n.AccessContextManagerServicePerimetersXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xc3\x02\n%AccessContextManagerServicePerimeters\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0e\n\x06parent\x18\x02 \x01(\t\x12k\n\x12service_perimeters\x18\x03 \x03(\x0b\x32O.oak9.tython.gcp.access.AccessContextManagerServicePerimetersXServicePerimeters\x12X\n\x08timeouts\x18\x04 \x01(\x0b\x32\x46.oak9.tython.gcp.access.AccessContextManagerServicePerimetersXTimeouts\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_access_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ACCESSCONTEXTMANAGERACCESSLEVELXBASICXCONDITIONSXDEVICEPOLICYXOSCONSTRAINTS._serialized_start=70
  _ACCESSCONTEXTMANAGERACCESSLEVELXBASICXCONDITIONSXDEVICEPOLICYXOSCONSTRAINTS._serialized_end=225
  _ACCESSCONTEXTMANAGERACCESSLEVELXBASICXCONDITIONSXDEVICEPOLICY._serialized_start=228
  _ACCESSCONTEXTMANAGERACCESSLEVELXBASICXCONDITIONSXDEVICEPOLICY._serialized_end=584
  _ACCESSCONTEXTMANAGERACCESSLEVELXBASICXCONDITIONS._serialized_start=587
  _ACCESSCONTEXTMANAGERACCESSLEVELXBASICXCONDITIONS._serialized_end=853
  _ACCESSCONTEXTMANAGERACCESSLEVELXBASIC._serialized_start=856
  _ACCESSCONTEXTMANAGERACCESSLEVELXBASIC._serialized_end=1017
  _ACCESSCONTEXTMANAGERACCESSLEVELXCUSTOMXEXPR._serialized_start=1019
  _ACCESSCONTEXTMANAGERACCESSLEVELXCUSTOMXEXPR._serialized_end=1138
  _ACCESSCONTEXTMANAGERACCESSLEVELXCUSTOM._serialized_start=1140
  _ACCESSCONTEXTMANAGERACCESSLEVELXCUSTOM._serialized_end=1263
  _ACCESSCONTEXTMANAGERACCESSLEVELXTIMEOUTS._serialized_start=1265
  _ACCESSCONTEXTMANAGERACCESSLEVELXTIMEOUTS._serialized_end=1355
  _ACCESSCONTEXTMANAGERACCESSLEVEL._serialized_start=1358
  _ACCESSCONTEXTMANAGERACCESSLEVEL._serialized_end=1768
  _ACCESSCONTEXTMANAGERACCESSLEVELCONDITIONXDEVICEPOLICYXOSCONSTRAINTS._serialized_start=1770
  _ACCESSCONTEXTMANAGERACCESSLEVELCONDITIONXDEVICEPOLICYXOSCONSTRAINTS._serialized_end=1881
  _ACCESSCONTEXTMANAGERACCESSLEVELCONDITIONXDEVICEPOLICY._serialized_start=1884
  _ACCESSCONTEXTMANAGERACCESSLEVELCONDITIONXDEVICEPOLICY._serialized_end=2224
  _ACCESSCONTEXTMANAGERACCESSLEVELCONDITIONXTIMEOUTS._serialized_start=2226
  _ACCESSCONTEXTMANAGERACCESSLEVELCONDITIONXTIMEOUTS._serialized_end=2309
  _ACCESSCONTEXTMANAGERACCESSLEVELCONDITION._serialized_start=2312
  _ACCESSCONTEXTMANAGERACCESSLEVELCONDITION._serialized_end=2746
  _ACCESSCONTEXTMANAGERACCESSLEVELSXACCESSLEVELSXBASICXCONDITIONSXDEVICEPOLICYXOSCONSTRAINTS._serialized_start=2749
  _ACCESSCONTEXTMANAGERACCESSLEVELSXACCESSLEVELSXBASICXCONDITIONSXDEVICEPOLICYXOSCONSTRAINTS._serialized_end=2882
  _ACCESSCONTEXTMANAGERACCESSLEVELSXACCESSLEVELSXBASICXCONDITIONSXDEVICEPOLICY._serialized_start=2885
  _ACCESSCONTEXTMANAGERACCESSLEVELSXACCESSLEVELSXBASICXCONDITIONSXDEVICEPOLICY._serialized_end=3270
  _ACCESSCONTEXTMANAGERACCESSLEVELSXACCESSLEVELSXBASICXCONDITIONS._serialized_start=3273
  _ACCESSCONTEXTMANAGERACCESSLEVELSXACCESSLEVELSXBASICXCONDITIONS._serialized_end=3567
  _ACCESSCONTEXTMANAGERACCESSLEVELSXACCESSLEVELSXBASIC._serialized_start=3570
  _ACCESSCONTEXTMANAGERACCESSLEVELSXACCESSLEVELSXBASIC._serialized_end=3759
  _ACCESSCONTEXTMANAGERACCESSLEVELSXACCESSLEVELSXCUSTOMXEXPR._serialized_start=3762
  _ACCESSCONTEXTMANAGERACCESSLEVELSXACCESSLEVELSXCUSTOMXEXPR._serialized_end=3895
  _ACCESSCONTEXTMANAGERACCESSLEVELSXACCESSLEVELSXCUSTOM._serialized_start=3898
  _ACCESSCONTEXTMANAGERACCESSLEVELSXACCESSLEVELSXCUSTOM._serialized_end=4049
  _ACCESSCONTEXTMANAGERACCESSLEVELSXACCESSLEVELS._serialized_start=4052
  _ACCESSCONTEXTMANAGERACCESSLEVELSXACCESSLEVELS._serialized_end=4335
  _ACCESSCONTEXTMANAGERACCESSLEVELSXTIMEOUTS._serialized_start=4337
  _ACCESSCONTEXTMANAGERACCESSLEVELSXTIMEOUTS._serialized_end=4428
  _ACCESSCONTEXTMANAGERACCESSLEVELS._serialized_start=4431
  _ACCESSCONTEXTMANAGERACCESSLEVELS._serialized_end=4729
  _ACCESSCONTEXTMANAGERACCESSPOLICYXTIMEOUTS._serialized_start=4731
  _ACCESSCONTEXTMANAGERACCESSPOLICYXTIMEOUTS._serialized_end=4822
  _ACCESSCONTEXTMANAGERACCESSPOLICY._serialized_start=4825
  _ACCESSCONTEXTMANAGERACCESSPOLICY._serialized_end=5116
  _ACCESSCONTEXTMANAGERACCESSPOLICYIAMBINDINGXCONDITION._serialized_start=5118
  _ACCESSCONTEXTMANAGERACCESSPOLICYIAMBINDINGXCONDITION._serialized_end=5228
  _ACCESSCONTEXTMANAGERACCESSPOLICYIAMBINDING._serialized_start=5231
  _ACCESSCONTEXTMANAGERACCESSPOLICYIAMBINDING._serialized_end=5500
  _ACCESSCONTEXTMANAGERACCESSPOLICYIAMMEMBERXCONDITION._serialized_start=5502
  _ACCESSCONTEXTMANAGERACCESSPOLICYIAMMEMBERXCONDITION._serialized_end=5611
  _ACCESSCONTEXTMANAGERACCESSPOLICYIAMMEMBER._serialized_start=5614
  _ACCESSCONTEXTMANAGERACCESSPOLICYIAMMEMBER._serialized_end=5880
  _ACCESSCONTEXTMANAGERACCESSPOLICYIAMPOLICY._serialized_start=5883
  _ACCESSCONTEXTMANAGERACCESSPOLICYIAMPOLICY._serialized_end=6044
  _ACCESSCONTEXTMANAGERGCPUSERACCESSBINDINGXTIMEOUTS._serialized_start=6046
  _ACCESSCONTEXTMANAGERGCPUSERACCESSBINDINGXTIMEOUTS._serialized_end=6145
  _ACCESSCONTEXTMANAGERGCPUSERACCESSBINDING._serialized_start=6148
  _ACCESSCONTEXTMANAGERGCPUSERACCESSBINDING._serialized_end=6433
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERXSPECXEGRESSPOLICIESXEGRESSFROM._serialized_start=6435
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERXSPECXEGRESSPOLICIESXEGRESSFROM._serialized_end=6547
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERXSPECXEGRESSPOLICIESXEGRESSTOXOPERATIONSXMETHODSELECTORS._serialized_start=6550
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERXSPECXEGRESSPOLICIESXEGRESSTOXOPERATIONSXMETHODSELECTORS._serialized_end=6680
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERXSPECXEGRESSPOLICIESXEGRESSTOXOPERATIONS._serialized_start=6683
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERXSPECXEGRESSPOLICIESXEGRESSTOXOPERATIONS._serialized_end=6928
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERXSPECXEGRESSPOLICIESXEGRESSTO._serialized_start=6931
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERXSPECXEGRESSPOLICIESXEGRESSTO._serialized_end=7167
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERXSPECXEGRESSPOLICIES._serialized_start=7170
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERXSPECXEGRESSPOLICIES._serialized_end=7452
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERXSPECXINGRESSPOLICIESXINGRESSFROMXSOURCES._serialized_start=7454
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERXSPECXINGRESSPOLICIESXINGRESSFROMXSOURCES._serialized_end=7573
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERXSPECXINGRESSPOLICIESXINGRESSFROM._serialized_start=7576
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERXSPECXINGRESSPOLICIESXINGRESSFROM._serialized_end=7810
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERXSPECXINGRESSPOLICIESXINGRESSTOXOPERATIONSXMETHODSELECTORS._serialized_start=7813
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERXSPECXINGRESSPOLICIESXINGRESSTOXOPERATIONSXMETHODSELECTORS._serialized_end=7945
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERXSPECXINGRESSPOLICIESXINGRESSTOXOPERATIONS._serialized_start=7948
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERXSPECXINGRESSPOLICIESXINGRESSTOXOPERATIONS._serialized_end=8197
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERXSPECXINGRESSPOLICIESXINGRESSTO._serialized_start=8200
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERXSPECXINGRESSPOLICIESXINGRESSTO._serialized_end=8412
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERXSPECXINGRESSPOLICIES._serialized_start=8415
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERXSPECXINGRESSPOLICIES._serialized_end=8704
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERXSPECXVPCACCESSIBLESERVICES._serialized_start=8706
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERXSPECXVPCACCESSIBLESERVICES._serialized_end=8825
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERXSPEC._serialized_start=8828
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERXSPEC._serialized_end=9280
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERXSTATUSXEGRESSPOLICIESXEGRESSFROM._serialized_start=9282
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERXSTATUSXEGRESSPOLICIESXEGRESSFROM._serialized_end=9396
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERXSTATUSXEGRESSPOLICIESXEGRESSTOXOPERATIONSXMETHODSELECTORS._serialized_start=9399
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERXSTATUSXEGRESSPOLICIESXEGRESSTOXOPERATIONSXMETHODSELECTORS._serialized_end=9531
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERXSTATUSXEGRESSPOLICIESXEGRESSTOXOPERATIONS._serialized_start=9534
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERXSTATUSXEGRESSPOLICIESXEGRESSTOXOPERATIONS._serialized_end=9783
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERXSTATUSXEGRESSPOLICIESXEGRESSTO._serialized_start=9786
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERXSTATUSXEGRESSPOLICIESXEGRESSTO._serialized_end=10026
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERXSTATUSXEGRESSPOLICIES._serialized_start=10029
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERXSTATUSXEGRESSPOLICIES._serialized_end=10317
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERXSTATUSXINGRESSPOLICIESXINGRESSFROMXSOURCES._serialized_start=10319
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERXSTATUSXINGRESSPOLICIESXINGRESSFROMXSOURCES._serialized_end=10440
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERXSTATUSXINGRESSPOLICIESXINGRESSFROM._serialized_start=10443
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERXSTATUSXINGRESSPOLICIESXINGRESSFROM._serialized_end=10681
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERXSTATUSXINGRESSPOLICIESXINGRESSTOXOPERATIONSXMETHODSELECTORS._serialized_start=10684
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERXSTATUSXINGRESSPOLICIESXINGRESSTOXOPERATIONSXMETHODSELECTORS._serialized_end=10818
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERXSTATUSXINGRESSPOLICIESXINGRESSTOXOPERATIONS._serialized_start=10821
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERXSTATUSXINGRESSPOLICIESXINGRESSTOXOPERATIONS._serialized_end=11074
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERXSTATUSXINGRESSPOLICIESXINGRESSTO._serialized_start=11077
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERXSTATUSXINGRESSPOLICIESXINGRESSTO._serialized_end=11293
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERXSTATUSXINGRESSPOLICIES._serialized_start=11296
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERXSTATUSXINGRESSPOLICIES._serialized_end=11591
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERXSTATUSXVPCACCESSIBLESERVICES._serialized_start=11593
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERXSTATUSXVPCACCESSIBLESERVICES._serialized_end=11714
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERXSTATUS._serialized_start=11717
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERXSTATUS._serialized_end=12177
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERXTIMEOUTS._serialized_start=12179
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERXTIMEOUTS._serialized_end=12274
  _ACCESSCONTEXTMANAGERSERVICEPERIMETER._serialized_start=12277
  _ACCESSCONTEXTMANAGERSERVICEPERIMETER._serialized_end=12806
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERRESOURCEXTIMEOUTS._serialized_start=12808
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERRESOURCEXTIMEOUTS._serialized_end=12895
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERRESOURCE._serialized_start=12898
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERRESOURCE._serialized_end=13152
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXSERVICEPERIMETERSXSPECXEGRESSPOLICIESXEGRESSFROM._serialized_start=13155
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXSERVICEPERIMETERSXSPECXEGRESSPOLICIESXEGRESSFROM._serialized_end=13286
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXSERVICEPERIMETERSXSPECXEGRESSPOLICIESXEGRESSTOXOPERATIONSXMETHODSELECTORS._serialized_start=13289
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXSERVICEPERIMETERSXSPECXEGRESSPOLICIESXEGRESSTOXOPERATIONSXMETHODSELECTORS._serialized_end=13438
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXSERVICEPERIMETERSXSPECXEGRESSPOLICIESXEGRESSTOXOPERATIONS._serialized_start=13441
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXSERVICEPERIMETERSXSPECXEGRESSPOLICIESXEGRESSTOXOPERATIONS._serialized_end=13725
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXSERVICEPERIMETERSXSPECXEGRESSPOLICIESXEGRESSTO._serialized_start=13728
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXSERVICEPERIMETERSXSPECXEGRESSPOLICIESXEGRESSTO._serialized_end=14003
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXSERVICEPERIMETERSXSPECXEGRESSPOLICIES._serialized_start=14006
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXSERVICEPERIMETERSXSPECXEGRESSPOLICIES._serialized_end=14346
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXSERVICEPERIMETERSXSPECXINGRESSPOLICIESXINGRESSFROMXSOURCES._serialized_start=14349
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXSERVICEPERIMETERSXSPECXINGRESSPOLICIESXINGRESSFROMXSOURCES._serialized_end=14487
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXSERVICEPERIMETERSXSPECXINGRESSPOLICIESXINGRESSFROM._serialized_start=14490
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXSERVICEPERIMETERSXSPECXINGRESSPOLICIESXINGRESSFROM._serialized_end=14763
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXSERVICEPERIMETERSXSPECXINGRESSPOLICIESXINGRESSTOXOPERATIONSXMETHODSELECTORS._serialized_start=14766
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXSERVICEPERIMETERSXSPECXINGRESSPOLICIESXINGRESSTOXOPERATIONSXMETHODSELECTORS._serialized_end=14917
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXSERVICEPERIMETERSXSPECXINGRESSPOLICIESXINGRESSTOXOPERATIONS._serialized_start=14920
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXSERVICEPERIMETERSXSPECXINGRESSPOLICIESXINGRESSTOXOPERATIONS._serialized_end=15208
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXSERVICEPERIMETERSXSPECXINGRESSPOLICIESXINGRESSTO._serialized_start=15211
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXSERVICEPERIMETERSXSPECXINGRESSPOLICIESXINGRESSTO._serialized_end=15462
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXSERVICEPERIMETERSXSPECXINGRESSPOLICIES._serialized_start=15465
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXSERVICEPERIMETERSXSPECXINGRESSPOLICIES._serialized_end=15813
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXSERVICEPERIMETERSXSPECXVPCACCESSIBLESERVICES._serialized_start=15816
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXSERVICEPERIMETERSXSPECXVPCACCESSIBLESERVICES._serialized_end=15954
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXSERVICEPERIMETERSXSPEC._serialized_start=15957
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXSERVICEPERIMETERSXSPEC._serialized_end=16486
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXSERVICEPERIMETERSXSTATUSXEGRESSPOLICIESXEGRESSFROM._serialized_start=16489
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXSERVICEPERIMETERSXSTATUSXEGRESSPOLICIESXEGRESSFROM._serialized_end=16622
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXSERVICEPERIMETERSXSTATUSXEGRESSPOLICIESXEGRESSTOXOPERATIONSXMETHODSELECTORS._serialized_start=16625
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXSERVICEPERIMETERSXSTATUSXEGRESSPOLICIESXEGRESSTOXOPERATIONSXMETHODSELECTORS._serialized_end=16776
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXSERVICEPERIMETERSXSTATUSXEGRESSPOLICIESXEGRESSTOXOPERATIONS._serialized_start=16779
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXSERVICEPERIMETERSXSTATUSXEGRESSPOLICIESXEGRESSTOXOPERATIONS._serialized_end=17067
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXSERVICEPERIMETERSXSTATUSXEGRESSPOLICIESXEGRESSTO._serialized_start=17070
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXSERVICEPERIMETERSXSTATUSXEGRESSPOLICIESXEGRESSTO._serialized_end=17349
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXSERVICEPERIMETERSXSTATUSXEGRESSPOLICIES._serialized_start=17352
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXSERVICEPERIMETERSXSTATUSXEGRESSPOLICIES._serialized_end=17699
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXSERVICEPERIMETERSXSTATUSXINGRESSPOLICIESXINGRESSFROMXSOURCES._serialized_start=17702
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXSERVICEPERIMETERSXSTATUSXINGRESSPOLICIESXINGRESSFROMXSOURCES._serialized_end=17842
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXSERVICEPERIMETERSXSTATUSXINGRESSPOLICIESXINGRESSFROM._serialized_start=17845
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXSERVICEPERIMETERSXSTATUSXINGRESSPOLICIESXINGRESSFROM._serialized_end=18122
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXSERVICEPERIMETERSXSTATUSXINGRESSPOLICIESXINGRESSTOXOPERATIONSXMETHODSELECTORS._serialized_start=18125
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXSERVICEPERIMETERSXSTATUSXINGRESSPOLICIESXINGRESSTOXOPERATIONSXMETHODSELECTORS._serialized_end=18278
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXSERVICEPERIMETERSXSTATUSXINGRESSPOLICIESXINGRESSTOXOPERATIONS._serialized_start=18281
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXSERVICEPERIMETERSXSTATUSXINGRESSPOLICIESXINGRESSTOXOPERATIONS._serialized_end=18573
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXSERVICEPERIMETERSXSTATUSXINGRESSPOLICIESXINGRESSTO._serialized_start=18576
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXSERVICEPERIMETERSXSTATUSXINGRESSPOLICIESXINGRESSTO._serialized_end=18831
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXSERVICEPERIMETERSXSTATUSXINGRESSPOLICIES._serialized_start=18834
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXSERVICEPERIMETERSXSTATUSXINGRESSPOLICIES._serialized_end=19188
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXSERVICEPERIMETERSXSTATUSXVPCACCESSIBLESERVICES._serialized_start=19191
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXSERVICEPERIMETERSXSTATUSXVPCACCESSIBLESERVICES._serialized_end=19331
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXSERVICEPERIMETERSXSTATUS._serialized_start=19334
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXSERVICEPERIMETERSXSTATUS._serialized_end=19872
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXSERVICEPERIMETERS._serialized_start=19875
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXSERVICEPERIMETERS._serialized_end=20287
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXTIMEOUTS._serialized_start=20289
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXTIMEOUTS._serialized_end=20385
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERS._serialized_start=20388
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERS._serialized_end=20711
# @@protoc_insertion_point(module_scope)
