# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kubernetes/kubernetes_io.k8s.api.policy.v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2
from oak9.tython.models.kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta import v1_pb2 as kubernetes_dot_kubernetes__io_dot_k8s_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1__pb2
from oak9.tython.models.kubernetes.kubernetes_io.k8s.apimachinery.pkg.util import intstr_pb2 as kubernetes_dot_kubernetes__io_dot_k8s_dot_apimachinery_dot_pkg_dot_util_dot_intstr__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0kubernetes/kubernetes_io.k8s.api.policy.v1.proto\x12\x1doak9.tython.k8s.api.policy.v1\x1a\x13shared/shared.proto\x1a@kubernetes/kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1.proto\x1a?kubernetes/kubernetes_io.k8s.apimachinery.pkg.util.intstr.proto\"\x89\x02\n\x08\x45viction\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12T\n\x0e\x64\x65lete_options\x18\x02 \x01(\x0b\x32<.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.DeleteOptions\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12K\n\x08metadata\x18\x04 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xce\x02\n\x13PodDisruptionBudget\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12K\n\x08metadata\x18\x03 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12\x44\n\x04spec\x18\x04 \x01(\x0b\x32\x36.oak9.tython.k8s.api.policy.v1.PodDisruptionBudgetSpec\x12H\n\x06status\x18\x05 \x01(\x0b\x32\x38.oak9.tython.k8s.api.policy.v1.PodDisruptionBudgetStatus\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x83\x02\n\x17PodDisruptionBudgetList\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x41\n\x05items\x18\x02 \x03(\x0b\x32\x32.oak9.tython.k8s.api.policy.v1.PodDisruptionBudget\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12I\n\x08metadata\x18\x04 \x01(\x0b\x32\x37.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ListMeta\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xef\x02\n\x17PodDisruptionBudgetSpec\x12R\n\x0fmax_unavailable\x18\x01 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.util.intstr.IntOrString\x12P\n\rmin_available\x18\x02 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.util.intstr.IntOrString\x12N\n\x08selector\x18\x03 \x01(\x0b\x32<.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.LabelSelector\x12%\n\x1dunhealthy_pod_eviction_policy\x18\x04 \x01(\t\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xc0\x03\n\x19PodDisruptionBudgetStatus\x12L\n\nconditions\x18\x01 \x03(\x0b\x32\x38.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.Condition\x12\x17\n\x0f\x63urrent_healthy\x18\x02 \x01(\x05\x12\x17\n\x0f\x64\x65sired_healthy\x18\x03 \x01(\x05\x12\x63\n\x0e\x64isrupted_pods\x18\x04 \x03(\x0b\x32K.oak9.tython.k8s.api.policy.v1.PodDisruptionBudgetStatus.DisruptedPodsEntry\x12\x1b\n\x13\x64isruptions_allowed\x18\x05 \x01(\x05\x12\x15\n\rexpected_pods\x18\x06 \x01(\x05\x12\x1b\n\x13observed_generation\x18\x07 \x01(\x05\x12\x37\n\rresource_info\x18\x08 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a\x34\n\x12\x44isruptedPodsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'kubernetes.kubernetes_io.k8s.api.policy.v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _PODDISRUPTIONBUDGETSTATUS_DISRUPTEDPODSENTRY._options = None
  _PODDISRUPTIONBUDGETSTATUS_DISRUPTEDPODSENTRY._serialized_options = b'8\001'
  _EVICTION._serialized_start=236
  _EVICTION._serialized_end=501
  _PODDISRUPTIONBUDGET._serialized_start=504
  _PODDISRUPTIONBUDGET._serialized_end=838
  _PODDISRUPTIONBUDGETLIST._serialized_start=841
  _PODDISRUPTIONBUDGETLIST._serialized_end=1100
  _PODDISRUPTIONBUDGETSPEC._serialized_start=1103
  _PODDISRUPTIONBUDGETSPEC._serialized_end=1470
  _PODDISRUPTIONBUDGETSTATUS._serialized_start=1473
  _PODDISRUPTIONBUDGETSTATUS._serialized_end=1921
  _PODDISRUPTIONBUDGETSTATUS_DISRUPTEDPODSENTRY._serialized_start=1869
  _PODDISRUPTIONBUDGETSTATUS_DISRUPTEDPODSENTRY._serialized_end=1921
# @@protoc_insertion_point(module_scope)
