"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import gcp.gcp_kms_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class GoogleKms(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KMS_CRYPTO_KEY_FIELD_NUMBER: builtins.int
    KMS_CRYPTO_KEY_IAM_BINDING_FIELD_NUMBER: builtins.int
    KMS_CRYPTO_KEY_IAM_MEMBER_FIELD_NUMBER: builtins.int
    KMS_CRYPTO_KEY_IAM_POLICY_FIELD_NUMBER: builtins.int
    KMS_KEY_RING_FIELD_NUMBER: builtins.int
    KMS_KEY_RING_IAM_BINDING_FIELD_NUMBER: builtins.int
    KMS_KEY_RING_IAM_MEMBER_FIELD_NUMBER: builtins.int
    KMS_KEY_RING_IAM_POLICY_FIELD_NUMBER: builtins.int
    KMS_KEY_RING_IMPORT_JOB_FIELD_NUMBER: builtins.int
    KMS_SECRET_CIPHERTEXT_FIELD_NUMBER: builtins.int
    @property
    def kms_crypto_key(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[gcp.gcp_kms_pb2.KmsCryptoKey]: ...
    @property
    def kms_crypto_key_iam_binding(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[gcp.gcp_kms_pb2.KmsCryptoKeyIamBinding]: ...
    @property
    def kms_crypto_key_iam_member(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[gcp.gcp_kms_pb2.KmsCryptoKeyIamMember]: ...
    @property
    def kms_crypto_key_iam_policy(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[gcp.gcp_kms_pb2.KmsCryptoKeyIamPolicy]: ...
    @property
    def kms_key_ring(self) -> gcp.gcp_kms_pb2.KmsKeyRing: ...
    @property
    def kms_key_ring_iam_binding(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[gcp.gcp_kms_pb2.KmsKeyRingIamBinding]: ...
    @property
    def kms_key_ring_iam_member(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[gcp.gcp_kms_pb2.KmsKeyRingIamMember]: ...
    @property
    def kms_key_ring_iam_policy(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[gcp.gcp_kms_pb2.KmsKeyRingIamPolicy]: ...
    @property
    def kms_key_ring_import_job(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[gcp.gcp_kms_pb2.KmsKeyRingImportJob]: ...
    @property
    def kms_secret_ciphertext(self) -> gcp.gcp_kms_pb2.KmsSecretCiphertext: ...
    def __init__(
        self,
        *,
        kms_crypto_key: collections.abc.Iterable[gcp.gcp_kms_pb2.KmsCryptoKey] | None = ...,
        kms_crypto_key_iam_binding: collections.abc.Iterable[gcp.gcp_kms_pb2.KmsCryptoKeyIamBinding] | None = ...,
        kms_crypto_key_iam_member: collections.abc.Iterable[gcp.gcp_kms_pb2.KmsCryptoKeyIamMember] | None = ...,
        kms_crypto_key_iam_policy: collections.abc.Iterable[gcp.gcp_kms_pb2.KmsCryptoKeyIamPolicy] | None = ...,
        kms_key_ring: gcp.gcp_kms_pb2.KmsKeyRing | None = ...,
        kms_key_ring_iam_binding: collections.abc.Iterable[gcp.gcp_kms_pb2.KmsKeyRingIamBinding] | None = ...,
        kms_key_ring_iam_member: collections.abc.Iterable[gcp.gcp_kms_pb2.KmsKeyRingIamMember] | None = ...,
        kms_key_ring_iam_policy: collections.abc.Iterable[gcp.gcp_kms_pb2.KmsKeyRingIamPolicy] | None = ...,
        kms_key_ring_import_job: collections.abc.Iterable[gcp.gcp_kms_pb2.KmsKeyRingImportJob] | None = ...,
        kms_secret_ciphertext: gcp.gcp_kms_pb2.KmsSecretCiphertext | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["kms_key_ring", b"kms_key_ring", "kms_secret_ciphertext", b"kms_secret_ciphertext"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["kms_crypto_key", b"kms_crypto_key", "kms_crypto_key_iam_binding", b"kms_crypto_key_iam_binding", "kms_crypto_key_iam_member", b"kms_crypto_key_iam_member", "kms_crypto_key_iam_policy", b"kms_crypto_key_iam_policy", "kms_key_ring", b"kms_key_ring", "kms_key_ring_iam_binding", b"kms_key_ring_iam_binding", "kms_key_ring_iam_member", b"kms_key_ring_iam_member", "kms_key_ring_iam_policy", b"kms_key_ring_iam_policy", "kms_key_ring_import_job", b"kms_key_ring_import_job", "kms_secret_ciphertext", b"kms_secret_ciphertext"]) -> None: ...

global___GoogleKms = GoogleKms
