# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_rds_dbcluster.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x61ws/aws_rds_dbcluster.proto\x12\x1doak9.tython.aws.rds_dbcluster\x1a\x13shared/shared.proto\"y\n\x16\x44\x42\x43lusterDBClusterRole\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0c\x66\x65\x61ture_name\x18\x02 \x01(\t\x12\x10\n\x08role_arn\x18\x03 \x01(\t\"\xba\x01\n\x1d\x44\x42\x43lusterScalingConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\nauto_pause\x18\x02 \x01(\x08\x12\x14\n\x0cmax_capacity\x18\x03 \x01(\x05\x12\x14\n\x0cmin_capacity\x18\x04 \x01(\x05\x12 \n\x18seconds_until_auto_pause\x18\x05 \x01(\x05\"\x97\t\n\tDBCluster\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12O\n\x10\x61ssociated_roles\x18\x02 \x03(\x0b\x32\x35.oak9.tython.aws.rds_dbcluster.DBClusterDBClusterRole\x12\x1a\n\x12\x61vailability_zones\x18\x03 \x03(\t\x12\x18\n\x10\x62\x61\x63ktrack_window\x18\x04 \x01(\x05\x12\x1f\n\x17\x62\x61\x63kup_retention_period\x18\x05 \x01(\x05\x12\x1d\n\x15\x64\x62_cluster_identifier\x18\x06 \x01(\t\x12\'\n\x1f\x64\x62_cluster_parameter_group_name\x18\x07 \x01(\t\x12\x1c\n\x14\x64\x62_subnet_group_name\x18\x08 \x01(\t\x12\x15\n\rdatabase_name\x18\t \x01(\t\x12\x1b\n\x13\x64\x65letion_protection\x18\n \x01(\x08\x12&\n\x1e\x65nable_cloudwatch_logs_exports\x18\x0b \x03(\t\x12\x1c\n\x14\x65nable_http_endpoint\x18\x0c \x01(\x08\x12*\n\"enable_iam_database_authentication\x18\r \x01(\x08\x12\x0e\n\x06\x65ngine\x18\x0e \x01(\t\x12\x13\n\x0b\x65ngine_mode\x18\x0f \x01(\t\x12\x16\n\x0e\x65ngine_version\x18\x10 \x01(\t\x12\x12\n\nkms_key_id\x18\x11 \x01(\t\x12\x1c\n\x14master_user_password\x18\x12 \x01(\t\x12\x17\n\x0fmaster_username\x18\x13 \x01(\t\x12\x0c\n\x04port\x18\x14 \x01(\x05\x12\x1f\n\x17preferred_backup_window\x18\x15 \x01(\t\x12$\n\x1cpreferred_maintenance_window\x18\x16 \x01(\t\x12%\n\x1dreplication_source_identifier\x18\x17 \x01(\t\x12\x14\n\x0crestore_type\x18\x18 \x01(\t\x12[\n\x15scaling_configuration\x18\x19 \x01(\x0b\x32<.oak9.tython.aws.rds_dbcluster.DBClusterScalingConfiguration\x12\x1b\n\x13snapshot_identifier\x18\x1a \x01(\t\x12$\n\x1csource_db_cluster_identifier\x18\x1b \x01(\t\x12\x15\n\rsource_region\x18\x1c \x01(\t\x12\x19\n\x11storage_encrypted\x18\x1d \x01(\x08\x12@\n\x04tags\x18\x1e \x03(\x0b\x32\x32.oak9.tython.aws.rds_dbcluster.DBCluster.TagsEntry\x12\"\n\x1ause_latest_restorable_time\x18\x1f \x01(\x08\x12\x1e\n\x16vpc_security_group_ids\x18  \x03(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb1\x05\n\rRDS_DBCluster\x12<\n\ndb_cluster\x18\x01 \x01(\x0b\x32(.oak9.tython.aws.rds_dbcluster.DBCluster\x12Z\n\x1a\x64\x62_cluster_parameter_group\x18\x02 \x01(\x0b\x32\x36.oak9.tython.aws.rds_dbcluster.DBClusterParameterGroup\x12\x38\n\x08\x64\x62_proxy\x18\x03 \x03(\x0b\x32&.oak9.tython.aws.rds_dbcluster.DBProxy\x12P\n\x15\x64\x62_proxy_target_group\x18\x04 \x03(\x0b\x32\x31.oak9.tython.aws.rds_dbcluster.DBProxyTargetGroup\x12I\n\x11\x64\x62_security_group\x18\x05 \x01(\x0b\x32..oak9.tython.aws.rds_dbcluster.DBSecurityGroup\x12X\n\x19\x64\x62_security_group_ingress\x18\x06 \x03(\x0b\x32\x35.oak9.tython.aws.rds_dbcluster.DBSecurityGroupIngress\x12\x45\n\x0f\x64\x62_subnet_group\x18\x07 \x01(\x0b\x32,.oak9.tython.aws.rds_dbcluster.DBSubnetGroup\x12L\n\x12\x65vent_subscription\x18\x08 \x01(\x0b\x32\x30.oak9.tython.aws.rds_dbcluster.EventSubscription\x12@\n\x0coption_group\x18\t \x01(\x0b\x32*.oak9.tython.aws.rds_dbcluster.OptionGroup\"\x83\x03\n\x17\x44\x42\x43lusterParameterGroup\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0e\n\x06\x66\x61mily\x18\x03 \x01(\t\x12Z\n\nparameters\x18\x04 \x03(\x0b\x32\x46.oak9.tython.aws.rds_dbcluster.DBClusterParameterGroup.ParametersEntry\x12N\n\x04tags\x18\x05 \x03(\x0b\x32@.oak9.tython.aws.rds_dbcluster.DBClusterParameterGroup.TagsEntry\x1a\x31\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"g\n\x10\x44\x42ProxyTagFormat\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\"\xfc\x02\n\x07\x44\x42Proxy\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rdb_proxy_name\x18\x02 \x01(\t\x12\x15\n\rdebug_logging\x18\x03 \x01(\x08\x12\x15\n\rengine_family\x18\x04 \x01(\t\x12\x1b\n\x13idle_client_timeout\x18\x05 \x01(\x05\x12\x13\n\x0brequire_tls\x18\x06 \x01(\x08\x12\x10\n\x08role_arn\x18\x07 \x01(\t\x12=\n\x04tags\x18\x08 \x03(\x0b\x32/.oak9.tython.aws.rds_dbcluster.DBProxyTagFormat\x12\x1e\n\x16vpc_security_group_ids\x18\t \x03(\t\x12\x16\n\x0evpc_subnet_ids\x18\n \x03(\t\x12\x38\n\x04\x61uth\x18\x0b \x03(\x0b\x32*.oak9.tython.aws.rds_dbcluster.DBProxyAuth\"\x91\x02\n7DBProxyTargetGroupConnectionPoolConfigurationInfoFormat\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1f\n\x17max_connections_percent\x18\x02 \x01(\x05\x12$\n\x1cmax_idle_connections_percent\x18\x03 \x01(\x05\x12!\n\x19\x63onnection_borrow_timeout\x18\x04 \x01(\x05\x12\x1f\n\x17session_pinning_filters\x18\x05 \x03(\t\x12\x12\n\ninit_query\x18\x06 \x01(\t\"\xc5\x02\n\x12\x44\x42ProxyTargetGroup\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rdb_proxy_name\x18\x02 \x01(\t\x12\x19\n\x11target_group_name\x18\x03 \x01(\t\x12\x82\x01\n\"connection_pool_configuration_info\x18\x04 \x01(\x0b\x32V.oak9.tython.aws.rds_dbcluster.DBProxyTargetGroupConnectionPoolConfigurationInfoFormat\x12\x1f\n\x17\x64\x62_instance_identifiers\x18\x05 \x03(\t\x12\x1e\n\x16\x64\x62_cluster_identifiers\x18\x06 \x03(\t\"\xca\x01\n\x16\x44\x42SecurityGroupIngress\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07\x63idr_ip\x18\x02 \x01(\t\x12\x1e\n\x16\x65_c2_security_group_id\x18\x03 \x01(\t\x12 \n\x18\x65_c2_security_group_name\x18\x04 \x01(\t\x12$\n\x1c\x65_c2_security_group_owner_id\x18\x05 \x01(\t\"\xc9\x02\n\x0f\x44\x42SecurityGroup\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12X\n\x19\x64\x62_security_group_ingress\x18\x02 \x03(\x0b\x32\x35.oak9.tython.aws.rds_dbcluster.DBSecurityGroupIngress\x12\x13\n\x0b\x65_c2_vpc_id\x18\x03 \x01(\t\x12\x19\n\x11group_description\x18\x04 \x01(\t\x12\x46\n\x04tags\x18\x05 \x03(\x0b\x32\x38.oak9.tython.aws.rds_dbcluster.DBSecurityGroup.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x92\x02\n\rDBSubnetGroup\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12#\n\x1b\x64\x62_subnet_group_description\x18\x02 \x01(\t\x12\x1c\n\x14\x64\x62_subnet_group_name\x18\x03 \x01(\t\x12\x12\n\nsubnet_ids\x18\x04 \x03(\t\x12\x44\n\x04tags\x18\x05 \x03(\x0b\x32\x36.oak9.tython.aws.rds_dbcluster.DBSubnetGroup.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb7\x01\n\x11\x45ventSubscription\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07\x65nabled\x18\x02 \x01(\x08\x12\x18\n\x10\x65vent_categories\x18\x03 \x03(\t\x12\x15\n\rsns_topic_arn\x18\x04 \x01(\t\x12\x12\n\nsource_ids\x18\x05 \x03(\t\x12\x13\n\x0bsource_type\x18\x06 \x01(\t\"p\n\x18OptionGroupOptionSetting\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\"\xb5\x02\n\x1eOptionGroupOptionConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12%\n\x1d\x64\x62_security_group_memberships\x18\x02 \x03(\t\x12\x13\n\x0boption_name\x18\x03 \x01(\t\x12P\n\x0foption_settings\x18\x04 \x03(\x0b\x32\x37.oak9.tython.aws.rds_dbcluster.OptionGroupOptionSetting\x12\x16\n\x0eoption_version\x18\x05 \x01(\t\x12\x0c\n\x04port\x18\x06 \x01(\x05\x12&\n\x1evpc_security_group_memberships\x18\x07 \x03(\t\"\xa9\x01\n\x0b\x44\x42ProxyAuth\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x61uth_scheme\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x10\n\x08iam_auth\x18\x04 \x01(\t\x12\x12\n\nsecret_arn\x18\x05 \x01(\t\x12\x11\n\tuser_name\x18\x06 \x01(\t\"\xea\x02\n\x0bOptionGroup\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x65ngine_name\x18\x02 \x01(\t\x12\x1c\n\x14major_engine_version\x18\x03 \x01(\t\x12\\\n\x15option_configurations\x18\x04 \x03(\x0b\x32=.oak9.tython.aws.rds_dbcluster.OptionGroupOptionConfiguration\x12 \n\x18option_group_description\x18\x05 \x01(\t\x12\x42\n\x04tags\x18\x06 \x03(\x0b\x32\x34.oak9.tython.aws.rds_dbcluster.OptionGroup.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_rds_dbcluster_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DBCLUSTER_TAGSENTRY._options = None
  _DBCLUSTER_TAGSENTRY._serialized_options = b'8\001'
  _DBCLUSTERPARAMETERGROUP_PARAMETERSENTRY._options = None
  _DBCLUSTERPARAMETERGROUP_PARAMETERSENTRY._serialized_options = b'8\001'
  _DBCLUSTERPARAMETERGROUP_TAGSENTRY._options = None
  _DBCLUSTERPARAMETERGROUP_TAGSENTRY._serialized_options = b'8\001'
  _DBSECURITYGROUP_TAGSENTRY._options = None
  _DBSECURITYGROUP_TAGSENTRY._serialized_options = b'8\001'
  _DBSUBNETGROUP_TAGSENTRY._options = None
  _DBSUBNETGROUP_TAGSENTRY._serialized_options = b'8\001'
  _OPTIONGROUP_TAGSENTRY._options = None
  _OPTIONGROUP_TAGSENTRY._serialized_options = b'8\001'
  _DBCLUSTERDBCLUSTERROLE._serialized_start=83
  _DBCLUSTERDBCLUSTERROLE._serialized_end=204
  _DBCLUSTERSCALINGCONFIGURATION._serialized_start=207
  _DBCLUSTERSCALINGCONFIGURATION._serialized_end=393
  _DBCLUSTER._serialized_start=396
  _DBCLUSTER._serialized_end=1571
  _DBCLUSTER_TAGSENTRY._serialized_start=1528
  _DBCLUSTER_TAGSENTRY._serialized_end=1571
  _RDS_DBCLUSTER._serialized_start=1574
  _RDS_DBCLUSTER._serialized_end=2263
  _DBCLUSTERPARAMETERGROUP._serialized_start=2266
  _DBCLUSTERPARAMETERGROUP._serialized_end=2653
  _DBCLUSTERPARAMETERGROUP_PARAMETERSENTRY._serialized_start=2559
  _DBCLUSTERPARAMETERGROUP_PARAMETERSENTRY._serialized_end=2608
  _DBCLUSTERPARAMETERGROUP_TAGSENTRY._serialized_start=1528
  _DBCLUSTERPARAMETERGROUP_TAGSENTRY._serialized_end=1571
  _DBPROXYTAGFORMAT._serialized_start=2655
  _DBPROXYTAGFORMAT._serialized_end=2758
  _DBPROXY._serialized_start=2761
  _DBPROXY._serialized_end=3141
  _DBPROXYTARGETGROUPCONNECTIONPOOLCONFIGURATIONINFOFORMAT._serialized_start=3144
  _DBPROXYTARGETGROUPCONNECTIONPOOLCONFIGURATIONINFOFORMAT._serialized_end=3417
  _DBPROXYTARGETGROUP._serialized_start=3420
  _DBPROXYTARGETGROUP._serialized_end=3745
  _DBSECURITYGROUPINGRESS._serialized_start=3748
  _DBSECURITYGROUPINGRESS._serialized_end=3950
  _DBSECURITYGROUP._serialized_start=3953
  _DBSECURITYGROUP._serialized_end=4282
  _DBSECURITYGROUP_TAGSENTRY._serialized_start=1528
  _DBSECURITYGROUP_TAGSENTRY._serialized_end=1571
  _DBSUBNETGROUP._serialized_start=4285
  _DBSUBNETGROUP._serialized_end=4559
  _DBSUBNETGROUP_TAGSENTRY._serialized_start=1528
  _DBSUBNETGROUP_TAGSENTRY._serialized_end=1571
  _EVENTSUBSCRIPTION._serialized_start=4562
  _EVENTSUBSCRIPTION._serialized_end=4745
  _OPTIONGROUPOPTIONSETTING._serialized_start=4747
  _OPTIONGROUPOPTIONSETTING._serialized_end=4859
  _OPTIONGROUPOPTIONCONFIGURATION._serialized_start=4862
  _OPTIONGROUPOPTIONCONFIGURATION._serialized_end=5171
  _DBPROXYAUTH._serialized_start=5174
  _DBPROXYAUTH._serialized_end=5343
  _OPTIONGROUP._serialized_start=5346
  _OPTIONGROUP._serialized_end=5708
  _OPTIONGROUP_TAGSENTRY._serialized_start=1528
  _OPTIONGROUP_TAGSENTRY._serialized_end=1571
# @@protoc_insertion_point(module_scope)
