# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_iot1click.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17\x61ws/aws_iot1click.proto\x12\x19oak9.tython.aws.iot1click\x1a\x13shared/shared.proto\"e\n\x06\x44\x65vice\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\tdevice_id\x18\x02 \x01(\t\x12\x0f\n\x07\x65nabled\x18\x03 \x01(\x08\"\xff\x01\n\tIoT1Click\x12\x31\n\x06\x64\x65vice\x18\x01 \x03(\x0b\x32!.oak9.tython.aws.iot1click.Device\x12\x37\n\tplacement\x18\x02 \x03(\x0b\x32$.oak9.tython.aws.iot1click.Placement\x12\x33\n\x07project\x18\x03 \x03(\x0b\x32\".oak9.tython.aws.iot1click.Project\x12Q\n\x17project_device_template\x18\x04 \x03(\x0b\x32\x30.oak9.tython.aws.iot1click.ProjectDeviceTemplate\"\x82\x03\n\tPlacement\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0eplacement_name\x18\x02 \x01(\t\x12\x14\n\x0cproject_name\x18\x03 \x01(\t\x12W\n\x12\x61ssociated_devices\x18\x04 \x03(\x0b\x32;.oak9.tython.aws.iot1click.Placement.AssociatedDevicesEntry\x12H\n\nattributes\x18\x05 \x03(\x0b\x32\x34.oak9.tython.aws.iot1click.Placement.AttributesEntry\x1a\x38\n\x16\x41ssociatedDevicesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x31\n\x0f\x41ttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x91\x03\n\x18ProjectPlacementTemplate\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x62\n\x10\x64\x65vice_templates\x18\x02 \x03(\x0b\x32H.oak9.tython.aws.iot1click.ProjectPlacementTemplate.DeviceTemplatesEntry\x12\x66\n\x12\x64\x65\x66\x61ult_attributes\x18\x03 \x03(\x0b\x32J.oak9.tython.aws.iot1click.ProjectPlacementTemplate.DefaultAttributesEntry\x1a\x36\n\x14\x44\x65viceTemplatesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x38\n\x16\x44\x65\x66\x61ultAttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xbe\x01\n\x07Project\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12O\n\x12placement_template\x18\x03 \x01(\x0b\x32\x33.oak9.tython.aws.iot1click.ProjectPlacementTemplate\x12\x14\n\x0cproject_name\x18\x04 \x01(\t\"\x84\x02\n\x15ProjectDeviceTemplate\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65vice_type\x18\x02 \x01(\t\x12\x63\n\x12\x63\x61llback_overrides\x18\x03 \x03(\x0b\x32G.oak9.tython.aws.iot1click.ProjectDeviceTemplate.CallbackOverridesEntry\x1a\x38\n\x16\x43\x61llbackOverridesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_iot1click_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _PLACEMENT_ASSOCIATEDDEVICESENTRY._options = None
  _PLACEMENT_ASSOCIATEDDEVICESENTRY._serialized_options = b'8\001'
  _PLACEMENT_ATTRIBUTESENTRY._options = None
  _PLACEMENT_ATTRIBUTESENTRY._serialized_options = b'8\001'
  _PROJECTPLACEMENTTEMPLATE_DEVICETEMPLATESENTRY._options = None
  _PROJECTPLACEMENTTEMPLATE_DEVICETEMPLATESENTRY._serialized_options = b'8\001'
  _PROJECTPLACEMENTTEMPLATE_DEFAULTATTRIBUTESENTRY._options = None
  _PROJECTPLACEMENTTEMPLATE_DEFAULTATTRIBUTESENTRY._serialized_options = b'8\001'
  _PROJECTDEVICETEMPLATE_CALLBACKOVERRIDESENTRY._options = None
  _PROJECTDEVICETEMPLATE_CALLBACKOVERRIDESENTRY._serialized_options = b'8\001'
  _DEVICE._serialized_start=75
  _DEVICE._serialized_end=176
  _IOT1CLICK._serialized_start=179
  _IOT1CLICK._serialized_end=434
  _PLACEMENT._serialized_start=437
  _PLACEMENT._serialized_end=823
  _PLACEMENT_ASSOCIATEDDEVICESENTRY._serialized_start=716
  _PLACEMENT_ASSOCIATEDDEVICESENTRY._serialized_end=772
  _PLACEMENT_ATTRIBUTESENTRY._serialized_start=774
  _PLACEMENT_ATTRIBUTESENTRY._serialized_end=823
  _PROJECTPLACEMENTTEMPLATE._serialized_start=826
  _PROJECTPLACEMENTTEMPLATE._serialized_end=1227
  _PROJECTPLACEMENTTEMPLATE_DEVICETEMPLATESENTRY._serialized_start=1115
  _PROJECTPLACEMENTTEMPLATE_DEVICETEMPLATESENTRY._serialized_end=1169
  _PROJECTPLACEMENTTEMPLATE_DEFAULTATTRIBUTESENTRY._serialized_start=1171
  _PROJECTPLACEMENTTEMPLATE_DEFAULTATTRIBUTESENTRY._serialized_end=1227
  _PROJECT._serialized_start=1230
  _PROJECT._serialized_end=1420
  _PROJECTDEVICETEMPLATE._serialized_start=1423
  _PROJECTDEVICETEMPLATE._serialized_end=1683
  _PROJECTDEVICETEMPLATE_CALLBACKOVERRIDESENTRY._serialized_start=1627
  _PROJECTDEVICETEMPLATE_CALLBACKOVERRIDESENTRY._serialized_end=1683
# @@protoc_insertion_point(module_scope)
