"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class AppEngineApplicationXFeatureSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SPLIT_HEALTH_CHECKS_FIELD_NUMBER: builtins.int
    split_health_checks: builtins.bool
    def __init__(
        self,
        *,
        split_health_checks: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["split_health_checks", b"split_health_checks"]) -> None: ...

global___AppEngineApplicationXFeatureSettings = AppEngineApplicationXFeatureSettings

@typing_extensions.final
class AppEngineApplicationXIap(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLED_FIELD_NUMBER: builtins.int
    OAUTH2_CLIENT_ID_FIELD_NUMBER: builtins.int
    OAUTH2_CLIENT_SECRET_FIELD_NUMBER: builtins.int
    OAUTH2_CLIENT_SECRET_SHA256_FIELD_NUMBER: builtins.int
    enabled: builtins.bool
    oauth2_client_id: builtins.str
    oauth2_client_secret: builtins.str
    oauth2_client_secret_sha256: builtins.str
    def __init__(
        self,
        *,
        enabled: builtins.bool = ...,
        oauth2_client_id: builtins.str = ...,
        oauth2_client_secret: builtins.str = ...,
        oauth2_client_secret_sha256: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["enabled", b"enabled", "oauth2_client_id", b"oauth2_client_id", "oauth2_client_secret", b"oauth2_client_secret", "oauth2_client_secret_sha256", b"oauth2_client_secret_sha256"]) -> None: ...

global___AppEngineApplicationXIap = AppEngineApplicationXIap

@typing_extensions.final
class AppEngineApplicationXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "update", b"update"]) -> None: ...

global___AppEngineApplicationXTimeouts = AppEngineApplicationXTimeouts

@typing_extensions.final
class AppEngineApplication(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class UrlDispatchRuleEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    APP_ID_FIELD_NUMBER: builtins.int
    AUTH_DOMAIN_FIELD_NUMBER: builtins.int
    CODE_BUCKET_FIELD_NUMBER: builtins.int
    DATABASE_TYPE_FIELD_NUMBER: builtins.int
    DEFAULT_BUCKET_FIELD_NUMBER: builtins.int
    DEFAULT_HOSTNAME_FIELD_NUMBER: builtins.int
    GCR_DOMAIN_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LOCATION_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    SERVING_STATUS_FIELD_NUMBER: builtins.int
    URL_DISPATCH_RULE_FIELD_NUMBER: builtins.int
    FEATURE_SETTINGS_FIELD_NUMBER: builtins.int
    IAP_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    app_id: builtins.str
    auth_domain: builtins.str
    code_bucket: builtins.str
    database_type: builtins.str
    default_bucket: builtins.str
    default_hostname: builtins.str
    gcr_domain: builtins.str
    id: builtins.str
    location_id: builtins.str
    name: builtins.str
    project: builtins.str
    serving_status: builtins.str
    @property
    def url_dispatch_rule(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def feature_settings(self) -> global___AppEngineApplicationXFeatureSettings: ...
    @property
    def iap(self) -> global___AppEngineApplicationXIap: ...
    @property
    def timeouts(self) -> global___AppEngineApplicationXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        app_id: builtins.str = ...,
        auth_domain: builtins.str = ...,
        code_bucket: builtins.str = ...,
        database_type: builtins.str = ...,
        default_bucket: builtins.str = ...,
        default_hostname: builtins.str = ...,
        gcr_domain: builtins.str = ...,
        id: builtins.str = ...,
        location_id: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        serving_status: builtins.str = ...,
        url_dispatch_rule: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        feature_settings: global___AppEngineApplicationXFeatureSettings | None = ...,
        iap: global___AppEngineApplicationXIap | None = ...,
        timeouts: global___AppEngineApplicationXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["feature_settings", b"feature_settings", "iap", b"iap", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["app_id", b"app_id", "auth_domain", b"auth_domain", "code_bucket", b"code_bucket", "database_type", b"database_type", "default_bucket", b"default_bucket", "default_hostname", b"default_hostname", "feature_settings", b"feature_settings", "gcr_domain", b"gcr_domain", "iap", b"iap", "id", b"id", "location_id", b"location_id", "name", b"name", "project", b"project", "resource_info", b"resource_info", "serving_status", b"serving_status", "timeouts", b"timeouts", "url_dispatch_rule", b"url_dispatch_rule"]) -> None: ...

global___AppEngineApplication = AppEngineApplication

@typing_extensions.final
class AppEngineApplicationUrlDispatchRulesXDispatchRules(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DOMAIN_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    SERVICE_FIELD_NUMBER: builtins.int
    domain: builtins.str
    path: builtins.str
    service: builtins.str
    def __init__(
        self,
        *,
        domain: builtins.str = ...,
        path: builtins.str = ...,
        service: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["domain", b"domain", "path", b"path", "service", b"service"]) -> None: ...

global___AppEngineApplicationUrlDispatchRulesXDispatchRules = AppEngineApplicationUrlDispatchRulesXDispatchRules

@typing_extensions.final
class AppEngineApplicationUrlDispatchRulesXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___AppEngineApplicationUrlDispatchRulesXTimeouts = AppEngineApplicationUrlDispatchRulesXTimeouts

@typing_extensions.final
class AppEngineApplicationUrlDispatchRules(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    DISPATCH_RULES_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    id: builtins.str
    project: builtins.str
    @property
    def dispatch_rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AppEngineApplicationUrlDispatchRulesXDispatchRules]: ...
    @property
    def timeouts(self) -> global___AppEngineApplicationUrlDispatchRulesXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        project: builtins.str = ...,
        dispatch_rules: collections.abc.Iterable[global___AppEngineApplicationUrlDispatchRulesXDispatchRules] | None = ...,
        timeouts: global___AppEngineApplicationUrlDispatchRulesXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["dispatch_rules", b"dispatch_rules", "id", b"id", "project", b"project", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> None: ...

global___AppEngineApplicationUrlDispatchRules = AppEngineApplicationUrlDispatchRules

@typing_extensions.final
class AppEngineDomainMappingXSslSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CERTIFICATE_ID_FIELD_NUMBER: builtins.int
    PENDING_MANAGED_CERTIFICATE_ID_FIELD_NUMBER: builtins.int
    SSL_MANAGEMENT_TYPE_FIELD_NUMBER: builtins.int
    certificate_id: builtins.str
    pending_managed_certificate_id: builtins.str
    ssl_management_type: builtins.str
    def __init__(
        self,
        *,
        certificate_id: builtins.str = ...,
        pending_managed_certificate_id: builtins.str = ...,
        ssl_management_type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["certificate_id", b"certificate_id", "pending_managed_certificate_id", b"pending_managed_certificate_id", "ssl_management_type", b"ssl_management_type"]) -> None: ...

global___AppEngineDomainMappingXSslSettings = AppEngineDomainMappingXSslSettings

@typing_extensions.final
class AppEngineDomainMappingXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___AppEngineDomainMappingXTimeouts = AppEngineDomainMappingXTimeouts

@typing_extensions.final
class AppEngineDomainMapping(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class ResourceRecordsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    DOMAIN_NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    OVERRIDE_STRATEGY_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    RESOURCE_RECORDS_FIELD_NUMBER: builtins.int
    SSL_SETTINGS_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    domain_name: builtins.str
    id: builtins.str
    name: builtins.str
    override_strategy: builtins.str
    project: builtins.str
    @property
    def resource_records(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def ssl_settings(self) -> global___AppEngineDomainMappingXSslSettings: ...
    @property
    def timeouts(self) -> global___AppEngineDomainMappingXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        domain_name: builtins.str = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        override_strategy: builtins.str = ...,
        project: builtins.str = ...,
        resource_records: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        ssl_settings: global___AppEngineDomainMappingXSslSettings | None = ...,
        timeouts: global___AppEngineDomainMappingXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "ssl_settings", b"ssl_settings", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["domain_name", b"domain_name", "id", b"id", "name", b"name", "override_strategy", b"override_strategy", "project", b"project", "resource_info", b"resource_info", "resource_records", b"resource_records", "ssl_settings", b"ssl_settings", "timeouts", b"timeouts"]) -> None: ...

global___AppEngineDomainMapping = AppEngineDomainMapping

@typing_extensions.final
class AppEngineFirewallRuleXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___AppEngineFirewallRuleXTimeouts = AppEngineFirewallRuleXTimeouts

@typing_extensions.final
class AppEngineFirewallRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACTION_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    PRIORITY_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    SOURCE_RANGE_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    action: builtins.str
    description: builtins.str
    id: builtins.str
    priority: builtins.float
    project: builtins.str
    source_range: builtins.str
    @property
    def timeouts(self) -> global___AppEngineFirewallRuleXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        action: builtins.str = ...,
        description: builtins.str = ...,
        id: builtins.str = ...,
        priority: builtins.float = ...,
        project: builtins.str = ...,
        source_range: builtins.str = ...,
        timeouts: global___AppEngineFirewallRuleXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["action", b"action", "description", b"description", "id", b"id", "priority", b"priority", "project", b"project", "resource_info", b"resource_info", "source_range", b"source_range", "timeouts", b"timeouts"]) -> None: ...

global___AppEngineFirewallRule = AppEngineFirewallRule

@typing_extensions.final
class AppEngineFlexibleAppVersionXApiConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUTH_FAIL_ACTION_FIELD_NUMBER: builtins.int
    LOGIN_FIELD_NUMBER: builtins.int
    SCRIPT_FIELD_NUMBER: builtins.int
    SECURITY_LEVEL_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    auth_fail_action: builtins.str
    login: builtins.str
    script: builtins.str
    security_level: builtins.str
    url: builtins.str
    def __init__(
        self,
        *,
        auth_fail_action: builtins.str = ...,
        login: builtins.str = ...,
        script: builtins.str = ...,
        security_level: builtins.str = ...,
        url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["auth_fail_action", b"auth_fail_action", "login", b"login", "script", b"script", "security_level", b"security_level", "url", b"url"]) -> None: ...

global___AppEngineFlexibleAppVersionXApiConfig = AppEngineFlexibleAppVersionXApiConfig

@typing_extensions.final
class AppEngineFlexibleAppVersionXAutomaticScalingXCpuUtilization(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AGGREGATION_WINDOW_LENGTH_FIELD_NUMBER: builtins.int
    TARGET_UTILIZATION_FIELD_NUMBER: builtins.int
    aggregation_window_length: builtins.str
    target_utilization: builtins.float
    def __init__(
        self,
        *,
        aggregation_window_length: builtins.str = ...,
        target_utilization: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["aggregation_window_length", b"aggregation_window_length", "target_utilization", b"target_utilization"]) -> None: ...

global___AppEngineFlexibleAppVersionXAutomaticScalingXCpuUtilization = AppEngineFlexibleAppVersionXAutomaticScalingXCpuUtilization

@typing_extensions.final
class AppEngineFlexibleAppVersionXAutomaticScalingXDiskUtilization(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TARGET_READ_BYTES_PER_SECOND_FIELD_NUMBER: builtins.int
    TARGET_READ_OPS_PER_SECOND_FIELD_NUMBER: builtins.int
    TARGET_WRITE_BYTES_PER_SECOND_FIELD_NUMBER: builtins.int
    TARGET_WRITE_OPS_PER_SECOND_FIELD_NUMBER: builtins.int
    target_read_bytes_per_second: builtins.float
    target_read_ops_per_second: builtins.float
    target_write_bytes_per_second: builtins.float
    target_write_ops_per_second: builtins.float
    def __init__(
        self,
        *,
        target_read_bytes_per_second: builtins.float = ...,
        target_read_ops_per_second: builtins.float = ...,
        target_write_bytes_per_second: builtins.float = ...,
        target_write_ops_per_second: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["target_read_bytes_per_second", b"target_read_bytes_per_second", "target_read_ops_per_second", b"target_read_ops_per_second", "target_write_bytes_per_second", b"target_write_bytes_per_second", "target_write_ops_per_second", b"target_write_ops_per_second"]) -> None: ...

global___AppEngineFlexibleAppVersionXAutomaticScalingXDiskUtilization = AppEngineFlexibleAppVersionXAutomaticScalingXDiskUtilization

@typing_extensions.final
class AppEngineFlexibleAppVersionXAutomaticScalingXNetworkUtilization(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TARGET_RECEIVED_BYTES_PER_SECOND_FIELD_NUMBER: builtins.int
    TARGET_RECEIVED_PACKETS_PER_SECOND_FIELD_NUMBER: builtins.int
    TARGET_SENT_BYTES_PER_SECOND_FIELD_NUMBER: builtins.int
    TARGET_SENT_PACKETS_PER_SECOND_FIELD_NUMBER: builtins.int
    target_received_bytes_per_second: builtins.float
    target_received_packets_per_second: builtins.float
    target_sent_bytes_per_second: builtins.float
    target_sent_packets_per_second: builtins.float
    def __init__(
        self,
        *,
        target_received_bytes_per_second: builtins.float = ...,
        target_received_packets_per_second: builtins.float = ...,
        target_sent_bytes_per_second: builtins.float = ...,
        target_sent_packets_per_second: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["target_received_bytes_per_second", b"target_received_bytes_per_second", "target_received_packets_per_second", b"target_received_packets_per_second", "target_sent_bytes_per_second", b"target_sent_bytes_per_second", "target_sent_packets_per_second", b"target_sent_packets_per_second"]) -> None: ...

global___AppEngineFlexibleAppVersionXAutomaticScalingXNetworkUtilization = AppEngineFlexibleAppVersionXAutomaticScalingXNetworkUtilization

@typing_extensions.final
class AppEngineFlexibleAppVersionXAutomaticScalingXRequestUtilization(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TARGET_CONCURRENT_REQUESTS_FIELD_NUMBER: builtins.int
    TARGET_REQUEST_COUNT_PER_SECOND_FIELD_NUMBER: builtins.int
    target_concurrent_requests: builtins.float
    target_request_count_per_second: builtins.str
    def __init__(
        self,
        *,
        target_concurrent_requests: builtins.float = ...,
        target_request_count_per_second: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["target_concurrent_requests", b"target_concurrent_requests", "target_request_count_per_second", b"target_request_count_per_second"]) -> None: ...

global___AppEngineFlexibleAppVersionXAutomaticScalingXRequestUtilization = AppEngineFlexibleAppVersionXAutomaticScalingXRequestUtilization

@typing_extensions.final
class AppEngineFlexibleAppVersionXAutomaticScaling(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COOL_DOWN_PERIOD_FIELD_NUMBER: builtins.int
    MAX_CONCURRENT_REQUESTS_FIELD_NUMBER: builtins.int
    MAX_IDLE_INSTANCES_FIELD_NUMBER: builtins.int
    MAX_PENDING_LATENCY_FIELD_NUMBER: builtins.int
    MAX_TOTAL_INSTANCES_FIELD_NUMBER: builtins.int
    MIN_IDLE_INSTANCES_FIELD_NUMBER: builtins.int
    MIN_PENDING_LATENCY_FIELD_NUMBER: builtins.int
    MIN_TOTAL_INSTANCES_FIELD_NUMBER: builtins.int
    CPU_UTILIZATION_FIELD_NUMBER: builtins.int
    DISK_UTILIZATION_FIELD_NUMBER: builtins.int
    NETWORK_UTILIZATION_FIELD_NUMBER: builtins.int
    REQUEST_UTILIZATION_FIELD_NUMBER: builtins.int
    cool_down_period: builtins.str
    max_concurrent_requests: builtins.float
    max_idle_instances: builtins.float
    max_pending_latency: builtins.str
    max_total_instances: builtins.float
    min_idle_instances: builtins.float
    min_pending_latency: builtins.str
    min_total_instances: builtins.float
    @property
    def cpu_utilization(self) -> global___AppEngineFlexibleAppVersionXAutomaticScalingXCpuUtilization: ...
    @property
    def disk_utilization(self) -> global___AppEngineFlexibleAppVersionXAutomaticScalingXDiskUtilization: ...
    @property
    def network_utilization(self) -> global___AppEngineFlexibleAppVersionXAutomaticScalingXNetworkUtilization: ...
    @property
    def request_utilization(self) -> global___AppEngineFlexibleAppVersionXAutomaticScalingXRequestUtilization: ...
    def __init__(
        self,
        *,
        cool_down_period: builtins.str = ...,
        max_concurrent_requests: builtins.float = ...,
        max_idle_instances: builtins.float = ...,
        max_pending_latency: builtins.str = ...,
        max_total_instances: builtins.float = ...,
        min_idle_instances: builtins.float = ...,
        min_pending_latency: builtins.str = ...,
        min_total_instances: builtins.float = ...,
        cpu_utilization: global___AppEngineFlexibleAppVersionXAutomaticScalingXCpuUtilization | None = ...,
        disk_utilization: global___AppEngineFlexibleAppVersionXAutomaticScalingXDiskUtilization | None = ...,
        network_utilization: global___AppEngineFlexibleAppVersionXAutomaticScalingXNetworkUtilization | None = ...,
        request_utilization: global___AppEngineFlexibleAppVersionXAutomaticScalingXRequestUtilization | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cpu_utilization", b"cpu_utilization", "disk_utilization", b"disk_utilization", "network_utilization", b"network_utilization", "request_utilization", b"request_utilization"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cool_down_period", b"cool_down_period", "cpu_utilization", b"cpu_utilization", "disk_utilization", b"disk_utilization", "max_concurrent_requests", b"max_concurrent_requests", "max_idle_instances", b"max_idle_instances", "max_pending_latency", b"max_pending_latency", "max_total_instances", b"max_total_instances", "min_idle_instances", b"min_idle_instances", "min_pending_latency", b"min_pending_latency", "min_total_instances", b"min_total_instances", "network_utilization", b"network_utilization", "request_utilization", b"request_utilization"]) -> None: ...

global___AppEngineFlexibleAppVersionXAutomaticScaling = AppEngineFlexibleAppVersionXAutomaticScaling

@typing_extensions.final
class AppEngineFlexibleAppVersionXDeploymentXCloudBuildOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APP_YAML_PATH_FIELD_NUMBER: builtins.int
    CLOUD_BUILD_TIMEOUT_FIELD_NUMBER: builtins.int
    app_yaml_path: builtins.str
    cloud_build_timeout: builtins.str
    def __init__(
        self,
        *,
        app_yaml_path: builtins.str = ...,
        cloud_build_timeout: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["app_yaml_path", b"app_yaml_path", "cloud_build_timeout", b"cloud_build_timeout"]) -> None: ...

global___AppEngineFlexibleAppVersionXDeploymentXCloudBuildOptions = AppEngineFlexibleAppVersionXDeploymentXCloudBuildOptions

@typing_extensions.final
class AppEngineFlexibleAppVersionXDeploymentXContainer(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IMAGE_FIELD_NUMBER: builtins.int
    image: builtins.str
    def __init__(
        self,
        *,
        image: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["image", b"image"]) -> None: ...

global___AppEngineFlexibleAppVersionXDeploymentXContainer = AppEngineFlexibleAppVersionXDeploymentXContainer

@typing_extensions.final
class AppEngineFlexibleAppVersionXDeploymentXFiles(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    SHA1_SUM_FIELD_NUMBER: builtins.int
    SOURCE_URL_FIELD_NUMBER: builtins.int
    name: builtins.str
    sha1_sum: builtins.str
    source_url: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        sha1_sum: builtins.str = ...,
        source_url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "sha1_sum", b"sha1_sum", "source_url", b"source_url"]) -> None: ...

global___AppEngineFlexibleAppVersionXDeploymentXFiles = AppEngineFlexibleAppVersionXDeploymentXFiles

@typing_extensions.final
class AppEngineFlexibleAppVersionXDeploymentXZip(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FILES_COUNT_FIELD_NUMBER: builtins.int
    SOURCE_URL_FIELD_NUMBER: builtins.int
    files_count: builtins.float
    source_url: builtins.str
    def __init__(
        self,
        *,
        files_count: builtins.float = ...,
        source_url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["files_count", b"files_count", "source_url", b"source_url"]) -> None: ...

global___AppEngineFlexibleAppVersionXDeploymentXZip = AppEngineFlexibleAppVersionXDeploymentXZip

@typing_extensions.final
class AppEngineFlexibleAppVersionXDeployment(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLOUD_BUILD_OPTIONS_FIELD_NUMBER: builtins.int
    CONTAINER_FIELD_NUMBER: builtins.int
    FILES_FIELD_NUMBER: builtins.int
    ZIP_FIELD_NUMBER: builtins.int
    @property
    def cloud_build_options(self) -> global___AppEngineFlexibleAppVersionXDeploymentXCloudBuildOptions: ...
    @property
    def container(self) -> global___AppEngineFlexibleAppVersionXDeploymentXContainer: ...
    @property
    def files(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AppEngineFlexibleAppVersionXDeploymentXFiles]: ...
    @property
    def zip(self) -> global___AppEngineFlexibleAppVersionXDeploymentXZip: ...
    def __init__(
        self,
        *,
        cloud_build_options: global___AppEngineFlexibleAppVersionXDeploymentXCloudBuildOptions | None = ...,
        container: global___AppEngineFlexibleAppVersionXDeploymentXContainer | None = ...,
        files: collections.abc.Iterable[global___AppEngineFlexibleAppVersionXDeploymentXFiles] | None = ...,
        zip: global___AppEngineFlexibleAppVersionXDeploymentXZip | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cloud_build_options", b"cloud_build_options", "container", b"container", "zip", b"zip"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cloud_build_options", b"cloud_build_options", "container", b"container", "files", b"files", "zip", b"zip"]) -> None: ...

global___AppEngineFlexibleAppVersionXDeployment = AppEngineFlexibleAppVersionXDeployment

@typing_extensions.final
class AppEngineFlexibleAppVersionXEndpointsApiService(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONFIG_ID_FIELD_NUMBER: builtins.int
    DISABLE_TRACE_SAMPLING_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ROLLOUT_STRATEGY_FIELD_NUMBER: builtins.int
    config_id: builtins.str
    disable_trace_sampling: builtins.bool
    name: builtins.str
    rollout_strategy: builtins.str
    def __init__(
        self,
        *,
        config_id: builtins.str = ...,
        disable_trace_sampling: builtins.bool = ...,
        name: builtins.str = ...,
        rollout_strategy: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["config_id", b"config_id", "disable_trace_sampling", b"disable_trace_sampling", "name", b"name", "rollout_strategy", b"rollout_strategy"]) -> None: ...

global___AppEngineFlexibleAppVersionXEndpointsApiService = AppEngineFlexibleAppVersionXEndpointsApiService

@typing_extensions.final
class AppEngineFlexibleAppVersionXEntrypoint(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SHELL_FIELD_NUMBER: builtins.int
    shell: builtins.str
    def __init__(
        self,
        *,
        shell: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["shell", b"shell"]) -> None: ...

global___AppEngineFlexibleAppVersionXEntrypoint = AppEngineFlexibleAppVersionXEntrypoint

@typing_extensions.final
class AppEngineFlexibleAppVersionXHandlersXScript(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SCRIPT_PATH_FIELD_NUMBER: builtins.int
    script_path: builtins.str
    def __init__(
        self,
        *,
        script_path: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["script_path", b"script_path"]) -> None: ...

global___AppEngineFlexibleAppVersionXHandlersXScript = AppEngineFlexibleAppVersionXHandlersXScript

@typing_extensions.final
class AppEngineFlexibleAppVersionXHandlersXStaticFiles(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class HttpHeadersEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    APPLICATION_READABLE_FIELD_NUMBER: builtins.int
    EXPIRATION_FIELD_NUMBER: builtins.int
    HTTP_HEADERS_FIELD_NUMBER: builtins.int
    MIME_TYPE_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    REQUIRE_MATCHING_FILE_FIELD_NUMBER: builtins.int
    UPLOAD_PATH_REGEX_FIELD_NUMBER: builtins.int
    application_readable: builtins.bool
    expiration: builtins.str
    @property
    def http_headers(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    mime_type: builtins.str
    path: builtins.str
    require_matching_file: builtins.bool
    upload_path_regex: builtins.str
    def __init__(
        self,
        *,
        application_readable: builtins.bool = ...,
        expiration: builtins.str = ...,
        http_headers: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        mime_type: builtins.str = ...,
        path: builtins.str = ...,
        require_matching_file: builtins.bool = ...,
        upload_path_regex: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["application_readable", b"application_readable", "expiration", b"expiration", "http_headers", b"http_headers", "mime_type", b"mime_type", "path", b"path", "require_matching_file", b"require_matching_file", "upload_path_regex", b"upload_path_regex"]) -> None: ...

global___AppEngineFlexibleAppVersionXHandlersXStaticFiles = AppEngineFlexibleAppVersionXHandlersXStaticFiles

@typing_extensions.final
class AppEngineFlexibleAppVersionXHandlers(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUTH_FAIL_ACTION_FIELD_NUMBER: builtins.int
    LOGIN_FIELD_NUMBER: builtins.int
    REDIRECT_HTTP_RESPONSE_CODE_FIELD_NUMBER: builtins.int
    SECURITY_LEVEL_FIELD_NUMBER: builtins.int
    URL_REGEX_FIELD_NUMBER: builtins.int
    SCRIPT_FIELD_NUMBER: builtins.int
    STATIC_FILES_FIELD_NUMBER: builtins.int
    auth_fail_action: builtins.str
    login: builtins.str
    redirect_http_response_code: builtins.str
    security_level: builtins.str
    url_regex: builtins.str
    @property
    def script(self) -> global___AppEngineFlexibleAppVersionXHandlersXScript: ...
    @property
    def static_files(self) -> global___AppEngineFlexibleAppVersionXHandlersXStaticFiles: ...
    def __init__(
        self,
        *,
        auth_fail_action: builtins.str = ...,
        login: builtins.str = ...,
        redirect_http_response_code: builtins.str = ...,
        security_level: builtins.str = ...,
        url_regex: builtins.str = ...,
        script: global___AppEngineFlexibleAppVersionXHandlersXScript | None = ...,
        static_files: global___AppEngineFlexibleAppVersionXHandlersXStaticFiles | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["script", b"script", "static_files", b"static_files"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auth_fail_action", b"auth_fail_action", "login", b"login", "redirect_http_response_code", b"redirect_http_response_code", "script", b"script", "security_level", b"security_level", "static_files", b"static_files", "url_regex", b"url_regex"]) -> None: ...

global___AppEngineFlexibleAppVersionXHandlers = AppEngineFlexibleAppVersionXHandlers

@typing_extensions.final
class AppEngineFlexibleAppVersionXLivenessCheck(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHECK_INTERVAL_FIELD_NUMBER: builtins.int
    FAILURE_THRESHOLD_FIELD_NUMBER: builtins.int
    HOST_FIELD_NUMBER: builtins.int
    INITIAL_DELAY_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    SUCCESS_THRESHOLD_FIELD_NUMBER: builtins.int
    TIMEOUT_FIELD_NUMBER: builtins.int
    check_interval: builtins.str
    failure_threshold: builtins.float
    host: builtins.str
    initial_delay: builtins.str
    path: builtins.str
    success_threshold: builtins.float
    timeout: builtins.str
    def __init__(
        self,
        *,
        check_interval: builtins.str = ...,
        failure_threshold: builtins.float = ...,
        host: builtins.str = ...,
        initial_delay: builtins.str = ...,
        path: builtins.str = ...,
        success_threshold: builtins.float = ...,
        timeout: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["check_interval", b"check_interval", "failure_threshold", b"failure_threshold", "host", b"host", "initial_delay", b"initial_delay", "path", b"path", "success_threshold", b"success_threshold", "timeout", b"timeout"]) -> None: ...

global___AppEngineFlexibleAppVersionXLivenessCheck = AppEngineFlexibleAppVersionXLivenessCheck

@typing_extensions.final
class AppEngineFlexibleAppVersionXManualScaling(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INSTANCES_FIELD_NUMBER: builtins.int
    instances: builtins.float
    def __init__(
        self,
        *,
        instances: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["instances", b"instances"]) -> None: ...

global___AppEngineFlexibleAppVersionXManualScaling = AppEngineFlexibleAppVersionXManualScaling

@typing_extensions.final
class AppEngineFlexibleAppVersionXNetwork(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FORWARDED_PORTS_FIELD_NUMBER: builtins.int
    INSTANCE_TAG_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    SESSION_AFFINITY_FIELD_NUMBER: builtins.int
    SUBNETWORK_FIELD_NUMBER: builtins.int
    @property
    def forwarded_ports(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    instance_tag: builtins.str
    name: builtins.str
    session_affinity: builtins.bool
    subnetwork: builtins.str
    def __init__(
        self,
        *,
        forwarded_ports: collections.abc.Iterable[builtins.str] | None = ...,
        instance_tag: builtins.str = ...,
        name: builtins.str = ...,
        session_affinity: builtins.bool = ...,
        subnetwork: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["forwarded_ports", b"forwarded_ports", "instance_tag", b"instance_tag", "name", b"name", "session_affinity", b"session_affinity", "subnetwork", b"subnetwork"]) -> None: ...

global___AppEngineFlexibleAppVersionXNetwork = AppEngineFlexibleAppVersionXNetwork

@typing_extensions.final
class AppEngineFlexibleAppVersionXReadinessCheck(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APP_START_TIMEOUT_FIELD_NUMBER: builtins.int
    CHECK_INTERVAL_FIELD_NUMBER: builtins.int
    FAILURE_THRESHOLD_FIELD_NUMBER: builtins.int
    HOST_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    SUCCESS_THRESHOLD_FIELD_NUMBER: builtins.int
    TIMEOUT_FIELD_NUMBER: builtins.int
    app_start_timeout: builtins.str
    check_interval: builtins.str
    failure_threshold: builtins.float
    host: builtins.str
    path: builtins.str
    success_threshold: builtins.float
    timeout: builtins.str
    def __init__(
        self,
        *,
        app_start_timeout: builtins.str = ...,
        check_interval: builtins.str = ...,
        failure_threshold: builtins.float = ...,
        host: builtins.str = ...,
        path: builtins.str = ...,
        success_threshold: builtins.float = ...,
        timeout: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["app_start_timeout", b"app_start_timeout", "check_interval", b"check_interval", "failure_threshold", b"failure_threshold", "host", b"host", "path", b"path", "success_threshold", b"success_threshold", "timeout", b"timeout"]) -> None: ...

global___AppEngineFlexibleAppVersionXReadinessCheck = AppEngineFlexibleAppVersionXReadinessCheck

@typing_extensions.final
class AppEngineFlexibleAppVersionXResourcesXVolumes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    SIZE_GB_FIELD_NUMBER: builtins.int
    VOLUME_TYPE_FIELD_NUMBER: builtins.int
    name: builtins.str
    size_gb: builtins.float
    volume_type: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        size_gb: builtins.float = ...,
        volume_type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "size_gb", b"size_gb", "volume_type", b"volume_type"]) -> None: ...

global___AppEngineFlexibleAppVersionXResourcesXVolumes = AppEngineFlexibleAppVersionXResourcesXVolumes

@typing_extensions.final
class AppEngineFlexibleAppVersionXResources(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CPU_FIELD_NUMBER: builtins.int
    DISK_GB_FIELD_NUMBER: builtins.int
    MEMORY_GB_FIELD_NUMBER: builtins.int
    VOLUMES_FIELD_NUMBER: builtins.int
    cpu: builtins.float
    disk_gb: builtins.float
    memory_gb: builtins.float
    @property
    def volumes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AppEngineFlexibleAppVersionXResourcesXVolumes]: ...
    def __init__(
        self,
        *,
        cpu: builtins.float = ...,
        disk_gb: builtins.float = ...,
        memory_gb: builtins.float = ...,
        volumes: collections.abc.Iterable[global___AppEngineFlexibleAppVersionXResourcesXVolumes] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cpu", b"cpu", "disk_gb", b"disk_gb", "memory_gb", b"memory_gb", "volumes", b"volumes"]) -> None: ...

global___AppEngineFlexibleAppVersionXResources = AppEngineFlexibleAppVersionXResources

@typing_extensions.final
class AppEngineFlexibleAppVersionXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___AppEngineFlexibleAppVersionXTimeouts = AppEngineFlexibleAppVersionXTimeouts

@typing_extensions.final
class AppEngineFlexibleAppVersionXVpcAccessConnector(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___AppEngineFlexibleAppVersionXVpcAccessConnector = AppEngineFlexibleAppVersionXVpcAccessConnector

@typing_extensions.final
class AppEngineFlexibleAppVersion(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class BetaSettingsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class EnvVariablesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    BETA_SETTINGS_FIELD_NUMBER: builtins.int
    DEFAULT_EXPIRATION_FIELD_NUMBER: builtins.int
    DELETE_SERVICE_ON_DESTROY_FIELD_NUMBER: builtins.int
    ENV_VARIABLES_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    INBOUND_SERVICES_FIELD_NUMBER: builtins.int
    INSTANCE_CLASS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    NOBUILD_FILES_REGEX_FIELD_NUMBER: builtins.int
    NOOP_ON_DESTROY_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    RUNTIME_FIELD_NUMBER: builtins.int
    RUNTIME_API_VERSION_FIELD_NUMBER: builtins.int
    RUNTIME_CHANNEL_FIELD_NUMBER: builtins.int
    RUNTIME_MAIN_EXECUTABLE_PATH_FIELD_NUMBER: builtins.int
    SERVICE_FIELD_NUMBER: builtins.int
    SERVING_STATUS_FIELD_NUMBER: builtins.int
    VERSION_ID_FIELD_NUMBER: builtins.int
    API_CONFIG_FIELD_NUMBER: builtins.int
    AUTOMATIC_SCALING_FIELD_NUMBER: builtins.int
    DEPLOYMENT_FIELD_NUMBER: builtins.int
    ENDPOINTS_API_SERVICE_FIELD_NUMBER: builtins.int
    ENTRYPOINT_FIELD_NUMBER: builtins.int
    HANDLERS_FIELD_NUMBER: builtins.int
    LIVENESS_CHECK_FIELD_NUMBER: builtins.int
    MANUAL_SCALING_FIELD_NUMBER: builtins.int
    NETWORK_FIELD_NUMBER: builtins.int
    READINESS_CHECK_FIELD_NUMBER: builtins.int
    RESOURCES_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    VPC_ACCESS_CONNECTOR_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def beta_settings(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    default_expiration: builtins.str
    delete_service_on_destroy: builtins.bool
    @property
    def env_variables(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    id: builtins.str
    @property
    def inbound_services(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    instance_class: builtins.str
    name: builtins.str
    nobuild_files_regex: builtins.str
    noop_on_destroy: builtins.bool
    project: builtins.str
    runtime: builtins.str
    runtime_api_version: builtins.str
    runtime_channel: builtins.str
    runtime_main_executable_path: builtins.str
    service: builtins.str
    serving_status: builtins.str
    version_id: builtins.str
    @property
    def api_config(self) -> global___AppEngineFlexibleAppVersionXApiConfig: ...
    @property
    def automatic_scaling(self) -> global___AppEngineFlexibleAppVersionXAutomaticScaling: ...
    @property
    def deployment(self) -> global___AppEngineFlexibleAppVersionXDeployment: ...
    @property
    def endpoints_api_service(self) -> global___AppEngineFlexibleAppVersionXEndpointsApiService: ...
    @property
    def entrypoint(self) -> global___AppEngineFlexibleAppVersionXEntrypoint: ...
    @property
    def handlers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AppEngineFlexibleAppVersionXHandlers]: ...
    @property
    def liveness_check(self) -> global___AppEngineFlexibleAppVersionXLivenessCheck: ...
    @property
    def manual_scaling(self) -> global___AppEngineFlexibleAppVersionXManualScaling: ...
    @property
    def network(self) -> global___AppEngineFlexibleAppVersionXNetwork: ...
    @property
    def readiness_check(self) -> global___AppEngineFlexibleAppVersionXReadinessCheck: ...
    @property
    def resources(self) -> global___AppEngineFlexibleAppVersionXResources: ...
    @property
    def timeouts(self) -> global___AppEngineFlexibleAppVersionXTimeouts: ...
    @property
    def vpc_access_connector(self) -> global___AppEngineFlexibleAppVersionXVpcAccessConnector: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        beta_settings: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        default_expiration: builtins.str = ...,
        delete_service_on_destroy: builtins.bool = ...,
        env_variables: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        id: builtins.str = ...,
        inbound_services: collections.abc.Iterable[builtins.str] | None = ...,
        instance_class: builtins.str = ...,
        name: builtins.str = ...,
        nobuild_files_regex: builtins.str = ...,
        noop_on_destroy: builtins.bool = ...,
        project: builtins.str = ...,
        runtime: builtins.str = ...,
        runtime_api_version: builtins.str = ...,
        runtime_channel: builtins.str = ...,
        runtime_main_executable_path: builtins.str = ...,
        service: builtins.str = ...,
        serving_status: builtins.str = ...,
        version_id: builtins.str = ...,
        api_config: global___AppEngineFlexibleAppVersionXApiConfig | None = ...,
        automatic_scaling: global___AppEngineFlexibleAppVersionXAutomaticScaling | None = ...,
        deployment: global___AppEngineFlexibleAppVersionXDeployment | None = ...,
        endpoints_api_service: global___AppEngineFlexibleAppVersionXEndpointsApiService | None = ...,
        entrypoint: global___AppEngineFlexibleAppVersionXEntrypoint | None = ...,
        handlers: collections.abc.Iterable[global___AppEngineFlexibleAppVersionXHandlers] | None = ...,
        liveness_check: global___AppEngineFlexibleAppVersionXLivenessCheck | None = ...,
        manual_scaling: global___AppEngineFlexibleAppVersionXManualScaling | None = ...,
        network: global___AppEngineFlexibleAppVersionXNetwork | None = ...,
        readiness_check: global___AppEngineFlexibleAppVersionXReadinessCheck | None = ...,
        resources: global___AppEngineFlexibleAppVersionXResources | None = ...,
        timeouts: global___AppEngineFlexibleAppVersionXTimeouts | None = ...,
        vpc_access_connector: global___AppEngineFlexibleAppVersionXVpcAccessConnector | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["api_config", b"api_config", "automatic_scaling", b"automatic_scaling", "deployment", b"deployment", "endpoints_api_service", b"endpoints_api_service", "entrypoint", b"entrypoint", "liveness_check", b"liveness_check", "manual_scaling", b"manual_scaling", "network", b"network", "readiness_check", b"readiness_check", "resource_info", b"resource_info", "resources", b"resources", "timeouts", b"timeouts", "vpc_access_connector", b"vpc_access_connector"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_config", b"api_config", "automatic_scaling", b"automatic_scaling", "beta_settings", b"beta_settings", "default_expiration", b"default_expiration", "delete_service_on_destroy", b"delete_service_on_destroy", "deployment", b"deployment", "endpoints_api_service", b"endpoints_api_service", "entrypoint", b"entrypoint", "env_variables", b"env_variables", "handlers", b"handlers", "id", b"id", "inbound_services", b"inbound_services", "instance_class", b"instance_class", "liveness_check", b"liveness_check", "manual_scaling", b"manual_scaling", "name", b"name", "network", b"network", "nobuild_files_regex", b"nobuild_files_regex", "noop_on_destroy", b"noop_on_destroy", "project", b"project", "readiness_check", b"readiness_check", "resource_info", b"resource_info", "resources", b"resources", "runtime", b"runtime", "runtime_api_version", b"runtime_api_version", "runtime_channel", b"runtime_channel", "runtime_main_executable_path", b"runtime_main_executable_path", "service", b"service", "serving_status", b"serving_status", "timeouts", b"timeouts", "version_id", b"version_id", "vpc_access_connector", b"vpc_access_connector"]) -> None: ...

global___AppEngineFlexibleAppVersion = AppEngineFlexibleAppVersion

@typing_extensions.final
class AppEngineServiceNetworkSettingsXNetworkSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INGRESS_TRAFFIC_ALLOWED_FIELD_NUMBER: builtins.int
    ingress_traffic_allowed: builtins.str
    def __init__(
        self,
        *,
        ingress_traffic_allowed: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["ingress_traffic_allowed", b"ingress_traffic_allowed"]) -> None: ...

global___AppEngineServiceNetworkSettingsXNetworkSettings = AppEngineServiceNetworkSettingsXNetworkSettings

@typing_extensions.final
class AppEngineServiceNetworkSettingsXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___AppEngineServiceNetworkSettingsXTimeouts = AppEngineServiceNetworkSettingsXTimeouts

@typing_extensions.final
class AppEngineServiceNetworkSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    SERVICE_FIELD_NUMBER: builtins.int
    NETWORK_SETTINGS_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    id: builtins.str
    project: builtins.str
    service: builtins.str
    @property
    def network_settings(self) -> global___AppEngineServiceNetworkSettingsXNetworkSettings: ...
    @property
    def timeouts(self) -> global___AppEngineServiceNetworkSettingsXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        project: builtins.str = ...,
        service: builtins.str = ...,
        network_settings: global___AppEngineServiceNetworkSettingsXNetworkSettings | None = ...,
        timeouts: global___AppEngineServiceNetworkSettingsXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["network_settings", b"network_settings", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "network_settings", b"network_settings", "project", b"project", "resource_info", b"resource_info", "service", b"service", "timeouts", b"timeouts"]) -> None: ...

global___AppEngineServiceNetworkSettings = AppEngineServiceNetworkSettings

@typing_extensions.final
class AppEngineServiceSplitTrafficXSplit(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class AllocationsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    ALLOCATIONS_FIELD_NUMBER: builtins.int
    SHARD_BY_FIELD_NUMBER: builtins.int
    @property
    def allocations(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    shard_by: builtins.str
    def __init__(
        self,
        *,
        allocations: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        shard_by: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["allocations", b"allocations", "shard_by", b"shard_by"]) -> None: ...

global___AppEngineServiceSplitTrafficXSplit = AppEngineServiceSplitTrafficXSplit

@typing_extensions.final
class AppEngineServiceSplitTrafficXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___AppEngineServiceSplitTrafficXTimeouts = AppEngineServiceSplitTrafficXTimeouts

@typing_extensions.final
class AppEngineServiceSplitTraffic(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    MIGRATE_TRAFFIC_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    SERVICE_FIELD_NUMBER: builtins.int
    SPLIT_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    id: builtins.str
    migrate_traffic: builtins.bool
    project: builtins.str
    service: builtins.str
    @property
    def split(self) -> global___AppEngineServiceSplitTrafficXSplit: ...
    @property
    def timeouts(self) -> global___AppEngineServiceSplitTrafficXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        migrate_traffic: builtins.bool = ...,
        project: builtins.str = ...,
        service: builtins.str = ...,
        split: global___AppEngineServiceSplitTrafficXSplit | None = ...,
        timeouts: global___AppEngineServiceSplitTrafficXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "split", b"split", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "migrate_traffic", b"migrate_traffic", "project", b"project", "resource_info", b"resource_info", "service", b"service", "split", b"split", "timeouts", b"timeouts"]) -> None: ...

global___AppEngineServiceSplitTraffic = AppEngineServiceSplitTraffic

@typing_extensions.final
class AppEngineStandardAppVersionXAutomaticScalingXStandardSchedulerSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MAX_INSTANCES_FIELD_NUMBER: builtins.int
    MIN_INSTANCES_FIELD_NUMBER: builtins.int
    TARGET_CPU_UTILIZATION_FIELD_NUMBER: builtins.int
    TARGET_THROUGHPUT_UTILIZATION_FIELD_NUMBER: builtins.int
    max_instances: builtins.float
    min_instances: builtins.float
    target_cpu_utilization: builtins.float
    target_throughput_utilization: builtins.float
    def __init__(
        self,
        *,
        max_instances: builtins.float = ...,
        min_instances: builtins.float = ...,
        target_cpu_utilization: builtins.float = ...,
        target_throughput_utilization: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["max_instances", b"max_instances", "min_instances", b"min_instances", "target_cpu_utilization", b"target_cpu_utilization", "target_throughput_utilization", b"target_throughput_utilization"]) -> None: ...

global___AppEngineStandardAppVersionXAutomaticScalingXStandardSchedulerSettings = AppEngineStandardAppVersionXAutomaticScalingXStandardSchedulerSettings

@typing_extensions.final
class AppEngineStandardAppVersionXAutomaticScaling(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MAX_CONCURRENT_REQUESTS_FIELD_NUMBER: builtins.int
    MAX_IDLE_INSTANCES_FIELD_NUMBER: builtins.int
    MAX_PENDING_LATENCY_FIELD_NUMBER: builtins.int
    MIN_IDLE_INSTANCES_FIELD_NUMBER: builtins.int
    MIN_PENDING_LATENCY_FIELD_NUMBER: builtins.int
    STANDARD_SCHEDULER_SETTINGS_FIELD_NUMBER: builtins.int
    max_concurrent_requests: builtins.float
    max_idle_instances: builtins.float
    max_pending_latency: builtins.str
    min_idle_instances: builtins.float
    min_pending_latency: builtins.str
    @property
    def standard_scheduler_settings(self) -> global___AppEngineStandardAppVersionXAutomaticScalingXStandardSchedulerSettings: ...
    def __init__(
        self,
        *,
        max_concurrent_requests: builtins.float = ...,
        max_idle_instances: builtins.float = ...,
        max_pending_latency: builtins.str = ...,
        min_idle_instances: builtins.float = ...,
        min_pending_latency: builtins.str = ...,
        standard_scheduler_settings: global___AppEngineStandardAppVersionXAutomaticScalingXStandardSchedulerSettings | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["standard_scheduler_settings", b"standard_scheduler_settings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["max_concurrent_requests", b"max_concurrent_requests", "max_idle_instances", b"max_idle_instances", "max_pending_latency", b"max_pending_latency", "min_idle_instances", b"min_idle_instances", "min_pending_latency", b"min_pending_latency", "standard_scheduler_settings", b"standard_scheduler_settings"]) -> None: ...

global___AppEngineStandardAppVersionXAutomaticScaling = AppEngineStandardAppVersionXAutomaticScaling

@typing_extensions.final
class AppEngineStandardAppVersionXBasicScaling(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IDLE_TIMEOUT_FIELD_NUMBER: builtins.int
    MAX_INSTANCES_FIELD_NUMBER: builtins.int
    idle_timeout: builtins.str
    max_instances: builtins.float
    def __init__(
        self,
        *,
        idle_timeout: builtins.str = ...,
        max_instances: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["idle_timeout", b"idle_timeout", "max_instances", b"max_instances"]) -> None: ...

global___AppEngineStandardAppVersionXBasicScaling = AppEngineStandardAppVersionXBasicScaling

@typing_extensions.final
class AppEngineStandardAppVersionXDeploymentXFiles(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    SHA1_SUM_FIELD_NUMBER: builtins.int
    SOURCE_URL_FIELD_NUMBER: builtins.int
    name: builtins.str
    sha1_sum: builtins.str
    source_url: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        sha1_sum: builtins.str = ...,
        source_url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "sha1_sum", b"sha1_sum", "source_url", b"source_url"]) -> None: ...

global___AppEngineStandardAppVersionXDeploymentXFiles = AppEngineStandardAppVersionXDeploymentXFiles

@typing_extensions.final
class AppEngineStandardAppVersionXDeploymentXZip(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FILES_COUNT_FIELD_NUMBER: builtins.int
    SOURCE_URL_FIELD_NUMBER: builtins.int
    files_count: builtins.float
    source_url: builtins.str
    def __init__(
        self,
        *,
        files_count: builtins.float = ...,
        source_url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["files_count", b"files_count", "source_url", b"source_url"]) -> None: ...

global___AppEngineStandardAppVersionXDeploymentXZip = AppEngineStandardAppVersionXDeploymentXZip

@typing_extensions.final
class AppEngineStandardAppVersionXDeployment(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FILES_FIELD_NUMBER: builtins.int
    ZIP_FIELD_NUMBER: builtins.int
    @property
    def files(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AppEngineStandardAppVersionXDeploymentXFiles]: ...
    @property
    def zip(self) -> global___AppEngineStandardAppVersionXDeploymentXZip: ...
    def __init__(
        self,
        *,
        files: collections.abc.Iterable[global___AppEngineStandardAppVersionXDeploymentXFiles] | None = ...,
        zip: global___AppEngineStandardAppVersionXDeploymentXZip | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["zip", b"zip"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["files", b"files", "zip", b"zip"]) -> None: ...

global___AppEngineStandardAppVersionXDeployment = AppEngineStandardAppVersionXDeployment

@typing_extensions.final
class AppEngineStandardAppVersionXEntrypoint(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SHELL_FIELD_NUMBER: builtins.int
    shell: builtins.str
    def __init__(
        self,
        *,
        shell: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["shell", b"shell"]) -> None: ...

global___AppEngineStandardAppVersionXEntrypoint = AppEngineStandardAppVersionXEntrypoint

@typing_extensions.final
class AppEngineStandardAppVersionXHandlersXScript(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SCRIPT_PATH_FIELD_NUMBER: builtins.int
    script_path: builtins.str
    def __init__(
        self,
        *,
        script_path: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["script_path", b"script_path"]) -> None: ...

global___AppEngineStandardAppVersionXHandlersXScript = AppEngineStandardAppVersionXHandlersXScript

@typing_extensions.final
class AppEngineStandardAppVersionXHandlersXStaticFiles(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class HttpHeadersEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    APPLICATION_READABLE_FIELD_NUMBER: builtins.int
    EXPIRATION_FIELD_NUMBER: builtins.int
    HTTP_HEADERS_FIELD_NUMBER: builtins.int
    MIME_TYPE_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    REQUIRE_MATCHING_FILE_FIELD_NUMBER: builtins.int
    UPLOAD_PATH_REGEX_FIELD_NUMBER: builtins.int
    application_readable: builtins.bool
    expiration: builtins.str
    @property
    def http_headers(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    mime_type: builtins.str
    path: builtins.str
    require_matching_file: builtins.bool
    upload_path_regex: builtins.str
    def __init__(
        self,
        *,
        application_readable: builtins.bool = ...,
        expiration: builtins.str = ...,
        http_headers: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        mime_type: builtins.str = ...,
        path: builtins.str = ...,
        require_matching_file: builtins.bool = ...,
        upload_path_regex: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["application_readable", b"application_readable", "expiration", b"expiration", "http_headers", b"http_headers", "mime_type", b"mime_type", "path", b"path", "require_matching_file", b"require_matching_file", "upload_path_regex", b"upload_path_regex"]) -> None: ...

global___AppEngineStandardAppVersionXHandlersXStaticFiles = AppEngineStandardAppVersionXHandlersXStaticFiles

@typing_extensions.final
class AppEngineStandardAppVersionXHandlers(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUTH_FAIL_ACTION_FIELD_NUMBER: builtins.int
    LOGIN_FIELD_NUMBER: builtins.int
    REDIRECT_HTTP_RESPONSE_CODE_FIELD_NUMBER: builtins.int
    SECURITY_LEVEL_FIELD_NUMBER: builtins.int
    URL_REGEX_FIELD_NUMBER: builtins.int
    SCRIPT_FIELD_NUMBER: builtins.int
    STATIC_FILES_FIELD_NUMBER: builtins.int
    auth_fail_action: builtins.str
    login: builtins.str
    redirect_http_response_code: builtins.str
    security_level: builtins.str
    url_regex: builtins.str
    @property
    def script(self) -> global___AppEngineStandardAppVersionXHandlersXScript: ...
    @property
    def static_files(self) -> global___AppEngineStandardAppVersionXHandlersXStaticFiles: ...
    def __init__(
        self,
        *,
        auth_fail_action: builtins.str = ...,
        login: builtins.str = ...,
        redirect_http_response_code: builtins.str = ...,
        security_level: builtins.str = ...,
        url_regex: builtins.str = ...,
        script: global___AppEngineStandardAppVersionXHandlersXScript | None = ...,
        static_files: global___AppEngineStandardAppVersionXHandlersXStaticFiles | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["script", b"script", "static_files", b"static_files"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auth_fail_action", b"auth_fail_action", "login", b"login", "redirect_http_response_code", b"redirect_http_response_code", "script", b"script", "security_level", b"security_level", "static_files", b"static_files", "url_regex", b"url_regex"]) -> None: ...

global___AppEngineStandardAppVersionXHandlers = AppEngineStandardAppVersionXHandlers

@typing_extensions.final
class AppEngineStandardAppVersionXLibraries(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    name: builtins.str
    version: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        version: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "version", b"version"]) -> None: ...

global___AppEngineStandardAppVersionXLibraries = AppEngineStandardAppVersionXLibraries

@typing_extensions.final
class AppEngineStandardAppVersionXManualScaling(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INSTANCES_FIELD_NUMBER: builtins.int
    instances: builtins.float
    def __init__(
        self,
        *,
        instances: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["instances", b"instances"]) -> None: ...

global___AppEngineStandardAppVersionXManualScaling = AppEngineStandardAppVersionXManualScaling

@typing_extensions.final
class AppEngineStandardAppVersionXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___AppEngineStandardAppVersionXTimeouts = AppEngineStandardAppVersionXTimeouts

@typing_extensions.final
class AppEngineStandardAppVersionXVpcAccessConnector(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___AppEngineStandardAppVersionXVpcAccessConnector = AppEngineStandardAppVersionXVpcAccessConnector

@typing_extensions.final
class AppEngineStandardAppVersion(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class EnvVariablesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    DELETE_SERVICE_ON_DESTROY_FIELD_NUMBER: builtins.int
    ENV_VARIABLES_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    INBOUND_SERVICES_FIELD_NUMBER: builtins.int
    INSTANCE_CLASS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    NOOP_ON_DESTROY_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    RUNTIME_FIELD_NUMBER: builtins.int
    RUNTIME_API_VERSION_FIELD_NUMBER: builtins.int
    SERVICE_FIELD_NUMBER: builtins.int
    THREADSAFE_FIELD_NUMBER: builtins.int
    VERSION_ID_FIELD_NUMBER: builtins.int
    AUTOMATIC_SCALING_FIELD_NUMBER: builtins.int
    BASIC_SCALING_FIELD_NUMBER: builtins.int
    DEPLOYMENT_FIELD_NUMBER: builtins.int
    ENTRYPOINT_FIELD_NUMBER: builtins.int
    HANDLERS_FIELD_NUMBER: builtins.int
    LIBRARIES_FIELD_NUMBER: builtins.int
    MANUAL_SCALING_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    VPC_ACCESS_CONNECTOR_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    delete_service_on_destroy: builtins.bool
    @property
    def env_variables(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    id: builtins.str
    @property
    def inbound_services(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    instance_class: builtins.str
    name: builtins.str
    noop_on_destroy: builtins.bool
    project: builtins.str
    runtime: builtins.str
    runtime_api_version: builtins.str
    service: builtins.str
    threadsafe: builtins.bool
    version_id: builtins.str
    @property
    def automatic_scaling(self) -> global___AppEngineStandardAppVersionXAutomaticScaling: ...
    @property
    def basic_scaling(self) -> global___AppEngineStandardAppVersionXBasicScaling: ...
    @property
    def deployment(self) -> global___AppEngineStandardAppVersionXDeployment: ...
    @property
    def entrypoint(self) -> global___AppEngineStandardAppVersionXEntrypoint: ...
    @property
    def handlers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AppEngineStandardAppVersionXHandlers]: ...
    @property
    def libraries(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AppEngineStandardAppVersionXLibraries]: ...
    @property
    def manual_scaling(self) -> global___AppEngineStandardAppVersionXManualScaling: ...
    @property
    def timeouts(self) -> global___AppEngineStandardAppVersionXTimeouts: ...
    @property
    def vpc_access_connector(self) -> global___AppEngineStandardAppVersionXVpcAccessConnector: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        delete_service_on_destroy: builtins.bool = ...,
        env_variables: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        id: builtins.str = ...,
        inbound_services: collections.abc.Iterable[builtins.str] | None = ...,
        instance_class: builtins.str = ...,
        name: builtins.str = ...,
        noop_on_destroy: builtins.bool = ...,
        project: builtins.str = ...,
        runtime: builtins.str = ...,
        runtime_api_version: builtins.str = ...,
        service: builtins.str = ...,
        threadsafe: builtins.bool = ...,
        version_id: builtins.str = ...,
        automatic_scaling: global___AppEngineStandardAppVersionXAutomaticScaling | None = ...,
        basic_scaling: global___AppEngineStandardAppVersionXBasicScaling | None = ...,
        deployment: global___AppEngineStandardAppVersionXDeployment | None = ...,
        entrypoint: global___AppEngineStandardAppVersionXEntrypoint | None = ...,
        handlers: collections.abc.Iterable[global___AppEngineStandardAppVersionXHandlers] | None = ...,
        libraries: collections.abc.Iterable[global___AppEngineStandardAppVersionXLibraries] | None = ...,
        manual_scaling: global___AppEngineStandardAppVersionXManualScaling | None = ...,
        timeouts: global___AppEngineStandardAppVersionXTimeouts | None = ...,
        vpc_access_connector: global___AppEngineStandardAppVersionXVpcAccessConnector | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["automatic_scaling", b"automatic_scaling", "basic_scaling", b"basic_scaling", "deployment", b"deployment", "entrypoint", b"entrypoint", "manual_scaling", b"manual_scaling", "resource_info", b"resource_info", "timeouts", b"timeouts", "vpc_access_connector", b"vpc_access_connector"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["automatic_scaling", b"automatic_scaling", "basic_scaling", b"basic_scaling", "delete_service_on_destroy", b"delete_service_on_destroy", "deployment", b"deployment", "entrypoint", b"entrypoint", "env_variables", b"env_variables", "handlers", b"handlers", "id", b"id", "inbound_services", b"inbound_services", "instance_class", b"instance_class", "libraries", b"libraries", "manual_scaling", b"manual_scaling", "name", b"name", "noop_on_destroy", b"noop_on_destroy", "project", b"project", "resource_info", b"resource_info", "runtime", b"runtime", "runtime_api_version", b"runtime_api_version", "service", b"service", "threadsafe", b"threadsafe", "timeouts", b"timeouts", "version_id", b"version_id", "vpc_access_connector", b"vpc_access_connector"]) -> None: ...

global___AppEngineStandardAppVersion = AppEngineStandardAppVersion
