"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Microsoft_Network_privateDnsZones(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PRIVATE_DNS_ZONES_FIELD_NUMBER: builtins.int
    PRIVATE_DNS_ZONES_VIRTUAL_NETWORK_LINKS_FIELD_NUMBER: builtins.int
    @property
    def private_dns_zones(self) -> global___PrivateDnsZones: ...
    @property
    def private_dns_zones_virtual_network_links(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PrivateDnsZonesVirtualNetworkLinks]: ...
    def __init__(
        self,
        *,
        private_dns_zones: global___PrivateDnsZones | None = ...,
        private_dns_zones_virtual_network_links: collections.abc.Iterable[global___PrivateDnsZonesVirtualNetworkLinks] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["private_dns_zones", b"private_dns_zones"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["private_dns_zones", b"private_dns_zones", "private_dns_zones_virtual_network_links", b"private_dns_zones_virtual_network_links"]) -> None: ...

global___Microsoft_Network_privateDnsZones = Microsoft_Network_privateDnsZones

@typing_extensions.final
class PrivateDnsZonesTXT(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class MetadataEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    TTL_FIELD_NUMBER: builtins.int
    A_RECORDS_FIELD_NUMBER: builtins.int
    AAAA_RECORDS_FIELD_NUMBER: builtins.int
    CNAME_RECORD_FIELD_NUMBER: builtins.int
    MX_RECORDS_FIELD_NUMBER: builtins.int
    PTR_RECORDS_FIELD_NUMBER: builtins.int
    SOA_RECORD_FIELD_NUMBER: builtins.int
    SRV_RECORDS_FIELD_NUMBER: builtins.int
    TXT_RECORDS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    etag: builtins.str
    @property
    def metadata(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    ttl: builtins.int
    @property
    def a_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ARecord]: ...
    @property
    def aaaa_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AaaaRecord]: ...
    @property
    def cname_record(self) -> global___CnameRecord: ...
    @property
    def mx_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MxRecord]: ...
    @property
    def ptr_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PtrRecord]: ...
    @property
    def soa_record(self) -> global___SoaRecord: ...
    @property
    def srv_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SrvRecord]: ...
    @property
    def txt_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TxtRecord]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        etag: builtins.str = ...,
        metadata: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        ttl: builtins.int = ...,
        a_records: collections.abc.Iterable[global___ARecord] | None = ...,
        aaaa_records: collections.abc.Iterable[global___AaaaRecord] | None = ...,
        cname_record: global___CnameRecord | None = ...,
        mx_records: collections.abc.Iterable[global___MxRecord] | None = ...,
        ptr_records: collections.abc.Iterable[global___PtrRecord] | None = ...,
        soa_record: global___SoaRecord | None = ...,
        srv_records: collections.abc.Iterable[global___SrvRecord] | None = ...,
        txt_records: collections.abc.Iterable[global___TxtRecord] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cname_record", b"cname_record", "resource_info", b"resource_info", "soa_record", b"soa_record"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["a_records", b"a_records", "aaaa_records", b"aaaa_records", "cname_record", b"cname_record", "etag", b"etag", "metadata", b"metadata", "mx_records", b"mx_records", "name", b"name", "ptr_records", b"ptr_records", "resource_info", b"resource_info", "soa_record", b"soa_record", "srv_records", b"srv_records", "ttl", b"ttl", "txt_records", b"txt_records"]) -> None: ...

global___PrivateDnsZonesTXT = PrivateDnsZonesTXT

@typing_extensions.final
class PrivateDnsZonesSRV(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class MetadataEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    TTL_FIELD_NUMBER: builtins.int
    A_RECORDS_FIELD_NUMBER: builtins.int
    AAAA_RECORDS_FIELD_NUMBER: builtins.int
    CNAME_RECORD_FIELD_NUMBER: builtins.int
    MX_RECORDS_FIELD_NUMBER: builtins.int
    PTR_RECORDS_FIELD_NUMBER: builtins.int
    SOA_RECORD_FIELD_NUMBER: builtins.int
    SRV_RECORDS_FIELD_NUMBER: builtins.int
    TXT_RECORDS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    etag: builtins.str
    @property
    def metadata(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    ttl: builtins.int
    @property
    def a_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ARecord]: ...
    @property
    def aaaa_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AaaaRecord]: ...
    @property
    def cname_record(self) -> global___CnameRecord: ...
    @property
    def mx_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MxRecord]: ...
    @property
    def ptr_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PtrRecord]: ...
    @property
    def soa_record(self) -> global___SoaRecord: ...
    @property
    def srv_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SrvRecord]: ...
    @property
    def txt_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TxtRecord]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        etag: builtins.str = ...,
        metadata: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        ttl: builtins.int = ...,
        a_records: collections.abc.Iterable[global___ARecord] | None = ...,
        aaaa_records: collections.abc.Iterable[global___AaaaRecord] | None = ...,
        cname_record: global___CnameRecord | None = ...,
        mx_records: collections.abc.Iterable[global___MxRecord] | None = ...,
        ptr_records: collections.abc.Iterable[global___PtrRecord] | None = ...,
        soa_record: global___SoaRecord | None = ...,
        srv_records: collections.abc.Iterable[global___SrvRecord] | None = ...,
        txt_records: collections.abc.Iterable[global___TxtRecord] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cname_record", b"cname_record", "resource_info", b"resource_info", "soa_record", b"soa_record"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["a_records", b"a_records", "aaaa_records", b"aaaa_records", "cname_record", b"cname_record", "etag", b"etag", "metadata", b"metadata", "mx_records", b"mx_records", "name", b"name", "ptr_records", b"ptr_records", "resource_info", b"resource_info", "soa_record", b"soa_record", "srv_records", b"srv_records", "ttl", b"ttl", "txt_records", b"txt_records"]) -> None: ...

global___PrivateDnsZonesSRV = PrivateDnsZonesSRV

@typing_extensions.final
class PrivateDnsZonesSOA(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class MetadataEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    TTL_FIELD_NUMBER: builtins.int
    A_RECORDS_FIELD_NUMBER: builtins.int
    AAAA_RECORDS_FIELD_NUMBER: builtins.int
    CNAME_RECORD_FIELD_NUMBER: builtins.int
    MX_RECORDS_FIELD_NUMBER: builtins.int
    PTR_RECORDS_FIELD_NUMBER: builtins.int
    SOA_RECORD_FIELD_NUMBER: builtins.int
    SRV_RECORDS_FIELD_NUMBER: builtins.int
    TXT_RECORDS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    etag: builtins.str
    @property
    def metadata(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    ttl: builtins.int
    @property
    def a_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ARecord]: ...
    @property
    def aaaa_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AaaaRecord]: ...
    @property
    def cname_record(self) -> global___CnameRecord: ...
    @property
    def mx_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MxRecord]: ...
    @property
    def ptr_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PtrRecord]: ...
    @property
    def soa_record(self) -> global___SoaRecord: ...
    @property
    def srv_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SrvRecord]: ...
    @property
    def txt_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TxtRecord]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        etag: builtins.str = ...,
        metadata: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        ttl: builtins.int = ...,
        a_records: collections.abc.Iterable[global___ARecord] | None = ...,
        aaaa_records: collections.abc.Iterable[global___AaaaRecord] | None = ...,
        cname_record: global___CnameRecord | None = ...,
        mx_records: collections.abc.Iterable[global___MxRecord] | None = ...,
        ptr_records: collections.abc.Iterable[global___PtrRecord] | None = ...,
        soa_record: global___SoaRecord | None = ...,
        srv_records: collections.abc.Iterable[global___SrvRecord] | None = ...,
        txt_records: collections.abc.Iterable[global___TxtRecord] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cname_record", b"cname_record", "resource_info", b"resource_info", "soa_record", b"soa_record"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["a_records", b"a_records", "aaaa_records", b"aaaa_records", "cname_record", b"cname_record", "etag", b"etag", "metadata", b"metadata", "mx_records", b"mx_records", "name", b"name", "ptr_records", b"ptr_records", "resource_info", b"resource_info", "soa_record", b"soa_record", "srv_records", b"srv_records", "ttl", b"ttl", "txt_records", b"txt_records"]) -> None: ...

global___PrivateDnsZonesSOA = PrivateDnsZonesSOA

@typing_extensions.final
class PrivateDnsZonesPTR(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class MetadataEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    TTL_FIELD_NUMBER: builtins.int
    A_RECORDS_FIELD_NUMBER: builtins.int
    AAAA_RECORDS_FIELD_NUMBER: builtins.int
    CNAME_RECORD_FIELD_NUMBER: builtins.int
    MX_RECORDS_FIELD_NUMBER: builtins.int
    PTR_RECORDS_FIELD_NUMBER: builtins.int
    SOA_RECORD_FIELD_NUMBER: builtins.int
    SRV_RECORDS_FIELD_NUMBER: builtins.int
    TXT_RECORDS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    etag: builtins.str
    @property
    def metadata(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    ttl: builtins.int
    @property
    def a_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ARecord]: ...
    @property
    def aaaa_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AaaaRecord]: ...
    @property
    def cname_record(self) -> global___CnameRecord: ...
    @property
    def mx_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MxRecord]: ...
    @property
    def ptr_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PtrRecord]: ...
    @property
    def soa_record(self) -> global___SoaRecord: ...
    @property
    def srv_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SrvRecord]: ...
    @property
    def txt_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TxtRecord]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        etag: builtins.str = ...,
        metadata: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        ttl: builtins.int = ...,
        a_records: collections.abc.Iterable[global___ARecord] | None = ...,
        aaaa_records: collections.abc.Iterable[global___AaaaRecord] | None = ...,
        cname_record: global___CnameRecord | None = ...,
        mx_records: collections.abc.Iterable[global___MxRecord] | None = ...,
        ptr_records: collections.abc.Iterable[global___PtrRecord] | None = ...,
        soa_record: global___SoaRecord | None = ...,
        srv_records: collections.abc.Iterable[global___SrvRecord] | None = ...,
        txt_records: collections.abc.Iterable[global___TxtRecord] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cname_record", b"cname_record", "resource_info", b"resource_info", "soa_record", b"soa_record"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["a_records", b"a_records", "aaaa_records", b"aaaa_records", "cname_record", b"cname_record", "etag", b"etag", "metadata", b"metadata", "mx_records", b"mx_records", "name", b"name", "ptr_records", b"ptr_records", "resource_info", b"resource_info", "soa_record", b"soa_record", "srv_records", b"srv_records", "ttl", b"ttl", "txt_records", b"txt_records"]) -> None: ...

global___PrivateDnsZonesPTR = PrivateDnsZonesPTR

@typing_extensions.final
class PrivateDnsZonesMX(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class MetadataEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    TTL_FIELD_NUMBER: builtins.int
    A_RECORDS_FIELD_NUMBER: builtins.int
    AAAA_RECORDS_FIELD_NUMBER: builtins.int
    CNAME_RECORD_FIELD_NUMBER: builtins.int
    MX_RECORDS_FIELD_NUMBER: builtins.int
    PTR_RECORDS_FIELD_NUMBER: builtins.int
    SOA_RECORD_FIELD_NUMBER: builtins.int
    SRV_RECORDS_FIELD_NUMBER: builtins.int
    TXT_RECORDS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    etag: builtins.str
    @property
    def metadata(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    ttl: builtins.int
    @property
    def a_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ARecord]: ...
    @property
    def aaaa_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AaaaRecord]: ...
    @property
    def cname_record(self) -> global___CnameRecord: ...
    @property
    def mx_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MxRecord]: ...
    @property
    def ptr_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PtrRecord]: ...
    @property
    def soa_record(self) -> global___SoaRecord: ...
    @property
    def srv_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SrvRecord]: ...
    @property
    def txt_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TxtRecord]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        etag: builtins.str = ...,
        metadata: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        ttl: builtins.int = ...,
        a_records: collections.abc.Iterable[global___ARecord] | None = ...,
        aaaa_records: collections.abc.Iterable[global___AaaaRecord] | None = ...,
        cname_record: global___CnameRecord | None = ...,
        mx_records: collections.abc.Iterable[global___MxRecord] | None = ...,
        ptr_records: collections.abc.Iterable[global___PtrRecord] | None = ...,
        soa_record: global___SoaRecord | None = ...,
        srv_records: collections.abc.Iterable[global___SrvRecord] | None = ...,
        txt_records: collections.abc.Iterable[global___TxtRecord] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cname_record", b"cname_record", "resource_info", b"resource_info", "soa_record", b"soa_record"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["a_records", b"a_records", "aaaa_records", b"aaaa_records", "cname_record", b"cname_record", "etag", b"etag", "metadata", b"metadata", "mx_records", b"mx_records", "name", b"name", "ptr_records", b"ptr_records", "resource_info", b"resource_info", "soa_record", b"soa_record", "srv_records", b"srv_records", "ttl", b"ttl", "txt_records", b"txt_records"]) -> None: ...

global___PrivateDnsZonesMX = PrivateDnsZonesMX

@typing_extensions.final
class PrivateDnsZonesCNAME(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class MetadataEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    TTL_FIELD_NUMBER: builtins.int
    A_RECORDS_FIELD_NUMBER: builtins.int
    AAAA_RECORDS_FIELD_NUMBER: builtins.int
    CNAME_RECORD_FIELD_NUMBER: builtins.int
    MX_RECORDS_FIELD_NUMBER: builtins.int
    PTR_RECORDS_FIELD_NUMBER: builtins.int
    SOA_RECORD_FIELD_NUMBER: builtins.int
    SRV_RECORDS_FIELD_NUMBER: builtins.int
    TXT_RECORDS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    etag: builtins.str
    @property
    def metadata(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    ttl: builtins.int
    @property
    def a_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ARecord]: ...
    @property
    def aaaa_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AaaaRecord]: ...
    @property
    def cname_record(self) -> global___CnameRecord: ...
    @property
    def mx_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MxRecord]: ...
    @property
    def ptr_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PtrRecord]: ...
    @property
    def soa_record(self) -> global___SoaRecord: ...
    @property
    def srv_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SrvRecord]: ...
    @property
    def txt_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TxtRecord]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        etag: builtins.str = ...,
        metadata: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        ttl: builtins.int = ...,
        a_records: collections.abc.Iterable[global___ARecord] | None = ...,
        aaaa_records: collections.abc.Iterable[global___AaaaRecord] | None = ...,
        cname_record: global___CnameRecord | None = ...,
        mx_records: collections.abc.Iterable[global___MxRecord] | None = ...,
        ptr_records: collections.abc.Iterable[global___PtrRecord] | None = ...,
        soa_record: global___SoaRecord | None = ...,
        srv_records: collections.abc.Iterable[global___SrvRecord] | None = ...,
        txt_records: collections.abc.Iterable[global___TxtRecord] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cname_record", b"cname_record", "resource_info", b"resource_info", "soa_record", b"soa_record"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["a_records", b"a_records", "aaaa_records", b"aaaa_records", "cname_record", b"cname_record", "etag", b"etag", "metadata", b"metadata", "mx_records", b"mx_records", "name", b"name", "ptr_records", b"ptr_records", "resource_info", b"resource_info", "soa_record", b"soa_record", "srv_records", b"srv_records", "ttl", b"ttl", "txt_records", b"txt_records"]) -> None: ...

global___PrivateDnsZonesCNAME = PrivateDnsZonesCNAME

@typing_extensions.final
class PrivateDnsZonesAAAA(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class MetadataEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    TTL_FIELD_NUMBER: builtins.int
    A_RECORDS_FIELD_NUMBER: builtins.int
    AAAA_RECORDS_FIELD_NUMBER: builtins.int
    CNAME_RECORD_FIELD_NUMBER: builtins.int
    MX_RECORDS_FIELD_NUMBER: builtins.int
    PTR_RECORDS_FIELD_NUMBER: builtins.int
    SOA_RECORD_FIELD_NUMBER: builtins.int
    SRV_RECORDS_FIELD_NUMBER: builtins.int
    TXT_RECORDS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    etag: builtins.str
    @property
    def metadata(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    ttl: builtins.int
    @property
    def a_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ARecord]: ...
    @property
    def aaaa_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AaaaRecord]: ...
    @property
    def cname_record(self) -> global___CnameRecord: ...
    @property
    def mx_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MxRecord]: ...
    @property
    def ptr_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PtrRecord]: ...
    @property
    def soa_record(self) -> global___SoaRecord: ...
    @property
    def srv_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SrvRecord]: ...
    @property
    def txt_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TxtRecord]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        etag: builtins.str = ...,
        metadata: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        ttl: builtins.int = ...,
        a_records: collections.abc.Iterable[global___ARecord] | None = ...,
        aaaa_records: collections.abc.Iterable[global___AaaaRecord] | None = ...,
        cname_record: global___CnameRecord | None = ...,
        mx_records: collections.abc.Iterable[global___MxRecord] | None = ...,
        ptr_records: collections.abc.Iterable[global___PtrRecord] | None = ...,
        soa_record: global___SoaRecord | None = ...,
        srv_records: collections.abc.Iterable[global___SrvRecord] | None = ...,
        txt_records: collections.abc.Iterable[global___TxtRecord] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cname_record", b"cname_record", "resource_info", b"resource_info", "soa_record", b"soa_record"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["a_records", b"a_records", "aaaa_records", b"aaaa_records", "cname_record", b"cname_record", "etag", b"etag", "metadata", b"metadata", "mx_records", b"mx_records", "name", b"name", "ptr_records", b"ptr_records", "resource_info", b"resource_info", "soa_record", b"soa_record", "srv_records", b"srv_records", "ttl", b"ttl", "txt_records", b"txt_records"]) -> None: ...

global___PrivateDnsZonesAAAA = PrivateDnsZonesAAAA

@typing_extensions.final
class PrivateDnsZonesA(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class MetadataEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    TTL_FIELD_NUMBER: builtins.int
    A_RECORDS_FIELD_NUMBER: builtins.int
    AAAA_RECORDS_FIELD_NUMBER: builtins.int
    CNAME_RECORD_FIELD_NUMBER: builtins.int
    MX_RECORDS_FIELD_NUMBER: builtins.int
    PTR_RECORDS_FIELD_NUMBER: builtins.int
    SOA_RECORD_FIELD_NUMBER: builtins.int
    SRV_RECORDS_FIELD_NUMBER: builtins.int
    TXT_RECORDS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    etag: builtins.str
    @property
    def metadata(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    ttl: builtins.int
    @property
    def a_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ARecord]: ...
    @property
    def aaaa_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AaaaRecord]: ...
    @property
    def cname_record(self) -> global___CnameRecord: ...
    @property
    def mx_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MxRecord]: ...
    @property
    def ptr_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PtrRecord]: ...
    @property
    def soa_record(self) -> global___SoaRecord: ...
    @property
    def srv_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SrvRecord]: ...
    @property
    def txt_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TxtRecord]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        etag: builtins.str = ...,
        metadata: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        ttl: builtins.int = ...,
        a_records: collections.abc.Iterable[global___ARecord] | None = ...,
        aaaa_records: collections.abc.Iterable[global___AaaaRecord] | None = ...,
        cname_record: global___CnameRecord | None = ...,
        mx_records: collections.abc.Iterable[global___MxRecord] | None = ...,
        ptr_records: collections.abc.Iterable[global___PtrRecord] | None = ...,
        soa_record: global___SoaRecord | None = ...,
        srv_records: collections.abc.Iterable[global___SrvRecord] | None = ...,
        txt_records: collections.abc.Iterable[global___TxtRecord] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cname_record", b"cname_record", "resource_info", b"resource_info", "soa_record", b"soa_record"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["a_records", b"a_records", "aaaa_records", b"aaaa_records", "cname_record", b"cname_record", "etag", b"etag", "metadata", b"metadata", "mx_records", b"mx_records", "name", b"name", "ptr_records", b"ptr_records", "resource_info", b"resource_info", "soa_record", b"soa_record", "srv_records", b"srv_records", "ttl", b"ttl", "txt_records", b"txt_records"]) -> None: ...

global___PrivateDnsZonesA = PrivateDnsZonesA

@typing_extensions.final
class TxtRecord(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALUE_FIELD_NUMBER: builtins.int
    @property
    def value(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        value: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["value", b"value"]) -> None: ...

global___TxtRecord = TxtRecord

@typing_extensions.final
class SrvRecord(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PRIORITY_FIELD_NUMBER: builtins.int
    WEIGHT_FIELD_NUMBER: builtins.int
    PORT_FIELD_NUMBER: builtins.int
    TARGET_FIELD_NUMBER: builtins.int
    priority: builtins.int
    weight: builtins.int
    port: builtins.int
    target: builtins.str
    def __init__(
        self,
        *,
        priority: builtins.int = ...,
        weight: builtins.int = ...,
        port: builtins.int = ...,
        target: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["port", b"port", "priority", b"priority", "target", b"target", "weight", b"weight"]) -> None: ...

global___SrvRecord = SrvRecord

@typing_extensions.final
class SoaRecord(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOST_FIELD_NUMBER: builtins.int
    EMAIL_FIELD_NUMBER: builtins.int
    SERIAL_NUMBER_FIELD_NUMBER: builtins.int
    REFRESH_TIME_FIELD_NUMBER: builtins.int
    RETRY_TIME_FIELD_NUMBER: builtins.int
    EXPIRE_TIME_FIELD_NUMBER: builtins.int
    MINIMUM_TTL_FIELD_NUMBER: builtins.int
    host: builtins.str
    email: builtins.str
    serial_number: builtins.int
    refresh_time: builtins.int
    retry_time: builtins.int
    expire_time: builtins.int
    minimum_ttl: builtins.int
    def __init__(
        self,
        *,
        host: builtins.str = ...,
        email: builtins.str = ...,
        serial_number: builtins.int = ...,
        refresh_time: builtins.int = ...,
        retry_time: builtins.int = ...,
        expire_time: builtins.int = ...,
        minimum_ttl: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["email", b"email", "expire_time", b"expire_time", "host", b"host", "minimum_ttl", b"minimum_ttl", "refresh_time", b"refresh_time", "retry_time", b"retry_time", "serial_number", b"serial_number"]) -> None: ...

global___SoaRecord = SoaRecord

@typing_extensions.final
class PtrRecord(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PTRDNAME_FIELD_NUMBER: builtins.int
    ptrdname: builtins.str
    def __init__(
        self,
        *,
        ptrdname: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["ptrdname", b"ptrdname"]) -> None: ...

global___PtrRecord = PtrRecord

@typing_extensions.final
class MxRecord(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PREFERENCE_FIELD_NUMBER: builtins.int
    EXCHANGE_FIELD_NUMBER: builtins.int
    preference: builtins.int
    exchange: builtins.str
    def __init__(
        self,
        *,
        preference: builtins.int = ...,
        exchange: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["exchange", b"exchange", "preference", b"preference"]) -> None: ...

global___MxRecord = MxRecord

@typing_extensions.final
class CnameRecord(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CNAME_FIELD_NUMBER: builtins.int
    cname: builtins.str
    def __init__(
        self,
        *,
        cname: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cname", b"cname"]) -> None: ...

global___CnameRecord = CnameRecord

@typing_extensions.final
class AaaaRecord(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IPV6_ADDRESS_FIELD_NUMBER: builtins.int
    ipv6_address: builtins.str
    def __init__(
        self,
        *,
        ipv6_address: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["ipv6_address", b"ipv6_address"]) -> None: ...

global___AaaaRecord = AaaaRecord

@typing_extensions.final
class ARecord(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IPV4_ADDRESS_FIELD_NUMBER: builtins.int
    ipv4_address: builtins.str
    def __init__(
        self,
        *,
        ipv4_address: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["ipv4_address", b"ipv4_address"]) -> None: ...

global___ARecord = ARecord

@typing_extensions.final
class PrivateDnsZonesVirtualNetworkLinks(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    VIRTUAL_NETWORK_FIELD_NUMBER: builtins.int
    REGISTRATION_ENABLED_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    etag: builtins.str
    virtual_network: builtins.str
    registration_enabled: builtins.bool
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        etag: builtins.str = ...,
        virtual_network: builtins.str = ...,
        registration_enabled: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["etag", b"etag", "name", b"name", "registration_enabled", b"registration_enabled", "resource_info", b"resource_info", "tags", b"tags", "virtual_network", b"virtual_network"]) -> None: ...

global___PrivateDnsZonesVirtualNetworkLinks = PrivateDnsZonesVirtualNetworkLinks

@typing_extensions.final
class PrivateDnsZones(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    PRIVATE_DNS_ZONES__A_FIELD_NUMBER: builtins.int
    PRIVATE_DNS_ZONES__AAAA_FIELD_NUMBER: builtins.int
    PRIVATE_DNS_ZONES__CNAME_FIELD_NUMBER: builtins.int
    PRIVATE_DNS_ZONES__MX_FIELD_NUMBER: builtins.int
    PRIVATE_DNS_ZONES__PTR_FIELD_NUMBER: builtins.int
    PRIVATE_DNS_ZONES__SOA_FIELD_NUMBER: builtins.int
    PRIVATE_DNS_ZONES__SRV_FIELD_NUMBER: builtins.int
    PRIVATE_DNS_ZONES__TXT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    location: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    etag: builtins.str
    @property
    def private_dns_zones__a(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PrivateDnsZonesA]: ...
    @property
    def private_dns_zones__aaaa(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PrivateDnsZonesAAAA]: ...
    @property
    def private_dns_zones__cname(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PrivateDnsZonesCNAME]: ...
    @property
    def private_dns_zones__mx(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PrivateDnsZonesMX]: ...
    @property
    def private_dns_zones__ptr(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PrivateDnsZonesPTR]: ...
    @property
    def private_dns_zones__soa(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PrivateDnsZonesSOA]: ...
    @property
    def private_dns_zones__srv(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PrivateDnsZonesSRV]: ...
    @property
    def private_dns_zones__txt(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PrivateDnsZonesTXT]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        location: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        etag: builtins.str = ...,
        private_dns_zones__a: collections.abc.Iterable[global___PrivateDnsZonesA] | None = ...,
        private_dns_zones__aaaa: collections.abc.Iterable[global___PrivateDnsZonesAAAA] | None = ...,
        private_dns_zones__cname: collections.abc.Iterable[global___PrivateDnsZonesCNAME] | None = ...,
        private_dns_zones__mx: collections.abc.Iterable[global___PrivateDnsZonesMX] | None = ...,
        private_dns_zones__ptr: collections.abc.Iterable[global___PrivateDnsZonesPTR] | None = ...,
        private_dns_zones__soa: collections.abc.Iterable[global___PrivateDnsZonesSOA] | None = ...,
        private_dns_zones__srv: collections.abc.Iterable[global___PrivateDnsZonesSRV] | None = ...,
        private_dns_zones__txt: collections.abc.Iterable[global___PrivateDnsZonesTXT] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["etag", b"etag", "location", b"location", "name", b"name", "private_dns_zones__a", b"private_dns_zones__a", "private_dns_zones__aaaa", b"private_dns_zones__aaaa", "private_dns_zones__cname", b"private_dns_zones__cname", "private_dns_zones__mx", b"private_dns_zones__mx", "private_dns_zones__ptr", b"private_dns_zones__ptr", "private_dns_zones__soa", b"private_dns_zones__soa", "private_dns_zones__srv", b"private_dns_zones__srv", "private_dns_zones__txt", b"private_dns_zones__txt", "resource_info", b"resource_info", "tags", b"tags"]) -> None: ...

global___PrivateDnsZones = PrivateDnsZones
