"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class LoggingBillingAccountBucketConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BILLING_ACCOUNT_FIELD_NUMBER: builtins.int
    BUCKET_ID_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LIFECYCLE_STATE_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    RETENTION_DAYS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    billing_account: builtins.str
    bucket_id: builtins.str
    description: builtins.str
    id: builtins.str
    lifecycle_state: builtins.str
    location: builtins.str
    name: builtins.str
    retention_days: builtins.float
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        billing_account: builtins.str = ...,
        bucket_id: builtins.str = ...,
        description: builtins.str = ...,
        id: builtins.str = ...,
        lifecycle_state: builtins.str = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        retention_days: builtins.float = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["billing_account", b"billing_account", "bucket_id", b"bucket_id", "description", b"description", "id", b"id", "lifecycle_state", b"lifecycle_state", "location", b"location", "name", b"name", "resource_info", b"resource_info", "retention_days", b"retention_days"]) -> None: ...

global___LoggingBillingAccountBucketConfig = LoggingBillingAccountBucketConfig

@typing_extensions.final
class LoggingBillingAccountExclusion(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BILLING_ACCOUNT_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    DISABLED_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    billing_account: builtins.str
    description: builtins.str
    disabled: builtins.bool
    filter: builtins.str
    id: builtins.str
    name: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        billing_account: builtins.str = ...,
        description: builtins.str = ...,
        disabled: builtins.bool = ...,
        filter: builtins.str = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["billing_account", b"billing_account", "description", b"description", "disabled", b"disabled", "filter", b"filter", "id", b"id", "name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___LoggingBillingAccountExclusion = LoggingBillingAccountExclusion

@typing_extensions.final
class LoggingBillingAccountSinkXBigqueryOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USE_PARTITIONED_TABLES_FIELD_NUMBER: builtins.int
    use_partitioned_tables: builtins.bool
    def __init__(
        self,
        *,
        use_partitioned_tables: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["use_partitioned_tables", b"use_partitioned_tables"]) -> None: ...

global___LoggingBillingAccountSinkXBigqueryOptions = LoggingBillingAccountSinkXBigqueryOptions

@typing_extensions.final
class LoggingBillingAccountSinkXExclusions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    DISABLED_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    description: builtins.str
    disabled: builtins.bool
    filter: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        disabled: builtins.bool = ...,
        filter: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "disabled", b"disabled", "filter", b"filter", "name", b"name"]) -> None: ...

global___LoggingBillingAccountSinkXExclusions = LoggingBillingAccountSinkXExclusions

@typing_extensions.final
class LoggingBillingAccountSink(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BILLING_ACCOUNT_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    DESTINATION_FIELD_NUMBER: builtins.int
    DISABLED_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    WRITER_IDENTITY_FIELD_NUMBER: builtins.int
    BIGQUERY_OPTIONS_FIELD_NUMBER: builtins.int
    EXCLUSIONS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    billing_account: builtins.str
    description: builtins.str
    destination: builtins.str
    disabled: builtins.bool
    filter: builtins.str
    id: builtins.str
    name: builtins.str
    writer_identity: builtins.str
    @property
    def bigquery_options(self) -> global___LoggingBillingAccountSinkXBigqueryOptions: ...
    @property
    def exclusions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___LoggingBillingAccountSinkXExclusions]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        billing_account: builtins.str = ...,
        description: builtins.str = ...,
        destination: builtins.str = ...,
        disabled: builtins.bool = ...,
        filter: builtins.str = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        writer_identity: builtins.str = ...,
        bigquery_options: global___LoggingBillingAccountSinkXBigqueryOptions | None = ...,
        exclusions: collections.abc.Iterable[global___LoggingBillingAccountSinkXExclusions] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["bigquery_options", b"bigquery_options", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bigquery_options", b"bigquery_options", "billing_account", b"billing_account", "description", b"description", "destination", b"destination", "disabled", b"disabled", "exclusions", b"exclusions", "filter", b"filter", "id", b"id", "name", b"name", "resource_info", b"resource_info", "writer_identity", b"writer_identity"]) -> None: ...

global___LoggingBillingAccountSink = LoggingBillingAccountSink

@typing_extensions.final
class LoggingFolderBucketConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUCKET_ID_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    FOLDER_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LIFECYCLE_STATE_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    RETENTION_DAYS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    bucket_id: builtins.str
    description: builtins.str
    folder: builtins.str
    id: builtins.str
    lifecycle_state: builtins.str
    location: builtins.str
    name: builtins.str
    retention_days: builtins.float
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        bucket_id: builtins.str = ...,
        description: builtins.str = ...,
        folder: builtins.str = ...,
        id: builtins.str = ...,
        lifecycle_state: builtins.str = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        retention_days: builtins.float = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bucket_id", b"bucket_id", "description", b"description", "folder", b"folder", "id", b"id", "lifecycle_state", b"lifecycle_state", "location", b"location", "name", b"name", "resource_info", b"resource_info", "retention_days", b"retention_days"]) -> None: ...

global___LoggingFolderBucketConfig = LoggingFolderBucketConfig

@typing_extensions.final
class LoggingFolderExclusion(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    DISABLED_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    FOLDER_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    description: builtins.str
    disabled: builtins.bool
    filter: builtins.str
    folder: builtins.str
    id: builtins.str
    name: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        disabled: builtins.bool = ...,
        filter: builtins.str = ...,
        folder: builtins.str = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "disabled", b"disabled", "filter", b"filter", "folder", b"folder", "id", b"id", "name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___LoggingFolderExclusion = LoggingFolderExclusion

@typing_extensions.final
class LoggingFolderSinkXBigqueryOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USE_PARTITIONED_TABLES_FIELD_NUMBER: builtins.int
    use_partitioned_tables: builtins.bool
    def __init__(
        self,
        *,
        use_partitioned_tables: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["use_partitioned_tables", b"use_partitioned_tables"]) -> None: ...

global___LoggingFolderSinkXBigqueryOptions = LoggingFolderSinkXBigqueryOptions

@typing_extensions.final
class LoggingFolderSinkXExclusions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    DISABLED_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    description: builtins.str
    disabled: builtins.bool
    filter: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        disabled: builtins.bool = ...,
        filter: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "disabled", b"disabled", "filter", b"filter", "name", b"name"]) -> None: ...

global___LoggingFolderSinkXExclusions = LoggingFolderSinkXExclusions

@typing_extensions.final
class LoggingFolderSink(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    DESTINATION_FIELD_NUMBER: builtins.int
    DISABLED_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    FOLDER_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    INCLUDE_CHILDREN_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    WRITER_IDENTITY_FIELD_NUMBER: builtins.int
    BIGQUERY_OPTIONS_FIELD_NUMBER: builtins.int
    EXCLUSIONS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    description: builtins.str
    destination: builtins.str
    disabled: builtins.bool
    filter: builtins.str
    folder: builtins.str
    id: builtins.str
    include_children: builtins.bool
    name: builtins.str
    writer_identity: builtins.str
    @property
    def bigquery_options(self) -> global___LoggingFolderSinkXBigqueryOptions: ...
    @property
    def exclusions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___LoggingFolderSinkXExclusions]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        destination: builtins.str = ...,
        disabled: builtins.bool = ...,
        filter: builtins.str = ...,
        folder: builtins.str = ...,
        id: builtins.str = ...,
        include_children: builtins.bool = ...,
        name: builtins.str = ...,
        writer_identity: builtins.str = ...,
        bigquery_options: global___LoggingFolderSinkXBigqueryOptions | None = ...,
        exclusions: collections.abc.Iterable[global___LoggingFolderSinkXExclusions] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["bigquery_options", b"bigquery_options", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bigquery_options", b"bigquery_options", "description", b"description", "destination", b"destination", "disabled", b"disabled", "exclusions", b"exclusions", "filter", b"filter", "folder", b"folder", "id", b"id", "include_children", b"include_children", "name", b"name", "resource_info", b"resource_info", "writer_identity", b"writer_identity"]) -> None: ...

global___LoggingFolderSink = LoggingFolderSink

@typing_extensions.final
class LoggingLogViewXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___LoggingLogViewXTimeouts = LoggingLogViewXTimeouts

@typing_extensions.final
class LoggingLogView(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUCKET_FIELD_NUMBER: builtins.int
    CREATE_TIME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PARENT_FIELD_NUMBER: builtins.int
    UPDATE_TIME_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    bucket: builtins.str
    create_time: builtins.str
    description: builtins.str
    filter: builtins.str
    id: builtins.str
    location: builtins.str
    name: builtins.str
    parent: builtins.str
    update_time: builtins.str
    @property
    def timeouts(self) -> global___LoggingLogViewXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        bucket: builtins.str = ...,
        create_time: builtins.str = ...,
        description: builtins.str = ...,
        filter: builtins.str = ...,
        id: builtins.str = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        parent: builtins.str = ...,
        update_time: builtins.str = ...,
        timeouts: global___LoggingLogViewXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bucket", b"bucket", "create_time", b"create_time", "description", b"description", "filter", b"filter", "id", b"id", "location", b"location", "name", b"name", "parent", b"parent", "resource_info", b"resource_info", "timeouts", b"timeouts", "update_time", b"update_time"]) -> None: ...

global___LoggingLogView = LoggingLogView

@typing_extensions.final
class LoggingMetricXBucketOptionsXExplicitBuckets(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BOUNDS_FIELD_NUMBER: builtins.int
    @property
    def bounds(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]: ...
    def __init__(
        self,
        *,
        bounds: collections.abc.Iterable[builtins.float] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bounds", b"bounds"]) -> None: ...

global___LoggingMetricXBucketOptionsXExplicitBuckets = LoggingMetricXBucketOptionsXExplicitBuckets

@typing_extensions.final
class LoggingMetricXBucketOptionsXExponentialBuckets(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GROWTH_FACTOR_FIELD_NUMBER: builtins.int
    NUM_FINITE_BUCKETS_FIELD_NUMBER: builtins.int
    SCALE_FIELD_NUMBER: builtins.int
    growth_factor: builtins.float
    num_finite_buckets: builtins.float
    scale: builtins.float
    def __init__(
        self,
        *,
        growth_factor: builtins.float = ...,
        num_finite_buckets: builtins.float = ...,
        scale: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["growth_factor", b"growth_factor", "num_finite_buckets", b"num_finite_buckets", "scale", b"scale"]) -> None: ...

global___LoggingMetricXBucketOptionsXExponentialBuckets = LoggingMetricXBucketOptionsXExponentialBuckets

@typing_extensions.final
class LoggingMetricXBucketOptionsXLinearBuckets(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NUM_FINITE_BUCKETS_FIELD_NUMBER: builtins.int
    OFFSET_FIELD_NUMBER: builtins.int
    WIDTH_FIELD_NUMBER: builtins.int
    num_finite_buckets: builtins.float
    offset: builtins.float
    width: builtins.float
    def __init__(
        self,
        *,
        num_finite_buckets: builtins.float = ...,
        offset: builtins.float = ...,
        width: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["num_finite_buckets", b"num_finite_buckets", "offset", b"offset", "width", b"width"]) -> None: ...

global___LoggingMetricXBucketOptionsXLinearBuckets = LoggingMetricXBucketOptionsXLinearBuckets

@typing_extensions.final
class LoggingMetricXBucketOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXPLICIT_BUCKETS_FIELD_NUMBER: builtins.int
    EXPONENTIAL_BUCKETS_FIELD_NUMBER: builtins.int
    LINEAR_BUCKETS_FIELD_NUMBER: builtins.int
    @property
    def explicit_buckets(self) -> global___LoggingMetricXBucketOptionsXExplicitBuckets: ...
    @property
    def exponential_buckets(self) -> global___LoggingMetricXBucketOptionsXExponentialBuckets: ...
    @property
    def linear_buckets(self) -> global___LoggingMetricXBucketOptionsXLinearBuckets: ...
    def __init__(
        self,
        *,
        explicit_buckets: global___LoggingMetricXBucketOptionsXExplicitBuckets | None = ...,
        exponential_buckets: global___LoggingMetricXBucketOptionsXExponentialBuckets | None = ...,
        linear_buckets: global___LoggingMetricXBucketOptionsXLinearBuckets | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["explicit_buckets", b"explicit_buckets", "exponential_buckets", b"exponential_buckets", "linear_buckets", b"linear_buckets"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["explicit_buckets", b"explicit_buckets", "exponential_buckets", b"exponential_buckets", "linear_buckets", b"linear_buckets"]) -> None: ...

global___LoggingMetricXBucketOptions = LoggingMetricXBucketOptions

@typing_extensions.final
class LoggingMetricXMetricDescriptorXLabels(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    VALUE_TYPE_FIELD_NUMBER: builtins.int
    description: builtins.str
    key: builtins.str
    value_type: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        key: builtins.str = ...,
        value_type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "key", b"key", "value_type", b"value_type"]) -> None: ...

global___LoggingMetricXMetricDescriptorXLabels = LoggingMetricXMetricDescriptorXLabels

@typing_extensions.final
class LoggingMetricXMetricDescriptor(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    METRIC_KIND_FIELD_NUMBER: builtins.int
    UNIT_FIELD_NUMBER: builtins.int
    VALUE_TYPE_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    display_name: builtins.str
    metric_kind: builtins.str
    unit: builtins.str
    value_type: builtins.str
    @property
    def labels(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___LoggingMetricXMetricDescriptorXLabels]: ...
    def __init__(
        self,
        *,
        display_name: builtins.str = ...,
        metric_kind: builtins.str = ...,
        unit: builtins.str = ...,
        value_type: builtins.str = ...,
        labels: collections.abc.Iterable[global___LoggingMetricXMetricDescriptorXLabels] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["display_name", b"display_name", "labels", b"labels", "metric_kind", b"metric_kind", "unit", b"unit", "value_type", b"value_type"]) -> None: ...

global___LoggingMetricXMetricDescriptor = LoggingMetricXMetricDescriptor

@typing_extensions.final
class LoggingMetricXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___LoggingMetricXTimeouts = LoggingMetricXTimeouts

@typing_extensions.final
class LoggingMetric(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class LabelExtractorsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    DESCRIPTION_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LABEL_EXTRACTORS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    VALUE_EXTRACTOR_FIELD_NUMBER: builtins.int
    BUCKET_OPTIONS_FIELD_NUMBER: builtins.int
    METRIC_DESCRIPTOR_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    description: builtins.str
    filter: builtins.str
    id: builtins.str
    @property
    def label_extractors(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    name: builtins.str
    project: builtins.str
    value_extractor: builtins.str
    @property
    def bucket_options(self) -> global___LoggingMetricXBucketOptions: ...
    @property
    def metric_descriptor(self) -> global___LoggingMetricXMetricDescriptor: ...
    @property
    def timeouts(self) -> global___LoggingMetricXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        filter: builtins.str = ...,
        id: builtins.str = ...,
        label_extractors: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        value_extractor: builtins.str = ...,
        bucket_options: global___LoggingMetricXBucketOptions | None = ...,
        metric_descriptor: global___LoggingMetricXMetricDescriptor | None = ...,
        timeouts: global___LoggingMetricXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["bucket_options", b"bucket_options", "metric_descriptor", b"metric_descriptor", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bucket_options", b"bucket_options", "description", b"description", "filter", b"filter", "id", b"id", "label_extractors", b"label_extractors", "metric_descriptor", b"metric_descriptor", "name", b"name", "project", b"project", "resource_info", b"resource_info", "timeouts", b"timeouts", "value_extractor", b"value_extractor"]) -> None: ...

global___LoggingMetric = LoggingMetric

@typing_extensions.final
class LoggingOrganizationBucketConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUCKET_ID_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LIFECYCLE_STATE_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ORGANIZATION_FIELD_NUMBER: builtins.int
    RETENTION_DAYS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    bucket_id: builtins.str
    description: builtins.str
    id: builtins.str
    lifecycle_state: builtins.str
    location: builtins.str
    name: builtins.str
    organization: builtins.str
    retention_days: builtins.float
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        bucket_id: builtins.str = ...,
        description: builtins.str = ...,
        id: builtins.str = ...,
        lifecycle_state: builtins.str = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        organization: builtins.str = ...,
        retention_days: builtins.float = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bucket_id", b"bucket_id", "description", b"description", "id", b"id", "lifecycle_state", b"lifecycle_state", "location", b"location", "name", b"name", "organization", b"organization", "resource_info", b"resource_info", "retention_days", b"retention_days"]) -> None: ...

global___LoggingOrganizationBucketConfig = LoggingOrganizationBucketConfig

@typing_extensions.final
class LoggingOrganizationExclusion(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    DISABLED_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ORG_ID_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    description: builtins.str
    disabled: builtins.bool
    filter: builtins.str
    id: builtins.str
    name: builtins.str
    org_id: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        disabled: builtins.bool = ...,
        filter: builtins.str = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        org_id: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "disabled", b"disabled", "filter", b"filter", "id", b"id", "name", b"name", "org_id", b"org_id", "resource_info", b"resource_info"]) -> None: ...

global___LoggingOrganizationExclusion = LoggingOrganizationExclusion

@typing_extensions.final
class LoggingOrganizationSinkXBigqueryOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USE_PARTITIONED_TABLES_FIELD_NUMBER: builtins.int
    use_partitioned_tables: builtins.bool
    def __init__(
        self,
        *,
        use_partitioned_tables: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["use_partitioned_tables", b"use_partitioned_tables"]) -> None: ...

global___LoggingOrganizationSinkXBigqueryOptions = LoggingOrganizationSinkXBigqueryOptions

@typing_extensions.final
class LoggingOrganizationSinkXExclusions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    DISABLED_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    description: builtins.str
    disabled: builtins.bool
    filter: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        disabled: builtins.bool = ...,
        filter: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "disabled", b"disabled", "filter", b"filter", "name", b"name"]) -> None: ...

global___LoggingOrganizationSinkXExclusions = LoggingOrganizationSinkXExclusions

@typing_extensions.final
class LoggingOrganizationSink(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    DESTINATION_FIELD_NUMBER: builtins.int
    DISABLED_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    INCLUDE_CHILDREN_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ORG_ID_FIELD_NUMBER: builtins.int
    WRITER_IDENTITY_FIELD_NUMBER: builtins.int
    BIGQUERY_OPTIONS_FIELD_NUMBER: builtins.int
    EXCLUSIONS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    description: builtins.str
    destination: builtins.str
    disabled: builtins.bool
    filter: builtins.str
    id: builtins.str
    include_children: builtins.bool
    name: builtins.str
    org_id: builtins.str
    writer_identity: builtins.str
    @property
    def bigquery_options(self) -> global___LoggingOrganizationSinkXBigqueryOptions: ...
    @property
    def exclusions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___LoggingOrganizationSinkXExclusions]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        destination: builtins.str = ...,
        disabled: builtins.bool = ...,
        filter: builtins.str = ...,
        id: builtins.str = ...,
        include_children: builtins.bool = ...,
        name: builtins.str = ...,
        org_id: builtins.str = ...,
        writer_identity: builtins.str = ...,
        bigquery_options: global___LoggingOrganizationSinkXBigqueryOptions | None = ...,
        exclusions: collections.abc.Iterable[global___LoggingOrganizationSinkXExclusions] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["bigquery_options", b"bigquery_options", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bigquery_options", b"bigquery_options", "description", b"description", "destination", b"destination", "disabled", b"disabled", "exclusions", b"exclusions", "filter", b"filter", "id", b"id", "include_children", b"include_children", "name", b"name", "org_id", b"org_id", "resource_info", b"resource_info", "writer_identity", b"writer_identity"]) -> None: ...

global___LoggingOrganizationSink = LoggingOrganizationSink

@typing_extensions.final
class LoggingProjectBucketConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUCKET_ID_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LIFECYCLE_STATE_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    RETENTION_DAYS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    bucket_id: builtins.str
    description: builtins.str
    id: builtins.str
    lifecycle_state: builtins.str
    location: builtins.str
    name: builtins.str
    project: builtins.str
    retention_days: builtins.float
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        bucket_id: builtins.str = ...,
        description: builtins.str = ...,
        id: builtins.str = ...,
        lifecycle_state: builtins.str = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        retention_days: builtins.float = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bucket_id", b"bucket_id", "description", b"description", "id", b"id", "lifecycle_state", b"lifecycle_state", "location", b"location", "name", b"name", "project", b"project", "resource_info", b"resource_info", "retention_days", b"retention_days"]) -> None: ...

global___LoggingProjectBucketConfig = LoggingProjectBucketConfig

@typing_extensions.final
class LoggingProjectExclusion(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    DISABLED_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    description: builtins.str
    disabled: builtins.bool
    filter: builtins.str
    id: builtins.str
    name: builtins.str
    project: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        disabled: builtins.bool = ...,
        filter: builtins.str = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "disabled", b"disabled", "filter", b"filter", "id", b"id", "name", b"name", "project", b"project", "resource_info", b"resource_info"]) -> None: ...

global___LoggingProjectExclusion = LoggingProjectExclusion

@typing_extensions.final
class LoggingProjectSinkXBigqueryOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USE_PARTITIONED_TABLES_FIELD_NUMBER: builtins.int
    use_partitioned_tables: builtins.bool
    def __init__(
        self,
        *,
        use_partitioned_tables: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["use_partitioned_tables", b"use_partitioned_tables"]) -> None: ...

global___LoggingProjectSinkXBigqueryOptions = LoggingProjectSinkXBigqueryOptions

@typing_extensions.final
class LoggingProjectSinkXExclusions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    DISABLED_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    description: builtins.str
    disabled: builtins.bool
    filter: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        disabled: builtins.bool = ...,
        filter: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "disabled", b"disabled", "filter", b"filter", "name", b"name"]) -> None: ...

global___LoggingProjectSinkXExclusions = LoggingProjectSinkXExclusions

@typing_extensions.final
class LoggingProjectSink(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    DESTINATION_FIELD_NUMBER: builtins.int
    DISABLED_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    UNIQUE_WRITER_IDENTITY_FIELD_NUMBER: builtins.int
    WRITER_IDENTITY_FIELD_NUMBER: builtins.int
    BIGQUERY_OPTIONS_FIELD_NUMBER: builtins.int
    EXCLUSIONS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    description: builtins.str
    destination: builtins.str
    disabled: builtins.bool
    filter: builtins.str
    id: builtins.str
    name: builtins.str
    project: builtins.str
    unique_writer_identity: builtins.bool
    writer_identity: builtins.str
    @property
    def bigquery_options(self) -> global___LoggingProjectSinkXBigqueryOptions: ...
    @property
    def exclusions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___LoggingProjectSinkXExclusions]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        destination: builtins.str = ...,
        disabled: builtins.bool = ...,
        filter: builtins.str = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        unique_writer_identity: builtins.bool = ...,
        writer_identity: builtins.str = ...,
        bigquery_options: global___LoggingProjectSinkXBigqueryOptions | None = ...,
        exclusions: collections.abc.Iterable[global___LoggingProjectSinkXExclusions] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["bigquery_options", b"bigquery_options", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bigquery_options", b"bigquery_options", "description", b"description", "destination", b"destination", "disabled", b"disabled", "exclusions", b"exclusions", "filter", b"filter", "id", b"id", "name", b"name", "project", b"project", "resource_info", b"resource_info", "unique_writer_identity", b"unique_writer_identity", "writer_identity", b"writer_identity"]) -> None: ...

global___LoggingProjectSink = LoggingProjectSink
