# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_compute_ssl.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19gcp/gcp_compute_ssl.proto\x12\x1boak9.tython.gcp.compute_ssl\x1a\x13shared/shared.proto\"@\n\x1e\x43omputeSslCertificateXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\"\xe5\x02\n\x15\x43omputeSslCertificate\x12\x13\n\x0b\x63\x65rtificate\x18\x01 \x01(\t\x12\x16\n\x0e\x63\x65rtificate_id\x18\x02 \x01(\x01\x12\x1a\n\x12\x63reation_timestamp\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\n\n\x02id\x18\x05 \x01(\t\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x13\n\x0bname_prefix\x18\x07 \x01(\t\x12\x13\n\x0bprivate_key\x18\x08 \x01(\t\x12\x0f\n\x07project\x18\t \x01(\t\x12\x11\n\tself_link\x18\n \x01(\t\x12M\n\x08timeouts\x18\x0b \x01(\x0b\x32;.oak9.tython.gcp.compute_ssl.ComputeSslCertificateXTimeouts\x12\x37\n\rresource_info\x18\x0c \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"K\n\x19\x43omputeSslPolicyXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xf6\x02\n\x10\x43omputeSslPolicy\x12\x1a\n\x12\x63reation_timestamp\x18\x01 \x01(\t\x12\x17\n\x0f\x63ustom_features\x18\x02 \x03(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x18\n\x10\x65nabled_features\x18\x04 \x03(\t\x12\x13\n\x0b\x66ingerprint\x18\x05 \x01(\t\x12\n\n\x02id\x18\x06 \x01(\t\x12\x17\n\x0fmin_tls_version\x18\x07 \x01(\t\x12\x0c\n\x04name\x18\x08 \x01(\t\x12\x0f\n\x07profile\x18\t \x01(\t\x12\x0f\n\x07project\x18\n \x01(\t\x12\x11\n\tself_link\x18\x0b \x01(\t\x12H\n\x08timeouts\x18\x0c \x01(\x0b\x32\x36.oak9.tython.gcp.compute_ssl.ComputeSslPolicyXTimeouts\x12\x37\n\rresource_info\x18\r \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_compute_ssl_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMPUTESSLCERTIFICATEXTIMEOUTS._serialized_start=79
  _COMPUTESSLCERTIFICATEXTIMEOUTS._serialized_end=143
  _COMPUTESSLCERTIFICATE._serialized_start=146
  _COMPUTESSLCERTIFICATE._serialized_end=503
  _COMPUTESSLPOLICYXTIMEOUTS._serialized_start=505
  _COMPUTESSLPOLICYXTIMEOUTS._serialized_end=580
  _COMPUTESSLPOLICY._serialized_start=583
  _COMPUTESSLPOLICY._serialized_end=957
# @@protoc_insertion_point(module_scope)
