"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ComputeManagedSslCertificateXManaged(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DOMAINS_FIELD_NUMBER: builtins.int
    @property
    def domains(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        domains: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["domains", b"domains"]) -> None: ...

global___ComputeManagedSslCertificateXManaged = ComputeManagedSslCertificateXManaged

@typing_extensions.final
class ComputeManagedSslCertificateXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete"]) -> None: ...

global___ComputeManagedSslCertificateXTimeouts = ComputeManagedSslCertificateXTimeouts

@typing_extensions.final
class ComputeManagedSslCertificate(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CERTIFICATE_ID_FIELD_NUMBER: builtins.int
    CREATION_TIMESTAMP_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPIRE_TIME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    SELF_LINK_FIELD_NUMBER: builtins.int
    SUBJECT_ALTERNATIVE_NAMES_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    MANAGED_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    certificate_id: builtins.float
    creation_timestamp: builtins.str
    description: builtins.str
    expire_time: builtins.str
    id: builtins.str
    name: builtins.str
    project: builtins.str
    self_link: builtins.str
    @property
    def subject_alternative_names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    type: builtins.str
    @property
    def managed(self) -> global___ComputeManagedSslCertificateXManaged: ...
    @property
    def timeouts(self) -> global___ComputeManagedSslCertificateXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        certificate_id: builtins.float = ...,
        creation_timestamp: builtins.str = ...,
        description: builtins.str = ...,
        expire_time: builtins.str = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        self_link: builtins.str = ...,
        subject_alternative_names: collections.abc.Iterable[builtins.str] | None = ...,
        type: builtins.str = ...,
        managed: global___ComputeManagedSslCertificateXManaged | None = ...,
        timeouts: global___ComputeManagedSslCertificateXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["managed", b"managed", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["certificate_id", b"certificate_id", "creation_timestamp", b"creation_timestamp", "description", b"description", "expire_time", b"expire_time", "id", b"id", "managed", b"managed", "name", b"name", "project", b"project", "resource_info", b"resource_info", "self_link", b"self_link", "subject_alternative_names", b"subject_alternative_names", "timeouts", b"timeouts", "type", b"type"]) -> None: ...

global___ComputeManagedSslCertificate = ComputeManagedSslCertificate
