# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: azure/azure_microsoft_elastic.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#azure/azure_microsoft_elastic.proto\x12#oak9.tython.azure.microsoft_elastic\x1a\x13shared/shared.proto\"T\n\x11Microsoft_Elastic\x12?\n\x08monitors\x18\x01 \x03(\x0b\x32-.oak9.tython.azure.microsoft_elastic.Monitors\"\xb7\x01\n\x10MonitorsTagRules\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12@\n\tlog_rules\x18\x03 \x01(\x0b\x32-.oak9.tython.azure.microsoft_elastic.LogRules\x12\x1a\n\x12provisioning_state\x18\x04 \x01(\t\"\xa8\x01\n\x08LogRules\x12I\n\x0e\x66iltering_tags\x18\x01 \x03(\x0b\x32\x31.oak9.tython.azure.microsoft_elastic.FilteringTag\x12\x15\n\rsend_aad_logs\x18\x02 \x01(\x08\x12\x1a\n\x12send_activity_logs\x18\x03 \x01(\x08\x12\x1e\n\x16send_subscription_logs\x18\x04 \x01(\x08\";\n\x0c\x46ilteringTag\x12\x0e\n\x06\x61\x63tion\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\"\xb3\x05\n\x08Monitors\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12I\n\x08identity\x18\x02 \x01(\x0b\x32\x37.oak9.tython.azure.microsoft_elastic.IdentityProperties\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12R\n\x12\x65lastic_properties\x18\x05 \x01(\x0b\x32\x36.oak9.tython.azure.microsoft_elastic.ElasticProperties\x12\x1f\n\x17liftr_resource_category\x18\x06 \x01(\t\x12\x19\n\x11monitoring_status\x18\x07 \x01(\t\x12\x1a\n\x12provisioning_state\x18\x08 \x01(\t\x12@\n\tuser_info\x18\t \x01(\x0b\x32-.oak9.tython.azure.microsoft_elastic.UserInfo\x12\x0f\n\x07version\x18\n \x01(\t\x12=\n\x03sku\x18\x0b \x01(\x0b\x32\x30.oak9.tython.azure.microsoft_elastic.ResourceSku\x12\x45\n\x04tags\x18\x0c \x03(\x0b\x32\x37.oak9.tython.azure.microsoft_elastic.Monitors.TagsEntry\x12Q\n\x12monitors_tag_rules\x18\r \x03(\x0b\x32\x35.oak9.tython.azure.microsoft_elastic.MonitorsTagRules\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x1b\n\x0bResourceSku\x12\x0c\n\x04name\x18\x01 \x01(\t\"\xa6\x01\n\x08UserInfo\x12\x46\n\x0c\x63ompany_info\x18\x01 \x01(\x0b\x32\x30.oak9.tython.azure.microsoft_elastic.CompanyInfo\x12\x14\n\x0c\x63ompany_name\x18\x02 \x01(\t\x12\x15\n\remail_address\x18\x03 \x01(\t\x12\x12\n\nfirst_name\x18\x04 \x01(\t\x12\x11\n\tlast_name\x18\x05 \x01(\t\"i\n\x0b\x43ompanyInfo\x12\x10\n\x08\x62usiness\x18\x01 \x01(\t\x12\x0f\n\x07\x63ountry\x18\x02 \x01(\t\x12\x0e\n\x06\x64omain\x18\x03 \x01(\t\x12\x18\n\x10\x65mployees_number\x18\x04 \x01(\t\x12\r\n\x05state\x18\x05 \x01(\t\"\xc5\x01\n\x11\x45lasticProperties\x12]\n\x18\x65lastic_cloud_deployment\x18\x01 \x01(\x0b\x32;.oak9.tython.azure.microsoft_elastic.ElasticCloudDeployment\x12Q\n\x12\x65lastic_cloud_user\x18\x02 \x01(\x0b\x32\x35.oak9.tython.azure.microsoft_elastic.ElasticCloudUser\" \n\x10\x45lasticCloudUser\x12\x0c\n\x04name\x18\x01 \x01(\t\"&\n\x16\x45lasticCloudDeployment\x12\x0c\n\x04name\x18\x01 \x01(\t\"\"\n\x12IdentityProperties\x12\x0c\n\x04type\x18\x01 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'azure.azure_microsoft_elastic_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _MONITORS_TAGSENTRY._options = None
  _MONITORS_TAGSENTRY._serialized_options = b'8\001'
  _MICROSOFT_ELASTIC._serialized_start=97
  _MICROSOFT_ELASTIC._serialized_end=181
  _MONITORSTAGRULES._serialized_start=184
  _MONITORSTAGRULES._serialized_end=367
  _LOGRULES._serialized_start=370
  _LOGRULES._serialized_end=538
  _FILTERINGTAG._serialized_start=540
  _FILTERINGTAG._serialized_end=599
  _MONITORS._serialized_start=602
  _MONITORS._serialized_end=1293
  _MONITORS_TAGSENTRY._serialized_start=1250
  _MONITORS_TAGSENTRY._serialized_end=1293
  _RESOURCESKU._serialized_start=1295
  _RESOURCESKU._serialized_end=1322
  _USERINFO._serialized_start=1325
  _USERINFO._serialized_end=1491
  _COMPANYINFO._serialized_start=1493
  _COMPANYINFO._serialized_end=1598
  _ELASTICPROPERTIES._serialized_start=1601
  _ELASTICPROPERTIES._serialized_end=1798
  _ELASTICCLOUDUSER._serialized_start=1800
  _ELASTICCLOUDUSER._serialized_end=1832
  _ELASTICCLOUDDEPLOYMENT._serialized_start=1834
  _ELASTICCLOUDDEPLOYMENT._serialized_end=1872
  _IDENTITYPROPERTIES._serialized_start=1874
  _IDENTITYPROPERTIES._serialized_end=1908
# @@protoc_insertion_point(module_scope)
