# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: azure/azure_microsoft_cdn.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x61zure/azure_microsoft_cdn.proto\x12\x1foak9.tython.azure.microsoft_cdn\x1a\x13shared/shared.proto\"\xc4\x04\n\rMicrosoft_Cdn\x12q\n%cdn_web_application_firewall_policies\x18\x01 \x03(\x0b\x32\x42.oak9.tython.azure.microsoft_cdn.CdnWebApplicationFirewallPolicies\x12;\n\x08profiles\x18\x02 \x01(\x0b\x32).oak9.tython.azure.microsoft_cdn.Profiles\x12N\n\x12profiles_endpoints\x18\x03 \x03(\x0b\x32\x32.oak9.tython.azure.microsoft_cdn.ProfilesEndpoints\x12j\n!profiles_endpoints_custom_domains\x18\x04 \x03(\x0b\x32?.oak9.tython.azure.microsoft_cdn.ProfilesEndpointsCustomDomains\x12h\n profiles_endpoints_origin_groups\x18\x05 \x03(\x0b\x32>.oak9.tython.azure.microsoft_cdn.ProfilesEndpointsOriginGroups\x12]\n\x1aprofiles_endpoints_origins\x18\x06 \x03(\x0b\x32\x39.oak9.tython.azure.microsoft_cdn.ProfilesEndpointsOrigins\"\xb0\x01\n\x18ProfilesSecurityPolicies\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12M\n\nparameters\x18\x03 \x01(\x0b\x32\x39.oak9.tython.azure.microsoft_cdn.SecurityPolicyParameters\"(\n\x18SecurityPolicyParameters\x12\x0c\n\x04name\x18\x01 \x01(\t\"\x9f\x01\n\x0fProfilesSecrets\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x45\n\nparameters\x18\x03 \x01(\x0b\x32\x31.oak9.tython.azure.microsoft_cdn.SecretParameters\" \n\x10SecretParameters\x12\x0c\n\x04name\x18\x01 \x01(\t\"\xa3\x02\n\x15ProfilesRuleSetsRules\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x45\n\x07\x61\x63tions\x18\x03 \x03(\x0b\x32\x34.oak9.tython.azure.microsoft_cdn.DeliveryRuleAction1\x12J\n\nconditions\x18\x04 \x03(\x0b\x32\x36.oak9.tython.azure.microsoft_cdn.DeliveryRuleCondition\x12!\n\x19match_processing_behavior\x18\x05 \x01(\t\x12\r\n\x05order\x18\x06 \x01(\x05\"\xb3\x01\n\x10ProfilesRuleSets\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12X\n\x18profiles_rule_sets_rules\x18\x03 \x03(\x0b\x32\x36.oak9.tython.azure.microsoft_cdn.ProfilesRuleSetsRules\"\xab\x04\n\x1bProfilesOriginGroupsOrigins\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12H\n\x0c\x61zure_origin\x18\x03 \x01(\x0b\x32\x32.oak9.tython.azure.microsoft_cdn.ResourceReference\x12\x15\n\renabled_state\x18\x04 \x01(\t\x12&\n\x1e\x65nforce_certificate_name_check\x18\x05 \x01(\x08\x12\x11\n\thost_name\x18\x06 \x01(\t\x12\x11\n\thttp_port\x18\x07 \x01(\x05\x12\x12\n\nhttps_port\x18\x08 \x01(\x05\x12\x1a\n\x12origin_host_header\x18\t \x01(\t\x12\x10\n\x08priority\x18\n \x01(\x05\x12\x81\x01\n\x1cshared_private_link_resource\x18\x0b \x03(\x0b\x32[.oak9.tython.azure.microsoft_cdn.ProfilesOriginGroupsOrigins.SharedPrivateLinkResourceEntry\x12\x0e\n\x06weight\x18\x0c \x01(\x05\x1a@\n\x1eSharedPrivateLinkResourceEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xf0\x04\n\x14ProfilesOriginGroups\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12U\n\x15health_probe_settings\x18\x03 \x01(\x0b\x32\x36.oak9.tython.azure.microsoft_cdn.HealthProbeParameters\x12\x61\n\x17load_balancing_settings\x18\x04 \x01(\x0b\x32@.oak9.tython.azure.microsoft_cdn.LoadBalancingSettingsParameters\x12\x88\x01\n2response_based_afd_origin_error_detection_settings\x18\x05 \x01(\x0b\x32L.oak9.tython.azure.microsoft_cdn.ResponseBasedOriginErrorDetectionParameters\x12\x1e\n\x16session_affinity_state\x18\x06 \x01(\t\x12\x46\n>traffic_restoration_time_to_healed_or_new_endpoints_in_minutes\x18\x07 \x01(\x05\x12\x64\n\x1eprofiles_origin_groups_origins\x18\x08 \x03(\x0b\x32<.oak9.tython.azure.microsoft_cdn.ProfilesOriginGroupsOrigins\"\x87\x01\n\x1fLoadBalancingSettingsParameters\x12*\n\"additional_latency_in_milliseconds\x18\x01 \x01(\x05\x12\x13\n\x0bsample_size\x18\x02 \x01(\x05\x12#\n\x1bsuccessful_samples_required\x18\x03 \x01(\x05\"\xee\x02\n\x18ProfilesEndpointsOrigins\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07\x65nabled\x18\x03 \x01(\x08\x12\x11\n\thost_name\x18\x04 \x01(\t\x12\x11\n\thttp_port\x18\x05 \x01(\x05\x12\x12\n\nhttps_port\x18\x06 \x01(\x05\x12\x1a\n\x12origin_host_header\x18\x07 \x01(\t\x12\x10\n\x08priority\x18\x08 \x01(\x05\x12\x1a\n\x12private_link_alias\x18\t \x01(\t\x12%\n\x1dprivate_link_approval_message\x18\n \x01(\t\x12\x1d\n\x15private_link_location\x18\x0b \x01(\t\x12 \n\x18private_link_resource_id\x18\x0c \x01(\t\x12\x0e\n\x06weight\x18\r \x01(\x05\"\xd1\x03\n\x1dProfilesEndpointsOriginGroups\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12U\n\x15health_probe_settings\x18\x03 \x01(\x0b\x32\x36.oak9.tython.azure.microsoft_cdn.HealthProbeParameters\x12\x43\n\x07origins\x18\x04 \x03(\x0b\x32\x32.oak9.tython.azure.microsoft_cdn.ResourceReference\x12\x84\x01\n.response_based_origin_error_detection_settings\x18\x05 \x01(\x0b\x32L.oak9.tython.azure.microsoft_cdn.ResponseBasedOriginErrorDetectionParameters\x12\x46\n>traffic_restoration_time_to_healed_or_new_endpoints_in_minutes\x18\x06 \x01(\x05\"z\n\x1eProfilesEndpointsCustomDomains\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x11\n\thost_name\x18\x03 \x01(\t\"\xd4\x08\n\x11ProfilesEndpoints\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08location\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12!\n\x19\x63ontent_types_to_compress\x18\x04 \x03(\t\x12P\n\x14\x64\x65\x66\x61ult_origin_group\x18\x05 \x01(\x0b\x32\x32.oak9.tython.azure.microsoft_cdn.ResourceReference\x12j\n\x0f\x64\x65livery_policy\x18\x06 \x01(\x0b\x32Q.oak9.tython.azure.microsoft_cdn.EndpointPropertiesUpdateParametersDeliveryPolicy\x12?\n\x0bgeo_filters\x18\x07 \x03(\x0b\x32*.oak9.tython.azure.microsoft_cdn.GeoFilter\x12\x1e\n\x16is_compression_enabled\x18\x08 \x01(\x08\x12\x17\n\x0fis_http_allowed\x18\t \x01(\x08\x12\x18\n\x10is_https_allowed\x18\n \x01(\x08\x12\x19\n\x11optimization_type\x18\x0b \x01(\t\x12N\n\rorigin_groups\x18\x0c \x03(\x0b\x32\x37.oak9.tython.azure.microsoft_cdn.DeepCreatedOriginGroup\x12\x1a\n\x12origin_host_header\x18\r \x01(\t\x12\x13\n\x0borigin_path\x18\x0e \x01(\t\x12\x43\n\x07origins\x18\x0f \x03(\x0b\x32\x32.oak9.tython.azure.microsoft_cdn.DeepCreatedOrigin\x12\x12\n\nprobe_path\x18\x10 \x01(\t\x12%\n\x1dquery_string_caching_behavior\x18\x11 \x01(\t\x12H\n\x10url_signing_keys\x18\x12 \x03(\x0b\x32..oak9.tython.azure.microsoft_cdn.UrlSigningKey\x12\x91\x01\n$web_application_firewall_policy_link\x18\x13 \x01(\x0b\x32\x63.oak9.tython.azure.microsoft_cdn.EndpointPropertiesUpdateParametersWebApplicationFirewallPolicyLink\x12J\n\x04tags\x18\x14 \x03(\x0b\x32<.oak9.tython.azure.microsoft_cdn.ProfilesEndpoints.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"P\nBEndpointPropertiesUpdateParametersWebApplicationFirewallPolicyLink\x12\n\n\x02id\x18\x01 \x01(\t\"}\n\rUrlSigningKey\x12\x0e\n\x06key_id\x18\x01 \x01(\t\x12\\\n\x15key_source_parameters\x18\x02 \x01(\x0b\x32=.oak9.tython.azure.microsoft_cdn.KeyVaultSigningKeyParameters\"\xa8\x01\n\x1cKeyVaultSigningKeyParameters\x12\x1b\n\x13resource_group_name\x18\x01 \x01(\t\x12\x13\n\x0bsecret_name\x18\x02 \x01(\t\x12\x16\n\x0esecret_version\x18\x03 \x01(\t\x12\x17\n\x0fsubscription_id\x18\x04 \x01(\t\x12\x11\n\ttype_name\x18\x05 \x01(\t\x12\x12\n\nvault_name\x18\x06 \x01(\t\"\xae\x02\n\x11\x44\x65\x65pCreatedOrigin\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07\x65nabled\x18\x02 \x01(\x08\x12\x11\n\thost_name\x18\x03 \x01(\t\x12\x11\n\thttp_port\x18\x04 \x01(\x05\x12\x12\n\nhttps_port\x18\x05 \x01(\x05\x12\x1a\n\x12origin_host_header\x18\x06 \x01(\t\x12\x10\n\x08priority\x18\x07 \x01(\x05\x12\x1a\n\x12private_link_alias\x18\x08 \x01(\t\x12%\n\x1dprivate_link_approval_message\x18\t \x01(\t\x12\x1d\n\x15private_link_location\x18\n \x01(\t\x12 \n\x18private_link_resource_id\x18\x0b \x01(\t\x12\x0e\n\x06weight\x18\x0c \x01(\x05\"\x91\x03\n\x16\x44\x65\x65pCreatedOriginGroup\x12\x0c\n\x04name\x18\x01 \x01(\t\x12U\n\x15health_probe_settings\x18\x02 \x01(\x0b\x32\x36.oak9.tython.azure.microsoft_cdn.HealthProbeParameters\x12\x43\n\x07origins\x18\x03 \x03(\x0b\x32\x32.oak9.tython.azure.microsoft_cdn.ResourceReference\x12\x84\x01\n.response_based_origin_error_detection_settings\x18\x04 \x01(\x0b\x32L.oak9.tython.azure.microsoft_cdn.ResponseBasedOriginErrorDetectionParameters\x12\x46\n>traffic_restoration_time_to_healed_or_new_endpoints_in_minutes\x18\x05 \x01(\x05\"\xe6\x01\n+ResponseBasedOriginErrorDetectionParameters\x12T\n\x11http_error_ranges\x18\x01 \x03(\x0b\x32\x39.oak9.tython.azure.microsoft_cdn.HttpErrorRangeParameters\x12+\n#response_based_detected_error_types\x18\x02 \x01(\t\x12\x34\n,response_based_failover_threshold_percentage\x18\x03 \x01(\x05\"6\n\x18HttpErrorRangeParameters\x12\r\n\x05\x62\x65gin\x18\x01 \x01(\x05\x12\x0b\n\x03\x65nd\x18\x02 \x01(\x05\"\x82\x01\n\x15HealthProbeParameters\x12!\n\x19probe_interval_in_seconds\x18\x01 \x01(\x05\x12\x12\n\nprobe_path\x18\x02 \x01(\t\x12\x16\n\x0eprobe_protocol\x18\x03 \x01(\t\x12\x1a\n\x12probe_request_type\x18\x04 \x01(\t\"I\n\tGeoFilter\x12\x0e\n\x06\x61\x63tion\x18\x01 \x01(\t\x12\x15\n\rcountry_codes\x18\x02 \x03(\t\x12\x15\n\rrelative_path\x18\x03 \x01(\t\"\x85\x01\n0EndpointPropertiesUpdateParametersDeliveryPolicy\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12<\n\x05rules\x18\x02 \x03(\x0b\x32-.oak9.tython.azure.microsoft_cdn.DeliveryRule\"\xbe\x01\n\x0c\x44\x65liveryRule\x12\x45\n\x07\x61\x63tions\x18\x01 \x03(\x0b\x32\x34.oak9.tython.azure.microsoft_cdn.DeliveryRuleAction1\x12J\n\nconditions\x18\x02 \x03(\x0b\x32\x36.oak9.tython.azure.microsoft_cdn.DeliveryRuleCondition\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\r\n\x05order\x18\x04 \x01(\x05\"%\n\x15\x44\x65liveryRuleCondition\x12\x0c\n\x04name\x18\x01 \x01(\t\"#\n\x13\x44\x65liveryRuleAction1\x12\x0c\n\x04name\x18\x01 \x01(\t\"\xf3\x02\n\x15ProfilesCustomDomains\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12J\n\x0e\x61zure_dns_zone\x18\x03 \x01(\x0b\x32\x32.oak9.tython.azure.microsoft_cdn.ResourceReference\x12\x11\n\thost_name\x18\x04 \x01(\t\x12\x63\n\'pre_validated_custom_domain_resource_id\x18\x05 \x01(\x0b\x32\x32.oak9.tython.azure.microsoft_cdn.ResourceReference\x12O\n\x0ctls_settings\x18\x06 \x01(\x0b\x32\x39.oak9.tython.azure.microsoft_cdn.AFDDomainHttpsParameters\"\x95\x01\n\x18\x41\x46\x44\x44omainHttpsParameters\x12\x18\n\x10\x63\x65rtificate_type\x18\x01 \x01(\t\x12\x1b\n\x13minimum_tls_version\x18\x02 \x01(\t\x12\x42\n\x06secret\x18\x03 \x01(\x0b\x32\x32.oak9.tython.azure.microsoft_cdn.ResourceReference\"\xdc\x04\n\x1aProfilesAfdEndpointsRoutes\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12X\n\x13\x63\x61\x63he_configuration\x18\x03 \x01(\x0b\x32;.oak9.tython.azure.microsoft_cdn.AfdRouteCacheConfiguration\x12S\n\x0e\x63ustom_domains\x18\x04 \x03(\x0b\x32;.oak9.tython.azure.microsoft_cdn.ActivatedResourceReference\x12\x15\n\renabled_state\x18\x05 \x01(\t\x12\x1b\n\x13\x66orwarding_protocol\x18\x06 \x01(\t\x12\x16\n\x0ehttps_redirect\x18\x07 \x01(\t\x12\x1e\n\x16link_to_default_domain\x18\x08 \x01(\t\x12H\n\x0corigin_group\x18\t \x01(\x0b\x32\x32.oak9.tython.azure.microsoft_cdn.ResourceReference\x12\x13\n\x0borigin_path\x18\n \x01(\t\x12\x19\n\x11patterns_to_match\x18\x0b \x03(\t\x12\x45\n\trule_sets\x18\x0c \x03(\x0b\x32\x32.oak9.tython.azure.microsoft_cdn.ResourceReference\x12\x1b\n\x13supported_protocols\x18\r \x03(\t\"\x1f\n\x11ResourceReference\x12\n\n\x02id\x18\x01 \x01(\t\"(\n\x1a\x41\x63tivatedResourceReference\x12\n\n\x02id\x18\x01 \x01(\t\"\x8d\x02\n\x1a\x41\x66\x64RouteCacheConfiguration\x12r\n\x14\x63ompression_settings\x18\x01 \x03(\x0b\x32T.oak9.tython.azure.microsoft_cdn.AfdRouteCacheConfiguration.CompressionSettingsEntry\x12\x18\n\x10query_parameters\x18\x02 \x01(\t\x12%\n\x1dquery_string_caching_behavior\x18\x03 \x01(\t\x1a:\n\x18\x43ompressionSettingsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x8f\x03\n\x14ProfilesAfdEndpoints\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08location\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x15\n\renabled_state\x18\x04 \x01(\t\x12\'\n\x1forigin_response_timeout_seconds\x18\x05 \x01(\x05\x12M\n\x04tags\x18\x06 \x03(\x0b\x32?.oak9.tython.azure.microsoft_cdn.ProfilesAfdEndpoints.TagsEntry\x12\x62\n\x1dprofiles_afd_endpoints_routes\x18\x07 \x03(\x0b\x32;.oak9.tython.azure.microsoft_cdn.ProfilesAfdEndpointsRoutes\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xfb\x06\n\x08Profiles\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08location\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12I\n\x08identity\x18\x04 \x01(\x0b\x32\x37.oak9.tython.azure.microsoft_cdn.ManagedServiceIdentity\x12\'\n\x1forigin_response_timeout_seconds\x18\x05 \x01(\x05\x12\x31\n\x03sku\x18\x06 \x01(\x0b\x32$.oak9.tython.azure.microsoft_cdn.Sku\x12\x41\n\x04tags\x18\x07 \x03(\x0b\x32\x33.oak9.tython.azure.microsoft_cdn.Profiles.TagsEntry\x12W\n\x17profiles_custom_domains\x18\x08 \x03(\x0b\x32\x36.oak9.tython.azure.microsoft_cdn.ProfilesCustomDomains\x12U\n\x16profiles_afd_endpoints\x18\t \x03(\x0b\x32\x35.oak9.tython.azure.microsoft_cdn.ProfilesAfdEndpoints\x12U\n\x16profiles_origin_groups\x18\n \x03(\x0b\x32\x35.oak9.tython.azure.microsoft_cdn.ProfilesOriginGroups\x12M\n\x12profiles_rule_sets\x18\x0b \x03(\x0b\x32\x31.oak9.tython.azure.microsoft_cdn.ProfilesRuleSets\x12]\n\x1aprofiles_security_policies\x18\x0c \x03(\x0b\x32\x39.oak9.tython.azure.microsoft_cdn.ProfilesSecurityPolicies\x12J\n\x10profiles_secrets\x18\r \x03(\x0b\x32\x30.oak9.tython.azure.microsoft_cdn.ProfilesSecrets\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"&\n\x16ManagedServiceIdentity\x12\x0c\n\x04type\x18\x01 \x01(\t\"\xf1\x04\n!CdnWebApplicationFirewallPolicies\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x45\n\x0c\x63ustom_rules\x18\x05 \x01(\x0b\x32/.oak9.tython.azure.microsoft_cdn.CustomRuleList\x12J\n\rmanaged_rules\x18\x06 \x01(\x0b\x32\x33.oak9.tython.azure.microsoft_cdn.ManagedRuleSetList\x12H\n\x0fpolicy_settings\x18\x07 \x01(\x0b\x32/.oak9.tython.azure.microsoft_cdn.PolicySettings\x12L\n\x10rate_limit_rules\x18\x08 \x01(\x0b\x32\x32.oak9.tython.azure.microsoft_cdn.RateLimitRuleList\x12\x31\n\x03sku\x18\t \x01(\x0b\x32$.oak9.tython.azure.microsoft_cdn.Sku\x12Z\n\x04tags\x18\n \x03(\x0b\x32L.oak9.tython.azure.microsoft_cdn.CdnWebApplicationFirewallPolicies.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x13\n\x03Sku\x12\x0c\n\x04name\x18\x01 \x01(\t\"R\n\x11RateLimitRuleList\x12=\n\x05rules\x18\x01 \x03(\x0b\x32..oak9.tython.azure.microsoft_cdn.RateLimitRule\"\xe7\x01\n\rRateLimitRule\x12\x0e\n\x06\x61\x63tion\x18\x01 \x01(\t\x12\x15\n\renabled_state\x18\x02 \x01(\t\x12I\n\x10match_conditions\x18\x03 \x03(\x0b\x32/.oak9.tython.azure.microsoft_cdn.MatchCondition\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x10\n\x08priority\x18\x05 \x01(\x05\x12&\n\x1erate_limit_duration_in_minutes\x18\x06 \x01(\x05\x12\x1c\n\x14rate_limit_threshold\x18\x07 \x01(\x05\"\xb2\x01\n\x0ePolicySettings\x12*\n\"default_custom_block_response_body\x18\x01 \x01(\t\x12\x31\n)default_custom_block_response_status_code\x18\x02 \x01(\x05\x12\x1c\n\x14\x64\x65\x66\x61ult_redirect_url\x18\x03 \x01(\t\x12\x15\n\renabled_state\x18\x04 \x01(\t\x12\x0c\n\x04mode\x18\x05 \x01(\t\"`\n\x12ManagedRuleSetList\x12J\n\x11managed_rule_sets\x18\x01 \x03(\x0b\x32/.oak9.tython.azure.microsoft_cdn.ManagedRuleSet\"\xb1\x01\n\x0eManagedRuleSet\x12\x15\n\ranomaly_score\x18\x01 \x01(\x05\x12W\n\x14rule_group_overrides\x18\x02 \x03(\x0b\x32\x39.oak9.tython.azure.microsoft_cdn.ManagedRuleGroupOverride\x12\x15\n\rrule_set_type\x18\x03 \x01(\t\x12\x18\n\x10rule_set_version\x18\x04 \x01(\t\"x\n\x18ManagedRuleGroupOverride\x12\x17\n\x0frule_group_name\x18\x01 \x01(\t\x12\x43\n\x05rules\x18\x02 \x03(\x0b\x32\x34.oak9.tython.azure.microsoft_cdn.ManagedRuleOverride\"M\n\x13ManagedRuleOverride\x12\x0e\n\x06\x61\x63tion\x18\x01 \x01(\t\x12\x15\n\renabled_state\x18\x02 \x01(\t\x12\x0f\n\x07rule_id\x18\x03 \x01(\t\"L\n\x0e\x43ustomRuleList\x12:\n\x05rules\x18\x01 \x03(\x0b\x32+.oak9.tython.azure.microsoft_cdn.CustomRule\"\x9e\x01\n\nCustomRule\x12\x0e\n\x06\x61\x63tion\x18\x01 \x01(\t\x12\x15\n\renabled_state\x18\x02 \x01(\t\x12I\n\x10match_conditions\x18\x03 \x03(\x0b\x32/.oak9.tython.azure.microsoft_cdn.MatchCondition\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x10\n\x08priority\x18\x05 \x01(\x05\"\x8f\x01\n\x0eMatchCondition\x12\x13\n\x0bmatch_value\x18\x01 \x03(\t\x12\x16\n\x0ematch_variable\x18\x02 \x01(\t\x12\x18\n\x10negate_condition\x18\x03 \x01(\x08\x12\x10\n\x08operator\x18\x04 \x01(\t\x12\x10\n\x08selector\x18\x05 \x01(\t\x12\x12\n\ntransforms\x18\x06 \x03(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'azure.azure_microsoft_cdn_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _PROFILESORIGINGROUPSORIGINS_SHAREDPRIVATELINKRESOURCEENTRY._options = None
  _PROFILESORIGINGROUPSORIGINS_SHAREDPRIVATELINKRESOURCEENTRY._serialized_options = b'8\001'
  _PROFILESENDPOINTS_TAGSENTRY._options = None
  _PROFILESENDPOINTS_TAGSENTRY._serialized_options = b'8\001'
  _AFDROUTECACHECONFIGURATION_COMPRESSIONSETTINGSENTRY._options = None
  _AFDROUTECACHECONFIGURATION_COMPRESSIONSETTINGSENTRY._serialized_options = b'8\001'
  _PROFILESAFDENDPOINTS_TAGSENTRY._options = None
  _PROFILESAFDENDPOINTS_TAGSENTRY._serialized_options = b'8\001'
  _PROFILES_TAGSENTRY._options = None
  _PROFILES_TAGSENTRY._serialized_options = b'8\001'
  _CDNWEBAPPLICATIONFIREWALLPOLICIES_TAGSENTRY._options = None
  _CDNWEBAPPLICATIONFIREWALLPOLICIES_TAGSENTRY._serialized_options = b'8\001'
  _MICROSOFT_CDN._serialized_start=90
  _MICROSOFT_CDN._serialized_end=670
  _PROFILESSECURITYPOLICIES._serialized_start=673
  _PROFILESSECURITYPOLICIES._serialized_end=849
  _SECURITYPOLICYPARAMETERS._serialized_start=851
  _SECURITYPOLICYPARAMETERS._serialized_end=891
  _PROFILESSECRETS._serialized_start=894
  _PROFILESSECRETS._serialized_end=1053
  _SECRETPARAMETERS._serialized_start=1055
  _SECRETPARAMETERS._serialized_end=1087
  _PROFILESRULESETSRULES._serialized_start=1090
  _PROFILESRULESETSRULES._serialized_end=1381
  _PROFILESRULESETS._serialized_start=1384
  _PROFILESRULESETS._serialized_end=1563
  _PROFILESORIGINGROUPSORIGINS._serialized_start=1566
  _PROFILESORIGINGROUPSORIGINS._serialized_end=2121
  _PROFILESORIGINGROUPSORIGINS_SHAREDPRIVATELINKRESOURCEENTRY._serialized_start=2057
  _PROFILESORIGINGROUPSORIGINS_SHAREDPRIVATELINKRESOURCEENTRY._serialized_end=2121
  _PROFILESORIGINGROUPS._serialized_start=2124
  _PROFILESORIGINGROUPS._serialized_end=2748
  _LOADBALANCINGSETTINGSPARAMETERS._serialized_start=2751
  _LOADBALANCINGSETTINGSPARAMETERS._serialized_end=2886
  _PROFILESENDPOINTSORIGINS._serialized_start=2889
  _PROFILESENDPOINTSORIGINS._serialized_end=3255
  _PROFILESENDPOINTSORIGINGROUPS._serialized_start=3258
  _PROFILESENDPOINTSORIGINGROUPS._serialized_end=3723
  _PROFILESENDPOINTSCUSTOMDOMAINS._serialized_start=3725
  _PROFILESENDPOINTSCUSTOMDOMAINS._serialized_end=3847
  _PROFILESENDPOINTS._serialized_start=3850
  _PROFILESENDPOINTS._serialized_end=4958
  _PROFILESENDPOINTS_TAGSENTRY._serialized_start=4915
  _PROFILESENDPOINTS_TAGSENTRY._serialized_end=4958
  _ENDPOINTPROPERTIESUPDATEPARAMETERSWEBAPPLICATIONFIREWALLPOLICYLINK._serialized_start=4960
  _ENDPOINTPROPERTIESUPDATEPARAMETERSWEBAPPLICATIONFIREWALLPOLICYLINK._serialized_end=5040
  _URLSIGNINGKEY._serialized_start=5042
  _URLSIGNINGKEY._serialized_end=5167
  _KEYVAULTSIGNINGKEYPARAMETERS._serialized_start=5170
  _KEYVAULTSIGNINGKEYPARAMETERS._serialized_end=5338
  _DEEPCREATEDORIGIN._serialized_start=5341
  _DEEPCREATEDORIGIN._serialized_end=5643
  _DEEPCREATEDORIGINGROUP._serialized_start=5646
  _DEEPCREATEDORIGINGROUP._serialized_end=6047
  _RESPONSEBASEDORIGINERRORDETECTIONPARAMETERS._serialized_start=6050
  _RESPONSEBASEDORIGINERRORDETECTIONPARAMETERS._serialized_end=6280
  _HTTPERRORRANGEPARAMETERS._serialized_start=6282
  _HTTPERRORRANGEPARAMETERS._serialized_end=6336
  _HEALTHPROBEPARAMETERS._serialized_start=6339
  _HEALTHPROBEPARAMETERS._serialized_end=6469
  _GEOFILTER._serialized_start=6471
  _GEOFILTER._serialized_end=6544
  _ENDPOINTPROPERTIESUPDATEPARAMETERSDELIVERYPOLICY._serialized_start=6547
  _ENDPOINTPROPERTIESUPDATEPARAMETERSDELIVERYPOLICY._serialized_end=6680
  _DELIVERYRULE._serialized_start=6683
  _DELIVERYRULE._serialized_end=6873
  _DELIVERYRULECONDITION._serialized_start=6875
  _DELIVERYRULECONDITION._serialized_end=6912
  _DELIVERYRULEACTION1._serialized_start=6914
  _DELIVERYRULEACTION1._serialized_end=6949
  _PROFILESCUSTOMDOMAINS._serialized_start=6952
  _PROFILESCUSTOMDOMAINS._serialized_end=7323
  _AFDDOMAINHTTPSPARAMETERS._serialized_start=7326
  _AFDDOMAINHTTPSPARAMETERS._serialized_end=7475
  _PROFILESAFDENDPOINTSROUTES._serialized_start=7478
  _PROFILESAFDENDPOINTSROUTES._serialized_end=8082
  _RESOURCEREFERENCE._serialized_start=8084
  _RESOURCEREFERENCE._serialized_end=8115
  _ACTIVATEDRESOURCEREFERENCE._serialized_start=8117
  _ACTIVATEDRESOURCEREFERENCE._serialized_end=8157
  _AFDROUTECACHECONFIGURATION._serialized_start=8160
  _AFDROUTECACHECONFIGURATION._serialized_end=8429
  _AFDROUTECACHECONFIGURATION_COMPRESSIONSETTINGSENTRY._serialized_start=8371
  _AFDROUTECACHECONFIGURATION_COMPRESSIONSETTINGSENTRY._serialized_end=8429
  _PROFILESAFDENDPOINTS._serialized_start=8432
  _PROFILESAFDENDPOINTS._serialized_end=8831
  _PROFILESAFDENDPOINTS_TAGSENTRY._serialized_start=4915
  _PROFILESAFDENDPOINTS_TAGSENTRY._serialized_end=4958
  _PROFILES._serialized_start=8834
  _PROFILES._serialized_end=9725
  _PROFILES_TAGSENTRY._serialized_start=4915
  _PROFILES_TAGSENTRY._serialized_end=4958
  _MANAGEDSERVICEIDENTITY._serialized_start=9727
  _MANAGEDSERVICEIDENTITY._serialized_end=9765
  _CDNWEBAPPLICATIONFIREWALLPOLICIES._serialized_start=9768
  _CDNWEBAPPLICATIONFIREWALLPOLICIES._serialized_end=10393
  _CDNWEBAPPLICATIONFIREWALLPOLICIES_TAGSENTRY._serialized_start=4915
  _CDNWEBAPPLICATIONFIREWALLPOLICIES_TAGSENTRY._serialized_end=4958
  _SKU._serialized_start=10395
  _SKU._serialized_end=10414
  _RATELIMITRULELIST._serialized_start=10416
  _RATELIMITRULELIST._serialized_end=10498
  _RATELIMITRULE._serialized_start=10501
  _RATELIMITRULE._serialized_end=10732
  _POLICYSETTINGS._serialized_start=10735
  _POLICYSETTINGS._serialized_end=10913
  _MANAGEDRULESETLIST._serialized_start=10915
  _MANAGEDRULESETLIST._serialized_end=11011
  _MANAGEDRULESET._serialized_start=11014
  _MANAGEDRULESET._serialized_end=11191
  _MANAGEDRULEGROUPOVERRIDE._serialized_start=11193
  _MANAGEDRULEGROUPOVERRIDE._serialized_end=11313
  _MANAGEDRULEOVERRIDE._serialized_start=11315
  _MANAGEDRULEOVERRIDE._serialized_end=11392
  _CUSTOMRULELIST._serialized_start=11394
  _CUSTOMRULELIST._serialized_end=11470
  _CUSTOMRULE._serialized_start=11473
  _CUSTOMRULE._serialized_end=11631
  _MATCHCONDITION._serialized_start=11634
  _MATCHCONDITION._serialized_end=11777
# @@protoc_insertion_point(module_scope)
