# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_google_sql_bundle.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2
from oak9.tython.models.gcp import gcp_sql_pb2 as gcp_dot_gcp__sql__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fgcp/gcp_google_sql_bundle.proto\x12!oak9.tython.gcp.google_sql_bundle\x1a\x13shared/shared.proto\x1a\x11gcp/gcp_sql.proto\"\xd5\x02\n\tGoogleSql\x12\x36\n\x0csql_database\x18\x01 \x03(\x0b\x32 .oak9.tython.gcp.sql.SqlDatabase\x12G\n\x15sql_database_instance\x18\x02 \x01(\x0b\x32(.oak9.tython.gcp.sql.SqlDatabaseInstance\x12`\n\"sql_source_representation_instance\x18\x03 \x01(\x0b\x32\x34.oak9.tython.gcp.sql.SqlSourceRepresentationInstance\x12\x35\n\x0csql_ssl_cert\x18\x04 \x03(\x0b\x32\x1f.oak9.tython.gcp.sql.SqlSslCert\x12.\n\x08sql_user\x18\x05 \x01(\x0b\x32\x1c.oak9.tython.gcp.sql.SqlUserb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_google_sql_bundle_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GOOGLESQL._serialized_start=111
  _GOOGLESQL._serialized_end=452
# @@protoc_insertion_point(module_scope)
