"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class CloudAssetFolderFeedXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    location: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        location: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "location", b"location", "title", b"title"]) -> None: ...

global___CloudAssetFolderFeedXCondition = CloudAssetFolderFeedXCondition

@typing_extensions.final
class CloudAssetFolderFeedXFeedOutputConfigXPubsubDestination(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOPIC_FIELD_NUMBER: builtins.int
    topic: builtins.str
    def __init__(
        self,
        *,
        topic: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["topic", b"topic"]) -> None: ...

global___CloudAssetFolderFeedXFeedOutputConfigXPubsubDestination = CloudAssetFolderFeedXFeedOutputConfigXPubsubDestination

@typing_extensions.final
class CloudAssetFolderFeedXFeedOutputConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PUBSUB_DESTINATION_FIELD_NUMBER: builtins.int
    @property
    def pubsub_destination(self) -> global___CloudAssetFolderFeedXFeedOutputConfigXPubsubDestination: ...
    def __init__(
        self,
        *,
        pubsub_destination: global___CloudAssetFolderFeedXFeedOutputConfigXPubsubDestination | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pubsub_destination", b"pubsub_destination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["pubsub_destination", b"pubsub_destination"]) -> None: ...

global___CloudAssetFolderFeedXFeedOutputConfig = CloudAssetFolderFeedXFeedOutputConfig

@typing_extensions.final
class CloudAssetFolderFeedXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___CloudAssetFolderFeedXTimeouts = CloudAssetFolderFeedXTimeouts

@typing_extensions.final
class CloudAssetFolderFeed(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ASSET_NAMES_FIELD_NUMBER: builtins.int
    ASSET_TYPES_FIELD_NUMBER: builtins.int
    BILLING_PROJECT_FIELD_NUMBER: builtins.int
    CONTENT_TYPE_FIELD_NUMBER: builtins.int
    FEED_ID_FIELD_NUMBER: builtins.int
    FOLDER_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    FEED_OUTPUT_CONFIG_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def asset_names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def asset_types(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    billing_project: builtins.str
    content_type: builtins.str
    feed_id: builtins.str
    folder: builtins.str
    folder_id: builtins.str
    id: builtins.str
    name: builtins.str
    @property
    def condition(self) -> global___CloudAssetFolderFeedXCondition: ...
    @property
    def feed_output_config(self) -> global___CloudAssetFolderFeedXFeedOutputConfig: ...
    @property
    def timeouts(self) -> global___CloudAssetFolderFeedXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        asset_names: collections.abc.Iterable[builtins.str] | None = ...,
        asset_types: collections.abc.Iterable[builtins.str] | None = ...,
        billing_project: builtins.str = ...,
        content_type: builtins.str = ...,
        feed_id: builtins.str = ...,
        folder: builtins.str = ...,
        folder_id: builtins.str = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        condition: global___CloudAssetFolderFeedXCondition | None = ...,
        feed_output_config: global___CloudAssetFolderFeedXFeedOutputConfig | None = ...,
        timeouts: global___CloudAssetFolderFeedXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "feed_output_config", b"feed_output_config", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["asset_names", b"asset_names", "asset_types", b"asset_types", "billing_project", b"billing_project", "condition", b"condition", "content_type", b"content_type", "feed_id", b"feed_id", "feed_output_config", b"feed_output_config", "folder", b"folder", "folder_id", b"folder_id", "id", b"id", "name", b"name", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> None: ...

global___CloudAssetFolderFeed = CloudAssetFolderFeed

@typing_extensions.final
class CloudAssetOrganizationFeedXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    location: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        location: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "location", b"location", "title", b"title"]) -> None: ...

global___CloudAssetOrganizationFeedXCondition = CloudAssetOrganizationFeedXCondition

@typing_extensions.final
class CloudAssetOrganizationFeedXFeedOutputConfigXPubsubDestination(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOPIC_FIELD_NUMBER: builtins.int
    topic: builtins.str
    def __init__(
        self,
        *,
        topic: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["topic", b"topic"]) -> None: ...

global___CloudAssetOrganizationFeedXFeedOutputConfigXPubsubDestination = CloudAssetOrganizationFeedXFeedOutputConfigXPubsubDestination

@typing_extensions.final
class CloudAssetOrganizationFeedXFeedOutputConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PUBSUB_DESTINATION_FIELD_NUMBER: builtins.int
    @property
    def pubsub_destination(self) -> global___CloudAssetOrganizationFeedXFeedOutputConfigXPubsubDestination: ...
    def __init__(
        self,
        *,
        pubsub_destination: global___CloudAssetOrganizationFeedXFeedOutputConfigXPubsubDestination | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pubsub_destination", b"pubsub_destination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["pubsub_destination", b"pubsub_destination"]) -> None: ...

global___CloudAssetOrganizationFeedXFeedOutputConfig = CloudAssetOrganizationFeedXFeedOutputConfig

@typing_extensions.final
class CloudAssetOrganizationFeedXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___CloudAssetOrganizationFeedXTimeouts = CloudAssetOrganizationFeedXTimeouts

@typing_extensions.final
class CloudAssetOrganizationFeed(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ASSET_NAMES_FIELD_NUMBER: builtins.int
    ASSET_TYPES_FIELD_NUMBER: builtins.int
    BILLING_PROJECT_FIELD_NUMBER: builtins.int
    CONTENT_TYPE_FIELD_NUMBER: builtins.int
    FEED_ID_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ORG_ID_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    FEED_OUTPUT_CONFIG_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def asset_names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def asset_types(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    billing_project: builtins.str
    content_type: builtins.str
    feed_id: builtins.str
    id: builtins.str
    name: builtins.str
    org_id: builtins.str
    @property
    def condition(self) -> global___CloudAssetOrganizationFeedXCondition: ...
    @property
    def feed_output_config(self) -> global___CloudAssetOrganizationFeedXFeedOutputConfig: ...
    @property
    def timeouts(self) -> global___CloudAssetOrganizationFeedXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        asset_names: collections.abc.Iterable[builtins.str] | None = ...,
        asset_types: collections.abc.Iterable[builtins.str] | None = ...,
        billing_project: builtins.str = ...,
        content_type: builtins.str = ...,
        feed_id: builtins.str = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        org_id: builtins.str = ...,
        condition: global___CloudAssetOrganizationFeedXCondition | None = ...,
        feed_output_config: global___CloudAssetOrganizationFeedXFeedOutputConfig | None = ...,
        timeouts: global___CloudAssetOrganizationFeedXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "feed_output_config", b"feed_output_config", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["asset_names", b"asset_names", "asset_types", b"asset_types", "billing_project", b"billing_project", "condition", b"condition", "content_type", b"content_type", "feed_id", b"feed_id", "feed_output_config", b"feed_output_config", "id", b"id", "name", b"name", "org_id", b"org_id", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> None: ...

global___CloudAssetOrganizationFeed = CloudAssetOrganizationFeed

@typing_extensions.final
class CloudAssetProjectFeedXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    location: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        location: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "location", b"location", "title", b"title"]) -> None: ...

global___CloudAssetProjectFeedXCondition = CloudAssetProjectFeedXCondition

@typing_extensions.final
class CloudAssetProjectFeedXFeedOutputConfigXPubsubDestination(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOPIC_FIELD_NUMBER: builtins.int
    topic: builtins.str
    def __init__(
        self,
        *,
        topic: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["topic", b"topic"]) -> None: ...

global___CloudAssetProjectFeedXFeedOutputConfigXPubsubDestination = CloudAssetProjectFeedXFeedOutputConfigXPubsubDestination

@typing_extensions.final
class CloudAssetProjectFeedXFeedOutputConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PUBSUB_DESTINATION_FIELD_NUMBER: builtins.int
    @property
    def pubsub_destination(self) -> global___CloudAssetProjectFeedXFeedOutputConfigXPubsubDestination: ...
    def __init__(
        self,
        *,
        pubsub_destination: global___CloudAssetProjectFeedXFeedOutputConfigXPubsubDestination | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pubsub_destination", b"pubsub_destination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["pubsub_destination", b"pubsub_destination"]) -> None: ...

global___CloudAssetProjectFeedXFeedOutputConfig = CloudAssetProjectFeedXFeedOutputConfig

@typing_extensions.final
class CloudAssetProjectFeedXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___CloudAssetProjectFeedXTimeouts = CloudAssetProjectFeedXTimeouts

@typing_extensions.final
class CloudAssetProjectFeed(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ASSET_NAMES_FIELD_NUMBER: builtins.int
    ASSET_TYPES_FIELD_NUMBER: builtins.int
    BILLING_PROJECT_FIELD_NUMBER: builtins.int
    CONTENT_TYPE_FIELD_NUMBER: builtins.int
    FEED_ID_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    FEED_OUTPUT_CONFIG_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def asset_names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def asset_types(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    billing_project: builtins.str
    content_type: builtins.str
    feed_id: builtins.str
    id: builtins.str
    name: builtins.str
    project: builtins.str
    @property
    def condition(self) -> global___CloudAssetProjectFeedXCondition: ...
    @property
    def feed_output_config(self) -> global___CloudAssetProjectFeedXFeedOutputConfig: ...
    @property
    def timeouts(self) -> global___CloudAssetProjectFeedXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        asset_names: collections.abc.Iterable[builtins.str] | None = ...,
        asset_types: collections.abc.Iterable[builtins.str] | None = ...,
        billing_project: builtins.str = ...,
        content_type: builtins.str = ...,
        feed_id: builtins.str = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        condition: global___CloudAssetProjectFeedXCondition | None = ...,
        feed_output_config: global___CloudAssetProjectFeedXFeedOutputConfig | None = ...,
        timeouts: global___CloudAssetProjectFeedXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "feed_output_config", b"feed_output_config", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["asset_names", b"asset_names", "asset_types", b"asset_types", "billing_project", b"billing_project", "condition", b"condition", "content_type", b"content_type", "feed_id", b"feed_id", "feed_output_config", b"feed_output_config", "id", b"id", "name", b"name", "project", b"project", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> None: ...

global___CloudAssetProjectFeed = CloudAssetProjectFeed

@typing_extensions.final
class CloudIdentityGroupXGroupKey(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    NAMESPACE_FIELD_NUMBER: builtins.int
    id: builtins.str
    namespace: builtins.str
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        namespace: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "namespace", b"namespace"]) -> None: ...

global___CloudIdentityGroupXGroupKey = CloudIdentityGroupXGroupKey

@typing_extensions.final
class CloudIdentityGroupXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___CloudIdentityGroupXTimeouts = CloudIdentityGroupXTimeouts

@typing_extensions.final
class CloudIdentityGroup(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    CREATE_TIME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    INITIAL_GROUP_CONFIG_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PARENT_FIELD_NUMBER: builtins.int
    UPDATE_TIME_FIELD_NUMBER: builtins.int
    GROUP_KEY_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    create_time: builtins.str
    description: builtins.str
    display_name: builtins.str
    id: builtins.str
    initial_group_config: builtins.str
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    name: builtins.str
    parent: builtins.str
    update_time: builtins.str
    @property
    def group_key(self) -> global___CloudIdentityGroupXGroupKey: ...
    @property
    def timeouts(self) -> global___CloudIdentityGroupXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        create_time: builtins.str = ...,
        description: builtins.str = ...,
        display_name: builtins.str = ...,
        id: builtins.str = ...,
        initial_group_config: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        name: builtins.str = ...,
        parent: builtins.str = ...,
        update_time: builtins.str = ...,
        group_key: global___CloudIdentityGroupXGroupKey | None = ...,
        timeouts: global___CloudIdentityGroupXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["group_key", b"group_key", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["create_time", b"create_time", "description", b"description", "display_name", b"display_name", "group_key", b"group_key", "id", b"id", "initial_group_config", b"initial_group_config", "labels", b"labels", "name", b"name", "parent", b"parent", "resource_info", b"resource_info", "timeouts", b"timeouts", "update_time", b"update_time"]) -> None: ...

global___CloudIdentityGroup = CloudIdentityGroup

@typing_extensions.final
class CloudIdentityGroupMembershipXPreferredMemberKey(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    NAMESPACE_FIELD_NUMBER: builtins.int
    id: builtins.str
    namespace: builtins.str
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        namespace: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "namespace", b"namespace"]) -> None: ...

global___CloudIdentityGroupMembershipXPreferredMemberKey = CloudIdentityGroupMembershipXPreferredMemberKey

@typing_extensions.final
class CloudIdentityGroupMembershipXRoles(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___CloudIdentityGroupMembershipXRoles = CloudIdentityGroupMembershipXRoles

@typing_extensions.final
class CloudIdentityGroupMembershipXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___CloudIdentityGroupMembershipXTimeouts = CloudIdentityGroupMembershipXTimeouts

@typing_extensions.final
class CloudIdentityGroupMembership(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_TIME_FIELD_NUMBER: builtins.int
    GROUP_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    UPDATE_TIME_FIELD_NUMBER: builtins.int
    PREFERRED_MEMBER_KEY_FIELD_NUMBER: builtins.int
    ROLES_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    create_time: builtins.str
    group: builtins.str
    id: builtins.str
    name: builtins.str
    type: builtins.str
    update_time: builtins.str
    @property
    def preferred_member_key(self) -> global___CloudIdentityGroupMembershipXPreferredMemberKey: ...
    @property
    def roles(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CloudIdentityGroupMembershipXRoles]: ...
    @property
    def timeouts(self) -> global___CloudIdentityGroupMembershipXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        create_time: builtins.str = ...,
        group: builtins.str = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        type: builtins.str = ...,
        update_time: builtins.str = ...,
        preferred_member_key: global___CloudIdentityGroupMembershipXPreferredMemberKey | None = ...,
        roles: collections.abc.Iterable[global___CloudIdentityGroupMembershipXRoles] | None = ...,
        timeouts: global___CloudIdentityGroupMembershipXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["preferred_member_key", b"preferred_member_key", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["create_time", b"create_time", "group", b"group", "id", b"id", "name", b"name", "preferred_member_key", b"preferred_member_key", "resource_info", b"resource_info", "roles", b"roles", "timeouts", b"timeouts", "type", b"type", "update_time", b"update_time"]) -> None: ...

global___CloudIdentityGroupMembership = CloudIdentityGroupMembership

@typing_extensions.final
class CloudRunDomainMappingXMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class AnnotationsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    ANNOTATIONS_FIELD_NUMBER: builtins.int
    GENERATION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    NAMESPACE_FIELD_NUMBER: builtins.int
    RESOURCE_VERSION_FIELD_NUMBER: builtins.int
    SELF_LINK_FIELD_NUMBER: builtins.int
    UID_FIELD_NUMBER: builtins.int
    @property
    def annotations(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    generation: builtins.float
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    namespace: builtins.str
    resource_version: builtins.str
    self_link: builtins.str
    uid: builtins.str
    def __init__(
        self,
        *,
        annotations: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        generation: builtins.float = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        namespace: builtins.str = ...,
        resource_version: builtins.str = ...,
        self_link: builtins.str = ...,
        uid: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["annotations", b"annotations", "generation", b"generation", "labels", b"labels", "namespace", b"namespace", "resource_version", b"resource_version", "self_link", b"self_link", "uid", b"uid"]) -> None: ...

global___CloudRunDomainMappingXMetadata = CloudRunDomainMappingXMetadata

@typing_extensions.final
class CloudRunDomainMappingXSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CERTIFICATE_MODE_FIELD_NUMBER: builtins.int
    FORCE_OVERRIDE_FIELD_NUMBER: builtins.int
    ROUTE_NAME_FIELD_NUMBER: builtins.int
    certificate_mode: builtins.str
    force_override: builtins.bool
    route_name: builtins.str
    def __init__(
        self,
        *,
        certificate_mode: builtins.str = ...,
        force_override: builtins.bool = ...,
        route_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["certificate_mode", b"certificate_mode", "force_override", b"force_override", "route_name", b"route_name"]) -> None: ...

global___CloudRunDomainMappingXSpec = CloudRunDomainMappingXSpec

@typing_extensions.final
class CloudRunDomainMappingXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete"]) -> None: ...

global___CloudRunDomainMappingXTimeouts = CloudRunDomainMappingXTimeouts

@typing_extensions.final
class CloudRunDomainMapping(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class StatusEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    SPEC_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    id: builtins.str
    location: builtins.str
    name: builtins.str
    project: builtins.str
    @property
    def status(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def metadata(self) -> global___CloudRunDomainMappingXMetadata: ...
    @property
    def spec(self) -> global___CloudRunDomainMappingXSpec: ...
    @property
    def timeouts(self) -> global___CloudRunDomainMappingXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        status: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        metadata: global___CloudRunDomainMappingXMetadata | None = ...,
        spec: global___CloudRunDomainMappingXSpec | None = ...,
        timeouts: global___CloudRunDomainMappingXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info", "spec", b"spec", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "location", b"location", "metadata", b"metadata", "name", b"name", "project", b"project", "resource_info", b"resource_info", "spec", b"spec", "status", b"status", "timeouts", b"timeouts"]) -> None: ...

global___CloudRunDomainMapping = CloudRunDomainMapping

@typing_extensions.final
class CloudRunServiceXMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class AnnotationsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    ANNOTATIONS_FIELD_NUMBER: builtins.int
    GENERATION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    NAMESPACE_FIELD_NUMBER: builtins.int
    RESOURCE_VERSION_FIELD_NUMBER: builtins.int
    SELF_LINK_FIELD_NUMBER: builtins.int
    UID_FIELD_NUMBER: builtins.int
    @property
    def annotations(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    generation: builtins.float
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    namespace: builtins.str
    resource_version: builtins.str
    self_link: builtins.str
    uid: builtins.str
    def __init__(
        self,
        *,
        annotations: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        generation: builtins.float = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        namespace: builtins.str = ...,
        resource_version: builtins.str = ...,
        self_link: builtins.str = ...,
        uid: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["annotations", b"annotations", "generation", b"generation", "labels", b"labels", "namespace", b"namespace", "resource_version", b"resource_version", "self_link", b"self_link", "uid", b"uid"]) -> None: ...

global___CloudRunServiceXMetadata = CloudRunServiceXMetadata

@typing_extensions.final
class CloudRunServiceXTemplateXMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class AnnotationsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    ANNOTATIONS_FIELD_NUMBER: builtins.int
    GENERATION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    NAMESPACE_FIELD_NUMBER: builtins.int
    RESOURCE_VERSION_FIELD_NUMBER: builtins.int
    SELF_LINK_FIELD_NUMBER: builtins.int
    UID_FIELD_NUMBER: builtins.int
    @property
    def annotations(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    generation: builtins.float
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    name: builtins.str
    namespace: builtins.str
    resource_version: builtins.str
    self_link: builtins.str
    uid: builtins.str
    def __init__(
        self,
        *,
        annotations: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        generation: builtins.float = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        name: builtins.str = ...,
        namespace: builtins.str = ...,
        resource_version: builtins.str = ...,
        self_link: builtins.str = ...,
        uid: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["annotations", b"annotations", "generation", b"generation", "labels", b"labels", "name", b"name", "namespace", b"namespace", "resource_version", b"resource_version", "self_link", b"self_link", "uid", b"uid"]) -> None: ...

global___CloudRunServiceXTemplateXMetadata = CloudRunServiceXTemplateXMetadata

@typing_extensions.final
class CloudRunServiceXTemplateXSpecXContainersXEnvXValueFromXSecretKeyRef(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    key: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        key: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "name", b"name"]) -> None: ...

global___CloudRunServiceXTemplateXSpecXContainersXEnvXValueFromXSecretKeyRef = CloudRunServiceXTemplateXSpecXContainersXEnvXValueFromXSecretKeyRef

@typing_extensions.final
class CloudRunServiceXTemplateXSpecXContainersXEnvXValueFrom(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SECRET_KEY_REF_FIELD_NUMBER: builtins.int
    @property
    def secret_key_ref(self) -> global___CloudRunServiceXTemplateXSpecXContainersXEnvXValueFromXSecretKeyRef: ...
    def __init__(
        self,
        *,
        secret_key_ref: global___CloudRunServiceXTemplateXSpecXContainersXEnvXValueFromXSecretKeyRef | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["secret_key_ref", b"secret_key_ref"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["secret_key_ref", b"secret_key_ref"]) -> None: ...

global___CloudRunServiceXTemplateXSpecXContainersXEnvXValueFrom = CloudRunServiceXTemplateXSpecXContainersXEnvXValueFrom

@typing_extensions.final
class CloudRunServiceXTemplateXSpecXContainersXEnv(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    VALUE_FROM_FIELD_NUMBER: builtins.int
    name: builtins.str
    value: builtins.str
    @property
    def value_from(self) -> global___CloudRunServiceXTemplateXSpecXContainersXEnvXValueFrom: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        value: builtins.str = ...,
        value_from: global___CloudRunServiceXTemplateXSpecXContainersXEnvXValueFrom | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["value_from", b"value_from"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "value", b"value", "value_from", b"value_from"]) -> None: ...

global___CloudRunServiceXTemplateXSpecXContainersXEnv = CloudRunServiceXTemplateXSpecXContainersXEnv

@typing_extensions.final
class CloudRunServiceXTemplateXSpecXContainersXEnvFromXConfigMapRefXLocalObjectReference(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___CloudRunServiceXTemplateXSpecXContainersXEnvFromXConfigMapRefXLocalObjectReference = CloudRunServiceXTemplateXSpecXContainersXEnvFromXConfigMapRefXLocalObjectReference

@typing_extensions.final
class CloudRunServiceXTemplateXSpecXContainersXEnvFromXConfigMapRef(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPTIONAL_FIELD_NUMBER: builtins.int
    LOCAL_OBJECT_REFERENCE_FIELD_NUMBER: builtins.int
    optional: builtins.bool
    @property
    def local_object_reference(self) -> global___CloudRunServiceXTemplateXSpecXContainersXEnvFromXConfigMapRefXLocalObjectReference: ...
    def __init__(
        self,
        *,
        optional: builtins.bool = ...,
        local_object_reference: global___CloudRunServiceXTemplateXSpecXContainersXEnvFromXConfigMapRefXLocalObjectReference | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["local_object_reference", b"local_object_reference"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["local_object_reference", b"local_object_reference", "optional", b"optional"]) -> None: ...

global___CloudRunServiceXTemplateXSpecXContainersXEnvFromXConfigMapRef = CloudRunServiceXTemplateXSpecXContainersXEnvFromXConfigMapRef

@typing_extensions.final
class CloudRunServiceXTemplateXSpecXContainersXEnvFromXSecretRefXLocalObjectReference(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___CloudRunServiceXTemplateXSpecXContainersXEnvFromXSecretRefXLocalObjectReference = CloudRunServiceXTemplateXSpecXContainersXEnvFromXSecretRefXLocalObjectReference

@typing_extensions.final
class CloudRunServiceXTemplateXSpecXContainersXEnvFromXSecretRef(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPTIONAL_FIELD_NUMBER: builtins.int
    LOCAL_OBJECT_REFERENCE_FIELD_NUMBER: builtins.int
    optional: builtins.bool
    @property
    def local_object_reference(self) -> global___CloudRunServiceXTemplateXSpecXContainersXEnvFromXSecretRefXLocalObjectReference: ...
    def __init__(
        self,
        *,
        optional: builtins.bool = ...,
        local_object_reference: global___CloudRunServiceXTemplateXSpecXContainersXEnvFromXSecretRefXLocalObjectReference | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["local_object_reference", b"local_object_reference"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["local_object_reference", b"local_object_reference", "optional", b"optional"]) -> None: ...

global___CloudRunServiceXTemplateXSpecXContainersXEnvFromXSecretRef = CloudRunServiceXTemplateXSpecXContainersXEnvFromXSecretRef

@typing_extensions.final
class CloudRunServiceXTemplateXSpecXContainersXEnvFrom(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PREFIX_FIELD_NUMBER: builtins.int
    CONFIG_MAP_REF_FIELD_NUMBER: builtins.int
    SECRET_REF_FIELD_NUMBER: builtins.int
    prefix: builtins.str
    @property
    def config_map_ref(self) -> global___CloudRunServiceXTemplateXSpecXContainersXEnvFromXConfigMapRef: ...
    @property
    def secret_ref(self) -> global___CloudRunServiceXTemplateXSpecXContainersXEnvFromXSecretRef: ...
    def __init__(
        self,
        *,
        prefix: builtins.str = ...,
        config_map_ref: global___CloudRunServiceXTemplateXSpecXContainersXEnvFromXConfigMapRef | None = ...,
        secret_ref: global___CloudRunServiceXTemplateXSpecXContainersXEnvFromXSecretRef | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["config_map_ref", b"config_map_ref", "secret_ref", b"secret_ref"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["config_map_ref", b"config_map_ref", "prefix", b"prefix", "secret_ref", b"secret_ref"]) -> None: ...

global___CloudRunServiceXTemplateXSpecXContainersXEnvFrom = CloudRunServiceXTemplateXSpecXContainersXEnvFrom

@typing_extensions.final
class CloudRunServiceXTemplateXSpecXContainersXPorts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTAINER_PORT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROTOCOL_FIELD_NUMBER: builtins.int
    container_port: builtins.float
    name: builtins.str
    protocol: builtins.str
    def __init__(
        self,
        *,
        container_port: builtins.float = ...,
        name: builtins.str = ...,
        protocol: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["container_port", b"container_port", "name", b"name", "protocol", b"protocol"]) -> None: ...

global___CloudRunServiceXTemplateXSpecXContainersXPorts = CloudRunServiceXTemplateXSpecXContainersXPorts

@typing_extensions.final
class CloudRunServiceXTemplateXSpecXContainersXResources(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class LimitsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class RequestsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    LIMITS_FIELD_NUMBER: builtins.int
    REQUESTS_FIELD_NUMBER: builtins.int
    @property
    def limits(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def requests(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        limits: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        requests: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["limits", b"limits", "requests", b"requests"]) -> None: ...

global___CloudRunServiceXTemplateXSpecXContainersXResources = CloudRunServiceXTemplateXSpecXContainersXResources

@typing_extensions.final
class CloudRunServiceXTemplateXSpecXContainersXVolumeMounts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MOUNT_PATH_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    mount_path: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        mount_path: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["mount_path", b"mount_path", "name", b"name"]) -> None: ...

global___CloudRunServiceXTemplateXSpecXContainersXVolumeMounts = CloudRunServiceXTemplateXSpecXContainersXVolumeMounts

@typing_extensions.final
class CloudRunServiceXTemplateXSpecXContainers(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ARGS_FIELD_NUMBER: builtins.int
    COMMAND_FIELD_NUMBER: builtins.int
    IMAGE_FIELD_NUMBER: builtins.int
    WORKING_DIR_FIELD_NUMBER: builtins.int
    ENV_FIELD_NUMBER: builtins.int
    ENV_FROM_FIELD_NUMBER: builtins.int
    PORTS_FIELD_NUMBER: builtins.int
    RESOURCES_FIELD_NUMBER: builtins.int
    VOLUME_MOUNTS_FIELD_NUMBER: builtins.int
    @property
    def args(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def command(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    image: builtins.str
    working_dir: builtins.str
    @property
    def env(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CloudRunServiceXTemplateXSpecXContainersXEnv]: ...
    @property
    def env_from(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CloudRunServiceXTemplateXSpecXContainersXEnvFrom]: ...
    @property
    def ports(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CloudRunServiceXTemplateXSpecXContainersXPorts]: ...
    @property
    def resources(self) -> global___CloudRunServiceXTemplateXSpecXContainersXResources: ...
    @property
    def volume_mounts(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CloudRunServiceXTemplateXSpecXContainersXVolumeMounts]: ...
    def __init__(
        self,
        *,
        args: collections.abc.Iterable[builtins.str] | None = ...,
        command: collections.abc.Iterable[builtins.str] | None = ...,
        image: builtins.str = ...,
        working_dir: builtins.str = ...,
        env: collections.abc.Iterable[global___CloudRunServiceXTemplateXSpecXContainersXEnv] | None = ...,
        env_from: collections.abc.Iterable[global___CloudRunServiceXTemplateXSpecXContainersXEnvFrom] | None = ...,
        ports: collections.abc.Iterable[global___CloudRunServiceXTemplateXSpecXContainersXPorts] | None = ...,
        resources: global___CloudRunServiceXTemplateXSpecXContainersXResources | None = ...,
        volume_mounts: collections.abc.Iterable[global___CloudRunServiceXTemplateXSpecXContainersXVolumeMounts] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resources", b"resources"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["args", b"args", "command", b"command", "env", b"env", "env_from", b"env_from", "image", b"image", "ports", b"ports", "resources", b"resources", "volume_mounts", b"volume_mounts", "working_dir", b"working_dir"]) -> None: ...

global___CloudRunServiceXTemplateXSpecXContainers = CloudRunServiceXTemplateXSpecXContainers

@typing_extensions.final
class CloudRunServiceXTemplateXSpecXVolumesXSecretXItems(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_FIELD_NUMBER: builtins.int
    MODE_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    key: builtins.str
    mode: builtins.float
    path: builtins.str
    def __init__(
        self,
        *,
        key: builtins.str = ...,
        mode: builtins.float = ...,
        path: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "mode", b"mode", "path", b"path"]) -> None: ...

global___CloudRunServiceXTemplateXSpecXVolumesXSecretXItems = CloudRunServiceXTemplateXSpecXVolumesXSecretXItems

@typing_extensions.final
class CloudRunServiceXTemplateXSpecXVolumesXSecret(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEFAULT_MODE_FIELD_NUMBER: builtins.int
    SECRET_NAME_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    default_mode: builtins.float
    secret_name: builtins.str
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CloudRunServiceXTemplateXSpecXVolumesXSecretXItems]: ...
    def __init__(
        self,
        *,
        default_mode: builtins.float = ...,
        secret_name: builtins.str = ...,
        items: collections.abc.Iterable[global___CloudRunServiceXTemplateXSpecXVolumesXSecretXItems] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["default_mode", b"default_mode", "items", b"items", "secret_name", b"secret_name"]) -> None: ...

global___CloudRunServiceXTemplateXSpecXVolumesXSecret = CloudRunServiceXTemplateXSpecXVolumesXSecret

@typing_extensions.final
class CloudRunServiceXTemplateXSpecXVolumes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    SECRET_FIELD_NUMBER: builtins.int
    name: builtins.str
    @property
    def secret(self) -> global___CloudRunServiceXTemplateXSpecXVolumesXSecret: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        secret: global___CloudRunServiceXTemplateXSpecXVolumesXSecret | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["secret", b"secret"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "secret", b"secret"]) -> None: ...

global___CloudRunServiceXTemplateXSpecXVolumes = CloudRunServiceXTemplateXSpecXVolumes

@typing_extensions.final
class CloudRunServiceXTemplateXSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTAINER_CONCURRENCY_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_NAME_FIELD_NUMBER: builtins.int
    SERVING_STATE_FIELD_NUMBER: builtins.int
    TIMEOUT_SECONDS_FIELD_NUMBER: builtins.int
    CONTAINERS_FIELD_NUMBER: builtins.int
    VOLUMES_FIELD_NUMBER: builtins.int
    container_concurrency: builtins.float
    service_account_name: builtins.str
    serving_state: builtins.str
    timeout_seconds: builtins.float
    @property
    def containers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CloudRunServiceXTemplateXSpecXContainers]: ...
    @property
    def volumes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CloudRunServiceXTemplateXSpecXVolumes]: ...
    def __init__(
        self,
        *,
        container_concurrency: builtins.float = ...,
        service_account_name: builtins.str = ...,
        serving_state: builtins.str = ...,
        timeout_seconds: builtins.float = ...,
        containers: collections.abc.Iterable[global___CloudRunServiceXTemplateXSpecXContainers] | None = ...,
        volumes: collections.abc.Iterable[global___CloudRunServiceXTemplateXSpecXVolumes] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["container_concurrency", b"container_concurrency", "containers", b"containers", "service_account_name", b"service_account_name", "serving_state", b"serving_state", "timeout_seconds", b"timeout_seconds", "volumes", b"volumes"]) -> None: ...

global___CloudRunServiceXTemplateXSpec = CloudRunServiceXTemplateXSpec

@typing_extensions.final
class CloudRunServiceXTemplate(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    METADATA_FIELD_NUMBER: builtins.int
    SPEC_FIELD_NUMBER: builtins.int
    @property
    def metadata(self) -> global___CloudRunServiceXTemplateXMetadata: ...
    @property
    def spec(self) -> global___CloudRunServiceXTemplateXSpec: ...
    def __init__(
        self,
        *,
        metadata: global___CloudRunServiceXTemplateXMetadata | None = ...,
        spec: global___CloudRunServiceXTemplateXSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "spec", b"spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "spec", b"spec"]) -> None: ...

global___CloudRunServiceXTemplate = CloudRunServiceXTemplate

@typing_extensions.final
class CloudRunServiceXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___CloudRunServiceXTimeouts = CloudRunServiceXTimeouts

@typing_extensions.final
class CloudRunServiceXTraffic(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LATEST_REVISION_FIELD_NUMBER: builtins.int
    PERCENT_FIELD_NUMBER: builtins.int
    REVISION_NAME_FIELD_NUMBER: builtins.int
    TAG_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    latest_revision: builtins.bool
    percent: builtins.float
    revision_name: builtins.str
    tag: builtins.str
    url: builtins.str
    def __init__(
        self,
        *,
        latest_revision: builtins.bool = ...,
        percent: builtins.float = ...,
        revision_name: builtins.str = ...,
        tag: builtins.str = ...,
        url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["latest_revision", b"latest_revision", "percent", b"percent", "revision_name", b"revision_name", "tag", b"tag", "url", b"url"]) -> None: ...

global___CloudRunServiceXTraffic = CloudRunServiceXTraffic

@typing_extensions.final
class CloudRunService(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class StatusEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    AUTOGENERATE_REVISION_NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    TEMPLATE_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    TRAFFIC_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    autogenerate_revision_name: builtins.bool
    id: builtins.str
    location: builtins.str
    name: builtins.str
    project: builtins.str
    @property
    def status(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def metadata(self) -> global___CloudRunServiceXMetadata: ...
    @property
    def template(self) -> global___CloudRunServiceXTemplate: ...
    @property
    def timeouts(self) -> global___CloudRunServiceXTimeouts: ...
    @property
    def traffic(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CloudRunServiceXTraffic]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        autogenerate_revision_name: builtins.bool = ...,
        id: builtins.str = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        status: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        metadata: global___CloudRunServiceXMetadata | None = ...,
        template: global___CloudRunServiceXTemplate | None = ...,
        timeouts: global___CloudRunServiceXTimeouts | None = ...,
        traffic: collections.abc.Iterable[global___CloudRunServiceXTraffic] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info", "template", b"template", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["autogenerate_revision_name", b"autogenerate_revision_name", "id", b"id", "location", b"location", "metadata", b"metadata", "name", b"name", "project", b"project", "resource_info", b"resource_info", "status", b"status", "template", b"template", "timeouts", b"timeouts", "traffic", b"traffic"]) -> None: ...

global___CloudRunService = CloudRunService

@typing_extensions.final
class CloudRunServiceIamBindingXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___CloudRunServiceIamBindingXCondition = CloudRunServiceIamBindingXCondition

@typing_extensions.final
class CloudRunServiceIamBinding(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    MEMBERS_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    SERVICE_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    location: builtins.str
    @property
    def members(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    project: builtins.str
    role: builtins.str
    service: builtins.str
    @property
    def condition(self) -> global___CloudRunServiceIamBindingXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        location: builtins.str = ...,
        members: collections.abc.Iterable[builtins.str] | None = ...,
        project: builtins.str = ...,
        role: builtins.str = ...,
        service: builtins.str = ...,
        condition: global___CloudRunServiceIamBindingXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "etag", b"etag", "id", b"id", "location", b"location", "members", b"members", "project", b"project", "resource_info", b"resource_info", "role", b"role", "service", b"service"]) -> None: ...

global___CloudRunServiceIamBinding = CloudRunServiceIamBinding

@typing_extensions.final
class CloudRunServiceIamMemberXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___CloudRunServiceIamMemberXCondition = CloudRunServiceIamMemberXCondition

@typing_extensions.final
class CloudRunServiceIamMember(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    MEMBER_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    SERVICE_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    location: builtins.str
    member: builtins.str
    project: builtins.str
    role: builtins.str
    service: builtins.str
    @property
    def condition(self) -> global___CloudRunServiceIamMemberXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        location: builtins.str = ...,
        member: builtins.str = ...,
        project: builtins.str = ...,
        role: builtins.str = ...,
        service: builtins.str = ...,
        condition: global___CloudRunServiceIamMemberXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "etag", b"etag", "id", b"id", "location", b"location", "member", b"member", "project", b"project", "resource_info", b"resource_info", "role", b"role", "service", b"service"]) -> None: ...

global___CloudRunServiceIamMember = CloudRunServiceIamMember

@typing_extensions.final
class CloudRunServiceIamPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    POLICY_DATA_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    SERVICE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    location: builtins.str
    policy_data: builtins.str
    project: builtins.str
    service: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        location: builtins.str = ...,
        policy_data: builtins.str = ...,
        project: builtins.str = ...,
        service: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["etag", b"etag", "id", b"id", "location", b"location", "policy_data", b"policy_data", "project", b"project", "resource_info", b"resource_info", "service", b"service"]) -> None: ...

global___CloudRunServiceIamPolicy = CloudRunServiceIamPolicy

@typing_extensions.final
class CloudSchedulerJobXAppEngineHttpTargetXAppEngineRouting(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INSTANCE_FIELD_NUMBER: builtins.int
    SERVICE_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    instance: builtins.str
    service: builtins.str
    version: builtins.str
    def __init__(
        self,
        *,
        instance: builtins.str = ...,
        service: builtins.str = ...,
        version: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["instance", b"instance", "service", b"service", "version", b"version"]) -> None: ...

global___CloudSchedulerJobXAppEngineHttpTargetXAppEngineRouting = CloudSchedulerJobXAppEngineHttpTargetXAppEngineRouting

@typing_extensions.final
class CloudSchedulerJobXAppEngineHttpTarget(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class HeadersEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    BODY_FIELD_NUMBER: builtins.int
    HEADERS_FIELD_NUMBER: builtins.int
    HTTP_METHOD_FIELD_NUMBER: builtins.int
    RELATIVE_URI_FIELD_NUMBER: builtins.int
    APP_ENGINE_ROUTING_FIELD_NUMBER: builtins.int
    body: builtins.str
    @property
    def headers(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    http_method: builtins.str
    relative_uri: builtins.str
    @property
    def app_engine_routing(self) -> global___CloudSchedulerJobXAppEngineHttpTargetXAppEngineRouting: ...
    def __init__(
        self,
        *,
        body: builtins.str = ...,
        headers: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        http_method: builtins.str = ...,
        relative_uri: builtins.str = ...,
        app_engine_routing: global___CloudSchedulerJobXAppEngineHttpTargetXAppEngineRouting | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["app_engine_routing", b"app_engine_routing"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["app_engine_routing", b"app_engine_routing", "body", b"body", "headers", b"headers", "http_method", b"http_method", "relative_uri", b"relative_uri"]) -> None: ...

global___CloudSchedulerJobXAppEngineHttpTarget = CloudSchedulerJobXAppEngineHttpTarget

@typing_extensions.final
class CloudSchedulerJobXHttpTargetXOauthToken(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SCOPE_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_EMAIL_FIELD_NUMBER: builtins.int
    scope: builtins.str
    service_account_email: builtins.str
    def __init__(
        self,
        *,
        scope: builtins.str = ...,
        service_account_email: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["scope", b"scope", "service_account_email", b"service_account_email"]) -> None: ...

global___CloudSchedulerJobXHttpTargetXOauthToken = CloudSchedulerJobXHttpTargetXOauthToken

@typing_extensions.final
class CloudSchedulerJobXHttpTargetXOidcToken(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUDIENCE_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_EMAIL_FIELD_NUMBER: builtins.int
    audience: builtins.str
    service_account_email: builtins.str
    def __init__(
        self,
        *,
        audience: builtins.str = ...,
        service_account_email: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["audience", b"audience", "service_account_email", b"service_account_email"]) -> None: ...

global___CloudSchedulerJobXHttpTargetXOidcToken = CloudSchedulerJobXHttpTargetXOidcToken

@typing_extensions.final
class CloudSchedulerJobXHttpTarget(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class HeadersEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    BODY_FIELD_NUMBER: builtins.int
    HEADERS_FIELD_NUMBER: builtins.int
    HTTP_METHOD_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    OAUTH_TOKEN_FIELD_NUMBER: builtins.int
    OIDC_TOKEN_FIELD_NUMBER: builtins.int
    body: builtins.str
    @property
    def headers(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    http_method: builtins.str
    uri: builtins.str
    @property
    def oauth_token(self) -> global___CloudSchedulerJobXHttpTargetXOauthToken: ...
    @property
    def oidc_token(self) -> global___CloudSchedulerJobXHttpTargetXOidcToken: ...
    def __init__(
        self,
        *,
        body: builtins.str = ...,
        headers: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        http_method: builtins.str = ...,
        uri: builtins.str = ...,
        oauth_token: global___CloudSchedulerJobXHttpTargetXOauthToken | None = ...,
        oidc_token: global___CloudSchedulerJobXHttpTargetXOidcToken | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["oauth_token", b"oauth_token", "oidc_token", b"oidc_token"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["body", b"body", "headers", b"headers", "http_method", b"http_method", "oauth_token", b"oauth_token", "oidc_token", b"oidc_token", "uri", b"uri"]) -> None: ...

global___CloudSchedulerJobXHttpTarget = CloudSchedulerJobXHttpTarget

@typing_extensions.final
class CloudSchedulerJobXPubsubTarget(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class AttributesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    ATTRIBUTES_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    TOPIC_NAME_FIELD_NUMBER: builtins.int
    @property
    def attributes(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    data: builtins.str
    topic_name: builtins.str
    def __init__(
        self,
        *,
        attributes: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        data: builtins.str = ...,
        topic_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["attributes", b"attributes", "data", b"data", "topic_name", b"topic_name"]) -> None: ...

global___CloudSchedulerJobXPubsubTarget = CloudSchedulerJobXPubsubTarget

@typing_extensions.final
class CloudSchedulerJobXRetryConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MAX_BACKOFF_DURATION_FIELD_NUMBER: builtins.int
    MAX_DOUBLINGS_FIELD_NUMBER: builtins.int
    MAX_RETRY_DURATION_FIELD_NUMBER: builtins.int
    MIN_BACKOFF_DURATION_FIELD_NUMBER: builtins.int
    RETRY_COUNT_FIELD_NUMBER: builtins.int
    max_backoff_duration: builtins.str
    max_doublings: builtins.float
    max_retry_duration: builtins.str
    min_backoff_duration: builtins.str
    retry_count: builtins.float
    def __init__(
        self,
        *,
        max_backoff_duration: builtins.str = ...,
        max_doublings: builtins.float = ...,
        max_retry_duration: builtins.str = ...,
        min_backoff_duration: builtins.str = ...,
        retry_count: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["max_backoff_duration", b"max_backoff_duration", "max_doublings", b"max_doublings", "max_retry_duration", b"max_retry_duration", "min_backoff_duration", b"min_backoff_duration", "retry_count", b"retry_count"]) -> None: ...

global___CloudSchedulerJobXRetryConfig = CloudSchedulerJobXRetryConfig

@typing_extensions.final
class CloudSchedulerJobXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___CloudSchedulerJobXTimeouts = CloudSchedulerJobXTimeouts

@typing_extensions.final
class CloudSchedulerJob(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ATTEMPT_DEADLINE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    SCHEDULE_FIELD_NUMBER: builtins.int
    TIME_ZONE_FIELD_NUMBER: builtins.int
    APP_ENGINE_HTTP_TARGET_FIELD_NUMBER: builtins.int
    HTTP_TARGET_FIELD_NUMBER: builtins.int
    PUBSUB_TARGET_FIELD_NUMBER: builtins.int
    RETRY_CONFIG_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    attempt_deadline: builtins.str
    description: builtins.str
    id: builtins.str
    name: builtins.str
    project: builtins.str
    region: builtins.str
    schedule: builtins.str
    time_zone: builtins.str
    @property
    def app_engine_http_target(self) -> global___CloudSchedulerJobXAppEngineHttpTarget: ...
    @property
    def http_target(self) -> global___CloudSchedulerJobXHttpTarget: ...
    @property
    def pubsub_target(self) -> global___CloudSchedulerJobXPubsubTarget: ...
    @property
    def retry_config(self) -> global___CloudSchedulerJobXRetryConfig: ...
    @property
    def timeouts(self) -> global___CloudSchedulerJobXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        attempt_deadline: builtins.str = ...,
        description: builtins.str = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        region: builtins.str = ...,
        schedule: builtins.str = ...,
        time_zone: builtins.str = ...,
        app_engine_http_target: global___CloudSchedulerJobXAppEngineHttpTarget | None = ...,
        http_target: global___CloudSchedulerJobXHttpTarget | None = ...,
        pubsub_target: global___CloudSchedulerJobXPubsubTarget | None = ...,
        retry_config: global___CloudSchedulerJobXRetryConfig | None = ...,
        timeouts: global___CloudSchedulerJobXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["app_engine_http_target", b"app_engine_http_target", "http_target", b"http_target", "pubsub_target", b"pubsub_target", "resource_info", b"resource_info", "retry_config", b"retry_config", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["app_engine_http_target", b"app_engine_http_target", "attempt_deadline", b"attempt_deadline", "description", b"description", "http_target", b"http_target", "id", b"id", "name", b"name", "project", b"project", "pubsub_target", b"pubsub_target", "region", b"region", "resource_info", b"resource_info", "retry_config", b"retry_config", "schedule", b"schedule", "time_zone", b"time_zone", "timeouts", b"timeouts"]) -> None: ...

global___CloudSchedulerJob = CloudSchedulerJob

@typing_extensions.final
class CloudTasksQueueXAppEngineRoutingOverride(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOST_FIELD_NUMBER: builtins.int
    INSTANCE_FIELD_NUMBER: builtins.int
    SERVICE_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    host: builtins.str
    instance: builtins.str
    service: builtins.str
    version: builtins.str
    def __init__(
        self,
        *,
        host: builtins.str = ...,
        instance: builtins.str = ...,
        service: builtins.str = ...,
        version: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["host", b"host", "instance", b"instance", "service", b"service", "version", b"version"]) -> None: ...

global___CloudTasksQueueXAppEngineRoutingOverride = CloudTasksQueueXAppEngineRoutingOverride

@typing_extensions.final
class CloudTasksQueueXRateLimits(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MAX_BURST_SIZE_FIELD_NUMBER: builtins.int
    MAX_CONCURRENT_DISPATCHES_FIELD_NUMBER: builtins.int
    MAX_DISPATCHES_PER_SECOND_FIELD_NUMBER: builtins.int
    max_burst_size: builtins.float
    max_concurrent_dispatches: builtins.float
    max_dispatches_per_second: builtins.float
    def __init__(
        self,
        *,
        max_burst_size: builtins.float = ...,
        max_concurrent_dispatches: builtins.float = ...,
        max_dispatches_per_second: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["max_burst_size", b"max_burst_size", "max_concurrent_dispatches", b"max_concurrent_dispatches", "max_dispatches_per_second", b"max_dispatches_per_second"]) -> None: ...

global___CloudTasksQueueXRateLimits = CloudTasksQueueXRateLimits

@typing_extensions.final
class CloudTasksQueueXRetryConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MAX_ATTEMPTS_FIELD_NUMBER: builtins.int
    MAX_BACKOFF_FIELD_NUMBER: builtins.int
    MAX_DOUBLINGS_FIELD_NUMBER: builtins.int
    MAX_RETRY_DURATION_FIELD_NUMBER: builtins.int
    MIN_BACKOFF_FIELD_NUMBER: builtins.int
    max_attempts: builtins.float
    max_backoff: builtins.str
    max_doublings: builtins.float
    max_retry_duration: builtins.str
    min_backoff: builtins.str
    def __init__(
        self,
        *,
        max_attempts: builtins.float = ...,
        max_backoff: builtins.str = ...,
        max_doublings: builtins.float = ...,
        max_retry_duration: builtins.str = ...,
        min_backoff: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["max_attempts", b"max_attempts", "max_backoff", b"max_backoff", "max_doublings", b"max_doublings", "max_retry_duration", b"max_retry_duration", "min_backoff", b"min_backoff"]) -> None: ...

global___CloudTasksQueueXRetryConfig = CloudTasksQueueXRetryConfig

@typing_extensions.final
class CloudTasksQueueXStackdriverLoggingConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SAMPLING_RATIO_FIELD_NUMBER: builtins.int
    sampling_ratio: builtins.float
    def __init__(
        self,
        *,
        sampling_ratio: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["sampling_ratio", b"sampling_ratio"]) -> None: ...

global___CloudTasksQueueXStackdriverLoggingConfig = CloudTasksQueueXStackdriverLoggingConfig

@typing_extensions.final
class CloudTasksQueueXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___CloudTasksQueueXTimeouts = CloudTasksQueueXTimeouts

@typing_extensions.final
class CloudTasksQueue(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    APP_ENGINE_ROUTING_OVERRIDE_FIELD_NUMBER: builtins.int
    RATE_LIMITS_FIELD_NUMBER: builtins.int
    RETRY_CONFIG_FIELD_NUMBER: builtins.int
    STACKDRIVER_LOGGING_CONFIG_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    id: builtins.str
    location: builtins.str
    name: builtins.str
    project: builtins.str
    @property
    def app_engine_routing_override(self) -> global___CloudTasksQueueXAppEngineRoutingOverride: ...
    @property
    def rate_limits(self) -> global___CloudTasksQueueXRateLimits: ...
    @property
    def retry_config(self) -> global___CloudTasksQueueXRetryConfig: ...
    @property
    def stackdriver_logging_config(self) -> global___CloudTasksQueueXStackdriverLoggingConfig: ...
    @property
    def timeouts(self) -> global___CloudTasksQueueXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        app_engine_routing_override: global___CloudTasksQueueXAppEngineRoutingOverride | None = ...,
        rate_limits: global___CloudTasksQueueXRateLimits | None = ...,
        retry_config: global___CloudTasksQueueXRetryConfig | None = ...,
        stackdriver_logging_config: global___CloudTasksQueueXStackdriverLoggingConfig | None = ...,
        timeouts: global___CloudTasksQueueXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["app_engine_routing_override", b"app_engine_routing_override", "rate_limits", b"rate_limits", "resource_info", b"resource_info", "retry_config", b"retry_config", "stackdriver_logging_config", b"stackdriver_logging_config", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["app_engine_routing_override", b"app_engine_routing_override", "id", b"id", "location", b"location", "name", b"name", "project", b"project", "rate_limits", b"rate_limits", "resource_info", b"resource_info", "retry_config", b"retry_config", "stackdriver_logging_config", b"stackdriver_logging_config", "timeouts", b"timeouts"]) -> None: ...

global___CloudTasksQueue = CloudTasksQueue

@typing_extensions.final
class CloudTasksQueueIamBindingXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___CloudTasksQueueIamBindingXCondition = CloudTasksQueueIamBindingXCondition

@typing_extensions.final
class CloudTasksQueueIamBinding(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    MEMBERS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    location: builtins.str
    @property
    def members(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    name: builtins.str
    project: builtins.str
    role: builtins.str
    @property
    def condition(self) -> global___CloudTasksQueueIamBindingXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        location: builtins.str = ...,
        members: collections.abc.Iterable[builtins.str] | None = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        role: builtins.str = ...,
        condition: global___CloudTasksQueueIamBindingXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "etag", b"etag", "id", b"id", "location", b"location", "members", b"members", "name", b"name", "project", b"project", "resource_info", b"resource_info", "role", b"role"]) -> None: ...

global___CloudTasksQueueIamBinding = CloudTasksQueueIamBinding

@typing_extensions.final
class CloudTasksQueueIamMemberXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___CloudTasksQueueIamMemberXCondition = CloudTasksQueueIamMemberXCondition

@typing_extensions.final
class CloudTasksQueueIamMember(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    MEMBER_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    location: builtins.str
    member: builtins.str
    name: builtins.str
    project: builtins.str
    role: builtins.str
    @property
    def condition(self) -> global___CloudTasksQueueIamMemberXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        location: builtins.str = ...,
        member: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        role: builtins.str = ...,
        condition: global___CloudTasksQueueIamMemberXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "etag", b"etag", "id", b"id", "location", b"location", "member", b"member", "name", b"name", "project", b"project", "resource_info", b"resource_info", "role", b"role"]) -> None: ...

global___CloudTasksQueueIamMember = CloudTasksQueueIamMember

@typing_extensions.final
class CloudTasksQueueIamPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    POLICY_DATA_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    location: builtins.str
    name: builtins.str
    policy_data: builtins.str
    project: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        policy_data: builtins.str = ...,
        project: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["etag", b"etag", "id", b"id", "location", b"location", "name", b"name", "policy_data", b"policy_data", "project", b"project", "resource_info", b"resource_info"]) -> None: ...

global___CloudTasksQueueIamPolicy = CloudTasksQueueIamPolicy
