# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_managedblockchain.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x61ws/aws_managedblockchain.proto\x12!oak9.tython.aws.managedblockchain\x1a\x13shared/shared.proto\"\x8a\x01\n\x1fMemberMemberFabricConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0e\x61\x64min_username\x18\x02 \x01(\t\x12\x16\n\x0e\x61\x64min_password\x18\x03 \x01(\t\"\xc6\x01\n\"MemberMemberFrameworkConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12g\n\x1bmember_fabric_configuration\x18\x02 \x01(\x0b\x32\x42.oak9.tython.aws.managedblockchain.MemberMemberFabricConfiguration\"\xe6\x01\n\x19MemberMemberConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12m\n\x1emember_framework_configuration\x18\x03 \x01(\x0b\x32\x45.oak9.tython.aws.managedblockchain.MemberMemberFrameworkConfiguration\x12\x0c\n\x04name\x18\x04 \x01(\t\"\xb8\x01\n\x1dMemberApprovalThresholdPolicy\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1c\n\x14threshold_comparator\x18\x02 \x01(\t\x12\x1c\n\x14threshold_percentage\x18\x03 \x01(\x05\x12\"\n\x1aproposal_duration_in_hours\x18\x04 \x01(\x05\"\xb2\x01\n\x12MemberVotingPolicy\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x63\n\x19\x61pproval_threshold_policy\x18\x02 \x01(\x0b\x32@.oak9.tython.aws.managedblockchain.MemberApprovalThresholdPolicy\"l\n MemberNetworkFabricConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07\x65\x64ition\x18\x02 \x01(\t\"\xc9\x01\n#MemberNetworkFrameworkConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12i\n\x1cnetwork_fabric_configuration\x18\x02 \x01(\x0b\x32\x43.oak9.tython.aws.managedblockchain.MemberNetworkFabricConfiguration\"\xe5\x02\n\x1aMemberNetworkConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x19\n\x11\x66ramework_version\x18\x03 \x01(\t\x12L\n\rvoting_policy\x18\x04 \x01(\x0b\x32\x35.oak9.tython.aws.managedblockchain.MemberVotingPolicy\x12\x11\n\tframework\x18\x05 \x01(\t\x12\x0c\n\x04name\x18\x06 \x01(\t\x12o\n\x1fnetwork_framework_configuration\x18\x07 \x01(\x0b\x32\x46.oak9.tython.aws.managedblockchain.MemberNetworkFrameworkConfiguration\"\xa6\x02\n\x06Member\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12Z\n\x14member_configuration\x18\x02 \x01(\x0b\x32<.oak9.tython.aws.managedblockchain.MemberMemberConfiguration\x12\\\n\x15network_configuration\x18\x03 \x01(\x0b\x32=.oak9.tython.aws.managedblockchain.MemberNetworkConfiguration\x12\x12\n\nnetwork_id\x18\x04 \x01(\t\x12\x15\n\rinvitation_id\x18\x05 \x01(\t\"\x85\x01\n\x11ManagedBlockchain\x12\x39\n\x06member\x18\x01 \x03(\x0b\x32).oak9.tython.aws.managedblockchain.Member\x12\x35\n\x04node\x18\x02 \x03(\x0b\x32\'.oak9.tython.aws.managedblockchain.Node\"\x82\x01\n\x15NodeNodeConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x19\n\x11\x61vailability_zone\x18\x02 \x01(\t\x12\x15\n\rinstance_type\x18\x03 \x01(\t\"\xbc\x01\n\x04Node\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\tmember_id\x18\x02 \x01(\t\x12\x12\n\nnetwork_id\x18\x03 \x01(\t\x12T\n\x12node_configuration\x18\x04 \x01(\x0b\x32\x38.oak9.tython.aws.managedblockchain.NodeNodeConfigurationb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_managedblockchain_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _MEMBERMEMBERFABRICCONFIGURATION._serialized_start=92
  _MEMBERMEMBERFABRICCONFIGURATION._serialized_end=230
  _MEMBERMEMBERFRAMEWORKCONFIGURATION._serialized_start=233
  _MEMBERMEMBERFRAMEWORKCONFIGURATION._serialized_end=431
  _MEMBERMEMBERCONFIGURATION._serialized_start=434
  _MEMBERMEMBERCONFIGURATION._serialized_end=664
  _MEMBERAPPROVALTHRESHOLDPOLICY._serialized_start=667
  _MEMBERAPPROVALTHRESHOLDPOLICY._serialized_end=851
  _MEMBERVOTINGPOLICY._serialized_start=854
  _MEMBERVOTINGPOLICY._serialized_end=1032
  _MEMBERNETWORKFABRICCONFIGURATION._serialized_start=1034
  _MEMBERNETWORKFABRICCONFIGURATION._serialized_end=1142
  _MEMBERNETWORKFRAMEWORKCONFIGURATION._serialized_start=1145
  _MEMBERNETWORKFRAMEWORKCONFIGURATION._serialized_end=1346
  _MEMBERNETWORKCONFIGURATION._serialized_start=1349
  _MEMBERNETWORKCONFIGURATION._serialized_end=1706
  _MEMBER._serialized_start=1709
  _MEMBER._serialized_end=2003
  _MANAGEDBLOCKCHAIN._serialized_start=2006
  _MANAGEDBLOCKCHAIN._serialized_end=2139
  _NODENODECONFIGURATION._serialized_start=2142
  _NODENODECONFIGURATION._serialized_end=2272
  _NODE._serialized_start=2275
  _NODE._serialized_end=2463
# @@protoc_insertion_point(module_scope)
