# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_compute_backend.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dgcp/gcp_compute_backend.proto\x12\x1foak9.tython.gcp.compute_backend\x1a\x13shared/shared.proto\"Q\n:ComputeBackendBucketXCdnPolicyXBypassCacheOnRequestHeaders\x12\x13\n\x0bheader_name\x18\x01 \x01(\t\"m\n-ComputeBackendBucketXCdnPolicyXCacheKeyPolicy\x12\x1c\n\x14include_http_headers\x18\x01 \x03(\t\x12\x1e\n\x16query_string_whitelist\x18\x02 \x03(\t\"Q\n4ComputeBackendBucketXCdnPolicyXNegativeCachingPolicy\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x01\x12\x0b\n\x03ttl\x18\x02 \x01(\x01\"\xce\x04\n\x1e\x43omputeBackendBucketXCdnPolicy\x12\x12\n\ncache_mode\x18\x01 \x01(\t\x12\x12\n\nclient_ttl\x18\x02 \x01(\x01\x12\x13\n\x0b\x64\x65\x66\x61ult_ttl\x18\x03 \x01(\x01\x12\x0f\n\x07max_ttl\x18\x04 \x01(\x01\x12\x18\n\x10negative_caching\x18\x05 \x01(\x08\x12\x1a\n\x12request_coalescing\x18\x06 \x01(\x08\x12\x19\n\x11serve_while_stale\x18\x07 \x01(\x01\x12$\n\x1csigned_url_cache_max_age_sec\x18\x08 \x01(\x01\x12\x84\x01\n\x1f\x62ypass_cache_on_request_headers\x18\t \x03(\x0b\x32[.oak9.tython.gcp.compute_backend.ComputeBackendBucketXCdnPolicyXBypassCacheOnRequestHeaders\x12h\n\x10\x63\x61\x63he_key_policy\x18\n \x01(\x0b\x32N.oak9.tython.gcp.compute_backend.ComputeBackendBucketXCdnPolicyXCacheKeyPolicy\x12v\n\x17negative_caching_policy\x18\x0b \x03(\x0b\x32U.oak9.tython.gcp.compute_backend.ComputeBackendBucketXCdnPolicyXNegativeCachingPolicy\"O\n\x1d\x43omputeBackendBucketXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xcd\x03\n\x14\x43omputeBackendBucket\x12\x13\n\x0b\x62ucket_name\x18\x01 \x01(\t\x12\x1a\n\x12\x63reation_timestamp\x18\x02 \x01(\t\x12\x1f\n\x17\x63ustom_response_headers\x18\x03 \x03(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x1c\n\x14\x65\x64ge_security_policy\x18\x05 \x01(\t\x12\x12\n\nenable_cdn\x18\x06 \x01(\x08\x12\n\n\x02id\x18\x07 \x01(\t\x12\x0c\n\x04name\x18\x08 \x01(\t\x12\x0f\n\x07project\x18\t \x01(\t\x12\x11\n\tself_link\x18\n \x01(\t\x12S\n\ncdn_policy\x18\x0b \x01(\x0b\x32?.oak9.tython.gcp.compute_backend.ComputeBackendBucketXCdnPolicy\x12P\n\x08timeouts\x18\x0c \x01(\x0b\x32>.oak9.tython.gcp.compute_backend.ComputeBackendBucketXTimeouts\x12\x37\n\rresource_info\x18\r \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"K\n)ComputeBackendBucketSignedUrlKeyXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\"\x8f\x02\n ComputeBackendBucketSignedUrlKey\x12\x16\n\x0e\x62\x61\x63kend_bucket\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x11\n\tkey_value\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\\\n\x08timeouts\x18\x06 \x01(\x0b\x32J.oak9.tython.gcp.compute_backend.ComputeBackendBucketSignedUrlKeyXTimeouts\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xc2\x02\n\x1d\x43omputeBackendServiceXBackend\x12\x16\n\x0e\x62\x61lancing_mode\x18\x01 \x01(\t\x12\x17\n\x0f\x63\x61pacity_scaler\x18\x02 \x01(\x01\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\r\n\x05group\x18\x04 \x01(\t\x12\x17\n\x0fmax_connections\x18\x05 \x01(\x01\x12$\n\x1cmax_connections_per_endpoint\x18\x06 \x01(\x01\x12$\n\x1cmax_connections_per_instance\x18\x07 \x01(\x01\x12\x10\n\x08max_rate\x18\x08 \x01(\x01\x12\x1d\n\x15max_rate_per_endpoint\x18\t \x01(\x01\x12\x1d\n\x15max_rate_per_instance\x18\n \x01(\x01\x12\x17\n\x0fmax_utilization\x18\x0b \x01(\x01\"\xdd\x01\n.ComputeBackendServiceXCdnPolicyXCacheKeyPolicy\x12\x14\n\x0cinclude_host\x18\x01 \x01(\x08\x12\x1d\n\x15include_named_cookies\x18\x02 \x03(\t\x12\x18\n\x10include_protocol\x18\x03 \x01(\x08\x12\x1c\n\x14include_query_string\x18\x04 \x01(\x08\x12\x1e\n\x16query_string_blacklist\x18\x05 \x03(\t\x12\x1e\n\x16query_string_whitelist\x18\x06 \x03(\t\"R\n5ComputeBackendServiceXCdnPolicyXNegativeCachingPolicy\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x01\x12\x0b\n\x03ttl\x18\x02 \x01(\x01\"\xae\x03\n\x1f\x43omputeBackendServiceXCdnPolicy\x12\x12\n\ncache_mode\x18\x01 \x01(\t\x12\x12\n\nclient_ttl\x18\x02 \x01(\x01\x12\x13\n\x0b\x64\x65\x66\x61ult_ttl\x18\x03 \x01(\x01\x12\x0f\n\x07max_ttl\x18\x04 \x01(\x01\x12\x18\n\x10negative_caching\x18\x05 \x01(\x08\x12\x19\n\x11serve_while_stale\x18\x06 \x01(\x01\x12$\n\x1csigned_url_cache_max_age_sec\x18\x07 \x01(\x01\x12i\n\x10\x63\x61\x63he_key_policy\x18\x08 \x01(\x0b\x32O.oak9.tython.gcp.compute_backend.ComputeBackendServiceXCdnPolicyXCacheKeyPolicy\x12w\n\x17negative_caching_policy\x18\t \x03(\x0b\x32V.oak9.tython.gcp.compute_backend.ComputeBackendServiceXCdnPolicyXNegativeCachingPolicy\"\xae\x01\n%ComputeBackendServiceXCircuitBreakers\x12\x17\n\x0fmax_connections\x18\x01 \x01(\x01\x12\x1c\n\x14max_pending_requests\x18\x02 \x01(\x01\x12\x14\n\x0cmax_requests\x18\x03 \x01(\x01\x12#\n\x1bmax_requests_per_connection\x18\x04 \x01(\x01\x12\x13\n\x0bmax_retries\x18\x05 \x01(\x01\"U\n3ComputeBackendServiceXConsistentHashXHttpCookieXTtl\x12\r\n\x05nanos\x18\x01 \x01(\x01\x12\x0f\n\x07seconds\x18\x02 \x01(\x01\"\xb0\x01\n/ComputeBackendServiceXConsistentHashXHttpCookie\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x61\n\x03ttl\x18\x03 \x01(\x0b\x32T.oak9.tython.gcp.compute_backend.ComputeBackendServiceXConsistentHashXHttpCookieXTtl\"\xc2\x01\n$ComputeBackendServiceXConsistentHash\x12\x18\n\x10http_header_name\x18\x01 \x01(\t\x12\x19\n\x11minimum_ring_size\x18\x02 \x01(\x01\x12\x65\n\x0bhttp_cookie\x18\x03 \x01(\x0b\x32P.oak9.tython.gcp.compute_backend.ComputeBackendServiceXConsistentHashXHttpCookie\"x\n\x19\x43omputeBackendServiceXIap\x12\x18\n\x10oauth2_client_id\x18\x01 \x01(\t\x12\x1c\n\x14oauth2_client_secret\x18\x02 \x01(\t\x12#\n\x1boauth2_client_secret_sha256\x18\x03 \x01(\t\"F\n\x1f\x43omputeBackendServiceXLogConfig\x12\x0e\n\x06\x65nable\x18\x01 \x01(\x08\x12\x13\n\x0bsample_rate\x18\x02 \x01(\x01\"Y\n7ComputeBackendServiceXOutlierDetectionXBaseEjectionTime\x12\r\n\x05nanos\x18\x01 \x01(\x01\x12\x0f\n\x07seconds\x18\x02 \x01(\x01\"Q\n/ComputeBackendServiceXOutlierDetectionXInterval\x12\r\n\x05nanos\x18\x01 \x01(\x01\x12\x0f\n\x07seconds\x18\x02 \x01(\x01\"\xc2\x04\n&ComputeBackendServiceXOutlierDetection\x12\x1a\n\x12\x63onsecutive_errors\x18\x01 \x01(\x01\x12#\n\x1b\x63onsecutive_gateway_failure\x18\x02 \x01(\x01\x12$\n\x1c\x65nforcing_consecutive_errors\x18\x03 \x01(\x01\x12-\n%enforcing_consecutive_gateway_failure\x18\x04 \x01(\x01\x12\x1e\n\x16\x65nforcing_success_rate\x18\x05 \x01(\x01\x12\x1c\n\x14max_ejection_percent\x18\x06 \x01(\x01\x12\"\n\x1asuccess_rate_minimum_hosts\x18\x07 \x01(\x01\x12#\n\x1bsuccess_rate_request_volume\x18\x08 \x01(\x01\x12!\n\x19success_rate_stdev_factor\x18\t \x01(\x01\x12t\n\x12\x62\x61se_ejection_time\x18\n \x01(\x0b\x32X.oak9.tython.gcp.compute_backend.ComputeBackendServiceXOutlierDetectionXBaseEjectionTime\x12\x62\n\x08interval\x18\x0b \x01(\x0b\x32P.oak9.tython.gcp.compute_backend.ComputeBackendServiceXOutlierDetectionXInterval\"^\n&ComputeBackendServiceXSecuritySettings\x12\x19\n\x11\x63lient_tls_policy\x18\x01 \x01(\t\x12\x19\n\x11subject_alt_names\x18\x02 \x03(\t\"P\n\x1e\x43omputeBackendServiceXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xd5\n\n\x15\x43omputeBackendService\x12\x1f\n\x17\x61\x66\x66inity_cookie_ttl_sec\x18\x01 \x01(\x01\x12\'\n\x1f\x63onnection_draining_timeout_sec\x18\x02 \x01(\x01\x12\x1a\n\x12\x63reation_timestamp\x18\x03 \x01(\t\x12\x1e\n\x16\x63ustom_request_headers\x18\x04 \x03(\t\x12\x1f\n\x17\x63ustom_response_headers\x18\x05 \x03(\t\x12\x13\n\x0b\x64\x65scription\x18\x06 \x01(\t\x12\x12\n\nenable_cdn\x18\x07 \x01(\x08\x12\x13\n\x0b\x66ingerprint\x18\x08 \x01(\t\x12\x15\n\rhealth_checks\x18\t \x03(\t\x12\n\n\x02id\x18\n \x01(\t\x12\x1d\n\x15load_balancing_scheme\x18\x0b \x01(\t\x12\x1a\n\x12locality_lb_policy\x18\x0c \x01(\t\x12\x0c\n\x04name\x18\r \x01(\t\x12\x11\n\tport_name\x18\x0e \x01(\t\x12\x0f\n\x07project\x18\x0f \x01(\t\x12\x10\n\x08protocol\x18\x10 \x01(\t\x12\x17\n\x0fsecurity_policy\x18\x11 \x01(\t\x12\x11\n\tself_link\x18\x12 \x01(\t\x12\x18\n\x10session_affinity\x18\x13 \x01(\t\x12\x13\n\x0btimeout_sec\x18\x14 \x01(\x01\x12O\n\x07\x62\x61\x63kend\x18\x15 \x03(\x0b\x32>.oak9.tython.gcp.compute_backend.ComputeBackendServiceXBackend\x12T\n\ncdn_policy\x18\x16 \x01(\x0b\x32@.oak9.tython.gcp.compute_backend.ComputeBackendServiceXCdnPolicy\x12`\n\x10\x63ircuit_breakers\x18\x17 \x01(\x0b\x32\x46.oak9.tython.gcp.compute_backend.ComputeBackendServiceXCircuitBreakers\x12^\n\x0f\x63onsistent_hash\x18\x18 \x01(\x0b\x32\x45.oak9.tython.gcp.compute_backend.ComputeBackendServiceXConsistentHash\x12G\n\x03iap\x18\x19 \x01(\x0b\x32:.oak9.tython.gcp.compute_backend.ComputeBackendServiceXIap\x12T\n\nlog_config\x18\x1a \x01(\x0b\x32@.oak9.tython.gcp.compute_backend.ComputeBackendServiceXLogConfig\x12\x62\n\x11outlier_detection\x18\x1b \x01(\x0b\x32G.oak9.tython.gcp.compute_backend.ComputeBackendServiceXOutlierDetection\x12\x62\n\x11security_settings\x18\x1c \x01(\x0b\x32G.oak9.tython.gcp.compute_backend.ComputeBackendServiceXSecuritySettings\x12Q\n\x08timeouts\x18\x1d \x01(\x0b\x32?.oak9.tython.gcp.compute_backend.ComputeBackendServiceXTimeouts\x12\x37\n\rresource_info\x18\x1e \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"L\n*ComputeBackendServiceSignedUrlKeyXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\"\x92\x02\n!ComputeBackendServiceSignedUrlKey\x12\x17\n\x0f\x62\x61\x63kend_service\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x11\n\tkey_value\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12]\n\x08timeouts\x18\x06 \x01(\x0b\x32K.oak9.tython.gcp.compute_backend.ComputeBackendServiceSignedUrlKeyXTimeouts\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_compute_backend_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMPUTEBACKENDBUCKETXCDNPOLICYXBYPASSCACHEONREQUESTHEADERS._serialized_start=87
  _COMPUTEBACKENDBUCKETXCDNPOLICYXBYPASSCACHEONREQUESTHEADERS._serialized_end=168
  _COMPUTEBACKENDBUCKETXCDNPOLICYXCACHEKEYPOLICY._serialized_start=170
  _COMPUTEBACKENDBUCKETXCDNPOLICYXCACHEKEYPOLICY._serialized_end=279
  _COMPUTEBACKENDBUCKETXCDNPOLICYXNEGATIVECACHINGPOLICY._serialized_start=281
  _COMPUTEBACKENDBUCKETXCDNPOLICYXNEGATIVECACHINGPOLICY._serialized_end=362
  _COMPUTEBACKENDBUCKETXCDNPOLICY._serialized_start=365
  _COMPUTEBACKENDBUCKETXCDNPOLICY._serialized_end=955
  _COMPUTEBACKENDBUCKETXTIMEOUTS._serialized_start=957
  _COMPUTEBACKENDBUCKETXTIMEOUTS._serialized_end=1036
  _COMPUTEBACKENDBUCKET._serialized_start=1039
  _COMPUTEBACKENDBUCKET._serialized_end=1500
  _COMPUTEBACKENDBUCKETSIGNEDURLKEYXTIMEOUTS._serialized_start=1502
  _COMPUTEBACKENDBUCKETSIGNEDURLKEYXTIMEOUTS._serialized_end=1577
  _COMPUTEBACKENDBUCKETSIGNEDURLKEY._serialized_start=1580
  _COMPUTEBACKENDBUCKETSIGNEDURLKEY._serialized_end=1851
  _COMPUTEBACKENDSERVICEXBACKEND._serialized_start=1854
  _COMPUTEBACKENDSERVICEXBACKEND._serialized_end=2176
  _COMPUTEBACKENDSERVICEXCDNPOLICYXCACHEKEYPOLICY._serialized_start=2179
  _COMPUTEBACKENDSERVICEXCDNPOLICYXCACHEKEYPOLICY._serialized_end=2400
  _COMPUTEBACKENDSERVICEXCDNPOLICYXNEGATIVECACHINGPOLICY._serialized_start=2402
  _COMPUTEBACKENDSERVICEXCDNPOLICYXNEGATIVECACHINGPOLICY._serialized_end=2484
  _COMPUTEBACKENDSERVICEXCDNPOLICY._serialized_start=2487
  _COMPUTEBACKENDSERVICEXCDNPOLICY._serialized_end=2917
  _COMPUTEBACKENDSERVICEXCIRCUITBREAKERS._serialized_start=2920
  _COMPUTEBACKENDSERVICEXCIRCUITBREAKERS._serialized_end=3094
  _COMPUTEBACKENDSERVICEXCONSISTENTHASHXHTTPCOOKIEXTTL._serialized_start=3096
  _COMPUTEBACKENDSERVICEXCONSISTENTHASHXHTTPCOOKIEXTTL._serialized_end=3181
  _COMPUTEBACKENDSERVICEXCONSISTENTHASHXHTTPCOOKIE._serialized_start=3184
  _COMPUTEBACKENDSERVICEXCONSISTENTHASHXHTTPCOOKIE._serialized_end=3360
  _COMPUTEBACKENDSERVICEXCONSISTENTHASH._serialized_start=3363
  _COMPUTEBACKENDSERVICEXCONSISTENTHASH._serialized_end=3557
  _COMPUTEBACKENDSERVICEXIAP._serialized_start=3559
  _COMPUTEBACKENDSERVICEXIAP._serialized_end=3679
  _COMPUTEBACKENDSERVICEXLOGCONFIG._serialized_start=3681
  _COMPUTEBACKENDSERVICEXLOGCONFIG._serialized_end=3751
  _COMPUTEBACKENDSERVICEXOUTLIERDETECTIONXBASEEJECTIONTIME._serialized_start=3753
  _COMPUTEBACKENDSERVICEXOUTLIERDETECTIONXBASEEJECTIONTIME._serialized_end=3842
  _COMPUTEBACKENDSERVICEXOUTLIERDETECTIONXINTERVAL._serialized_start=3844
  _COMPUTEBACKENDSERVICEXOUTLIERDETECTIONXINTERVAL._serialized_end=3925
  _COMPUTEBACKENDSERVICEXOUTLIERDETECTION._serialized_start=3928
  _COMPUTEBACKENDSERVICEXOUTLIERDETECTION._serialized_end=4506
  _COMPUTEBACKENDSERVICEXSECURITYSETTINGS._serialized_start=4508
  _COMPUTEBACKENDSERVICEXSECURITYSETTINGS._serialized_end=4602
  _COMPUTEBACKENDSERVICEXTIMEOUTS._serialized_start=4604
  _COMPUTEBACKENDSERVICEXTIMEOUTS._serialized_end=4684
  _COMPUTEBACKENDSERVICE._serialized_start=4687
  _COMPUTEBACKENDSERVICE._serialized_end=6052
  _COMPUTEBACKENDSERVICESIGNEDURLKEYXTIMEOUTS._serialized_start=6054
  _COMPUTEBACKENDSERVICESIGNEDURLKEYXTIMEOUTS._serialized_end=6130
  _COMPUTEBACKENDSERVICESIGNEDURLKEY._serialized_start=6133
  _COMPUTEBACKENDSERVICESIGNEDURLKEY._serialized_end=6407
# @@protoc_insertion_point(module_scope)
