"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class VirtualMachinesExtensions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class PropertiesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROPERTIES_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    location: builtins.str
    name: builtins.str
    @property
    def properties(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        properties: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["location", b"location", "name", b"name", "properties", b"properties", "resource_info", b"resource_info", "tags", b"tags"]) -> None: ...

global___VirtualMachinesExtensions = VirtualMachinesExtensions

@typing_extensions.final
class AvailabilitySet(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    def __init__(
        self,
        *,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id"]) -> None: ...

global___AvailabilitySet = AvailabilitySet

@typing_extensions.final
class Microsoft_Compute_VirtualMachines(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VIRTUAL_MACHINES_FIELD_NUMBER: builtins.int
    @property
    def virtual_machines(self) -> global___VirtualMachines: ...
    def __init__(
        self,
        *,
        virtual_machines: global___VirtualMachines | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["virtual_machines", b"virtual_machines"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["virtual_machines", b"virtual_machines"]) -> None: ...

global___Microsoft_Compute_VirtualMachines = Microsoft_Compute_VirtualMachines

@typing_extensions.final
class VirtualMachinesRunCommands(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ASYNC_EXECUTION_FIELD_NUMBER: builtins.int
    ERROR_BLOB_URI_FIELD_NUMBER: builtins.int
    OUTPUT_BLOB_URI_FIELD_NUMBER: builtins.int
    PARAMETERS_FIELD_NUMBER: builtins.int
    PROTECTED_PARAMETERS_FIELD_NUMBER: builtins.int
    RUN_AS_PASSWORD_FIELD_NUMBER: builtins.int
    RUN_AS_USER_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    TIMEOUT_IN_SECONDS_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    location: builtins.str
    name: builtins.str
    async_execution: builtins.bool
    error_blob_uri: builtins.str
    output_blob_uri: builtins.str
    @property
    def parameters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RunCommandInputParameter]: ...
    @property
    def protected_parameters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RunCommandInputParameter]: ...
    run_as_password: builtins.str
    run_as_user: builtins.str
    @property
    def source(self) -> global___VirtualMachineRunCommandScriptSource: ...
    timeout_in_seconds: builtins.int
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        async_execution: builtins.bool = ...,
        error_blob_uri: builtins.str = ...,
        output_blob_uri: builtins.str = ...,
        parameters: collections.abc.Iterable[global___RunCommandInputParameter] | None = ...,
        protected_parameters: collections.abc.Iterable[global___RunCommandInputParameter] | None = ...,
        run_as_password: builtins.str = ...,
        run_as_user: builtins.str = ...,
        source: global___VirtualMachineRunCommandScriptSource | None = ...,
        timeout_in_seconds: builtins.int = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "source", b"source"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["async_execution", b"async_execution", "error_blob_uri", b"error_blob_uri", "location", b"location", "name", b"name", "output_blob_uri", b"output_blob_uri", "parameters", b"parameters", "protected_parameters", b"protected_parameters", "resource_info", b"resource_info", "run_as_password", b"run_as_password", "run_as_user", b"run_as_user", "source", b"source", "tags", b"tags", "timeout_in_seconds", b"timeout_in_seconds"]) -> None: ...

global___VirtualMachinesRunCommands = VirtualMachinesRunCommands

@typing_extensions.final
class VirtualMachineRunCommandScriptSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMMAND_ID_FIELD_NUMBER: builtins.int
    SCRIPT_FIELD_NUMBER: builtins.int
    SCRIPT_URI_FIELD_NUMBER: builtins.int
    command_id: builtins.str
    script: builtins.str
    script_uri: builtins.str
    def __init__(
        self,
        *,
        command_id: builtins.str = ...,
        script: builtins.str = ...,
        script_uri: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["command_id", b"command_id", "script", b"script", "script_uri", b"script_uri"]) -> None: ...

global___VirtualMachineRunCommandScriptSource = VirtualMachineRunCommandScriptSource

@typing_extensions.final
class RunCommandInputParameter(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    name: builtins.str
    value: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "value", b"value"]) -> None: ...

global___RunCommandInputParameter = RunCommandInputParameter

@typing_extensions.final
class VirtualMachines(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    EXTENDED_LOCATION_FIELD_NUMBER: builtins.int
    IDENTITY_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PLAN_FIELD_NUMBER: builtins.int
    ADDITIONAL_CAPABILITIES_FIELD_NUMBER: builtins.int
    APPLICATION_PROFILE_FIELD_NUMBER: builtins.int
    BILLING_PROFILE_FIELD_NUMBER: builtins.int
    CAPACITY_RESERVATION_FIELD_NUMBER: builtins.int
    DIAGNOSTICS_PROFILE_FIELD_NUMBER: builtins.int
    EVICTION_POLICY_FIELD_NUMBER: builtins.int
    EXTENSIONS_TIME_BUDGET_FIELD_NUMBER: builtins.int
    HARDWARE_PROFILE_FIELD_NUMBER: builtins.int
    HOST_FIELD_NUMBER: builtins.int
    HOST_GROUP_FIELD_NUMBER: builtins.int
    LICENSE_TYPE_FIELD_NUMBER: builtins.int
    NETWORK_PROFILE_FIELD_NUMBER: builtins.int
    OS_PROFILE_FIELD_NUMBER: builtins.int
    PLATFORM_FAULT_DOMAIN_FIELD_NUMBER: builtins.int
    PRIORITY_FIELD_NUMBER: builtins.int
    PROXIMITY_PLACEMENT_GROUP_FIELD_NUMBER: builtins.int
    SCHEDULED_EVENTS_PROFILE_FIELD_NUMBER: builtins.int
    SECURITY_PROFILE_FIELD_NUMBER: builtins.int
    STORAGE_PROFILE_FIELD_NUMBER: builtins.int
    USER_DATA_FIELD_NUMBER: builtins.int
    VIRTUAL_MACHINE_SCALE_SET_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    ZONES_FIELD_NUMBER: builtins.int
    VIRTUAL_MACHINES_EXTENSIONS_FIELD_NUMBER: builtins.int
    VIRTUAL_MACHINES_RUN_COMMANDS_FIELD_NUMBER: builtins.int
    AVAILABILITY_SET_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def extended_location(self) -> global___ExtendedLocation: ...
    @property
    def identity(self) -> global___VirtualMachineIdentity: ...
    location: builtins.str
    name: builtins.str
    @property
    def plan(self) -> global___Plan: ...
    @property
    def additional_capabilities(self) -> global___AdditionalCapabilities: ...
    @property
    def application_profile(self) -> global___ApplicationProfile: ...
    @property
    def billing_profile(self) -> global___BillingProfile: ...
    @property
    def capacity_reservation(self) -> global___CapacityReservationProfile: ...
    @property
    def diagnostics_profile(self) -> global___DiagnosticsProfile: ...
    eviction_policy: builtins.str
    extensions_time_budget: builtins.str
    @property
    def hardware_profile(self) -> global___HardwareProfile: ...
    host: builtins.str
    host_group: builtins.str
    license_type: builtins.str
    @property
    def network_profile(self) -> global___NetworkProfile: ...
    @property
    def os_profile(self) -> global___OSProfile: ...
    platform_fault_domain: builtins.int
    priority: builtins.str
    proximity_placement_group: builtins.str
    @property
    def scheduled_events_profile(self) -> global___ScheduledEventsProfile: ...
    @property
    def security_profile(self) -> global___SecurityProfile: ...
    @property
    def storage_profile(self) -> global___StorageProfile: ...
    user_data: builtins.str
    virtual_machine_scale_set: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def zones(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def virtual_machines_extensions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VirtualMachinesExtensions]: ...
    @property
    def virtual_machines_run_commands(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VirtualMachinesRunCommands]: ...
    @property
    def availability_set(self) -> global___AvailabilitySet: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        extended_location: global___ExtendedLocation | None = ...,
        identity: global___VirtualMachineIdentity | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        plan: global___Plan | None = ...,
        additional_capabilities: global___AdditionalCapabilities | None = ...,
        application_profile: global___ApplicationProfile | None = ...,
        billing_profile: global___BillingProfile | None = ...,
        capacity_reservation: global___CapacityReservationProfile | None = ...,
        diagnostics_profile: global___DiagnosticsProfile | None = ...,
        eviction_policy: builtins.str = ...,
        extensions_time_budget: builtins.str = ...,
        hardware_profile: global___HardwareProfile | None = ...,
        host: builtins.str = ...,
        host_group: builtins.str = ...,
        license_type: builtins.str = ...,
        network_profile: global___NetworkProfile | None = ...,
        os_profile: global___OSProfile | None = ...,
        platform_fault_domain: builtins.int = ...,
        priority: builtins.str = ...,
        proximity_placement_group: builtins.str = ...,
        scheduled_events_profile: global___ScheduledEventsProfile | None = ...,
        security_profile: global___SecurityProfile | None = ...,
        storage_profile: global___StorageProfile | None = ...,
        user_data: builtins.str = ...,
        virtual_machine_scale_set: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        zones: collections.abc.Iterable[builtins.str] | None = ...,
        virtual_machines_extensions: collections.abc.Iterable[global___VirtualMachinesExtensions] | None = ...,
        virtual_machines_run_commands: collections.abc.Iterable[global___VirtualMachinesRunCommands] | None = ...,
        availability_set: global___AvailabilitySet | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["additional_capabilities", b"additional_capabilities", "application_profile", b"application_profile", "availability_set", b"availability_set", "billing_profile", b"billing_profile", "capacity_reservation", b"capacity_reservation", "diagnostics_profile", b"diagnostics_profile", "extended_location", b"extended_location", "hardware_profile", b"hardware_profile", "identity", b"identity", "network_profile", b"network_profile", "os_profile", b"os_profile", "plan", b"plan", "resource_info", b"resource_info", "scheduled_events_profile", b"scheduled_events_profile", "security_profile", b"security_profile", "storage_profile", b"storage_profile"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["additional_capabilities", b"additional_capabilities", "application_profile", b"application_profile", "availability_set", b"availability_set", "billing_profile", b"billing_profile", "capacity_reservation", b"capacity_reservation", "diagnostics_profile", b"diagnostics_profile", "eviction_policy", b"eviction_policy", "extended_location", b"extended_location", "extensions_time_budget", b"extensions_time_budget", "hardware_profile", b"hardware_profile", "host", b"host", "host_group", b"host_group", "identity", b"identity", "license_type", b"license_type", "location", b"location", "name", b"name", "network_profile", b"network_profile", "os_profile", b"os_profile", "plan", b"plan", "platform_fault_domain", b"platform_fault_domain", "priority", b"priority", "proximity_placement_group", b"proximity_placement_group", "resource_info", b"resource_info", "scheduled_events_profile", b"scheduled_events_profile", "security_profile", b"security_profile", "storage_profile", b"storage_profile", "tags", b"tags", "user_data", b"user_data", "virtual_machine_scale_set", b"virtual_machine_scale_set", "virtual_machines_extensions", b"virtual_machines_extensions", "virtual_machines_run_commands", b"virtual_machines_run_commands", "zones", b"zones"]) -> None: ...

global___VirtualMachines = VirtualMachines

@typing_extensions.final
class StorageProfile(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATA_DISKS_FIELD_NUMBER: builtins.int
    IMAGE_REFERENCE_FIELD_NUMBER: builtins.int
    OS_DISK_FIELD_NUMBER: builtins.int
    @property
    def data_disks(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DataDisk]: ...
    @property
    def image_reference(self) -> global___ImageReference: ...
    @property
    def os_disk(self) -> global___OSDisk: ...
    def __init__(
        self,
        *,
        data_disks: collections.abc.Iterable[global___DataDisk] | None = ...,
        image_reference: global___ImageReference | None = ...,
        os_disk: global___OSDisk | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["image_reference", b"image_reference", "os_disk", b"os_disk"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["data_disks", b"data_disks", "image_reference", b"image_reference", "os_disk", b"os_disk"]) -> None: ...

global___StorageProfile = StorageProfile

@typing_extensions.final
class OSDisk(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CACHING_FIELD_NUMBER: builtins.int
    CREATE_OPTION_FIELD_NUMBER: builtins.int
    DELETE_OPTION_FIELD_NUMBER: builtins.int
    DIFF_DISK_SETTINGS_FIELD_NUMBER: builtins.int
    DISK_SIZE_GB_FIELD_NUMBER: builtins.int
    ENCRYPTION_SETTINGS_FIELD_NUMBER: builtins.int
    IMAGE_FIELD_NUMBER: builtins.int
    MANAGED_DISK_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    OS_TYPE_FIELD_NUMBER: builtins.int
    VHD_FIELD_NUMBER: builtins.int
    WRITE_ACCELERATOR_ENABLED_FIELD_NUMBER: builtins.int
    caching: builtins.str
    create_option: builtins.str
    delete_option: builtins.str
    @property
    def diff_disk_settings(self) -> global___DiffDiskSettings: ...
    disk_size_gb: builtins.int
    @property
    def encryption_settings(self) -> global___DiskEncryptionSettings: ...
    @property
    def image(self) -> global___VirtualHardDisk: ...
    @property
    def managed_disk(self) -> global___ManagedDiskParameters: ...
    name: builtins.str
    os_type: builtins.str
    @property
    def vhd(self) -> global___VirtualHardDisk: ...
    write_accelerator_enabled: builtins.bool
    def __init__(
        self,
        *,
        caching: builtins.str = ...,
        create_option: builtins.str = ...,
        delete_option: builtins.str = ...,
        diff_disk_settings: global___DiffDiskSettings | None = ...,
        disk_size_gb: builtins.int = ...,
        encryption_settings: global___DiskEncryptionSettings | None = ...,
        image: global___VirtualHardDisk | None = ...,
        managed_disk: global___ManagedDiskParameters | None = ...,
        name: builtins.str = ...,
        os_type: builtins.str = ...,
        vhd: global___VirtualHardDisk | None = ...,
        write_accelerator_enabled: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["diff_disk_settings", b"diff_disk_settings", "encryption_settings", b"encryption_settings", "image", b"image", "managed_disk", b"managed_disk", "vhd", b"vhd"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["caching", b"caching", "create_option", b"create_option", "delete_option", b"delete_option", "diff_disk_settings", b"diff_disk_settings", "disk_size_gb", b"disk_size_gb", "encryption_settings", b"encryption_settings", "image", b"image", "managed_disk", b"managed_disk", "name", b"name", "os_type", b"os_type", "vhd", b"vhd", "write_accelerator_enabled", b"write_accelerator_enabled"]) -> None: ...

global___OSDisk = OSDisk

@typing_extensions.final
class DiskEncryptionSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISK_ENCRYPTION_KEY_FIELD_NUMBER: builtins.int
    ENABLED_FIELD_NUMBER: builtins.int
    KEY_ENCRYPTION_KEY_FIELD_NUMBER: builtins.int
    @property
    def disk_encryption_key(self) -> global___KeyVaultSecretReference: ...
    enabled: builtins.bool
    @property
    def key_encryption_key(self) -> global___KeyVaultKeyReference: ...
    def __init__(
        self,
        *,
        disk_encryption_key: global___KeyVaultSecretReference | None = ...,
        enabled: builtins.bool = ...,
        key_encryption_key: global___KeyVaultKeyReference | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["disk_encryption_key", b"disk_encryption_key", "key_encryption_key", b"key_encryption_key"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["disk_encryption_key", b"disk_encryption_key", "enabled", b"enabled", "key_encryption_key", b"key_encryption_key"]) -> None: ...

global___DiskEncryptionSettings = DiskEncryptionSettings

@typing_extensions.final
class KeyVaultKeyReference(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_URL_FIELD_NUMBER: builtins.int
    SOURCE_VAULT_FIELD_NUMBER: builtins.int
    key_url: builtins.str
    source_vault: builtins.str
    def __init__(
        self,
        *,
        key_url: builtins.str = ...,
        source_vault: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["key_url", b"key_url", "source_vault", b"source_vault"]) -> None: ...

global___KeyVaultKeyReference = KeyVaultKeyReference

@typing_extensions.final
class KeyVaultSecretReference(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SECRET_URL_FIELD_NUMBER: builtins.int
    SOURCE_VAULT_FIELD_NUMBER: builtins.int
    secret_url: builtins.str
    source_vault: builtins.str
    def __init__(
        self,
        *,
        secret_url: builtins.str = ...,
        source_vault: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["secret_url", b"secret_url", "source_vault", b"source_vault"]) -> None: ...

global___KeyVaultSecretReference = KeyVaultSecretReference

@typing_extensions.final
class DiffDiskSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPTION_FIELD_NUMBER: builtins.int
    PLACEMENT_FIELD_NUMBER: builtins.int
    option: builtins.str
    placement: builtins.str
    def __init__(
        self,
        *,
        option: builtins.str = ...,
        placement: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["option", b"option", "placement", b"placement"]) -> None: ...

global___DiffDiskSettings = DiffDiskSettings

@typing_extensions.final
class ImageReference(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMMUNITY_GALLERY_IMAGE_ID_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    OFFER_FIELD_NUMBER: builtins.int
    PUBLISHER_FIELD_NUMBER: builtins.int
    SHARED_GALLERY_IMAGE_ID_FIELD_NUMBER: builtins.int
    SKU_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    community_gallery_image_id: builtins.str
    id: builtins.str
    offer: builtins.str
    publisher: builtins.str
    shared_gallery_image_id: builtins.str
    sku: builtins.str
    version: builtins.str
    def __init__(
        self,
        *,
        community_gallery_image_id: builtins.str = ...,
        id: builtins.str = ...,
        offer: builtins.str = ...,
        publisher: builtins.str = ...,
        shared_gallery_image_id: builtins.str = ...,
        sku: builtins.str = ...,
        version: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["community_gallery_image_id", b"community_gallery_image_id", "id", b"id", "offer", b"offer", "publisher", b"publisher", "shared_gallery_image_id", b"shared_gallery_image_id", "sku", b"sku", "version", b"version"]) -> None: ...

global___ImageReference = ImageReference

@typing_extensions.final
class DataDisk(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CACHING_FIELD_NUMBER: builtins.int
    CREATE_OPTION_FIELD_NUMBER: builtins.int
    DELETE_OPTION_FIELD_NUMBER: builtins.int
    DETACH_OPTION_FIELD_NUMBER: builtins.int
    DISK_SIZE_GB_FIELD_NUMBER: builtins.int
    IMAGE_FIELD_NUMBER: builtins.int
    LUN_FIELD_NUMBER: builtins.int
    MANAGED_DISK_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    TO_BE_DETACHED_FIELD_NUMBER: builtins.int
    VHD_FIELD_NUMBER: builtins.int
    WRITE_ACCELERATOR_ENABLED_FIELD_NUMBER: builtins.int
    caching: builtins.str
    create_option: builtins.str
    delete_option: builtins.str
    detach_option: builtins.str
    disk_size_gb: builtins.int
    @property
    def image(self) -> global___VirtualHardDisk: ...
    lun: builtins.int
    @property
    def managed_disk(self) -> global___ManagedDiskParameters: ...
    name: builtins.str
    to_be_detached: builtins.bool
    @property
    def vhd(self) -> global___VirtualHardDisk: ...
    write_accelerator_enabled: builtins.bool
    def __init__(
        self,
        *,
        caching: builtins.str = ...,
        create_option: builtins.str = ...,
        delete_option: builtins.str = ...,
        detach_option: builtins.str = ...,
        disk_size_gb: builtins.int = ...,
        image: global___VirtualHardDisk | None = ...,
        lun: builtins.int = ...,
        managed_disk: global___ManagedDiskParameters | None = ...,
        name: builtins.str = ...,
        to_be_detached: builtins.bool = ...,
        vhd: global___VirtualHardDisk | None = ...,
        write_accelerator_enabled: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["image", b"image", "managed_disk", b"managed_disk", "vhd", b"vhd"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["caching", b"caching", "create_option", b"create_option", "delete_option", b"delete_option", "detach_option", b"detach_option", "disk_size_gb", b"disk_size_gb", "image", b"image", "lun", b"lun", "managed_disk", b"managed_disk", "name", b"name", "to_be_detached", b"to_be_detached", "vhd", b"vhd", "write_accelerator_enabled", b"write_accelerator_enabled"]) -> None: ...

global___DataDisk = DataDisk

@typing_extensions.final
class ManagedDiskParameters(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISK_ENCRYPTION_SET_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    SECURITY_PROFILE_FIELD_NUMBER: builtins.int
    STORAGE_ACCOUNT_TYPE_FIELD_NUMBER: builtins.int
    @property
    def disk_encryption_set(self) -> global___DiskEncryptionSetParameters: ...
    id: builtins.str
    @property
    def security_profile(self) -> global___VMDiskSecurityProfile: ...
    storage_account_type: builtins.str
    def __init__(
        self,
        *,
        disk_encryption_set: global___DiskEncryptionSetParameters | None = ...,
        id: builtins.str = ...,
        security_profile: global___VMDiskSecurityProfile | None = ...,
        storage_account_type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["disk_encryption_set", b"disk_encryption_set", "security_profile", b"security_profile"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["disk_encryption_set", b"disk_encryption_set", "id", b"id", "security_profile", b"security_profile", "storage_account_type", b"storage_account_type"]) -> None: ...

global___ManagedDiskParameters = ManagedDiskParameters

@typing_extensions.final
class VMDiskSecurityProfile(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISK_ENCRYPTION_SET_FIELD_NUMBER: builtins.int
    SECURITY_ENCRYPTION_TYPE_FIELD_NUMBER: builtins.int
    @property
    def disk_encryption_set(self) -> global___DiskEncryptionSetParameters: ...
    security_encryption_type: builtins.str
    def __init__(
        self,
        *,
        disk_encryption_set: global___DiskEncryptionSetParameters | None = ...,
        security_encryption_type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["disk_encryption_set", b"disk_encryption_set"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["disk_encryption_set", b"disk_encryption_set", "security_encryption_type", b"security_encryption_type"]) -> None: ...

global___VMDiskSecurityProfile = VMDiskSecurityProfile

@typing_extensions.final
class DiskEncryptionSetParameters(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    def __init__(
        self,
        *,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id"]) -> None: ...

global___DiskEncryptionSetParameters = DiskEncryptionSetParameters

@typing_extensions.final
class VirtualHardDisk(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    URI_FIELD_NUMBER: builtins.int
    uri: builtins.str
    def __init__(
        self,
        *,
        uri: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["uri", b"uri"]) -> None: ...

global___VirtualHardDisk = VirtualHardDisk

@typing_extensions.final
class SecurityProfile(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENCRYPTION_AT_HOST_FIELD_NUMBER: builtins.int
    SECURITY_TYPE_FIELD_NUMBER: builtins.int
    UEFI_SETTINGS_FIELD_NUMBER: builtins.int
    encryption_at_host: builtins.bool
    security_type: builtins.str
    @property
    def uefi_settings(self) -> global___UefiSettings: ...
    def __init__(
        self,
        *,
        encryption_at_host: builtins.bool = ...,
        security_type: builtins.str = ...,
        uefi_settings: global___UefiSettings | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["uefi_settings", b"uefi_settings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["encryption_at_host", b"encryption_at_host", "security_type", b"security_type", "uefi_settings", b"uefi_settings"]) -> None: ...

global___SecurityProfile = SecurityProfile

@typing_extensions.final
class UefiSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SECURE_BOOT_ENABLED_FIELD_NUMBER: builtins.int
    V_TPM_ENABLED_FIELD_NUMBER: builtins.int
    secure_boot_enabled: builtins.bool
    v_tpm_enabled: builtins.bool
    def __init__(
        self,
        *,
        secure_boot_enabled: builtins.bool = ...,
        v_tpm_enabled: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["secure_boot_enabled", b"secure_boot_enabled", "v_tpm_enabled", b"v_tpm_enabled"]) -> None: ...

global___UefiSettings = UefiSettings

@typing_extensions.final
class ScheduledEventsProfile(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TERMINATE_NOTIFICATION_PROFILE_FIELD_NUMBER: builtins.int
    @property
    def terminate_notification_profile(self) -> global___TerminateNotificationProfile: ...
    def __init__(
        self,
        *,
        terminate_notification_profile: global___TerminateNotificationProfile | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["terminate_notification_profile", b"terminate_notification_profile"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["terminate_notification_profile", b"terminate_notification_profile"]) -> None: ...

global___ScheduledEventsProfile = ScheduledEventsProfile

@typing_extensions.final
class TerminateNotificationProfile(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLE_FIELD_NUMBER: builtins.int
    NOT_BEFORE_TIMEOUT_FIELD_NUMBER: builtins.int
    enable: builtins.bool
    not_before_timeout: builtins.str
    def __init__(
        self,
        *,
        enable: builtins.bool = ...,
        not_before_timeout: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["enable", b"enable", "not_before_timeout", b"not_before_timeout"]) -> None: ...

global___TerminateNotificationProfile = TerminateNotificationProfile

@typing_extensions.final
class OSProfile(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADMIN_PASSWORD_FIELD_NUMBER: builtins.int
    ADMIN_USERNAME_FIELD_NUMBER: builtins.int
    ALLOW_EXTENSION_OPERATIONS_FIELD_NUMBER: builtins.int
    COMPUTER_NAME_FIELD_NUMBER: builtins.int
    CUSTOM_DATA_FIELD_NUMBER: builtins.int
    LINUX_CONFIGURATION_FIELD_NUMBER: builtins.int
    REQUIRE_GUEST_PROVISION_SIGNAL_FIELD_NUMBER: builtins.int
    SECRETS_FIELD_NUMBER: builtins.int
    WINDOWS_CONFIGURATION_FIELD_NUMBER: builtins.int
    admin_password: builtins.str
    admin_username: builtins.str
    allow_extension_operations: builtins.bool
    computer_name: builtins.str
    custom_data: builtins.str
    @property
    def linux_configuration(self) -> global___LinuxConfiguration: ...
    require_guest_provision_signal: builtins.bool
    @property
    def secrets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VaultSecretGroup]: ...
    @property
    def windows_configuration(self) -> global___WindowsConfiguration: ...
    def __init__(
        self,
        *,
        admin_password: builtins.str = ...,
        admin_username: builtins.str = ...,
        allow_extension_operations: builtins.bool = ...,
        computer_name: builtins.str = ...,
        custom_data: builtins.str = ...,
        linux_configuration: global___LinuxConfiguration | None = ...,
        require_guest_provision_signal: builtins.bool = ...,
        secrets: collections.abc.Iterable[global___VaultSecretGroup] | None = ...,
        windows_configuration: global___WindowsConfiguration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["linux_configuration", b"linux_configuration", "windows_configuration", b"windows_configuration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["admin_password", b"admin_password", "admin_username", b"admin_username", "allow_extension_operations", b"allow_extension_operations", "computer_name", b"computer_name", "custom_data", b"custom_data", "linux_configuration", b"linux_configuration", "require_guest_provision_signal", b"require_guest_provision_signal", "secrets", b"secrets", "windows_configuration", b"windows_configuration"]) -> None: ...

global___OSProfile = OSProfile

@typing_extensions.final
class WindowsConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADDITIONAL_UNATTEND_CONTENT_FIELD_NUMBER: builtins.int
    ENABLE_AUTOMATIC_UPDATES_FIELD_NUMBER: builtins.int
    PATCH_SETTINGS_FIELD_NUMBER: builtins.int
    PROVISION_V_M_AGENT_FIELD_NUMBER: builtins.int
    TIME_ZONE_FIELD_NUMBER: builtins.int
    WIN_R_M_FIELD_NUMBER: builtins.int
    @property
    def additional_unattend_content(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AdditionalUnattendContent]: ...
    enable_automatic_updates: builtins.bool
    @property
    def patch_settings(self) -> global___PatchSettings: ...
    provision_v_m_agent: builtins.bool
    time_zone: builtins.str
    @property
    def win_r_m(self) -> global___WinRMConfiguration: ...
    def __init__(
        self,
        *,
        additional_unattend_content: collections.abc.Iterable[global___AdditionalUnattendContent] | None = ...,
        enable_automatic_updates: builtins.bool = ...,
        patch_settings: global___PatchSettings | None = ...,
        provision_v_m_agent: builtins.bool = ...,
        time_zone: builtins.str = ...,
        win_r_m: global___WinRMConfiguration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["patch_settings", b"patch_settings", "win_r_m", b"win_r_m"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["additional_unattend_content", b"additional_unattend_content", "enable_automatic_updates", b"enable_automatic_updates", "patch_settings", b"patch_settings", "provision_v_m_agent", b"provision_v_m_agent", "time_zone", b"time_zone", "win_r_m", b"win_r_m"]) -> None: ...

global___WindowsConfiguration = WindowsConfiguration

@typing_extensions.final
class WinRMConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LISTENERS_FIELD_NUMBER: builtins.int
    @property
    def listeners(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___WinRMListener]: ...
    def __init__(
        self,
        *,
        listeners: collections.abc.Iterable[global___WinRMListener] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["listeners", b"listeners"]) -> None: ...

global___WinRMConfiguration = WinRMConfiguration

@typing_extensions.final
class WinRMListener(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CERTIFICATE_URL_FIELD_NUMBER: builtins.int
    PROTOCOL_FIELD_NUMBER: builtins.int
    certificate_url: builtins.str
    protocol: builtins.str
    def __init__(
        self,
        *,
        certificate_url: builtins.str = ...,
        protocol: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["certificate_url", b"certificate_url", "protocol", b"protocol"]) -> None: ...

global___WinRMListener = WinRMListener

@typing_extensions.final
class PatchSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ASSESSMENT_MODE_FIELD_NUMBER: builtins.int
    ENABLE_HOTPATCHING_FIELD_NUMBER: builtins.int
    PATCH_MODE_FIELD_NUMBER: builtins.int
    assessment_mode: builtins.str
    enable_hotpatching: builtins.bool
    patch_mode: builtins.str
    def __init__(
        self,
        *,
        assessment_mode: builtins.str = ...,
        enable_hotpatching: builtins.bool = ...,
        patch_mode: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["assessment_mode", b"assessment_mode", "enable_hotpatching", b"enable_hotpatching", "patch_mode", b"patch_mode"]) -> None: ...

global___PatchSettings = PatchSettings

@typing_extensions.final
class AdditionalUnattendContent(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMPONENT_NAME_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    PASS_NAME_FIELD_NUMBER: builtins.int
    SETTING_NAME_FIELD_NUMBER: builtins.int
    component_name: builtins.str
    content: builtins.str
    pass_name: builtins.str
    setting_name: builtins.str
    def __init__(
        self,
        *,
        component_name: builtins.str = ...,
        content: builtins.str = ...,
        pass_name: builtins.str = ...,
        setting_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["component_name", b"component_name", "content", b"content", "pass_name", b"pass_name", "setting_name", b"setting_name"]) -> None: ...

global___AdditionalUnattendContent = AdditionalUnattendContent

@typing_extensions.final
class VaultSecretGroup(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SOURCE_VAULT_FIELD_NUMBER: builtins.int
    VAULT_CERTIFICATES_FIELD_NUMBER: builtins.int
    source_vault: builtins.str
    @property
    def vault_certificates(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VaultCertificate]: ...
    def __init__(
        self,
        *,
        source_vault: builtins.str = ...,
        vault_certificates: collections.abc.Iterable[global___VaultCertificate] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["source_vault", b"source_vault", "vault_certificates", b"vault_certificates"]) -> None: ...

global___VaultSecretGroup = VaultSecretGroup

@typing_extensions.final
class VaultCertificate(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CERTIFICATE_STORE_FIELD_NUMBER: builtins.int
    CERTIFICATE_URL_FIELD_NUMBER: builtins.int
    certificate_store: builtins.str
    certificate_url: builtins.str
    def __init__(
        self,
        *,
        certificate_store: builtins.str = ...,
        certificate_url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["certificate_store", b"certificate_store", "certificate_url", b"certificate_url"]) -> None: ...

global___VaultCertificate = VaultCertificate

@typing_extensions.final
class LinuxConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISABLE_PASSWORD_AUTHENTICATION_FIELD_NUMBER: builtins.int
    PATCH_SETTINGS_FIELD_NUMBER: builtins.int
    PROVISION_V_M_AGENT_FIELD_NUMBER: builtins.int
    SSH_FIELD_NUMBER: builtins.int
    disable_password_authentication: builtins.bool
    @property
    def patch_settings(self) -> global___LinuxPatchSettings: ...
    provision_v_m_agent: builtins.bool
    @property
    def ssh(self) -> global___SshConfiguration: ...
    def __init__(
        self,
        *,
        disable_password_authentication: builtins.bool = ...,
        patch_settings: global___LinuxPatchSettings | None = ...,
        provision_v_m_agent: builtins.bool = ...,
        ssh: global___SshConfiguration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["patch_settings", b"patch_settings", "ssh", b"ssh"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["disable_password_authentication", b"disable_password_authentication", "patch_settings", b"patch_settings", "provision_v_m_agent", b"provision_v_m_agent", "ssh", b"ssh"]) -> None: ...

global___LinuxConfiguration = LinuxConfiguration

@typing_extensions.final
class SshConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PUBLIC_KEYS_FIELD_NUMBER: builtins.int
    @property
    def public_keys(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SshPublicKey]: ...
    def __init__(
        self,
        *,
        public_keys: collections.abc.Iterable[global___SshPublicKey] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["public_keys", b"public_keys"]) -> None: ...

global___SshConfiguration = SshConfiguration

@typing_extensions.final
class SshPublicKey(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_DATA_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    key_data: builtins.str
    path: builtins.str
    def __init__(
        self,
        *,
        key_data: builtins.str = ...,
        path: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["key_data", b"key_data", "path", b"path"]) -> None: ...

global___SshPublicKey = SshPublicKey

@typing_extensions.final
class LinuxPatchSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ASSESSMENT_MODE_FIELD_NUMBER: builtins.int
    PATCH_MODE_FIELD_NUMBER: builtins.int
    assessment_mode: builtins.str
    patch_mode: builtins.str
    def __init__(
        self,
        *,
        assessment_mode: builtins.str = ...,
        patch_mode: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["assessment_mode", b"assessment_mode", "patch_mode", b"patch_mode"]) -> None: ...

global___LinuxPatchSettings = LinuxPatchSettings

@typing_extensions.final
class NetworkProfile(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NETWORK_API_VERSION_FIELD_NUMBER: builtins.int
    NETWORK_INTERFACE_CONFIGURATIONS_FIELD_NUMBER: builtins.int
    NETWORK_INTERFACES_FIELD_NUMBER: builtins.int
    network_api_version: builtins.str
    @property
    def network_interface_configurations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VirtualMachineNetworkInterfaceConfiguration]: ...
    @property
    def network_interfaces(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NetworkInterfaceReference]: ...
    def __init__(
        self,
        *,
        network_api_version: builtins.str = ...,
        network_interface_configurations: collections.abc.Iterable[global___VirtualMachineNetworkInterfaceConfiguration] | None = ...,
        network_interfaces: collections.abc.Iterable[global___NetworkInterfaceReference] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["network_api_version", b"network_api_version", "network_interface_configurations", b"network_interface_configurations", "network_interfaces", b"network_interfaces"]) -> None: ...

global___NetworkProfile = NetworkProfile

@typing_extensions.final
class NetworkInterfaceReference(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    DELETE_OPTION_FIELD_NUMBER: builtins.int
    PRIMARY_FIELD_NUMBER: builtins.int
    id: builtins.str
    delete_option: builtins.str
    primary: builtins.bool
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        delete_option: builtins.str = ...,
        primary: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["delete_option", b"delete_option", "id", b"id", "primary", b"primary"]) -> None: ...

global___NetworkInterfaceReference = NetworkInterfaceReference

@typing_extensions.final
class VirtualMachineNetworkInterfaceConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    DELETE_OPTION_FIELD_NUMBER: builtins.int
    DNS_SETTINGS_FIELD_NUMBER: builtins.int
    DSCP_CONFIGURATION_FIELD_NUMBER: builtins.int
    ENABLE_ACCELERATED_NETWORKING_FIELD_NUMBER: builtins.int
    ENABLE_FPGA_FIELD_NUMBER: builtins.int
    ENABLE_IP_FORWARDING_FIELD_NUMBER: builtins.int
    IP_CONFIGURATIONS_FIELD_NUMBER: builtins.int
    NETWORK_SECURITY_GROUP_FIELD_NUMBER: builtins.int
    PRIMARY_FIELD_NUMBER: builtins.int
    name: builtins.str
    delete_option: builtins.str
    @property
    def dns_settings(self) -> global___VirtualMachineNetworkInterfaceDnsSettingsConfiguration: ...
    dscp_configuration: builtins.str
    enable_accelerated_networking: builtins.bool
    enable_fpga: builtins.bool
    enable_ip_forwarding: builtins.bool
    @property
    def ip_configurations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VirtualMachineNetworkInterfaceIPConfiguration]: ...
    network_security_group: builtins.str
    primary: builtins.bool
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        delete_option: builtins.str = ...,
        dns_settings: global___VirtualMachineNetworkInterfaceDnsSettingsConfiguration | None = ...,
        dscp_configuration: builtins.str = ...,
        enable_accelerated_networking: builtins.bool = ...,
        enable_fpga: builtins.bool = ...,
        enable_ip_forwarding: builtins.bool = ...,
        ip_configurations: collections.abc.Iterable[global___VirtualMachineNetworkInterfaceIPConfiguration] | None = ...,
        network_security_group: builtins.str = ...,
        primary: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["dns_settings", b"dns_settings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["delete_option", b"delete_option", "dns_settings", b"dns_settings", "dscp_configuration", b"dscp_configuration", "enable_accelerated_networking", b"enable_accelerated_networking", "enable_fpga", b"enable_fpga", "enable_ip_forwarding", b"enable_ip_forwarding", "ip_configurations", b"ip_configurations", "name", b"name", "network_security_group", b"network_security_group", "primary", b"primary"]) -> None: ...

global___VirtualMachineNetworkInterfaceConfiguration = VirtualMachineNetworkInterfaceConfiguration

@typing_extensions.final
class VirtualMachineNetworkInterfaceIPConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    APPLICATION_GATEWAY_BACKEND_ADDRESS_POOLS_FIELD_NUMBER: builtins.int
    APPLICATION_SECURITY_GROUPS_FIELD_NUMBER: builtins.int
    LOAD_BALANCER_BACKEND_ADDRESS_POOLS_FIELD_NUMBER: builtins.int
    PRIMARY_FIELD_NUMBER: builtins.int
    PRIVATE_IP_ADDRESS_VERSION_FIELD_NUMBER: builtins.int
    PUBLIC_IP_ADDRESS_CONFIGURATION_FIELD_NUMBER: builtins.int
    SUBNET_FIELD_NUMBER: builtins.int
    name: builtins.str
    @property
    def application_gateway_backend_address_pools(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def application_security_groups(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def load_balancer_backend_address_pools(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    primary: builtins.bool
    private_ip_address_version: builtins.str
    @property
    def public_ip_address_configuration(self) -> global___VirtualMachinePublicIPAddressConfiguration: ...
    subnet: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        application_gateway_backend_address_pools: collections.abc.Iterable[builtins.str] | None = ...,
        application_security_groups: collections.abc.Iterable[builtins.str] | None = ...,
        load_balancer_backend_address_pools: collections.abc.Iterable[builtins.str] | None = ...,
        primary: builtins.bool = ...,
        private_ip_address_version: builtins.str = ...,
        public_ip_address_configuration: global___VirtualMachinePublicIPAddressConfiguration | None = ...,
        subnet: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["public_ip_address_configuration", b"public_ip_address_configuration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["application_gateway_backend_address_pools", b"application_gateway_backend_address_pools", "application_security_groups", b"application_security_groups", "load_balancer_backend_address_pools", b"load_balancer_backend_address_pools", "name", b"name", "primary", b"primary", "private_ip_address_version", b"private_ip_address_version", "public_ip_address_configuration", b"public_ip_address_configuration", "subnet", b"subnet"]) -> None: ...

global___VirtualMachineNetworkInterfaceIPConfiguration = VirtualMachineNetworkInterfaceIPConfiguration

@typing_extensions.final
class VirtualMachinePublicIPAddressConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    DELETE_OPTION_FIELD_NUMBER: builtins.int
    DNS_SETTINGS_FIELD_NUMBER: builtins.int
    IDLE_TIMEOUT_IN_MINUTES_FIELD_NUMBER: builtins.int
    IP_TAGS_FIELD_NUMBER: builtins.int
    PUBLIC_IP_ADDRESS_VERSION_FIELD_NUMBER: builtins.int
    PUBLIC_IP_ALLOCATION_METHOD_FIELD_NUMBER: builtins.int
    PUBLIC_IP_PREFIX_FIELD_NUMBER: builtins.int
    SKU_FIELD_NUMBER: builtins.int
    name: builtins.str
    delete_option: builtins.str
    @property
    def dns_settings(self) -> global___VirtualMachinePublicIPAddressDnsSettingsConfiguration: ...
    idle_timeout_in_minutes: builtins.int
    @property
    def ip_tags(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VirtualMachineIpTag]: ...
    public_ip_address_version: builtins.str
    public_ip_allocation_method: builtins.str
    public_ip_prefix: builtins.str
    @property
    def sku(self) -> global___PublicIPAddressSku: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        delete_option: builtins.str = ...,
        dns_settings: global___VirtualMachinePublicIPAddressDnsSettingsConfiguration | None = ...,
        idle_timeout_in_minutes: builtins.int = ...,
        ip_tags: collections.abc.Iterable[global___VirtualMachineIpTag] | None = ...,
        public_ip_address_version: builtins.str = ...,
        public_ip_allocation_method: builtins.str = ...,
        public_ip_prefix: builtins.str = ...,
        sku: global___PublicIPAddressSku | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["dns_settings", b"dns_settings", "sku", b"sku"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["delete_option", b"delete_option", "dns_settings", b"dns_settings", "idle_timeout_in_minutes", b"idle_timeout_in_minutes", "ip_tags", b"ip_tags", "name", b"name", "public_ip_address_version", b"public_ip_address_version", "public_ip_allocation_method", b"public_ip_allocation_method", "public_ip_prefix", b"public_ip_prefix", "sku", b"sku"]) -> None: ...

global___VirtualMachinePublicIPAddressConfiguration = VirtualMachinePublicIPAddressConfiguration

@typing_extensions.final
class PublicIPAddressSku(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    TIER_FIELD_NUMBER: builtins.int
    name: builtins.str
    tier: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        tier: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "tier", b"tier"]) -> None: ...

global___PublicIPAddressSku = PublicIPAddressSku

@typing_extensions.final
class VirtualMachineIpTag(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IP_TAG_TYPE_FIELD_NUMBER: builtins.int
    TAG_FIELD_NUMBER: builtins.int
    ip_tag_type: builtins.str
    tag: builtins.str
    def __init__(
        self,
        *,
        ip_tag_type: builtins.str = ...,
        tag: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["ip_tag_type", b"ip_tag_type", "tag", b"tag"]) -> None: ...

global___VirtualMachineIpTag = VirtualMachineIpTag

@typing_extensions.final
class VirtualMachinePublicIPAddressDnsSettingsConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DOMAIN_NAME_LABEL_FIELD_NUMBER: builtins.int
    domain_name_label: builtins.str
    def __init__(
        self,
        *,
        domain_name_label: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["domain_name_label", b"domain_name_label"]) -> None: ...

global___VirtualMachinePublicIPAddressDnsSettingsConfiguration = VirtualMachinePublicIPAddressDnsSettingsConfiguration

@typing_extensions.final
class VirtualMachineNetworkInterfaceDnsSettingsConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DNS_SERVERS_FIELD_NUMBER: builtins.int
    @property
    def dns_servers(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        dns_servers: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["dns_servers", b"dns_servers"]) -> None: ...

global___VirtualMachineNetworkInterfaceDnsSettingsConfiguration = VirtualMachineNetworkInterfaceDnsSettingsConfiguration

@typing_extensions.final
class HardwareProfile(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VM_SIZE_FIELD_NUMBER: builtins.int
    VM_SIZE_PROPERTIES_FIELD_NUMBER: builtins.int
    vm_size: builtins.str
    @property
    def vm_size_properties(self) -> global___VMSizeProperties: ...
    def __init__(
        self,
        *,
        vm_size: builtins.str = ...,
        vm_size_properties: global___VMSizeProperties | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["vm_size_properties", b"vm_size_properties"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["vm_size", b"vm_size", "vm_size_properties", b"vm_size_properties"]) -> None: ...

global___HardwareProfile = HardwareProfile

@typing_extensions.final
class VMSizeProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    V_CPUS_AVAILABLE_FIELD_NUMBER: builtins.int
    V_CPUS_PER_CORE_FIELD_NUMBER: builtins.int
    v_cpus_available: builtins.int
    v_cpus_per_core: builtins.int
    def __init__(
        self,
        *,
        v_cpus_available: builtins.int = ...,
        v_cpus_per_core: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["v_cpus_available", b"v_cpus_available", "v_cpus_per_core", b"v_cpus_per_core"]) -> None: ...

global___VMSizeProperties = VMSizeProperties

@typing_extensions.final
class DiagnosticsProfile(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BOOT_DIAGNOSTICS_FIELD_NUMBER: builtins.int
    @property
    def boot_diagnostics(self) -> global___BootDiagnostics: ...
    def __init__(
        self,
        *,
        boot_diagnostics: global___BootDiagnostics | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["boot_diagnostics", b"boot_diagnostics"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["boot_diagnostics", b"boot_diagnostics"]) -> None: ...

global___DiagnosticsProfile = DiagnosticsProfile

@typing_extensions.final
class BootDiagnostics(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLED_FIELD_NUMBER: builtins.int
    STORAGE_URI_FIELD_NUMBER: builtins.int
    enabled: builtins.bool
    storage_uri: builtins.str
    def __init__(
        self,
        *,
        enabled: builtins.bool = ...,
        storage_uri: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["enabled", b"enabled", "storage_uri", b"storage_uri"]) -> None: ...

global___BootDiagnostics = BootDiagnostics

@typing_extensions.final
class CapacityReservationProfile(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CAPACITY_RESERVATION_GROUP_FIELD_NUMBER: builtins.int
    capacity_reservation_group: builtins.str
    def __init__(
        self,
        *,
        capacity_reservation_group: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["capacity_reservation_group", b"capacity_reservation_group"]) -> None: ...

global___CapacityReservationProfile = CapacityReservationProfile

@typing_extensions.final
class BillingProfile(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MAX_PRICE_FIELD_NUMBER: builtins.int
    max_price: builtins.float
    def __init__(
        self,
        *,
        max_price: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["max_price", b"max_price"]) -> None: ...

global___BillingProfile = BillingProfile

@typing_extensions.final
class ApplicationProfile(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GALLERY_APPLICATIONS_FIELD_NUMBER: builtins.int
    @property
    def gallery_applications(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VMGalleryApplication]: ...
    def __init__(
        self,
        *,
        gallery_applications: collections.abc.Iterable[global___VMGalleryApplication] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["gallery_applications", b"gallery_applications"]) -> None: ...

global___ApplicationProfile = ApplicationProfile

@typing_extensions.final
class VMGalleryApplication(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONFIGURATION_REFERENCE_FIELD_NUMBER: builtins.int
    ORDER_FIELD_NUMBER: builtins.int
    PACKAGE_REFERENCE_ID_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    configuration_reference: builtins.str
    order: builtins.int
    package_reference_id: builtins.str
    tags: builtins.str
    def __init__(
        self,
        *,
        configuration_reference: builtins.str = ...,
        order: builtins.int = ...,
        package_reference_id: builtins.str = ...,
        tags: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["configuration_reference", b"configuration_reference", "order", b"order", "package_reference_id", b"package_reference_id", "tags", b"tags"]) -> None: ...

global___VMGalleryApplication = VMGalleryApplication

@typing_extensions.final
class AdditionalCapabilities(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HIBERNATION_ENABLED_FIELD_NUMBER: builtins.int
    ULTRA_SSD_ENABLED_FIELD_NUMBER: builtins.int
    hibernation_enabled: builtins.bool
    ultra_ssd_enabled: builtins.bool
    def __init__(
        self,
        *,
        hibernation_enabled: builtins.bool = ...,
        ultra_ssd_enabled: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["hibernation_enabled", b"hibernation_enabled", "ultra_ssd_enabled", b"ultra_ssd_enabled"]) -> None: ...

global___AdditionalCapabilities = AdditionalCapabilities

@typing_extensions.final
class Plan(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    PRODUCT_FIELD_NUMBER: builtins.int
    PROMOTION_CODE_FIELD_NUMBER: builtins.int
    PUBLISHER_FIELD_NUMBER: builtins.int
    name: builtins.str
    product: builtins.str
    promotion_code: builtins.str
    publisher: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        product: builtins.str = ...,
        promotion_code: builtins.str = ...,
        publisher: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "product", b"product", "promotion_code", b"promotion_code", "publisher", b"publisher"]) -> None: ...

global___Plan = Plan

@typing_extensions.final
class VirtualMachineIdentity(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class UserAssignedIdentitiesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    TYPE_FIELD_NUMBER: builtins.int
    USER_ASSIGNED_IDENTITIES_FIELD_NUMBER: builtins.int
    type: builtins.str
    @property
    def user_assigned_identities(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        type: builtins.str = ...,
        user_assigned_identities: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["type", b"type", "user_assigned_identities", b"user_assigned_identities"]) -> None: ...

global___VirtualMachineIdentity = VirtualMachineIdentity

@typing_extensions.final
class ExtendedLocation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    name: builtins.str
    type: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "type", b"type"]) -> None: ...

global___ExtendedLocation = ExtendedLocation
