# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_logs.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12\x61ws/aws_logs.proto\x12\x14oak9.tython.aws.logs\x1a\x13shared/shared.proto\"\xa2\x01\n\x0b\x44\x65stination\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x18\n\x10\x64\x65stination_name\x18\x02 \x01(\t\x12\x1a\n\x12\x64\x65stination_policy\x18\x03 \x01(\t\x12\x10\n\x08role_arn\x18\x04 \x01(\t\x12\x12\n\ntarget_arn\x18\x05 \x01(\t\"\xa8\x02\n\x04Logs\x12\x36\n\x0b\x64\x65stination\x18\x01 \x03(\x0b\x32!.oak9.tython.aws.logs.Destination\x12\x31\n\tlog_group\x18\x02 \x03(\x0b\x32\x1e.oak9.tython.aws.logs.LogGroup\x12\x33\n\nlog_stream\x18\x03 \x03(\x0b\x32\x1f.oak9.tython.aws.logs.LogStream\x12\x39\n\rmetric_filter\x18\x04 \x03(\x0b\x32\".oak9.tython.aws.logs.MetricFilter\x12\x45\n\x13subscription_filter\x18\x05 \x03(\x0b\x32(.oak9.tython.aws.logs.SubscriptionFilter\"v\n\x08LogGroup\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0elog_group_name\x18\x02 \x01(\t\x12\x19\n\x11retention_in_days\x18\x03 \x01(\x05\"u\n\tLogStream\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0elog_group_name\x18\x02 \x01(\t\x12\x17\n\x0flog_stream_name\x18\x03 \x01(\t\"\xb7\x01\n MetricFilterMetricTransformation\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rdefault_value\x18\x02 \x01(\x01\x12\x13\n\x0bmetric_name\x18\x03 \x01(\t\x12\x18\n\x10metric_namespace\x18\x04 \x01(\t\x12\x14\n\x0cmetric_value\x18\x05 \x01(\t\"\xcf\x01\n\x0cMetricFilter\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0e\x66ilter_pattern\x18\x02 \x01(\t\x12\x16\n\x0elog_group_name\x18\x03 \x01(\t\x12V\n\x16metric_transformations\x18\x04 \x03(\x0b\x32\x36.oak9.tython.aws.logs.MetricFilterMetricTransformation\"\xa8\x01\n\x12SubscriptionFilter\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x17\n\x0f\x64\x65stination_arn\x18\x02 \x01(\t\x12\x16\n\x0e\x66ilter_pattern\x18\x03 \x01(\t\x12\x16\n\x0elog_group_name\x18\x04 \x01(\t\x12\x10\n\x08role_arn\x18\x05 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_logs_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DESTINATION._serialized_start=66
  _DESTINATION._serialized_end=228
  _LOGS._serialized_start=231
  _LOGS._serialized_end=527
  _LOGGROUP._serialized_start=529
  _LOGGROUP._serialized_end=647
  _LOGSTREAM._serialized_start=649
  _LOGSTREAM._serialized_end=766
  _METRICFILTERMETRICTRANSFORMATION._serialized_start=769
  _METRICFILTERMETRICTRANSFORMATION._serialized_end=952
  _METRICFILTER._serialized_start=955
  _METRICFILTER._serialized_end=1162
  _SUBSCRIPTIONFILTER._serialized_start=1165
  _SUBSCRIPTIONFILTER._serialized_end=1333
# @@protoc_insertion_point(module_scope)
