"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class CacheCluster(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    AZ_MODE_FIELD_NUMBER: builtins.int
    AUTO_MINOR_VERSION_UPGRADE_FIELD_NUMBER: builtins.int
    CACHE_NODE_TYPE_FIELD_NUMBER: builtins.int
    CACHE_PARAMETER_GROUP_NAME_FIELD_NUMBER: builtins.int
    CACHE_SECURITY_GROUP_NAMES_FIELD_NUMBER: builtins.int
    CACHE_SUBNET_GROUP_NAME_FIELD_NUMBER: builtins.int
    CLUSTER_NAME_FIELD_NUMBER: builtins.int
    ENGINE_FIELD_NUMBER: builtins.int
    ENGINE_VERSION_FIELD_NUMBER: builtins.int
    NOTIFICATION_TOPIC_ARN_FIELD_NUMBER: builtins.int
    NUM_CACHE_NODES_FIELD_NUMBER: builtins.int
    PORT_FIELD_NUMBER: builtins.int
    PREFERRED_AVAILABILITY_ZONE_FIELD_NUMBER: builtins.int
    PREFERRED_AVAILABILITY_ZONES_FIELD_NUMBER: builtins.int
    PREFERRED_MAINTENANCE_WINDOW_FIELD_NUMBER: builtins.int
    SNAPSHOT_ARNS_FIELD_NUMBER: builtins.int
    SNAPSHOT_NAME_FIELD_NUMBER: builtins.int
    SNAPSHOT_RETENTION_LIMIT_FIELD_NUMBER: builtins.int
    SNAPSHOT_WINDOW_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    VPC_SECURITY_GROUP_IDS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    az_mode: builtins.str
    auto_minor_version_upgrade: builtins.bool
    cache_node_type: builtins.str
    cache_parameter_group_name: builtins.str
    @property
    def cache_security_group_names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    cache_subnet_group_name: builtins.str
    cluster_name: builtins.str
    engine: builtins.str
    engine_version: builtins.str
    notification_topic_arn: builtins.str
    num_cache_nodes: builtins.int
    port: builtins.int
    preferred_availability_zone: builtins.str
    @property
    def preferred_availability_zones(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    preferred_maintenance_window: builtins.str
    @property
    def snapshot_arns(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    snapshot_name: builtins.str
    snapshot_retention_limit: builtins.int
    snapshot_window: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def vpc_security_group_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        az_mode: builtins.str = ...,
        auto_minor_version_upgrade: builtins.bool = ...,
        cache_node_type: builtins.str = ...,
        cache_parameter_group_name: builtins.str = ...,
        cache_security_group_names: collections.abc.Iterable[builtins.str] | None = ...,
        cache_subnet_group_name: builtins.str = ...,
        cluster_name: builtins.str = ...,
        engine: builtins.str = ...,
        engine_version: builtins.str = ...,
        notification_topic_arn: builtins.str = ...,
        num_cache_nodes: builtins.int = ...,
        port: builtins.int = ...,
        preferred_availability_zone: builtins.str = ...,
        preferred_availability_zones: collections.abc.Iterable[builtins.str] | None = ...,
        preferred_maintenance_window: builtins.str = ...,
        snapshot_arns: collections.abc.Iterable[builtins.str] | None = ...,
        snapshot_name: builtins.str = ...,
        snapshot_retention_limit: builtins.int = ...,
        snapshot_window: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        vpc_security_group_ids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auto_minor_version_upgrade", b"auto_minor_version_upgrade", "az_mode", b"az_mode", "cache_node_type", b"cache_node_type", "cache_parameter_group_name", b"cache_parameter_group_name", "cache_security_group_names", b"cache_security_group_names", "cache_subnet_group_name", b"cache_subnet_group_name", "cluster_name", b"cluster_name", "engine", b"engine", "engine_version", b"engine_version", "notification_topic_arn", b"notification_topic_arn", "num_cache_nodes", b"num_cache_nodes", "port", b"port", "preferred_availability_zone", b"preferred_availability_zone", "preferred_availability_zones", b"preferred_availability_zones", "preferred_maintenance_window", b"preferred_maintenance_window", "resource_info", b"resource_info", "snapshot_arns", b"snapshot_arns", "snapshot_name", b"snapshot_name", "snapshot_retention_limit", b"snapshot_retention_limit", "snapshot_window", b"snapshot_window", "tags", b"tags", "vpc_security_group_ids", b"vpc_security_group_ids"]) -> None: ...

global___CacheCluster = CacheCluster

@typing_extensions.final
class ElastiCache_CacheCluster(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CACHE_CLUSTER_FIELD_NUMBER: builtins.int
    SECURITY_GROUP_FIELD_NUMBER: builtins.int
    SECURITY_GROUP_INGRESS_FIELD_NUMBER: builtins.int
    SUBNET_GROUP_FIELD_NUMBER: builtins.int
    @property
    def cache_cluster(self) -> global___CacheCluster: ...
    @property
    def security_group(self) -> global___SecurityGroup: ...
    @property
    def security_group_ingress(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SecurityGroupIngress]: ...
    @property
    def subnet_group(self) -> global___SubnetGroup: ...
    def __init__(
        self,
        *,
        cache_cluster: global___CacheCluster | None = ...,
        security_group: global___SecurityGroup | None = ...,
        security_group_ingress: collections.abc.Iterable[global___SecurityGroupIngress] | None = ...,
        subnet_group: global___SubnetGroup | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cache_cluster", b"cache_cluster", "security_group", b"security_group", "subnet_group", b"subnet_group"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cache_cluster", b"cache_cluster", "security_group", b"security_group", "security_group_ingress", b"security_group_ingress", "subnet_group", b"subnet_group"]) -> None: ...

global___ElastiCache_CacheCluster = ElastiCache_CacheCluster

@typing_extensions.final
class SecurityGroup(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    description: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        description: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "resource_info", b"resource_info"]) -> None: ...

global___SecurityGroup = SecurityGroup

@typing_extensions.final
class SecurityGroupIngress(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CACHE_SECURITY_GROUP_NAME_FIELD_NUMBER: builtins.int
    E_C2_SECURITY_GROUP_NAME_FIELD_NUMBER: builtins.int
    E_C2_SECURITY_GROUP_OWNER_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    cache_security_group_name: builtins.str
    e_c2_security_group_name: builtins.str
    e_c2_security_group_owner_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        cache_security_group_name: builtins.str = ...,
        e_c2_security_group_name: builtins.str = ...,
        e_c2_security_group_owner_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cache_security_group_name", b"cache_security_group_name", "e_c2_security_group_name", b"e_c2_security_group_name", "e_c2_security_group_owner_id", b"e_c2_security_group_owner_id", "resource_info", b"resource_info"]) -> None: ...

global___SecurityGroupIngress = SecurityGroupIngress

@typing_extensions.final
class SubnetGroup(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CACHE_SUBNET_GROUP_NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    SUBNET_IDS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    cache_subnet_group_name: builtins.str
    description: builtins.str
    @property
    def subnet_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        cache_subnet_group_name: builtins.str = ...,
        description: builtins.str = ...,
        subnet_ids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cache_subnet_group_name", b"cache_subnet_group_name", "description", b"description", "resource_info", b"resource_info", "subnet_ids", b"subnet_ids"]) -> None: ...

global___SubnetGroup = SubnetGroup
