# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_google_cloud_tasks_bundle.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2
from oak9.tython.models.gcp import gcp_cloud_pb2 as gcp_dot_gcp__cloud__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'gcp/gcp_google_cloud_tasks_bundle.proto\x12)oak9.tython.gcp.google_cloud_tasks_bundle\x1a\x13shared/shared.proto\x1a\x13gcp/gcp_cloud.proto\"\xdc\x02\n\x10GoogleCloudTasks\x12\x41\n\x11\x63loud_tasks_queue\x18\x01 \x01(\x0b\x32&.oak9.tython.gcp.cloud.CloudTasksQueue\x12W\n\x1d\x63loud_tasks_queue_iam_binding\x18\x02 \x03(\x0b\x32\x30.oak9.tython.gcp.cloud.CloudTasksQueueIamBinding\x12U\n\x1c\x63loud_tasks_queue_iam_member\x18\x03 \x03(\x0b\x32/.oak9.tython.gcp.cloud.CloudTasksQueueIamMember\x12U\n\x1c\x63loud_tasks_queue_iam_policy\x18\x04 \x03(\x0b\x32/.oak9.tython.gcp.cloud.CloudTasksQueueIamPolicyb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_google_cloud_tasks_bundle_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GOOGLECLOUDTASKS._serialized_start=129
  _GOOGLECLOUDTASKS._serialized_end=477
# @@protoc_insertion_point(module_scope)
