# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_iam.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11\x61ws/aws_iam.proto\x12\x13oak9.tython.aws.iam\x1a\x13shared/shared.proto\"w\n\tAccessKey\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06serial\x18\x02 \x01(\x05\x12\x0e\n\x06status\x18\x03 \x01(\t\x12\x11\n\tuser_name\x18\x04 \x01(\t\"\xeb\x01\n\x03IAM\x12)\n\x05group\x18\x01 \x03(\x0b\x32\x1a.oak9.tython.aws.iam.Group\x12:\n\x0emanaged_policy\x18\x02 \x03(\x0b\x32\".oak9.tython.aws.iam.ManagedPolicy\x12+\n\x06policy\x18\x03 \x03(\x0b\x32\x1b.oak9.tython.aws.iam.Policy\x12\'\n\x04role\x18\x04 \x03(\x0b\x32\x19.oak9.tython.aws.iam.Role\x12\'\n\x04user\x18\x05 \x03(\x0b\x32\x19.oak9.tython.aws.iam.User\"t\n\x0bGroupPolicy\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0bpolicy_name\x18\x02 \x01(\t\x12\x17\n\x0fpolicy_document\x18\x03 \x01(\t\"\xb3\x01\n\x05Group\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\ngroup_name\x18\x02 \x01(\t\x12\x1b\n\x13managed_policy_arns\x18\x03 \x03(\t\x12\x0c\n\x04path\x18\x04 \x01(\t\x12\x32\n\x08policies\x18\x05 \x03(\x0b\x32 .oak9.tython.aws.iam.GroupPolicy\"\x86\x01\n\x0fInstanceProfile\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1d\n\x15instance_profile_name\x18\x02 \x01(\t\x12\x0c\n\x04path\x18\x03 \x01(\t\x12\r\n\x05roles\x18\x04 \x03(\t\"\xcf\x01\n\rManagedPolicy\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0e\n\x06groups\x18\x03 \x03(\t\x12\x1b\n\x13managed_policy_name\x18\x04 \x01(\t\x12\x0c\n\x04path\x18\x05 \x01(\t\x12\r\n\x05roles\x18\x06 \x03(\t\x12\r\n\x05users\x18\x07 \x03(\t\x12\x17\n\x0fpolicy_document\x18\x08 \x01(\t\"\x9d\x01\n\x06Policy\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06groups\x18\x02 \x03(\t\x12\x13\n\x0bpolicy_name\x18\x03 \x01(\t\x12\r\n\x05roles\x18\x04 \x03(\t\x12\r\n\x05users\x18\x05 \x03(\t\x12\x17\n\x0fpolicy_document\x18\x06 \x01(\t\"s\n\nRolePolicy\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0bpolicy_name\x18\x02 \x01(\t\x12\x17\n\x0fpolicy_document\x18\x03 \x01(\t\"\x86\x03\n\x04Role\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x1b\n\x13managed_policy_arns\x18\x03 \x03(\t\x12\x1c\n\x14max_session_duration\x18\x04 \x01(\x05\x12\x0c\n\x04path\x18\x05 \x01(\t\x12\x1c\n\x14permissions_boundary\x18\x06 \x01(\t\x12\x31\n\x08policies\x18\x07 \x03(\x0b\x32\x1f.oak9.tython.aws.iam.RolePolicy\x12\x11\n\trole_name\x18\x08 \x01(\t\x12\x31\n\x04tags\x18\t \x03(\x0b\x32#.oak9.tython.aws.iam.Role.TagsEntry\x12#\n\x1b\x61ssume_role_policy_document\x18\n \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x92\x01\n\x11ServiceLinkedRole\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rcustom_suffix\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x18\n\x10\x61ws_service_name\x18\x04 \x01(\t\"~\n\x10UserLoginProfile\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08password\x18\x02 \x01(\t\x12\x1f\n\x17password_reset_required\x18\x03 \x01(\x08\"s\n\nUserPolicy\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0bpolicy_name\x18\x02 \x01(\t\x12\x17\n\x0fpolicy_document\x18\x03 \x01(\t\"\xfc\x02\n\x04User\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06groups\x18\x02 \x03(\t\x12<\n\rlogin_profile\x18\x03 \x01(\x0b\x32%.oak9.tython.aws.iam.UserLoginProfile\x12\x1b\n\x13managed_policy_arns\x18\x04 \x03(\t\x12\x0c\n\x04path\x18\x05 \x01(\t\x12\x1c\n\x14permissions_boundary\x18\x06 \x01(\t\x12\x31\n\x08policies\x18\x07 \x03(\x0b\x32\x1f.oak9.tython.aws.iam.UserPolicy\x12\x31\n\x04tags\x18\x08 \x03(\x0b\x32#.oak9.tython.aws.iam.User.TagsEntry\x12\x11\n\tuser_name\x18\t \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"q\n\x13UserToGroupAddition\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\ngroup_name\x18\x02 \x01(\t\x12\r\n\x05users\x18\x03 \x03(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_iam_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ROLE_TAGSENTRY._options = None
  _ROLE_TAGSENTRY._serialized_options = b'8\001'
  _USER_TAGSENTRY._options = None
  _USER_TAGSENTRY._serialized_options = b'8\001'
  _ACCESSKEY._serialized_start=63
  _ACCESSKEY._serialized_end=182
  _IAM._serialized_start=185
  _IAM._serialized_end=420
  _GROUPPOLICY._serialized_start=422
  _GROUPPOLICY._serialized_end=538
  _GROUP._serialized_start=541
  _GROUP._serialized_end=720
  _INSTANCEPROFILE._serialized_start=723
  _INSTANCEPROFILE._serialized_end=857
  _MANAGEDPOLICY._serialized_start=860
  _MANAGEDPOLICY._serialized_end=1067
  _POLICY._serialized_start=1070
  _POLICY._serialized_end=1227
  _ROLEPOLICY._serialized_start=1229
  _ROLEPOLICY._serialized_end=1344
  _ROLE._serialized_start=1347
  _ROLE._serialized_end=1737
  _ROLE_TAGSENTRY._serialized_start=1694
  _ROLE_TAGSENTRY._serialized_end=1737
  _SERVICELINKEDROLE._serialized_start=1740
  _SERVICELINKEDROLE._serialized_end=1886
  _USERLOGINPROFILE._serialized_start=1888
  _USERLOGINPROFILE._serialized_end=2014
  _USERPOLICY._serialized_start=2016
  _USERPOLICY._serialized_end=2131
  _USER._serialized_start=2134
  _USER._serialized_end=2514
  _USER_TAGSENTRY._serialized_start=1694
  _USER_TAGSENTRY._serialized_end=1737
  _USERTOGROUPADDITION._serialized_start=2516
  _USERTOGROUPADDITION._serialized_end=2629
# @@protoc_insertion_point(module_scope)
