# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_athena.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14\x61ws/aws_athena.proto\x12\x16oak9.tython.aws.athena\x1a\x13shared/shared.proto\"\xb8\x01\n\x0f\x44\x61taCatalogTags\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12?\n\x04tags\x18\x02 \x03(\x0b\x32\x31.oak9.tython.aws.athena.DataCatalogTags.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xaa\x02\n\x0b\x44\x61taCatalog\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12G\n\nparameters\x18\x04 \x03(\x0b\x32\x33.oak9.tython.aws.athena.DataCatalog.ParametersEntry\x12\x35\n\x04tags\x18\x05 \x01(\x0b\x32\'.oak9.tython.aws.athena.DataCatalogTags\x12\x0c\n\x04type\x18\x06 \x01(\t\x1a\x31\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb3\x01\n\x06\x41thena\x12\x39\n\x0c\x64\x61ta_catalog\x18\x01 \x03(\x0b\x32#.oak9.tython.aws.athena.DataCatalog\x12\x37\n\x0bnamed_query\x18\x02 \x03(\x0b\x32\".oak9.tython.aws.athena.NamedQuery\x12\x35\n\nwork_group\x18\x03 \x03(\x0b\x32!.oak9.tython.aws.athena.WorkGroup\"\x90\x01\n\nNamedQuery\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08\x64\x61tabase\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x14\n\x0cquery_string\x18\x05 \x01(\t\"\xb4\x01\n\rWorkGroupTags\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12=\n\x04tags\x18\x02 \x03(\x0b\x32/.oak9.tython.aws.athena.WorkGroupTags.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x87\x01\n WorkGroupEncryptionConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x19\n\x11\x65ncryption_option\x18\x02 \x01(\t\x12\x0f\n\x07kms_key\x18\x03 \x01(\t\"\xcc\x01\n\x1cWorkGroupResultConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12Z\n\x18\x65ncryption_configuration\x18\x02 \x01(\x0b\x32\x38.oak9.tython.aws.athena.WorkGroupEncryptionConfiguration\x12\x17\n\x0foutput_location\x18\x03 \x01(\t\"\xcd\x02\n\x1fWorkGroupWorkGroupConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12&\n\x1e\x62ytes_scanned_cutoff_per_query\x18\x02 \x01(\x05\x12(\n enforce_work_group_configuration\x18\x03 \x01(\x08\x12+\n#publish_cloud_watch_metrics_enabled\x18\x04 \x01(\x08\x12\x1e\n\x16requester_pays_enabled\x18\x05 \x01(\x08\x12R\n\x14result_configuration\x18\x06 \x01(\x0b\x32\x34.oak9.tython.aws.athena.WorkGroupResultConfiguration\"\x9c\x02\n#WorkGroupResultConfigurationUpdates\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12Z\n\x18\x65ncryption_configuration\x18\x02 \x01(\x0b\x32\x38.oak9.tython.aws.athena.WorkGroupEncryptionConfiguration\x12\x17\n\x0foutput_location\x18\x03 \x01(\t\x12\'\n\x1fremove_encryption_configuration\x18\x04 \x01(\x08\x12\x1e\n\x16remove_output_location\x18\x05 \x01(\x08\"\x92\x03\n&WorkGroupWorkGroupConfigurationUpdates\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12&\n\x1e\x62ytes_scanned_cutoff_per_query\x18\x02 \x01(\x05\x12(\n enforce_work_group_configuration\x18\x03 \x01(\x08\x12+\n#publish_cloud_watch_metrics_enabled\x18\x04 \x01(\x08\x12\x1e\n\x16requester_pays_enabled\x18\x05 \x01(\x08\x12\x61\n\x1cresult_configuration_updates\x18\x06 \x01(\x0b\x32;.oak9.tython.aws.athena.WorkGroupResultConfigurationUpdates\x12-\n%remove_bytes_scanned_cutoff_per_query\x18\x07 \x01(\x08\"\x91\x03\n\tWorkGroup\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x33\n\x04tags\x18\x04 \x01(\x0b\x32%.oak9.tython.aws.athena.WorkGroupTags\x12Y\n\x18work_group_configuration\x18\x05 \x01(\x0b\x32\x37.oak9.tython.aws.athena.WorkGroupWorkGroupConfiguration\x12h\n work_group_configuration_updates\x18\x06 \x01(\x0b\x32>.oak9.tython.aws.athena.WorkGroupWorkGroupConfigurationUpdates\x12\r\n\x05state\x18\x07 \x01(\t\x12\x1f\n\x17recursive_delete_option\x18\x08 \x01(\x08\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_athena_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DATACATALOGTAGS_TAGSENTRY._options = None
  _DATACATALOGTAGS_TAGSENTRY._serialized_options = b'8\001'
  _DATACATALOG_PARAMETERSENTRY._options = None
  _DATACATALOG_PARAMETERSENTRY._serialized_options = b'8\001'
  _WORKGROUPTAGS_TAGSENTRY._options = None
  _WORKGROUPTAGS_TAGSENTRY._serialized_options = b'8\001'
  _DATACATALOGTAGS._serialized_start=70
  _DATACATALOGTAGS._serialized_end=254
  _DATACATALOGTAGS_TAGSENTRY._serialized_start=211
  _DATACATALOGTAGS_TAGSENTRY._serialized_end=254
  _DATACATALOG._serialized_start=257
  _DATACATALOG._serialized_end=555
  _DATACATALOG_PARAMETERSENTRY._serialized_start=506
  _DATACATALOG_PARAMETERSENTRY._serialized_end=555
  _ATHENA._serialized_start=558
  _ATHENA._serialized_end=737
  _NAMEDQUERY._serialized_start=740
  _NAMEDQUERY._serialized_end=884
  _WORKGROUPTAGS._serialized_start=887
  _WORKGROUPTAGS._serialized_end=1067
  _WORKGROUPTAGS_TAGSENTRY._serialized_start=211
  _WORKGROUPTAGS_TAGSENTRY._serialized_end=254
  _WORKGROUPENCRYPTIONCONFIGURATION._serialized_start=1070
  _WORKGROUPENCRYPTIONCONFIGURATION._serialized_end=1205
  _WORKGROUPRESULTCONFIGURATION._serialized_start=1208
  _WORKGROUPRESULTCONFIGURATION._serialized_end=1412
  _WORKGROUPWORKGROUPCONFIGURATION._serialized_start=1415
  _WORKGROUPWORKGROUPCONFIGURATION._serialized_end=1748
  _WORKGROUPRESULTCONFIGURATIONUPDATES._serialized_start=1751
  _WORKGROUPRESULTCONFIGURATIONUPDATES._serialized_end=2035
  _WORKGROUPWORKGROUPCONFIGURATIONUPDATES._serialized_start=2038
  _WORKGROUPWORKGROUPCONFIGURATIONUPDATES._serialized_end=2440
  _WORKGROUP._serialized_start=2443
  _WORKGROUP._serialized_end=2844
# @@protoc_insertion_point(module_scope)
