# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_compute_per.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19gcp/gcp_compute_per.proto\x12\x1boak9.tython.gcp.compute_per\x1a\x13shared/shared.proto\"v\n,ComputePerInstanceConfigXPreservedStateXDisk\x12\x13\n\x0b\x64\x65lete_rule\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65vice_name\x18\x02 \x01(\t\x12\x0c\n\x04mode\x18\x03 \x01(\t\x12\x0e\n\x06source\x18\x04 \x01(\t\"\x99\x02\n\'ComputePerInstanceConfigXPreservedState\x12\x64\n\x08metadata\x18\x01 \x03(\x0b\x32R.oak9.tython.gcp.compute_per.ComputePerInstanceConfigXPreservedState.MetadataEntry\x12W\n\x04\x64isk\x18\x02 \x03(\x0b\x32I.oak9.tython.gcp.compute_per.ComputePerInstanceConfigXPreservedStateXDisk\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"S\n!ComputePerInstanceConfigXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xc7\x03\n\x18\x43omputePerInstanceConfig\x12\n\n\x02id\x18\x01 \x01(\t\x12\x1e\n\x16instance_group_manager\x18\x02 \x01(\t\x12\x16\n\x0eminimal_action\x18\x03 \x01(\t\x12&\n\x1emost_disruptive_allowed_action\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x0f\n\x07project\x18\x06 \x01(\t\x12(\n remove_instance_state_on_destroy\x18\x07 \x01(\x08\x12\x0c\n\x04zone\x18\x08 \x01(\t\x12]\n\x0fpreserved_state\x18\t \x01(\x0b\x32\x44.oak9.tython.gcp.compute_per.ComputePerInstanceConfigXPreservedState\x12P\n\x08timeouts\x18\n \x01(\x0b\x32>.oak9.tython.gcp.compute_per.ComputePerInstanceConfigXTimeouts\x12\x37\n\rresource_info\x18\x0b \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_compute_per_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMPUTEPERINSTANCECONFIGXPRESERVEDSTATE_METADATAENTRY._options = None
  _COMPUTEPERINSTANCECONFIGXPRESERVEDSTATE_METADATAENTRY._serialized_options = b'8\001'
  _COMPUTEPERINSTANCECONFIGXPRESERVEDSTATEXDISK._serialized_start=79
  _COMPUTEPERINSTANCECONFIGXPRESERVEDSTATEXDISK._serialized_end=197
  _COMPUTEPERINSTANCECONFIGXPRESERVEDSTATE._serialized_start=200
  _COMPUTEPERINSTANCECONFIGXPRESERVEDSTATE._serialized_end=481
  _COMPUTEPERINSTANCECONFIGXPRESERVEDSTATE_METADATAENTRY._serialized_start=434
  _COMPUTEPERINSTANCECONFIGXPRESERVEDSTATE_METADATAENTRY._serialized_end=481
  _COMPUTEPERINSTANCECONFIGXTIMEOUTS._serialized_start=483
  _COMPUTEPERINSTANCECONFIGXTIMEOUTS._serialized_end=566
  _COMPUTEPERINSTANCECONFIG._serialized_start=569
  _COMPUTEPERINSTANCECONFIG._serialized_end=1024
# @@protoc_insertion_point(module_scope)
