# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kubernetes/kubernetes_io.k8s.api.scheduling.v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2
from oak9.tython.models.kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta import v1_pb2 as kubernetes_dot_kubernetes__io_dot_k8s_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4kubernetes/kubernetes_io.k8s.api.scheduling.v1.proto\x12!oak9.tython.k8s.api.scheduling.v1\x1a\x13shared/shared.proto\x1a@kubernetes/kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1.proto\"\x8f\x02\n\rPriorityClass\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x16\n\x0eglobal_default\x18\x03 \x01(\x08\x12\x0c\n\x04kind\x18\x04 \x01(\t\x12K\n\x08metadata\x18\x05 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12\x19\n\x11preemption_policy\x18\x06 \x01(\t\x12\r\n\x05value\x18\x07 \x01(\x05\x12\x37\n\rresource_info\x18\x08 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xfb\x01\n\x11PriorityClassList\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12?\n\x05items\x18\x02 \x03(\x0b\x32\x30.oak9.tython.k8s.api.scheduling.v1.PriorityClass\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12I\n\x08metadata\x18\x04 \x01(\x0b\x32\x37.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ListMeta\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'kubernetes.kubernetes_io.k8s.api.scheduling.v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _PRIORITYCLASS._serialized_start=179
  _PRIORITYCLASS._serialized_end=450
  _PRIORITYCLASSLIST._serialized_start=453
  _PRIORITYCLASSLIST._serialized_end=704
# @@protoc_insertion_point(module_scope)
