# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_clouddeploy.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19gcp/gcp_clouddeploy.proto\x12\x1boak9.tython.gcp.clouddeploy\x1a\x13shared/shared.proto\"X\n1ClouddeployDeliveryPipelineXSerialPipelineXStages\x12\x10\n\x08profiles\x18\x01 \x03(\t\x12\x11\n\ttarget_id\x18\x02 \x01(\t\"\x8c\x01\n*ClouddeployDeliveryPipelineXSerialPipeline\x12^\n\x06stages\x18\x01 \x03(\x0b\x32N.oak9.tython.gcp.clouddeploy.ClouddeployDeliveryPipelineXSerialPipelineXStages\"V\n$ClouddeployDeliveryPipelineXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xde\x06\n\x1b\x43louddeployDeliveryPipeline\x12^\n\x0b\x61nnotations\x18\x01 \x03(\x0b\x32I.oak9.tython.gcp.clouddeploy.ClouddeployDeliveryPipeline.AnnotationsEntry\x12Z\n\tcondition\x18\x02 \x03(\x0b\x32G.oak9.tython.gcp.clouddeploy.ClouddeployDeliveryPipeline.ConditionEntry\x12\x13\n\x0b\x63reate_time\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x0c\n\x04\x65tag\x18\x05 \x01(\t\x12\n\n\x02id\x18\x06 \x01(\t\x12T\n\x06labels\x18\x07 \x03(\x0b\x32\x44.oak9.tython.gcp.clouddeploy.ClouddeployDeliveryPipeline.LabelsEntry\x12\x10\n\x08location\x18\x08 \x01(\t\x12\x0c\n\x04name\x18\t \x01(\t\x12\x0f\n\x07project\x18\n \x01(\t\x12\x11\n\tsuspended\x18\x0b \x01(\x08\x12\x0b\n\x03uid\x18\x0c \x01(\t\x12\x13\n\x0bupdate_time\x18\r \x01(\t\x12`\n\x0fserial_pipeline\x18\x0e \x01(\x0b\x32G.oak9.tython.gcp.clouddeploy.ClouddeployDeliveryPipelineXSerialPipeline\x12S\n\x08timeouts\x18\x0f \x01(\x0b\x32\x41.oak9.tython.gcp.clouddeploy.ClouddeployDeliveryPipelineXTimeouts\x12\x37\n\rresource_info\x18\x10 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a\x32\n\x10\x41nnotationsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x30\n\x0e\x43onditionEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"5\n\x1f\x43louddeployTargetXAnthosCluster\x12\x12\n\nmembership\x18\x01 \x01(\t\"|\n\"ClouddeployTargetXExecutionConfigs\x12\x18\n\x10\x61rtifact_storage\x18\x01 \x01(\t\x12\x17\n\x0fservice_account\x18\x02 \x01(\t\x12\x0e\n\x06usages\x18\x03 \x03(\t\x12\x13\n\x0bworker_pool\x18\x04 \x01(\t\"=\n\x15\x43louddeployTargetXGke\x12\x0f\n\x07\x63luster\x18\x01 \x01(\t\x12\x13\n\x0binternal_ip\x18\x02 \x01(\x08\"L\n\x1a\x43louddeployTargetXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xd3\x06\n\x11\x43louddeployTarget\x12T\n\x0b\x61nnotations\x18\x01 \x03(\x0b\x32?.oak9.tython.gcp.clouddeploy.ClouddeployTarget.AnnotationsEntry\x12\x13\n\x0b\x63reate_time\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x0c\n\x04\x65tag\x18\x04 \x01(\t\x12\n\n\x02id\x18\x05 \x01(\t\x12J\n\x06labels\x18\x06 \x03(\x0b\x32:.oak9.tython.gcp.clouddeploy.ClouddeployTarget.LabelsEntry\x12\x10\n\x08location\x18\x07 \x01(\t\x12\x0c\n\x04name\x18\x08 \x01(\t\x12\x0f\n\x07project\x18\t \x01(\t\x12\x18\n\x10require_approval\x18\n \x01(\x08\x12\x11\n\ttarget_id\x18\x0b \x01(\t\x12\x0b\n\x03uid\x18\x0c \x01(\t\x12\x13\n\x0bupdate_time\x18\r \x01(\t\x12T\n\x0e\x61nthos_cluster\x18\x0e \x01(\x0b\x32<.oak9.tython.gcp.clouddeploy.ClouddeployTargetXAnthosCluster\x12Z\n\x11\x65xecution_configs\x18\x0f \x03(\x0b\x32?.oak9.tython.gcp.clouddeploy.ClouddeployTargetXExecutionConfigs\x12?\n\x03gke\x18\x10 \x01(\x0b\x32\x32.oak9.tython.gcp.clouddeploy.ClouddeployTargetXGke\x12I\n\x08timeouts\x18\x11 \x01(\x0b\x32\x37.oak9.tython.gcp.clouddeploy.ClouddeployTargetXTimeouts\x12\x37\n\rresource_info\x18\x12 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a\x32\n\x10\x41nnotationsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_clouddeploy_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CLOUDDEPLOYDELIVERYPIPELINE_ANNOTATIONSENTRY._options = None
  _CLOUDDEPLOYDELIVERYPIPELINE_ANNOTATIONSENTRY._serialized_options = b'8\001'
  _CLOUDDEPLOYDELIVERYPIPELINE_CONDITIONENTRY._options = None
  _CLOUDDEPLOYDELIVERYPIPELINE_CONDITIONENTRY._serialized_options = b'8\001'
  _CLOUDDEPLOYDELIVERYPIPELINE_LABELSENTRY._options = None
  _CLOUDDEPLOYDELIVERYPIPELINE_LABELSENTRY._serialized_options = b'8\001'
  _CLOUDDEPLOYTARGET_ANNOTATIONSENTRY._options = None
  _CLOUDDEPLOYTARGET_ANNOTATIONSENTRY._serialized_options = b'8\001'
  _CLOUDDEPLOYTARGET_LABELSENTRY._options = None
  _CLOUDDEPLOYTARGET_LABELSENTRY._serialized_options = b'8\001'
  _CLOUDDEPLOYDELIVERYPIPELINEXSERIALPIPELINEXSTAGES._serialized_start=79
  _CLOUDDEPLOYDELIVERYPIPELINEXSERIALPIPELINEXSTAGES._serialized_end=167
  _CLOUDDEPLOYDELIVERYPIPELINEXSERIALPIPELINE._serialized_start=170
  _CLOUDDEPLOYDELIVERYPIPELINEXSERIALPIPELINE._serialized_end=310
  _CLOUDDEPLOYDELIVERYPIPELINEXTIMEOUTS._serialized_start=312
  _CLOUDDEPLOYDELIVERYPIPELINEXTIMEOUTS._serialized_end=398
  _CLOUDDEPLOYDELIVERYPIPELINE._serialized_start=401
  _CLOUDDEPLOYDELIVERYPIPELINE._serialized_end=1263
  _CLOUDDEPLOYDELIVERYPIPELINE_ANNOTATIONSENTRY._serialized_start=1116
  _CLOUDDEPLOYDELIVERYPIPELINE_ANNOTATIONSENTRY._serialized_end=1166
  _CLOUDDEPLOYDELIVERYPIPELINE_CONDITIONENTRY._serialized_start=1168
  _CLOUDDEPLOYDELIVERYPIPELINE_CONDITIONENTRY._serialized_end=1216
  _CLOUDDEPLOYDELIVERYPIPELINE_LABELSENTRY._serialized_start=1218
  _CLOUDDEPLOYDELIVERYPIPELINE_LABELSENTRY._serialized_end=1263
  _CLOUDDEPLOYTARGETXANTHOSCLUSTER._serialized_start=1265
  _CLOUDDEPLOYTARGETXANTHOSCLUSTER._serialized_end=1318
  _CLOUDDEPLOYTARGETXEXECUTIONCONFIGS._serialized_start=1320
  _CLOUDDEPLOYTARGETXEXECUTIONCONFIGS._serialized_end=1444
  _CLOUDDEPLOYTARGETXGKE._serialized_start=1446
  _CLOUDDEPLOYTARGETXGKE._serialized_end=1507
  _CLOUDDEPLOYTARGETXTIMEOUTS._serialized_start=1509
  _CLOUDDEPLOYTARGETXTIMEOUTS._serialized_end=1585
  _CLOUDDEPLOYTARGET._serialized_start=1588
  _CLOUDDEPLOYTARGET._serialized_end=2439
  _CLOUDDEPLOYTARGET_ANNOTATIONSENTRY._serialized_start=1116
  _CLOUDDEPLOYTARGET_ANNOTATIONSENTRY._serialized_end=1166
  _CLOUDDEPLOYTARGET_LABELSENTRY._serialized_start=1218
  _CLOUDDEPLOYTARGET_LABELSENTRY._serialized_end=1263
# @@protoc_insertion_point(module_scope)
