# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_elasticloadbalancing.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"aws/aws_elasticloadbalancing.proto\x12$oak9.tython.aws.elasticloadbalancing\x1a\x13shared/shared.proto\"\xb4\x01\n\x1fLoadBalancerAccessLoggingPolicy\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\remit_interval\x18\x02 \x01(\x05\x12\x0f\n\x07\x65nabled\x18\x03 \x01(\x08\x12\x16\n\x0es3_bucket_name\x18\x04 \x01(\t\x12\x18\n\x10s3_bucket_prefix\x18\x05 \x01(\t\"\x8a\x01\n%LoadBalancerAppCookieStickinessPolicy\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x63ookie_name\x18\x02 \x01(\t\x12\x13\n\x0bpolicy_name\x18\x03 \x01(\t\"\x81\x01\n$LoadBalancerConnectionDrainingPolicy\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07\x65nabled\x18\x02 \x01(\x08\x12\x0f\n\x07timeout\x18\x03 \x01(\x05\"o\n\x1eLoadBalancerConnectionSettings\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0cidle_timeout\x18\x02 \x01(\x05\"\xbd\x01\n\x17LoadBalancerHealthCheck\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x19\n\x11healthy_threshold\x18\x02 \x01(\t\x12\x10\n\x08interval\x18\x03 \x01(\t\x12\x0e\n\x06target\x18\x04 \x01(\t\x12\x0f\n\x07timeout\x18\x05 \x01(\t\x12\x1b\n\x13unhealthy_threshold\x18\x06 \x01(\t\"\x96\x01\n$LoadBalancerLBCookieStickinessPolicy\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12 \n\x18\x63ookie_expiration_period\x18\x02 \x01(\t\x12\x13\n\x0bpolicy_name\x18\x03 \x01(\t\"\xe2\x01\n\x15LoadBalancerListeners\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rinstance_port\x18\x02 \x01(\t\x12\x19\n\x11instance_protocol\x18\x03 \x01(\t\x12\x1a\n\x12load_balancer_port\x18\x04 \x01(\t\x12\x14\n\x0cpolicy_names\x18\x05 \x03(\t\x12\x10\n\x08protocol\x18\x06 \x01(\t\x12\x1a\n\x12ssl_certificate_id\x18\x07 \x01(\t\"\xc1\x02\n\x14LoadBalancerPolicies\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12^\n\nattributes\x18\x02 \x03(\x0b\x32J.oak9.tython.aws.elasticloadbalancing.LoadBalancerPolicies.AttributesEntry\x12\x16\n\x0einstance_ports\x18\x03 \x03(\t\x12\x1b\n\x13load_balancer_ports\x18\x04 \x03(\t\x12\x13\n\x0bpolicy_name\x18\x05 \x01(\t\x12\x13\n\x0bpolicy_type\x18\x06 \x01(\t\x1a\x31\n\x0f\x41ttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xe9\x08\n\x0cLoadBalancer\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x64\n\x15\x61\x63\x63\x65ss_logging_policy\x18\x02 \x01(\x0b\x32\x45.oak9.tython.aws.elasticloadbalancing.LoadBalancerAccessLoggingPolicy\x12q\n\x1c\x61pp_cookie_stickiness_policy\x18\x03 \x03(\x0b\x32K.oak9.tython.aws.elasticloadbalancing.LoadBalancerAppCookieStickinessPolicy\x12\x1a\n\x12\x61vailability_zones\x18\x04 \x03(\t\x12n\n\x1a\x63onnection_draining_policy\x18\x05 \x01(\x0b\x32J.oak9.tython.aws.elasticloadbalancing.LoadBalancerConnectionDrainingPolicy\x12\x61\n\x13\x63onnection_settings\x18\x06 \x01(\x0b\x32\x44.oak9.tython.aws.elasticloadbalancing.LoadBalancerConnectionSettings\x12\x12\n\ncross_zone\x18\x07 \x01(\x08\x12S\n\x0chealth_check\x18\x08 \x01(\x0b\x32=.oak9.tython.aws.elasticloadbalancing.LoadBalancerHealthCheck\x12\x11\n\tinstances\x18\t \x03(\t\x12o\n\x1blb_cookie_stickiness_policy\x18\n \x03(\x0b\x32J.oak9.tython.aws.elasticloadbalancing.LoadBalancerLBCookieStickinessPolicy\x12N\n\tlisteners\x18\x0b \x03(\x0b\x32;.oak9.tython.aws.elasticloadbalancing.LoadBalancerListeners\x12\x1a\n\x12load_balancer_name\x18\x0c \x01(\t\x12L\n\x08policies\x18\r \x03(\x0b\x32:.oak9.tython.aws.elasticloadbalancing.LoadBalancerPolicies\x12\x0e\n\x06scheme\x18\x0e \x01(\t\x12\x17\n\x0fsecurity_groups\x18\x0f \x03(\t\x12\x0f\n\x07subnets\x18\x10 \x03(\t\x12J\n\x04tags\x18\x11 \x03(\x0b\x32<.oak9.tython.aws.elasticloadbalancing.LoadBalancer.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"a\n\x14\x45lasticLoadBalancing\x12I\n\rload_balancer\x18\x01 \x01(\x0b\x32\x32.oak9.tython.aws.elasticloadbalancing.LoadBalancerb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_elasticloadbalancing_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _LOADBALANCERPOLICIES_ATTRIBUTESENTRY._options = None
  _LOADBALANCERPOLICIES_ATTRIBUTESENTRY._serialized_options = b'8\001'
  _LOADBALANCER_TAGSENTRY._options = None
  _LOADBALANCER_TAGSENTRY._serialized_options = b'8\001'
  _LOADBALANCERACCESSLOGGINGPOLICY._serialized_start=98
  _LOADBALANCERACCESSLOGGINGPOLICY._serialized_end=278
  _LOADBALANCERAPPCOOKIESTICKINESSPOLICY._serialized_start=281
  _LOADBALANCERAPPCOOKIESTICKINESSPOLICY._serialized_end=419
  _LOADBALANCERCONNECTIONDRAININGPOLICY._serialized_start=422
  _LOADBALANCERCONNECTIONDRAININGPOLICY._serialized_end=551
  _LOADBALANCERCONNECTIONSETTINGS._serialized_start=553
  _LOADBALANCERCONNECTIONSETTINGS._serialized_end=664
  _LOADBALANCERHEALTHCHECK._serialized_start=667
  _LOADBALANCERHEALTHCHECK._serialized_end=856
  _LOADBALANCERLBCOOKIESTICKINESSPOLICY._serialized_start=859
  _LOADBALANCERLBCOOKIESTICKINESSPOLICY._serialized_end=1009
  _LOADBALANCERLISTENERS._serialized_start=1012
  _LOADBALANCERLISTENERS._serialized_end=1238
  _LOADBALANCERPOLICIES._serialized_start=1241
  _LOADBALANCERPOLICIES._serialized_end=1562
  _LOADBALANCERPOLICIES_ATTRIBUTESENTRY._serialized_start=1513
  _LOADBALANCERPOLICIES_ATTRIBUTESENTRY._serialized_end=1562
  _LOADBALANCER._serialized_start=1565
  _LOADBALANCER._serialized_end=2694
  _LOADBALANCER_TAGSENTRY._serialized_start=2651
  _LOADBALANCER_TAGSENTRY._serialized_end=2694
  _ELASTICLOADBALANCING._serialized_start=2696
  _ELASTICLOADBALANCING._serialized_end=2793
# @@protoc_insertion_point(module_scope)
