"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class PubsubLiteReservationXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___PubsubLiteReservationXTimeouts = PubsubLiteReservationXTimeouts

@typing_extensions.final
class PubsubLiteReservation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    THROUGHPUT_CAPACITY_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    id: builtins.str
    name: builtins.str
    project: builtins.str
    region: builtins.str
    throughput_capacity: builtins.float
    @property
    def timeouts(self) -> global___PubsubLiteReservationXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        region: builtins.str = ...,
        throughput_capacity: builtins.float = ...,
        timeouts: global___PubsubLiteReservationXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "name", b"name", "project", b"project", "region", b"region", "resource_info", b"resource_info", "throughput_capacity", b"throughput_capacity", "timeouts", b"timeouts"]) -> None: ...

global___PubsubLiteReservation = PubsubLiteReservation

@typing_extensions.final
class PubsubLiteSubscriptionXDeliveryConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DELIVERY_REQUIREMENT_FIELD_NUMBER: builtins.int
    delivery_requirement: builtins.str
    def __init__(
        self,
        *,
        delivery_requirement: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["delivery_requirement", b"delivery_requirement"]) -> None: ...

global___PubsubLiteSubscriptionXDeliveryConfig = PubsubLiteSubscriptionXDeliveryConfig

@typing_extensions.final
class PubsubLiteSubscriptionXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___PubsubLiteSubscriptionXTimeouts = PubsubLiteSubscriptionXTimeouts

@typing_extensions.final
class PubsubLiteSubscription(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    TOPIC_FIELD_NUMBER: builtins.int
    ZONE_FIELD_NUMBER: builtins.int
    DELIVERY_CONFIG_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    id: builtins.str
    name: builtins.str
    project: builtins.str
    region: builtins.str
    topic: builtins.str
    zone: builtins.str
    @property
    def delivery_config(self) -> global___PubsubLiteSubscriptionXDeliveryConfig: ...
    @property
    def timeouts(self) -> global___PubsubLiteSubscriptionXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        region: builtins.str = ...,
        topic: builtins.str = ...,
        zone: builtins.str = ...,
        delivery_config: global___PubsubLiteSubscriptionXDeliveryConfig | None = ...,
        timeouts: global___PubsubLiteSubscriptionXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["delivery_config", b"delivery_config", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["delivery_config", b"delivery_config", "id", b"id", "name", b"name", "project", b"project", "region", b"region", "resource_info", b"resource_info", "timeouts", b"timeouts", "topic", b"topic", "zone", b"zone"]) -> None: ...

global___PubsubLiteSubscription = PubsubLiteSubscription

@typing_extensions.final
class PubsubLiteTopicXPartitionConfigXCapacity(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PUBLISH_MIB_PER_SEC_FIELD_NUMBER: builtins.int
    SUBSCRIBE_MIB_PER_SEC_FIELD_NUMBER: builtins.int
    publish_mib_per_sec: builtins.float
    subscribe_mib_per_sec: builtins.float
    def __init__(
        self,
        *,
        publish_mib_per_sec: builtins.float = ...,
        subscribe_mib_per_sec: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["publish_mib_per_sec", b"publish_mib_per_sec", "subscribe_mib_per_sec", b"subscribe_mib_per_sec"]) -> None: ...

global___PubsubLiteTopicXPartitionConfigXCapacity = PubsubLiteTopicXPartitionConfigXCapacity

@typing_extensions.final
class PubsubLiteTopicXPartitionConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COUNT_FIELD_NUMBER: builtins.int
    CAPACITY_FIELD_NUMBER: builtins.int
    count: builtins.float
    @property
    def capacity(self) -> global___PubsubLiteTopicXPartitionConfigXCapacity: ...
    def __init__(
        self,
        *,
        count: builtins.float = ...,
        capacity: global___PubsubLiteTopicXPartitionConfigXCapacity | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["capacity", b"capacity"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["capacity", b"capacity", "count", b"count"]) -> None: ...

global___PubsubLiteTopicXPartitionConfig = PubsubLiteTopicXPartitionConfig

@typing_extensions.final
class PubsubLiteTopicXReservationConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    THROUGHPUT_RESERVATION_FIELD_NUMBER: builtins.int
    throughput_reservation: builtins.str
    def __init__(
        self,
        *,
        throughput_reservation: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["throughput_reservation", b"throughput_reservation"]) -> None: ...

global___PubsubLiteTopicXReservationConfig = PubsubLiteTopicXReservationConfig

@typing_extensions.final
class PubsubLiteTopicXRetentionConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PER_PARTITION_BYTES_FIELD_NUMBER: builtins.int
    PERIOD_FIELD_NUMBER: builtins.int
    per_partition_bytes: builtins.str
    period: builtins.str
    def __init__(
        self,
        *,
        per_partition_bytes: builtins.str = ...,
        period: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["per_partition_bytes", b"per_partition_bytes", "period", b"period"]) -> None: ...

global___PubsubLiteTopicXRetentionConfig = PubsubLiteTopicXRetentionConfig

@typing_extensions.final
class PubsubLiteTopicXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___PubsubLiteTopicXTimeouts = PubsubLiteTopicXTimeouts

@typing_extensions.final
class PubsubLiteTopic(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    ZONE_FIELD_NUMBER: builtins.int
    PARTITION_CONFIG_FIELD_NUMBER: builtins.int
    RESERVATION_CONFIG_FIELD_NUMBER: builtins.int
    RETENTION_CONFIG_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    id: builtins.str
    name: builtins.str
    project: builtins.str
    region: builtins.str
    zone: builtins.str
    @property
    def partition_config(self) -> global___PubsubLiteTopicXPartitionConfig: ...
    @property
    def reservation_config(self) -> global___PubsubLiteTopicXReservationConfig: ...
    @property
    def retention_config(self) -> global___PubsubLiteTopicXRetentionConfig: ...
    @property
    def timeouts(self) -> global___PubsubLiteTopicXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        region: builtins.str = ...,
        zone: builtins.str = ...,
        partition_config: global___PubsubLiteTopicXPartitionConfig | None = ...,
        reservation_config: global___PubsubLiteTopicXReservationConfig | None = ...,
        retention_config: global___PubsubLiteTopicXRetentionConfig | None = ...,
        timeouts: global___PubsubLiteTopicXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["partition_config", b"partition_config", "reservation_config", b"reservation_config", "resource_info", b"resource_info", "retention_config", b"retention_config", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "name", b"name", "partition_config", b"partition_config", "project", b"project", "region", b"region", "reservation_config", b"reservation_config", "resource_info", b"resource_info", "retention_config", b"retention_config", "timeouts", b"timeouts", "zone", b"zone"]) -> None: ...

global___PubsubLiteTopic = PubsubLiteTopic

@typing_extensions.final
class PubsubSchemaXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete"]) -> None: ...

global___PubsubSchemaXTimeouts = PubsubSchemaXTimeouts

@typing_extensions.final
class PubsubSchema(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEFINITION_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    definition: builtins.str
    id: builtins.str
    name: builtins.str
    project: builtins.str
    type: builtins.str
    @property
    def timeouts(self) -> global___PubsubSchemaXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        definition: builtins.str = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        type: builtins.str = ...,
        timeouts: global___PubsubSchemaXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["definition", b"definition", "id", b"id", "name", b"name", "project", b"project", "resource_info", b"resource_info", "timeouts", b"timeouts", "type", b"type"]) -> None: ...

global___PubsubSchema = PubsubSchema

@typing_extensions.final
class PubsubSubscriptionXDeadLetterPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEAD_LETTER_TOPIC_FIELD_NUMBER: builtins.int
    MAX_DELIVERY_ATTEMPTS_FIELD_NUMBER: builtins.int
    dead_letter_topic: builtins.str
    max_delivery_attempts: builtins.float
    def __init__(
        self,
        *,
        dead_letter_topic: builtins.str = ...,
        max_delivery_attempts: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["dead_letter_topic", b"dead_letter_topic", "max_delivery_attempts", b"max_delivery_attempts"]) -> None: ...

global___PubsubSubscriptionXDeadLetterPolicy = PubsubSubscriptionXDeadLetterPolicy

@typing_extensions.final
class PubsubSubscriptionXExpirationPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TTL_FIELD_NUMBER: builtins.int
    ttl: builtins.str
    def __init__(
        self,
        *,
        ttl: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["ttl", b"ttl"]) -> None: ...

global___PubsubSubscriptionXExpirationPolicy = PubsubSubscriptionXExpirationPolicy

@typing_extensions.final
class PubsubSubscriptionXPushConfigXOidcToken(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUDIENCE_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_EMAIL_FIELD_NUMBER: builtins.int
    audience: builtins.str
    service_account_email: builtins.str
    def __init__(
        self,
        *,
        audience: builtins.str = ...,
        service_account_email: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["audience", b"audience", "service_account_email", b"service_account_email"]) -> None: ...

global___PubsubSubscriptionXPushConfigXOidcToken = PubsubSubscriptionXPushConfigXOidcToken

@typing_extensions.final
class PubsubSubscriptionXPushConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class AttributesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    ATTRIBUTES_FIELD_NUMBER: builtins.int
    PUSH_ENDPOINT_FIELD_NUMBER: builtins.int
    OIDC_TOKEN_FIELD_NUMBER: builtins.int
    @property
    def attributes(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    push_endpoint: builtins.str
    @property
    def oidc_token(self) -> global___PubsubSubscriptionXPushConfigXOidcToken: ...
    def __init__(
        self,
        *,
        attributes: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        push_endpoint: builtins.str = ...,
        oidc_token: global___PubsubSubscriptionXPushConfigXOidcToken | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["oidc_token", b"oidc_token"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["attributes", b"attributes", "oidc_token", b"oidc_token", "push_endpoint", b"push_endpoint"]) -> None: ...

global___PubsubSubscriptionXPushConfig = PubsubSubscriptionXPushConfig

@typing_extensions.final
class PubsubSubscriptionXRetryPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MAXIMUM_BACKOFF_FIELD_NUMBER: builtins.int
    MINIMUM_BACKOFF_FIELD_NUMBER: builtins.int
    maximum_backoff: builtins.str
    minimum_backoff: builtins.str
    def __init__(
        self,
        *,
        maximum_backoff: builtins.str = ...,
        minimum_backoff: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["maximum_backoff", b"maximum_backoff", "minimum_backoff", b"minimum_backoff"]) -> None: ...

global___PubsubSubscriptionXRetryPolicy = PubsubSubscriptionXRetryPolicy

@typing_extensions.final
class PubsubSubscriptionXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___PubsubSubscriptionXTimeouts = PubsubSubscriptionXTimeouts

@typing_extensions.final
class PubsubSubscription(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    ACK_DEADLINE_SECONDS_FIELD_NUMBER: builtins.int
    ENABLE_EXACTLY_ONCE_DELIVERY_FIELD_NUMBER: builtins.int
    ENABLE_MESSAGE_ORDERING_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    MESSAGE_RETENTION_DURATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    RETAIN_ACKED_MESSAGES_FIELD_NUMBER: builtins.int
    TOPIC_FIELD_NUMBER: builtins.int
    DEAD_LETTER_POLICY_FIELD_NUMBER: builtins.int
    EXPIRATION_POLICY_FIELD_NUMBER: builtins.int
    PUSH_CONFIG_FIELD_NUMBER: builtins.int
    RETRY_POLICY_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ack_deadline_seconds: builtins.float
    enable_exactly_once_delivery: builtins.bool
    enable_message_ordering: builtins.bool
    filter: builtins.str
    id: builtins.str
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    message_retention_duration: builtins.str
    name: builtins.str
    project: builtins.str
    retain_acked_messages: builtins.bool
    topic: builtins.str
    @property
    def dead_letter_policy(self) -> global___PubsubSubscriptionXDeadLetterPolicy: ...
    @property
    def expiration_policy(self) -> global___PubsubSubscriptionXExpirationPolicy: ...
    @property
    def push_config(self) -> global___PubsubSubscriptionXPushConfig: ...
    @property
    def retry_policy(self) -> global___PubsubSubscriptionXRetryPolicy: ...
    @property
    def timeouts(self) -> global___PubsubSubscriptionXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        ack_deadline_seconds: builtins.float = ...,
        enable_exactly_once_delivery: builtins.bool = ...,
        enable_message_ordering: builtins.bool = ...,
        filter: builtins.str = ...,
        id: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        message_retention_duration: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        retain_acked_messages: builtins.bool = ...,
        topic: builtins.str = ...,
        dead_letter_policy: global___PubsubSubscriptionXDeadLetterPolicy | None = ...,
        expiration_policy: global___PubsubSubscriptionXExpirationPolicy | None = ...,
        push_config: global___PubsubSubscriptionXPushConfig | None = ...,
        retry_policy: global___PubsubSubscriptionXRetryPolicy | None = ...,
        timeouts: global___PubsubSubscriptionXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["dead_letter_policy", b"dead_letter_policy", "expiration_policy", b"expiration_policy", "push_config", b"push_config", "resource_info", b"resource_info", "retry_policy", b"retry_policy", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ack_deadline_seconds", b"ack_deadline_seconds", "dead_letter_policy", b"dead_letter_policy", "enable_exactly_once_delivery", b"enable_exactly_once_delivery", "enable_message_ordering", b"enable_message_ordering", "expiration_policy", b"expiration_policy", "filter", b"filter", "id", b"id", "labels", b"labels", "message_retention_duration", b"message_retention_duration", "name", b"name", "project", b"project", "push_config", b"push_config", "resource_info", b"resource_info", "retain_acked_messages", b"retain_acked_messages", "retry_policy", b"retry_policy", "timeouts", b"timeouts", "topic", b"topic"]) -> None: ...

global___PubsubSubscription = PubsubSubscription

@typing_extensions.final
class PubsubSubscriptionIamBindingXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___PubsubSubscriptionIamBindingXCondition = PubsubSubscriptionIamBindingXCondition

@typing_extensions.final
class PubsubSubscriptionIamBinding(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    MEMBERS_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    SUBSCRIPTION_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    @property
    def members(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    project: builtins.str
    role: builtins.str
    subscription: builtins.str
    @property
    def condition(self) -> global___PubsubSubscriptionIamBindingXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        members: collections.abc.Iterable[builtins.str] | None = ...,
        project: builtins.str = ...,
        role: builtins.str = ...,
        subscription: builtins.str = ...,
        condition: global___PubsubSubscriptionIamBindingXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "etag", b"etag", "id", b"id", "members", b"members", "project", b"project", "resource_info", b"resource_info", "role", b"role", "subscription", b"subscription"]) -> None: ...

global___PubsubSubscriptionIamBinding = PubsubSubscriptionIamBinding

@typing_extensions.final
class PubsubSubscriptionIamMemberXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___PubsubSubscriptionIamMemberXCondition = PubsubSubscriptionIamMemberXCondition

@typing_extensions.final
class PubsubSubscriptionIamMember(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    MEMBER_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    SUBSCRIPTION_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    member: builtins.str
    project: builtins.str
    role: builtins.str
    subscription: builtins.str
    @property
    def condition(self) -> global___PubsubSubscriptionIamMemberXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        member: builtins.str = ...,
        project: builtins.str = ...,
        role: builtins.str = ...,
        subscription: builtins.str = ...,
        condition: global___PubsubSubscriptionIamMemberXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "etag", b"etag", "id", b"id", "member", b"member", "project", b"project", "resource_info", b"resource_info", "role", b"role", "subscription", b"subscription"]) -> None: ...

global___PubsubSubscriptionIamMember = PubsubSubscriptionIamMember

@typing_extensions.final
class PubsubSubscriptionIamPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    POLICY_DATA_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    SUBSCRIPTION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    policy_data: builtins.str
    project: builtins.str
    subscription: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        policy_data: builtins.str = ...,
        project: builtins.str = ...,
        subscription: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["etag", b"etag", "id", b"id", "policy_data", b"policy_data", "project", b"project", "resource_info", b"resource_info", "subscription", b"subscription"]) -> None: ...

global___PubsubSubscriptionIamPolicy = PubsubSubscriptionIamPolicy

@typing_extensions.final
class PubsubTopicXMessageStoragePolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALLOWED_PERSISTENCE_REGIONS_FIELD_NUMBER: builtins.int
    @property
    def allowed_persistence_regions(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        allowed_persistence_regions: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["allowed_persistence_regions", b"allowed_persistence_regions"]) -> None: ...

global___PubsubTopicXMessageStoragePolicy = PubsubTopicXMessageStoragePolicy

@typing_extensions.final
class PubsubTopicXSchemaSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENCODING_FIELD_NUMBER: builtins.int
    SCHEMA_FIELD_NUMBER: builtins.int
    encoding: builtins.str
    schema: builtins.str
    def __init__(
        self,
        *,
        encoding: builtins.str = ...,
        schema: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["encoding", b"encoding", "schema", b"schema"]) -> None: ...

global___PubsubTopicXSchemaSettings = PubsubTopicXSchemaSettings

@typing_extensions.final
class PubsubTopicXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___PubsubTopicXTimeouts = PubsubTopicXTimeouts

@typing_extensions.final
class PubsubTopic(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    KMS_KEY_NAME_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    MESSAGE_RETENTION_DURATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    MESSAGE_STORAGE_POLICY_FIELD_NUMBER: builtins.int
    SCHEMA_SETTINGS_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    id: builtins.str
    kms_key_name: builtins.str
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    message_retention_duration: builtins.str
    name: builtins.str
    project: builtins.str
    @property
    def message_storage_policy(self) -> global___PubsubTopicXMessageStoragePolicy: ...
    @property
    def schema_settings(self) -> global___PubsubTopicXSchemaSettings: ...
    @property
    def timeouts(self) -> global___PubsubTopicXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        kms_key_name: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        message_retention_duration: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        message_storage_policy: global___PubsubTopicXMessageStoragePolicy | None = ...,
        schema_settings: global___PubsubTopicXSchemaSettings | None = ...,
        timeouts: global___PubsubTopicXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["message_storage_policy", b"message_storage_policy", "resource_info", b"resource_info", "schema_settings", b"schema_settings", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "kms_key_name", b"kms_key_name", "labels", b"labels", "message_retention_duration", b"message_retention_duration", "message_storage_policy", b"message_storage_policy", "name", b"name", "project", b"project", "resource_info", b"resource_info", "schema_settings", b"schema_settings", "timeouts", b"timeouts"]) -> None: ...

global___PubsubTopic = PubsubTopic

@typing_extensions.final
class PubsubTopicIamBindingXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___PubsubTopicIamBindingXCondition = PubsubTopicIamBindingXCondition

@typing_extensions.final
class PubsubTopicIamBinding(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    MEMBERS_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    TOPIC_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    @property
    def members(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    project: builtins.str
    role: builtins.str
    topic: builtins.str
    @property
    def condition(self) -> global___PubsubTopicIamBindingXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        members: collections.abc.Iterable[builtins.str] | None = ...,
        project: builtins.str = ...,
        role: builtins.str = ...,
        topic: builtins.str = ...,
        condition: global___PubsubTopicIamBindingXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "etag", b"etag", "id", b"id", "members", b"members", "project", b"project", "resource_info", b"resource_info", "role", b"role", "topic", b"topic"]) -> None: ...

global___PubsubTopicIamBinding = PubsubTopicIamBinding

@typing_extensions.final
class PubsubTopicIamMemberXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___PubsubTopicIamMemberXCondition = PubsubTopicIamMemberXCondition

@typing_extensions.final
class PubsubTopicIamMember(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    MEMBER_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    TOPIC_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    member: builtins.str
    project: builtins.str
    role: builtins.str
    topic: builtins.str
    @property
    def condition(self) -> global___PubsubTopicIamMemberXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        member: builtins.str = ...,
        project: builtins.str = ...,
        role: builtins.str = ...,
        topic: builtins.str = ...,
        condition: global___PubsubTopicIamMemberXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "etag", b"etag", "id", b"id", "member", b"member", "project", b"project", "resource_info", b"resource_info", "role", b"role", "topic", b"topic"]) -> None: ...

global___PubsubTopicIamMember = PubsubTopicIamMember

@typing_extensions.final
class PubsubTopicIamPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    POLICY_DATA_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    TOPIC_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    policy_data: builtins.str
    project: builtins.str
    topic: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        policy_data: builtins.str = ...,
        project: builtins.str = ...,
        topic: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["etag", b"etag", "id", b"id", "policy_data", b"policy_data", "project", b"project", "resource_info", b"resource_info", "topic", b"topic"]) -> None: ...

global___PubsubTopicIamPolicy = PubsubTopicIamPolicy
