"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Alexa_ASK_Skill_AuthenticationConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    REFRESH_TOKEN_FIELD_NUMBER: builtins.int
    CLIENT_SECRET_FIELD_NUMBER: builtins.int
    CLIENT_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    refresh_token: builtins.str
    client_secret: builtins.str
    client_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        refresh_token: builtins.str = ...,
        client_secret: builtins.str = ...,
        client_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["client_id", b"client_id", "client_secret", b"client_secret", "refresh_token", b"refresh_token", "resource_info", b"resource_info"]) -> None: ...

global___Alexa_ASK_Skill_AuthenticationConfiguration = Alexa_ASK_Skill_AuthenticationConfiguration

@typing_extensions.final
class Alexa_ASK_Skill_Overrides(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class ManifestEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    MANIFEST_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def manifest(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        manifest: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["manifest", b"manifest", "resource_info", b"resource_info"]) -> None: ...

global___Alexa_ASK_Skill_Overrides = Alexa_ASK_Skill_Overrides

@typing_extensions.final
class Alexa_ASK_Skill_SkillPackage(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    S3_BUCKET_ROLE_FIELD_NUMBER: builtins.int
    S3_OBJECT_VERSION_FIELD_NUMBER: builtins.int
    S3_BUCKET_FIELD_NUMBER: builtins.int
    S3_KEY_FIELD_NUMBER: builtins.int
    OVERRIDES_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    s3_bucket_role: builtins.str
    s3_object_version: builtins.str
    s3_bucket: builtins.str
    s3_key: builtins.str
    @property
    def overrides(self) -> global___Alexa_ASK_Skill_Overrides: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        s3_bucket_role: builtins.str = ...,
        s3_object_version: builtins.str = ...,
        s3_bucket: builtins.str = ...,
        s3_key: builtins.str = ...,
        overrides: global___Alexa_ASK_Skill_Overrides | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["overrides", b"overrides", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["overrides", b"overrides", "resource_info", b"resource_info", "s3_bucket", b"s3_bucket", "s3_bucket_role", b"s3_bucket_role", "s3_key", b"s3_key", "s3_object_version", b"s3_object_version"]) -> None: ...

global___Alexa_ASK_Skill_SkillPackage = Alexa_ASK_Skill_SkillPackage

@typing_extensions.final
class Alexa_ASK_Skill(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    AUTHENTICATION_CONFIGURATION_FIELD_NUMBER: builtins.int
    VENDOR_ID_FIELD_NUMBER: builtins.int
    SKILL_PACKAGE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def authentication_configuration(self) -> global___Alexa_ASK_Skill_AuthenticationConfiguration: ...
    vendor_id: builtins.str
    @property
    def skill_package(self) -> global___Alexa_ASK_Skill_SkillPackage: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        authentication_configuration: global___Alexa_ASK_Skill_AuthenticationConfiguration | None = ...,
        vendor_id: builtins.str = ...,
        skill_package: global___Alexa_ASK_Skill_SkillPackage | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["authentication_configuration", b"authentication_configuration", "resource_info", b"resource_info", "skill_package", b"skill_package"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["authentication_configuration", b"authentication_configuration", "resource_info", b"resource_info", "skill_package", b"skill_package", "vendor_id", b"vendor_id"]) -> None: ...

global___Alexa_ASK_Skill = Alexa_ASK_Skill

@typing_extensions.final
class Alexa_ASK(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALEXA__A_S_K__SKILL_FIELD_NUMBER: builtins.int
    @property
    def alexa__a_s_k__skill(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Alexa_ASK_Skill]: ...
    def __init__(
        self,
        *,
        alexa__a_s_k__skill: collections.abc.Iterable[global___Alexa_ASK_Skill] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["alexa__a_s_k__skill", b"alexa__a_s_k__skill"]) -> None: ...

global___Alexa_ASK = Alexa_ASK
