"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import kubernetes.kubernetes_io.k8s.apimachinery.pkg.runtime_pb2
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class APIGroup(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PREFERRED_VERSION_FIELD_NUMBER: builtins.int
    SERVER_ADDRESS_BY_CLIENT_CIDRS_FIELD_NUMBER: builtins.int
    VERSIONS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    kind: builtins.str
    name: builtins.str
    @property
    def preferred_version(self) -> global___GroupVersionForDiscovery: ...
    @property
    def server_address_by_client_cidrs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServerAddressByClientCIDR]: ...
    @property
    def versions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___GroupVersionForDiscovery]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        kind: builtins.str = ...,
        name: builtins.str = ...,
        preferred_version: global___GroupVersionForDiscovery | None = ...,
        server_address_by_client_cidrs: collections.abc.Iterable[global___ServerAddressByClientCIDR] | None = ...,
        versions: collections.abc.Iterable[global___GroupVersionForDiscovery] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["preferred_version", b"preferred_version", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "kind", b"kind", "name", b"name", "preferred_version", b"preferred_version", "resource_info", b"resource_info", "server_address_by_client_cidrs", b"server_address_by_client_cidrs", "versions", b"versions"]) -> None: ...

global___APIGroup = APIGroup

@typing_extensions.final
class APIGroupList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    GROUPS_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    @property
    def groups(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___APIGroup]: ...
    kind: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        groups: collections.abc.Iterable[global___APIGroup] | None = ...,
        kind: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "groups", b"groups", "kind", b"kind", "resource_info", b"resource_info"]) -> None: ...

global___APIGroupList = APIGroupList

@typing_extensions.final
class APIResource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CATEGORIES_FIELD_NUMBER: builtins.int
    GROUP_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    NAMESPACED_FIELD_NUMBER: builtins.int
    SHORT_NAMES_FIELD_NUMBER: builtins.int
    SINGULAR_NAME_FIELD_NUMBER: builtins.int
    STORAGE_VERSION_HASH_FIELD_NUMBER: builtins.int
    VERBS_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def categories(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    group: builtins.str
    kind: builtins.str
    name: builtins.str
    namespaced: builtins.bool
    @property
    def short_names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    singular_name: builtins.str
    storage_version_hash: builtins.str
    @property
    def verbs(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    version: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        categories: collections.abc.Iterable[builtins.str] | None = ...,
        group: builtins.str = ...,
        kind: builtins.str = ...,
        name: builtins.str = ...,
        namespaced: builtins.bool = ...,
        short_names: collections.abc.Iterable[builtins.str] | None = ...,
        singular_name: builtins.str = ...,
        storage_version_hash: builtins.str = ...,
        verbs: collections.abc.Iterable[builtins.str] | None = ...,
        version: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["categories", b"categories", "group", b"group", "kind", b"kind", "name", b"name", "namespaced", b"namespaced", "resource_info", b"resource_info", "short_names", b"short_names", "singular_name", b"singular_name", "storage_version_hash", b"storage_version_hash", "verbs", b"verbs", "version", b"version"]) -> None: ...

global___APIResource = APIResource

@typing_extensions.final
class APIResourceList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    GROUP_VERSION_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    RESOURCES_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    group_version: builtins.str
    kind: builtins.str
    @property
    def resources(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___APIResource]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        group_version: builtins.str = ...,
        kind: builtins.str = ...,
        resources: collections.abc.Iterable[global___APIResource] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "group_version", b"group_version", "kind", b"kind", "resource_info", b"resource_info", "resources", b"resources"]) -> None: ...

global___APIResourceList = APIResourceList

@typing_extensions.final
class APIVersions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    SERVER_ADDRESS_BY_CLIENT_CIDRS_FIELD_NUMBER: builtins.int
    VERSIONS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    kind: builtins.str
    @property
    def server_address_by_client_cidrs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServerAddressByClientCIDR]: ...
    @property
    def versions(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        kind: builtins.str = ...,
        server_address_by_client_cidrs: collections.abc.Iterable[global___ServerAddressByClientCIDR] | None = ...,
        versions: collections.abc.Iterable[builtins.str] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "kind", b"kind", "resource_info", b"resource_info", "server_address_by_client_cidrs", b"server_address_by_client_cidrs", "versions", b"versions"]) -> None: ...

global___APIVersions = APIVersions

@typing_extensions.final
class Condition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LAST_TRANSITION_TIME_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    OBSERVED_GENERATION_FIELD_NUMBER: builtins.int
    REASON_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def last_transition_time(self) -> global___Time: ...
    message: builtins.str
    observed_generation: builtins.int
    reason: builtins.str
    status: builtins.str
    type: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        last_transition_time: global___Time | None = ...,
        message: builtins.str = ...,
        observed_generation: builtins.int = ...,
        reason: builtins.str = ...,
        status: builtins.str = ...,
        type: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["last_transition_time", b"last_transition_time", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["last_transition_time", b"last_transition_time", "message", b"message", "observed_generation", b"observed_generation", "reason", b"reason", "resource_info", b"resource_info", "status", b"status", "type", b"type"]) -> None: ...

global___Condition = Condition

@typing_extensions.final
class DeleteOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    DRY_RUN_FIELD_NUMBER: builtins.int
    GRACE_PERIOD_SECONDS_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    ORPHAN_DEPENDENTS_FIELD_NUMBER: builtins.int
    PRECONDITIONS_FIELD_NUMBER: builtins.int
    PROPAGATION_POLICY_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    @property
    def dry_run(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    grace_period_seconds: builtins.int
    kind: builtins.str
    orphan_dependents: builtins.bool
    @property
    def preconditions(self) -> global___Preconditions: ...
    propagation_policy: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        dry_run: collections.abc.Iterable[builtins.str] | None = ...,
        grace_period_seconds: builtins.int = ...,
        kind: builtins.str = ...,
        orphan_dependents: builtins.bool = ...,
        preconditions: global___Preconditions | None = ...,
        propagation_policy: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["preconditions", b"preconditions", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "dry_run", b"dry_run", "grace_period_seconds", b"grace_period_seconds", "kind", b"kind", "orphan_dependents", b"orphan_dependents", "preconditions", b"preconditions", "propagation_policy", b"propagation_policy", "resource_info", b"resource_info"]) -> None: ...

global___DeleteOptions = DeleteOptions

@typing_extensions.final
class FieldsV1(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> None: ...

global___FieldsV1 = FieldsV1

@typing_extensions.final
class GroupVersionForDiscovery(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GROUP_VERSION_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    group_version: builtins.str
    version: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        group_version: builtins.str = ...,
        version: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["group_version", b"group_version", "resource_info", b"resource_info", "version", b"version"]) -> None: ...

global___GroupVersionForDiscovery = GroupVersionForDiscovery

@typing_extensions.final
class LabelSelector(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class MatchLabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    MATCH_EXPRESSIONS_FIELD_NUMBER: builtins.int
    MATCH_LABELS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def match_expressions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___LabelSelectorRequirement]: ...
    @property
    def match_labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        match_expressions: collections.abc.Iterable[global___LabelSelectorRequirement] | None = ...,
        match_labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["match_expressions", b"match_expressions", "match_labels", b"match_labels", "resource_info", b"resource_info"]) -> None: ...

global___LabelSelector = LabelSelector

@typing_extensions.final
class LabelSelectorRequirement(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_FIELD_NUMBER: builtins.int
    OPERATOR_FIELD_NUMBER: builtins.int
    VALUES_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    key: builtins.str
    operator: builtins.str
    @property
    def values(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        key: builtins.str = ...,
        operator: builtins.str = ...,
        values: collections.abc.Iterable[builtins.str] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "operator", b"operator", "resource_info", b"resource_info", "values", b"values"]) -> None: ...

global___LabelSelectorRequirement = LabelSelectorRequirement

@typing_extensions.final
class ListMeta(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTINUE_FIELD_NUMBER: builtins.int
    REMAINING_ITEM_COUNT_FIELD_NUMBER: builtins.int
    RESOURCE_VERSION_FIELD_NUMBER: builtins.int
    SELF_LINK_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    remaining_item_count: builtins.int
    resource_version: builtins.str
    self_link: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        remaining_item_count: builtins.int = ...,
        resource_version: builtins.str = ...,
        self_link: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["continue", b"continue", "remaining_item_count", b"remaining_item_count", "resource_info", b"resource_info", "resource_version", b"resource_version", "self_link", b"self_link"]) -> None: ...

global___ListMeta = ListMeta

@typing_extensions.final
class ManagedFieldsEntry(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    FIELDS_TYPE_FIELD_NUMBER: builtins.int
    FIELDS_V1_FIELD_NUMBER: builtins.int
    MANAGER_FIELD_NUMBER: builtins.int
    OPERATION_FIELD_NUMBER: builtins.int
    SUBRESOURCE_FIELD_NUMBER: builtins.int
    TIME_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    fields_type: builtins.str
    @property
    def fields_v1(self) -> global___FieldsV1: ...
    manager: builtins.str
    operation: builtins.str
    subresource: builtins.str
    @property
    def time(self) -> global___Time: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        fields_type: builtins.str = ...,
        fields_v1: global___FieldsV1 | None = ...,
        manager: builtins.str = ...,
        operation: builtins.str = ...,
        subresource: builtins.str = ...,
        time: global___Time | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["fields_v1", b"fields_v1", "resource_info", b"resource_info", "time", b"time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "fields_type", b"fields_type", "fields_v1", b"fields_v1", "manager", b"manager", "operation", b"operation", "resource_info", b"resource_info", "subresource", b"subresource", "time", b"time"]) -> None: ...

global___ManagedFieldsEntry = ManagedFieldsEntry

@typing_extensions.final
class MicroTime(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> None: ...

global___MicroTime = MicroTime

@typing_extensions.final
class ObjectMeta(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class AnnotationsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    ANNOTATIONS_FIELD_NUMBER: builtins.int
    CREATION_TIMESTAMP_FIELD_NUMBER: builtins.int
    DELETION_GRACE_PERIOD_SECONDS_FIELD_NUMBER: builtins.int
    DELETION_TIMESTAMP_FIELD_NUMBER: builtins.int
    FINALIZERS_FIELD_NUMBER: builtins.int
    GENERATE_NAME_FIELD_NUMBER: builtins.int
    GENERATION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    MANAGED_FIELDS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    NAMESPACE_FIELD_NUMBER: builtins.int
    OWNER_REFERENCES_FIELD_NUMBER: builtins.int
    RESOURCE_VERSION_FIELD_NUMBER: builtins.int
    SELF_LINK_FIELD_NUMBER: builtins.int
    UID_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def annotations(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def creation_timestamp(self) -> global___Time: ...
    deletion_grace_period_seconds: builtins.int
    @property
    def deletion_timestamp(self) -> global___Time: ...
    @property
    def finalizers(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    generate_name: builtins.str
    generation: builtins.int
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def managed_fields(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ManagedFieldsEntry]: ...
    name: builtins.str
    namespace: builtins.str
    @property
    def owner_references(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___OwnerReference]: ...
    resource_version: builtins.str
    self_link: builtins.str
    uid: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        annotations: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        creation_timestamp: global___Time | None = ...,
        deletion_grace_period_seconds: builtins.int = ...,
        deletion_timestamp: global___Time | None = ...,
        finalizers: collections.abc.Iterable[builtins.str] | None = ...,
        generate_name: builtins.str = ...,
        generation: builtins.int = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        managed_fields: collections.abc.Iterable[global___ManagedFieldsEntry] | None = ...,
        name: builtins.str = ...,
        namespace: builtins.str = ...,
        owner_references: collections.abc.Iterable[global___OwnerReference] | None = ...,
        resource_version: builtins.str = ...,
        self_link: builtins.str = ...,
        uid: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["creation_timestamp", b"creation_timestamp", "deletion_timestamp", b"deletion_timestamp", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["annotations", b"annotations", "creation_timestamp", b"creation_timestamp", "deletion_grace_period_seconds", b"deletion_grace_period_seconds", "deletion_timestamp", b"deletion_timestamp", "finalizers", b"finalizers", "generate_name", b"generate_name", "generation", b"generation", "labels", b"labels", "managed_fields", b"managed_fields", "name", b"name", "namespace", b"namespace", "owner_references", b"owner_references", "resource_info", b"resource_info", "resource_version", b"resource_version", "self_link", b"self_link", "uid", b"uid"]) -> None: ...

global___ObjectMeta = ObjectMeta

@typing_extensions.final
class OwnerReference(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    BLOCK_OWNER_DELETION_FIELD_NUMBER: builtins.int
    CONTROLLER_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    UID_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    block_owner_deletion: builtins.bool
    controller: builtins.bool
    kind: builtins.str
    name: builtins.str
    uid: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        block_owner_deletion: builtins.bool = ...,
        controller: builtins.bool = ...,
        kind: builtins.str = ...,
        name: builtins.str = ...,
        uid: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "block_owner_deletion", b"block_owner_deletion", "controller", b"controller", "kind", b"kind", "name", b"name", "resource_info", b"resource_info", "uid", b"uid"]) -> None: ...

global___OwnerReference = OwnerReference

@typing_extensions.final
class Patch(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> None: ...

global___Patch = Patch

@typing_extensions.final
class Preconditions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_VERSION_FIELD_NUMBER: builtins.int
    UID_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    resource_version: builtins.str
    uid: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        resource_version: builtins.str = ...,
        uid: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "resource_version", b"resource_version", "uid", b"uid"]) -> None: ...

global___Preconditions = Preconditions

@typing_extensions.final
class ServerAddressByClientCIDR(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLIENT_CIDR_FIELD_NUMBER: builtins.int
    SERVER_ADDRESS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    client_cidr: builtins.str
    server_address: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        client_cidr: builtins.str = ...,
        server_address: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["client_cidr", b"client_cidr", "resource_info", b"resource_info", "server_address", b"server_address"]) -> None: ...

global___ServerAddressByClientCIDR = ServerAddressByClientCIDR

@typing_extensions.final
class Status(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    CODE_FIELD_NUMBER: builtins.int
    DETAILS_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    REASON_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    code: builtins.int
    @property
    def details(self) -> global___StatusDetails: ...
    kind: builtins.str
    message: builtins.str
    @property
    def metadata(self) -> global___ListMeta: ...
    reason: builtins.str
    status: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        code: builtins.int = ...,
        details: global___StatusDetails | None = ...,
        kind: builtins.str = ...,
        message: builtins.str = ...,
        metadata: global___ListMeta | None = ...,
        reason: builtins.str = ...,
        status: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["details", b"details", "metadata", b"metadata", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "code", b"code", "details", b"details", "kind", b"kind", "message", b"message", "metadata", b"metadata", "reason", b"reason", "resource_info", b"resource_info", "status", b"status"]) -> None: ...

global___Status = Status

@typing_extensions.final
class StatusCause(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FIELD_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    REASON_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    field: builtins.str
    message: builtins.str
    reason: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        field: builtins.str = ...,
        message: builtins.str = ...,
        reason: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["field", b"field", "message", b"message", "reason", b"reason", "resource_info", b"resource_info"]) -> None: ...

global___StatusCause = StatusCause

@typing_extensions.final
class StatusDetails(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CAUSES_FIELD_NUMBER: builtins.int
    GROUP_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    RETRY_AFTER_SECONDS_FIELD_NUMBER: builtins.int
    UID_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def causes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___StatusCause]: ...
    group: builtins.str
    kind: builtins.str
    name: builtins.str
    retry_after_seconds: builtins.int
    uid: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        causes: collections.abc.Iterable[global___StatusCause] | None = ...,
        group: builtins.str = ...,
        kind: builtins.str = ...,
        name: builtins.str = ...,
        retry_after_seconds: builtins.int = ...,
        uid: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["causes", b"causes", "group", b"group", "kind", b"kind", "name", b"name", "resource_info", b"resource_info", "retry_after_seconds", b"retry_after_seconds", "uid", b"uid"]) -> None: ...

global___StatusDetails = StatusDetails

@typing_extensions.final
class Time(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> None: ...

global___Time = Time

@typing_extensions.final
class WatchEvent(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OBJECT_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def object(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.runtime_pb2.RawExtension: ...
    type: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        object: kubernetes.kubernetes_io.k8s.apimachinery.pkg.runtime_pb2.RawExtension | None = ...,
        type: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["object", b"object", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["object", b"object", "resource_info", b"resource_info", "type", b"type"]) -> None: ...

global___WatchEvent = WatchEvent
