"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Microsoft_Sql_Databases(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERVERS_DATABASES_FIELD_NUMBER: builtins.int
    SERVERS_DATABASES_AUDITING_SETTINGS_FIELD_NUMBER: builtins.int
    SERVERS_DATABASES_BACKUP_LONG_TERM_RETENTION_POLICIES_FIELD_NUMBER: builtins.int
    SERVERS_DATABASES_BACKUP_SHORT_TERM_RETENTION_POLICIES_FIELD_NUMBER: builtins.int
    SERVERS_DATABASES_EXTENDED_AUDITING_SETTINGS_FIELD_NUMBER: builtins.int
    SERVERS_DATABASES_EXTENSIONS_FIELD_NUMBER: builtins.int
    SERVERS_DATABASES_SECURITY_ALERT_POLICIES_FIELD_NUMBER: builtins.int
    SERVERS_DATABASES_SYNC_GROUPS_FIELD_NUMBER: builtins.int
    SERVERS_DATABASES_SYNC_GROUPS_SYNC_MEMBERS_FIELD_NUMBER: builtins.int
    SERVERS_DATABASES_TRANSPARENT_DATA_ENCRYPTION_FIELD_NUMBER: builtins.int
    SERVERS_DATABASES_VULNERABILITY_ASSESSMENTS_FIELD_NUMBER: builtins.int
    SERVERS_DATABASES_VULNERABILITY_ASSESSMENTS_RULES_BASELINES_FIELD_NUMBER: builtins.int
    SERVERS_DATABASES_CONNECTION_POLICIES_FIELD_NUMBER: builtins.int
    SERVERS_DATABASES_DATA_MASKING_POLICIES_FIELD_NUMBER: builtins.int
    SERVERS_DATABASES_GEO_BACKUP_POLICIES_FIELD_NUMBER: builtins.int
    @property
    def servers_databases(self) -> global___ServersDatabases: ...
    @property
    def servers_databases_auditing_settings(self) -> global___ServersDatabasesAuditingSettings: ...
    @property
    def servers_databases_backup_long_term_retention_policies(self) -> global___ServersDatabasesBackupLongTermRetentionPolicies: ...
    @property
    def servers_databases_backup_short_term_retention_policies(self) -> global___ServersDatabasesBackupShortTermRetentionPolicies: ...
    @property
    def servers_databases_extended_auditing_settings(self) -> global___ServersDatabasesExtendedAuditingSettings: ...
    @property
    def servers_databases_extensions(self) -> global___ServersDatabasesExtensions: ...
    @property
    def servers_databases_security_alert_policies(self) -> global___ServersDatabasesSecurityAlertPolicies: ...
    @property
    def servers_databases_sync_groups(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServersDatabasesSyncGroups]: ...
    @property
    def servers_databases_sync_groups_sync_members(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServersDatabasesSyncGroupsSyncMembers]: ...
    @property
    def servers_databases_transparent_data_encryption(self) -> global___ServersDatabasesTransparentDataEncryption: ...
    @property
    def servers_databases_vulnerability_assessments(self) -> global___ServersDatabasesVulnerabilityAssessments: ...
    @property
    def servers_databases_vulnerability_assessments_rules_baselines(self) -> global___ServersDatabasesVulnerabilityAssessmentsRulesBaselines: ...
    @property
    def servers_databases_connection_policies(self) -> global___ServersDatabasesConnectionPolicies: ...
    @property
    def servers_databases_data_masking_policies(self) -> global___ServersDatabasesDataMaskingPolicies: ...
    @property
    def servers_databases_geo_backup_policies(self) -> global___ServersDatabasesGeoBackupPolicies: ...
    def __init__(
        self,
        *,
        servers_databases: global___ServersDatabases | None = ...,
        servers_databases_auditing_settings: global___ServersDatabasesAuditingSettings | None = ...,
        servers_databases_backup_long_term_retention_policies: global___ServersDatabasesBackupLongTermRetentionPolicies | None = ...,
        servers_databases_backup_short_term_retention_policies: global___ServersDatabasesBackupShortTermRetentionPolicies | None = ...,
        servers_databases_extended_auditing_settings: global___ServersDatabasesExtendedAuditingSettings | None = ...,
        servers_databases_extensions: global___ServersDatabasesExtensions | None = ...,
        servers_databases_security_alert_policies: global___ServersDatabasesSecurityAlertPolicies | None = ...,
        servers_databases_sync_groups: collections.abc.Iterable[global___ServersDatabasesSyncGroups] | None = ...,
        servers_databases_sync_groups_sync_members: collections.abc.Iterable[global___ServersDatabasesSyncGroupsSyncMembers] | None = ...,
        servers_databases_transparent_data_encryption: global___ServersDatabasesTransparentDataEncryption | None = ...,
        servers_databases_vulnerability_assessments: global___ServersDatabasesVulnerabilityAssessments | None = ...,
        servers_databases_vulnerability_assessments_rules_baselines: global___ServersDatabasesVulnerabilityAssessmentsRulesBaselines | None = ...,
        servers_databases_connection_policies: global___ServersDatabasesConnectionPolicies | None = ...,
        servers_databases_data_masking_policies: global___ServersDatabasesDataMaskingPolicies | None = ...,
        servers_databases_geo_backup_policies: global___ServersDatabasesGeoBackupPolicies | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["servers_databases", b"servers_databases", "servers_databases_auditing_settings", b"servers_databases_auditing_settings", "servers_databases_backup_long_term_retention_policies", b"servers_databases_backup_long_term_retention_policies", "servers_databases_backup_short_term_retention_policies", b"servers_databases_backup_short_term_retention_policies", "servers_databases_connection_policies", b"servers_databases_connection_policies", "servers_databases_data_masking_policies", b"servers_databases_data_masking_policies", "servers_databases_extended_auditing_settings", b"servers_databases_extended_auditing_settings", "servers_databases_extensions", b"servers_databases_extensions", "servers_databases_geo_backup_policies", b"servers_databases_geo_backup_policies", "servers_databases_security_alert_policies", b"servers_databases_security_alert_policies", "servers_databases_transparent_data_encryption", b"servers_databases_transparent_data_encryption", "servers_databases_vulnerability_assessments", b"servers_databases_vulnerability_assessments", "servers_databases_vulnerability_assessments_rules_baselines", b"servers_databases_vulnerability_assessments_rules_baselines"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["servers_databases", b"servers_databases", "servers_databases_auditing_settings", b"servers_databases_auditing_settings", "servers_databases_backup_long_term_retention_policies", b"servers_databases_backup_long_term_retention_policies", "servers_databases_backup_short_term_retention_policies", b"servers_databases_backup_short_term_retention_policies", "servers_databases_connection_policies", b"servers_databases_connection_policies", "servers_databases_data_masking_policies", b"servers_databases_data_masking_policies", "servers_databases_extended_auditing_settings", b"servers_databases_extended_auditing_settings", "servers_databases_extensions", b"servers_databases_extensions", "servers_databases_geo_backup_policies", b"servers_databases_geo_backup_policies", "servers_databases_security_alert_policies", b"servers_databases_security_alert_policies", "servers_databases_sync_groups", b"servers_databases_sync_groups", "servers_databases_sync_groups_sync_members", b"servers_databases_sync_groups_sync_members", "servers_databases_transparent_data_encryption", b"servers_databases_transparent_data_encryption", "servers_databases_vulnerability_assessments", b"servers_databases_vulnerability_assessments", "servers_databases_vulnerability_assessments_rules_baselines", b"servers_databases_vulnerability_assessments_rules_baselines"]) -> None: ...

global___Microsoft_Sql_Databases = Microsoft_Sql_Databases

@typing_extensions.final
class ServersDatabasesGeoBackupPolicies(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    STORAGE_TYPE_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    id: builtins.str
    kind: builtins.str
    location: builtins.str
    name: builtins.str
    state: builtins.str
    storage_type: builtins.str
    type: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        id: builtins.str = ...,
        kind: builtins.str = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        state: builtins.str = ...,
        storage_type: builtins.str = ...,
        type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "kind", b"kind", "location", b"location", "name", b"name", "resource_info", b"resource_info", "state", b"state", "storage_type", b"storage_type", "type", b"type"]) -> None: ...

global___ServersDatabasesGeoBackupPolicies = ServersDatabasesGeoBackupPolicies

@typing_extensions.final
class ServersDatabasesDataMaskingPolicies(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    DATA_MASKING_STATE_FIELD_NUMBER: builtins.int
    APPLICATION_PRINCIPALS_FIELD_NUMBER: builtins.int
    EXEMPT_PRINCIPALS_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    id: builtins.str
    name: builtins.str
    kind: builtins.str
    data_masking_state: builtins.str
    application_principals: builtins.str
    exempt_principals: builtins.str
    type: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        kind: builtins.str = ...,
        data_masking_state: builtins.str = ...,
        application_principals: builtins.str = ...,
        exempt_principals: builtins.str = ...,
        type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["application_principals", b"application_principals", "data_masking_state", b"data_masking_state", "exempt_principals", b"exempt_principals", "id", b"id", "kind", b"kind", "name", b"name", "resource_info", b"resource_info", "type", b"type"]) -> None: ...

global___ServersDatabasesDataMaskingPolicies = ServersDatabasesDataMaskingPolicies

@typing_extensions.final
class ServersDatabasesConnectionPolicies(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    CONNECTION_TYPE_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    id: builtins.str
    name: builtins.str
    connection_type: builtins.str
    kind: builtins.str
    location: builtins.str
    type: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        connection_type: builtins.str = ...,
        kind: builtins.str = ...,
        location: builtins.str = ...,
        type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["connection_type", b"connection_type", "id", b"id", "kind", b"kind", "location", b"location", "name", b"name", "resource_info", b"resource_info", "type", b"type"]) -> None: ...

global___ServersDatabasesConnectionPolicies = ServersDatabasesConnectionPolicies

@typing_extensions.final
class ServersDatabasesWorkloadGroupsWorkloadClassifiers(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    CONTEXT_FIELD_NUMBER: builtins.int
    END_TIME_FIELD_NUMBER: builtins.int
    IMPORTANCE_FIELD_NUMBER: builtins.int
    LABEL_FIELD_NUMBER: builtins.int
    MEMBER_NAME_FIELD_NUMBER: builtins.int
    START_TIME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    context: builtins.str
    end_time: builtins.str
    importance: builtins.str
    label: builtins.str
    member_name: builtins.str
    start_time: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        context: builtins.str = ...,
        end_time: builtins.str = ...,
        importance: builtins.str = ...,
        label: builtins.str = ...,
        member_name: builtins.str = ...,
        start_time: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["context", b"context", "end_time", b"end_time", "importance", b"importance", "label", b"label", "member_name", b"member_name", "name", b"name", "resource_info", b"resource_info", "start_time", b"start_time"]) -> None: ...

global___ServersDatabasesWorkloadGroupsWorkloadClassifiers = ServersDatabasesWorkloadGroupsWorkloadClassifiers

@typing_extensions.final
class ServersDatabasesWorkloadGroups(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    IMPORTANCE_FIELD_NUMBER: builtins.int
    MAX_RESOURCE_PERCENT_FIELD_NUMBER: builtins.int
    MAX_RESOURCE_PERCENT_PER_REQUEST_FIELD_NUMBER: builtins.int
    MIN_RESOURCE_PERCENT_FIELD_NUMBER: builtins.int
    MIN_RESOURCE_PERCENT_PER_REQUEST_FIELD_NUMBER: builtins.int
    QUERY_EXECUTION_TIMEOUT_FIELD_NUMBER: builtins.int
    SERVERS_DATABASES_WORKLOAD_GROUPS_WORKLOAD_CLASSIFIERS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    importance: builtins.str
    max_resource_percent: builtins.int
    max_resource_percent_per_request: builtins.float
    min_resource_percent: builtins.int
    min_resource_percent_per_request: builtins.float
    query_execution_timeout: builtins.int
    @property
    def servers_databases_workload_groups_workload_classifiers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServersDatabasesWorkloadGroupsWorkloadClassifiers]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        importance: builtins.str = ...,
        max_resource_percent: builtins.int = ...,
        max_resource_percent_per_request: builtins.float = ...,
        min_resource_percent: builtins.int = ...,
        min_resource_percent_per_request: builtins.float = ...,
        query_execution_timeout: builtins.int = ...,
        servers_databases_workload_groups_workload_classifiers: collections.abc.Iterable[global___ServersDatabasesWorkloadGroupsWorkloadClassifiers] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["importance", b"importance", "max_resource_percent", b"max_resource_percent", "max_resource_percent_per_request", b"max_resource_percent_per_request", "min_resource_percent", b"min_resource_percent", "min_resource_percent_per_request", b"min_resource_percent_per_request", "name", b"name", "query_execution_timeout", b"query_execution_timeout", "resource_info", b"resource_info", "servers_databases_workload_groups_workload_classifiers", b"servers_databases_workload_groups_workload_classifiers"]) -> None: ...

global___ServersDatabasesWorkloadGroups = ServersDatabasesWorkloadGroups

@typing_extensions.final
class ServersDatabasesVulnerabilityAssessmentsRulesBaselines(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    BASELINE_RESULTS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def baseline_results(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DatabaseVulnerabilityAssessmentRuleBaselineItem]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        baseline_results: collections.abc.Iterable[global___DatabaseVulnerabilityAssessmentRuleBaselineItem] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["baseline_results", b"baseline_results", "name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___ServersDatabasesVulnerabilityAssessmentsRulesBaselines = ServersDatabasesVulnerabilityAssessmentsRulesBaselines

@typing_extensions.final
class DatabaseVulnerabilityAssessmentRuleBaselineItem(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESULT_FIELD_NUMBER: builtins.int
    @property
    def result(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        result: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["result", b"result"]) -> None: ...

global___DatabaseVulnerabilityAssessmentRuleBaselineItem = DatabaseVulnerabilityAssessmentRuleBaselineItem

@typing_extensions.final
class ServersDatabasesVulnerabilityAssessments(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    RECURRING_SCANS_FIELD_NUMBER: builtins.int
    STORAGE_ACCOUNT_ACCESS_KEY_FIELD_NUMBER: builtins.int
    STORAGE_CONTAINER_PATH_FIELD_NUMBER: builtins.int
    STORAGE_CONTAINER_SAS_KEY_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    EMAILS_FIELD_NUMBER: builtins.int
    EMAIL_SUBSCRIPTION_ADMINS_FIELD_NUMBER: builtins.int
    IS_ENABLED_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def recurring_scans(self) -> global___VulnerabilityAssessmentRecurringScansProperties: ...
    storage_account_access_key: builtins.str
    storage_container_path: builtins.str
    storage_container_sas_key: builtins.str
    id: builtins.str
    type: builtins.str
    emails: builtins.str
    email_subscription_admins: builtins.str
    is_enabled: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        recurring_scans: global___VulnerabilityAssessmentRecurringScansProperties | None = ...,
        storage_account_access_key: builtins.str = ...,
        storage_container_path: builtins.str = ...,
        storage_container_sas_key: builtins.str = ...,
        id: builtins.str = ...,
        type: builtins.str = ...,
        emails: builtins.str = ...,
        email_subscription_admins: builtins.str = ...,
        is_enabled: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["recurring_scans", b"recurring_scans", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["email_subscription_admins", b"email_subscription_admins", "emails", b"emails", "id", b"id", "is_enabled", b"is_enabled", "name", b"name", "recurring_scans", b"recurring_scans", "resource_info", b"resource_info", "storage_account_access_key", b"storage_account_access_key", "storage_container_path", b"storage_container_path", "storage_container_sas_key", b"storage_container_sas_key", "type", b"type"]) -> None: ...

global___ServersDatabasesVulnerabilityAssessments = ServersDatabasesVulnerabilityAssessments

@typing_extensions.final
class VulnerabilityAssessmentRecurringScansProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMAILS_FIELD_NUMBER: builtins.int
    EMAIL_SUBSCRIPTION_ADMINS_FIELD_NUMBER: builtins.int
    IS_ENABLED_FIELD_NUMBER: builtins.int
    @property
    def emails(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    email_subscription_admins: builtins.bool
    is_enabled: builtins.bool
    def __init__(
        self,
        *,
        emails: collections.abc.Iterable[builtins.str] | None = ...,
        email_subscription_admins: builtins.bool = ...,
        is_enabled: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["email_subscription_admins", b"email_subscription_admins", "emails", b"emails", "is_enabled", b"is_enabled"]) -> None: ...

global___VulnerabilityAssessmentRecurringScansProperties = VulnerabilityAssessmentRecurringScansProperties

@typing_extensions.final
class ServersDatabasesTransparentDataEncryption(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    state: builtins.str
    id: builtins.str
    type: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        state: builtins.str = ...,
        id: builtins.str = ...,
        type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "name", b"name", "resource_info", b"resource_info", "state", b"state", "type", b"type"]) -> None: ...

global___ServersDatabasesTransparentDataEncryption = ServersDatabasesTransparentDataEncryption

@typing_extensions.final
class ServersDatabasesSyncGroupsSyncMembers(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DATABASE_NAME_FIELD_NUMBER: builtins.int
    DATABASE_TYPE_FIELD_NUMBER: builtins.int
    PASSWORD_FIELD_NUMBER: builtins.int
    SERVER_NAME_FIELD_NUMBER: builtins.int
    SQL_SERVER_DATABASE_ID_FIELD_NUMBER: builtins.int
    SYNC_AGENT_ID_FIELD_NUMBER: builtins.int
    SYNC_DIRECTION_FIELD_NUMBER: builtins.int
    SYNC_MEMBER_AZURE_DATABASE_RESOURCE_ID_FIELD_NUMBER: builtins.int
    USE_PRIVATE_LINK_CONNECTION_FIELD_NUMBER: builtins.int
    USER_NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    database_name: builtins.str
    database_type: builtins.str
    password: builtins.str
    server_name: builtins.str
    sql_server_database_id: builtins.str
    sync_agent_id: builtins.str
    sync_direction: builtins.str
    sync_member_azure_database_resource_id: builtins.str
    use_private_link_connection: builtins.bool
    user_name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        database_name: builtins.str = ...,
        database_type: builtins.str = ...,
        password: builtins.str = ...,
        server_name: builtins.str = ...,
        sql_server_database_id: builtins.str = ...,
        sync_agent_id: builtins.str = ...,
        sync_direction: builtins.str = ...,
        sync_member_azure_database_resource_id: builtins.str = ...,
        use_private_link_connection: builtins.bool = ...,
        user_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["database_name", b"database_name", "database_type", b"database_type", "name", b"name", "password", b"password", "resource_info", b"resource_info", "server_name", b"server_name", "sql_server_database_id", b"sql_server_database_id", "sync_agent_id", b"sync_agent_id", "sync_direction", b"sync_direction", "sync_member_azure_database_resource_id", b"sync_member_azure_database_resource_id", "use_private_link_connection", b"use_private_link_connection", "user_name", b"user_name"]) -> None: ...

global___ServersDatabasesSyncGroupsSyncMembers = ServersDatabasesSyncGroupsSyncMembers

@typing_extensions.final
class ServersDatabasesSyncGroups(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    CONFLICT_LOGGING_RETENTION_IN_DAYS_FIELD_NUMBER: builtins.int
    CONFLICT_RESOLUTION_POLICY_FIELD_NUMBER: builtins.int
    ENABLE_CONFLICT_LOGGING_FIELD_NUMBER: builtins.int
    HUB_DATABASE_PASSWORD_FIELD_NUMBER: builtins.int
    HUB_DATABASE_USER_NAME_FIELD_NUMBER: builtins.int
    INTERVAL_FIELD_NUMBER: builtins.int
    SCHEMA_FIELD_NUMBER: builtins.int
    SYNC_DATABASE_ID_FIELD_NUMBER: builtins.int
    USE_PRIVATE_LINK_CONNECTION_FIELD_NUMBER: builtins.int
    SKU_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    conflict_logging_retention_in_days: builtins.int
    conflict_resolution_policy: builtins.str
    enable_conflict_logging: builtins.bool
    hub_database_password: builtins.str
    hub_database_user_name: builtins.str
    interval: builtins.int
    @property
    def schema(self) -> global___SyncGroupSchema: ...
    sync_database_id: builtins.str
    use_private_link_connection: builtins.bool
    @property
    def sku(self) -> global___Sku: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        conflict_logging_retention_in_days: builtins.int = ...,
        conflict_resolution_policy: builtins.str = ...,
        enable_conflict_logging: builtins.bool = ...,
        hub_database_password: builtins.str = ...,
        hub_database_user_name: builtins.str = ...,
        interval: builtins.int = ...,
        schema: global___SyncGroupSchema | None = ...,
        sync_database_id: builtins.str = ...,
        use_private_link_connection: builtins.bool = ...,
        sku: global___Sku | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "schema", b"schema", "sku", b"sku"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["conflict_logging_retention_in_days", b"conflict_logging_retention_in_days", "conflict_resolution_policy", b"conflict_resolution_policy", "enable_conflict_logging", b"enable_conflict_logging", "hub_database_password", b"hub_database_password", "hub_database_user_name", b"hub_database_user_name", "interval", b"interval", "name", b"name", "resource_info", b"resource_info", "schema", b"schema", "sku", b"sku", "sync_database_id", b"sync_database_id", "use_private_link_connection", b"use_private_link_connection"]) -> None: ...

global___ServersDatabasesSyncGroups = ServersDatabasesSyncGroups

@typing_extensions.final
class SyncGroupSchema(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MASTER_SYNC_MEMBER_NAME_FIELD_NUMBER: builtins.int
    TABLES_FIELD_NUMBER: builtins.int
    master_sync_member_name: builtins.str
    @property
    def tables(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SyncGroupSchemaTable]: ...
    def __init__(
        self,
        *,
        master_sync_member_name: builtins.str = ...,
        tables: collections.abc.Iterable[global___SyncGroupSchemaTable] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["master_sync_member_name", b"master_sync_member_name", "tables", b"tables"]) -> None: ...

global___SyncGroupSchema = SyncGroupSchema

@typing_extensions.final
class SyncGroupSchemaTable(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COLUMNS_FIELD_NUMBER: builtins.int
    QUOTED_NAME_FIELD_NUMBER: builtins.int
    @property
    def columns(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SyncGroupSchemaTableColumn]: ...
    quoted_name: builtins.str
    def __init__(
        self,
        *,
        columns: collections.abc.Iterable[global___SyncGroupSchemaTableColumn] | None = ...,
        quoted_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["columns", b"columns", "quoted_name", b"quoted_name"]) -> None: ...

global___SyncGroupSchemaTable = SyncGroupSchemaTable

@typing_extensions.final
class SyncGroupSchemaTableColumn(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATA_SIZE_FIELD_NUMBER: builtins.int
    DATA_TYPE_FIELD_NUMBER: builtins.int
    QUOTED_NAME_FIELD_NUMBER: builtins.int
    data_size: builtins.str
    data_type: builtins.str
    quoted_name: builtins.str
    def __init__(
        self,
        *,
        data_size: builtins.str = ...,
        data_type: builtins.str = ...,
        quoted_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["data_size", b"data_size", "data_type", b"data_type", "quoted_name", b"quoted_name"]) -> None: ...

global___SyncGroupSchemaTableColumn = SyncGroupSchemaTableColumn

@typing_extensions.final
class ServersDatabasesSecurityAlertPolicies(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DISABLED_ALERTS_FIELD_NUMBER: builtins.int
    EMAIL_ACCOUNT_ADMINS_FIELD_NUMBER: builtins.int
    EMAIL_ADDRESSES_FIELD_NUMBER: builtins.int
    RETENTION_DAYS_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    STORAGE_ACCOUNT_ACCESS_KEY_FIELD_NUMBER: builtins.int
    STORAGE_ENDPOINT_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def disabled_alerts(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    email_account_admins: builtins.bool
    @property
    def email_addresses(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    retention_days: builtins.int
    state: builtins.str
    storage_account_access_key: builtins.str
    storage_endpoint: builtins.str
    id: builtins.str
    type: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        disabled_alerts: collections.abc.Iterable[builtins.str] | None = ...,
        email_account_admins: builtins.bool = ...,
        email_addresses: collections.abc.Iterable[builtins.str] | None = ...,
        retention_days: builtins.int = ...,
        state: builtins.str = ...,
        storage_account_access_key: builtins.str = ...,
        storage_endpoint: builtins.str = ...,
        id: builtins.str = ...,
        type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["disabled_alerts", b"disabled_alerts", "email_account_admins", b"email_account_admins", "email_addresses", b"email_addresses", "id", b"id", "name", b"name", "resource_info", b"resource_info", "retention_days", b"retention_days", "state", b"state", "storage_account_access_key", b"storage_account_access_key", "storage_endpoint", b"storage_endpoint", "type", b"type"]) -> None: ...

global___ServersDatabasesSecurityAlertPolicies = ServersDatabasesSecurityAlertPolicies

@typing_extensions.final
class ServersDatabasesSchemasTablesColumnsSensitivityLabels(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    INFORMATION_TYPE_FIELD_NUMBER: builtins.int
    INFORMATION_TYPE_ID_FIELD_NUMBER: builtins.int
    LABEL_ID_FIELD_NUMBER: builtins.int
    LABEL_NAME_FIELD_NUMBER: builtins.int
    RANK_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    information_type: builtins.str
    information_type_id: builtins.str
    label_id: builtins.str
    label_name: builtins.str
    rank: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        information_type: builtins.str = ...,
        information_type_id: builtins.str = ...,
        label_id: builtins.str = ...,
        label_name: builtins.str = ...,
        rank: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["information_type", b"information_type", "information_type_id", b"information_type_id", "label_id", b"label_id", "label_name", b"label_name", "name", b"name", "rank", b"rank", "resource_info", b"resource_info"]) -> None: ...

global___ServersDatabasesSchemasTablesColumnsSensitivityLabels = ServersDatabasesSchemasTablesColumnsSensitivityLabels

@typing_extensions.final
class ServersDatabasesMaintenanceWindows(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    TIME_RANGES_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def time_ranges(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MaintenanceWindowTimeRange]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        time_ranges: collections.abc.Iterable[global___MaintenanceWindowTimeRange] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info", "time_ranges", b"time_ranges"]) -> None: ...

global___ServersDatabasesMaintenanceWindows = ServersDatabasesMaintenanceWindows

@typing_extensions.final
class MaintenanceWindowTimeRange(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DAY_OF_WEEK_FIELD_NUMBER: builtins.int
    DURATION_FIELD_NUMBER: builtins.int
    START_TIME_FIELD_NUMBER: builtins.int
    day_of_week: builtins.str
    duration: builtins.str
    start_time: builtins.str
    def __init__(
        self,
        *,
        day_of_week: builtins.str = ...,
        duration: builtins.str = ...,
        start_time: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["day_of_week", b"day_of_week", "duration", b"duration", "start_time", b"start_time"]) -> None: ...

global___MaintenanceWindowTimeRange = MaintenanceWindowTimeRange

@typing_extensions.final
class ServersDatabasesLedgerDigestUploads(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DIGEST_STORAGE_ENDPOINT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    digest_storage_endpoint: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        digest_storage_endpoint: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["digest_storage_endpoint", b"digest_storage_endpoint", "name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___ServersDatabasesLedgerDigestUploads = ServersDatabasesLedgerDigestUploads

@typing_extensions.final
class ServersDatabasesExtensions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ADMINISTRATOR_LOGIN_FIELD_NUMBER: builtins.int
    ADMINISTRATOR_LOGIN_PASSWORD_FIELD_NUMBER: builtins.int
    AUTHENTICATION_TYPE_FIELD_NUMBER: builtins.int
    DATABASE_EDITION_FIELD_NUMBER: builtins.int
    MAX_SIZE_BYTES_FIELD_NUMBER: builtins.int
    NETWORK_ISOLATION_FIELD_NUMBER: builtins.int
    OPERATION_MODE_FIELD_NUMBER: builtins.int
    SERVICE_OBJECTIVE_NAME_FIELD_NUMBER: builtins.int
    STORAGE_KEY_FIELD_NUMBER: builtins.int
    STORAGE_KEY_TYPE_FIELD_NUMBER: builtins.int
    STORAGE_URI_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    administrator_login: builtins.str
    administrator_login_password: builtins.str
    authentication_type: builtins.str
    database_edition: builtins.str
    max_size_bytes: builtins.str
    @property
    def network_isolation(self) -> global___NetworkIsolationSettings: ...
    operation_mode: builtins.str
    service_objective_name: builtins.str
    storage_key: builtins.str
    storage_key_type: builtins.str
    storage_uri: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        administrator_login: builtins.str = ...,
        administrator_login_password: builtins.str = ...,
        authentication_type: builtins.str = ...,
        database_edition: builtins.str = ...,
        max_size_bytes: builtins.str = ...,
        network_isolation: global___NetworkIsolationSettings | None = ...,
        operation_mode: builtins.str = ...,
        service_objective_name: builtins.str = ...,
        storage_key: builtins.str = ...,
        storage_key_type: builtins.str = ...,
        storage_uri: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["network_isolation", b"network_isolation", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["administrator_login", b"administrator_login", "administrator_login_password", b"administrator_login_password", "authentication_type", b"authentication_type", "database_edition", b"database_edition", "max_size_bytes", b"max_size_bytes", "name", b"name", "network_isolation", b"network_isolation", "operation_mode", b"operation_mode", "resource_info", b"resource_info", "service_objective_name", b"service_objective_name", "storage_key", b"storage_key", "storage_key_type", b"storage_key_type", "storage_uri", b"storage_uri"]) -> None: ...

global___ServersDatabasesExtensions = ServersDatabasesExtensions

@typing_extensions.final
class NetworkIsolationSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SQL_SERVER_RESOURCE_ID_FIELD_NUMBER: builtins.int
    STORAGE_ACCOUNT_RESOURCE_ID_FIELD_NUMBER: builtins.int
    sql_server_resource_id: builtins.str
    storage_account_resource_id: builtins.str
    def __init__(
        self,
        *,
        sql_server_resource_id: builtins.str = ...,
        storage_account_resource_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["sql_server_resource_id", b"sql_server_resource_id", "storage_account_resource_id", b"storage_account_resource_id"]) -> None: ...

global___NetworkIsolationSettings = NetworkIsolationSettings

@typing_extensions.final
class ServersDatabasesExtendedAuditingSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    AUDIT_ACTIONS_AND_GROUPS_FIELD_NUMBER: builtins.int
    IS_AZURE_MONITOR_TARGET_ENABLED_FIELD_NUMBER: builtins.int
    IS_STORAGE_SECONDARY_KEY_IN_USE_FIELD_NUMBER: builtins.int
    PREDICATE_EXPRESSION_FIELD_NUMBER: builtins.int
    QUEUE_DELAY_MS_FIELD_NUMBER: builtins.int
    RETENTION_DAYS_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    STORAGE_ACCOUNT_ACCESS_KEY_FIELD_NUMBER: builtins.int
    STORAGE_ACCOUNT_SUBSCRIPTION_ID_FIELD_NUMBER: builtins.int
    STORAGE_ENDPOINT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def audit_actions_and_groups(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    is_azure_monitor_target_enabled: builtins.bool
    is_storage_secondary_key_in_use: builtins.bool
    predicate_expression: builtins.str
    queue_delay_ms: builtins.int
    retention_days: builtins.int
    state: builtins.str
    storage_account_access_key: builtins.str
    storage_account_subscription_id: builtins.str
    storage_endpoint: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        audit_actions_and_groups: collections.abc.Iterable[builtins.str] | None = ...,
        is_azure_monitor_target_enabled: builtins.bool = ...,
        is_storage_secondary_key_in_use: builtins.bool = ...,
        predicate_expression: builtins.str = ...,
        queue_delay_ms: builtins.int = ...,
        retention_days: builtins.int = ...,
        state: builtins.str = ...,
        storage_account_access_key: builtins.str = ...,
        storage_account_subscription_id: builtins.str = ...,
        storage_endpoint: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["audit_actions_and_groups", b"audit_actions_and_groups", "is_azure_monitor_target_enabled", b"is_azure_monitor_target_enabled", "is_storage_secondary_key_in_use", b"is_storage_secondary_key_in_use", "name", b"name", "predicate_expression", b"predicate_expression", "queue_delay_ms", b"queue_delay_ms", "resource_info", b"resource_info", "retention_days", b"retention_days", "state", b"state", "storage_account_access_key", b"storage_account_access_key", "storage_account_subscription_id", b"storage_account_subscription_id", "storage_endpoint", b"storage_endpoint"]) -> None: ...

global___ServersDatabasesExtendedAuditingSettings = ServersDatabasesExtendedAuditingSettings

@typing_extensions.final
class ServersDatabasesBackupShortTermRetentionPolicies(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DIFF_BACKUP_INTERVAL_IN_HOURS_FIELD_NUMBER: builtins.int
    RETENTION_DAYS_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    diff_backup_interval_in_hours: builtins.int
    retention_days: builtins.int
    id: builtins.str
    type: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        diff_backup_interval_in_hours: builtins.int = ...,
        retention_days: builtins.int = ...,
        id: builtins.str = ...,
        type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["diff_backup_interval_in_hours", b"diff_backup_interval_in_hours", "id", b"id", "name", b"name", "resource_info", b"resource_info", "retention_days", b"retention_days", "type", b"type"]) -> None: ...

global___ServersDatabasesBackupShortTermRetentionPolicies = ServersDatabasesBackupShortTermRetentionPolicies

@typing_extensions.final
class ServersDatabasesBackupLongTermRetentionPolicies(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    MONTHLY_RETENTION_FIELD_NUMBER: builtins.int
    WEEKLY_RETENTION_FIELD_NUMBER: builtins.int
    WEEK_OF_YEAR_FIELD_NUMBER: builtins.int
    YEARLY_RETENTION_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    monthly_retention: builtins.str
    weekly_retention: builtins.str
    week_of_year: builtins.int
    yearly_retention: builtins.str
    id: builtins.str
    type: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        monthly_retention: builtins.str = ...,
        weekly_retention: builtins.str = ...,
        week_of_year: builtins.int = ...,
        yearly_retention: builtins.str = ...,
        id: builtins.str = ...,
        type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "monthly_retention", b"monthly_retention", "name", b"name", "resource_info", b"resource_info", "type", b"type", "week_of_year", b"week_of_year", "weekly_retention", b"weekly_retention", "yearly_retention", b"yearly_retention"]) -> None: ...

global___ServersDatabasesBackupLongTermRetentionPolicies = ServersDatabasesBackupLongTermRetentionPolicies

@typing_extensions.final
class ServersDatabasesAuditingSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    AUDIT_ACTIONS_AND_GROUPS_FIELD_NUMBER: builtins.int
    IS_AZURE_MONITOR_TARGET_ENABLED_FIELD_NUMBER: builtins.int
    IS_STORAGE_SECONDARY_KEY_IN_USE_FIELD_NUMBER: builtins.int
    QUEUE_DELAY_MS_FIELD_NUMBER: builtins.int
    RETENTION_DAYS_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    STORAGE_ACCOUNT_ACCESS_KEY_FIELD_NUMBER: builtins.int
    STORAGE_ACCOUNT_SUBSCRIPTION_ID_FIELD_NUMBER: builtins.int
    STORAGE_ENDPOINT_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    IS_MANAGED_IDENTITY_IN_USE_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def audit_actions_and_groups(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    is_azure_monitor_target_enabled: builtins.bool
    is_storage_secondary_key_in_use: builtins.bool
    queue_delay_ms: builtins.int
    retention_days: builtins.int
    state: builtins.str
    storage_account_access_key: builtins.str
    storage_account_subscription_id: builtins.str
    storage_endpoint: builtins.str
    kind: builtins.str
    is_managed_identity_in_use: builtins.str
    id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        audit_actions_and_groups: collections.abc.Iterable[builtins.str] | None = ...,
        is_azure_monitor_target_enabled: builtins.bool = ...,
        is_storage_secondary_key_in_use: builtins.bool = ...,
        queue_delay_ms: builtins.int = ...,
        retention_days: builtins.int = ...,
        state: builtins.str = ...,
        storage_account_access_key: builtins.str = ...,
        storage_account_subscription_id: builtins.str = ...,
        storage_endpoint: builtins.str = ...,
        kind: builtins.str = ...,
        is_managed_identity_in_use: builtins.str = ...,
        id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["audit_actions_and_groups", b"audit_actions_and_groups", "id", b"id", "is_azure_monitor_target_enabled", b"is_azure_monitor_target_enabled", "is_managed_identity_in_use", b"is_managed_identity_in_use", "is_storage_secondary_key_in_use", b"is_storage_secondary_key_in_use", "kind", b"kind", "name", b"name", "queue_delay_ms", b"queue_delay_ms", "resource_info", b"resource_info", "retention_days", b"retention_days", "state", b"state", "storage_account_access_key", b"storage_account_access_key", "storage_account_subscription_id", b"storage_account_subscription_id", "storage_endpoint", b"storage_endpoint"]) -> None: ...

global___ServersDatabasesAuditingSettings = ServersDatabasesAuditingSettings

@typing_extensions.final
class ServersDatabases(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    IDENTITY_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    AUTO_PAUSE_DELAY_FIELD_NUMBER: builtins.int
    CATALOG_COLLATION_FIELD_NUMBER: builtins.int
    COLLATION_FIELD_NUMBER: builtins.int
    CREATE_MODE_FIELD_NUMBER: builtins.int
    ELASTIC_POOL_ID_FIELD_NUMBER: builtins.int
    FEDERATED_CLIENT_ID_FIELD_NUMBER: builtins.int
    HIGH_AVAILABILITY_REPLICA_COUNT_FIELD_NUMBER: builtins.int
    IS_LEDGER_ON_FIELD_NUMBER: builtins.int
    LICENSE_TYPE_FIELD_NUMBER: builtins.int
    LONG_TERM_RETENTION_BACKUP_RESOURCE_ID_FIELD_NUMBER: builtins.int
    MAINTENANCE_CONFIGURATION_ID_FIELD_NUMBER: builtins.int
    MAX_SIZE_BYTES_FIELD_NUMBER: builtins.int
    MIN_CAPACITY_FIELD_NUMBER: builtins.int
    PRIMARY_DELEGATED_IDENTITY_CLIENT_ID_FIELD_NUMBER: builtins.int
    READ_SCALE_FIELD_NUMBER: builtins.int
    RECOVERABLE_DATABASE_ID_FIELD_NUMBER: builtins.int
    RECOVERY_SERVICES_RECOVERY_POINT_ID_FIELD_NUMBER: builtins.int
    REQUESTED_BACKUP_STORAGE_REDUNDANCY_FIELD_NUMBER: builtins.int
    RESTORABLE_DROPPED_DATABASE_ID_FIELD_NUMBER: builtins.int
    RESTORE_POINT_IN_TIME_FIELD_NUMBER: builtins.int
    SAMPLE_NAME_FIELD_NUMBER: builtins.int
    SECONDARY_TYPE_FIELD_NUMBER: builtins.int
    SOURCE_DATABASE_DELETION_DATE_FIELD_NUMBER: builtins.int
    SOURCE_DATABASE_ID_FIELD_NUMBER: builtins.int
    ZONE_REDUNDANT_FIELD_NUMBER: builtins.int
    SKU_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    SERVERS_DATABASES_LEDGER_DIGEST_UPLOADS_FIELD_NUMBER: builtins.int
    SERVERS_DATABASES_MAINTENANCE_WINDOWS_FIELD_NUMBER: builtins.int
    SERVERS_DATABASES_WORKLOAD_GROUPS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def identity(self) -> global___DatabaseIdentity: ...
    location: builtins.str
    name: builtins.str
    auto_pause_delay: builtins.int
    catalog_collation: builtins.str
    collation: builtins.str
    create_mode: builtins.str
    elastic_pool_id: builtins.str
    federated_client_id: builtins.str
    high_availability_replica_count: builtins.int
    is_ledger_on: builtins.bool
    license_type: builtins.str
    long_term_retention_backup_resource_id: builtins.str
    maintenance_configuration_id: builtins.str
    max_size_bytes: builtins.int
    min_capacity: builtins.float
    primary_delegated_identity_client_id: builtins.str
    read_scale: builtins.str
    recoverable_database_id: builtins.str
    recovery_services_recovery_point_id: builtins.str
    requested_backup_storage_redundancy: builtins.str
    restorable_dropped_database_id: builtins.str
    restore_point_in_time: builtins.str
    sample_name: builtins.str
    secondary_type: builtins.str
    source_database_deletion_date: builtins.str
    source_database_id: builtins.str
    zone_redundant: builtins.bool
    @property
    def sku(self) -> global___Sku: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def servers_databases_ledger_digest_uploads(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServersDatabasesLedgerDigestUploads]: ...
    @property
    def servers_databases_maintenance_windows(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServersDatabasesMaintenanceWindows]: ...
    @property
    def servers_databases_workload_groups(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServersDatabasesWorkloadGroups]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        identity: global___DatabaseIdentity | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        auto_pause_delay: builtins.int = ...,
        catalog_collation: builtins.str = ...,
        collation: builtins.str = ...,
        create_mode: builtins.str = ...,
        elastic_pool_id: builtins.str = ...,
        federated_client_id: builtins.str = ...,
        high_availability_replica_count: builtins.int = ...,
        is_ledger_on: builtins.bool = ...,
        license_type: builtins.str = ...,
        long_term_retention_backup_resource_id: builtins.str = ...,
        maintenance_configuration_id: builtins.str = ...,
        max_size_bytes: builtins.int = ...,
        min_capacity: builtins.float = ...,
        primary_delegated_identity_client_id: builtins.str = ...,
        read_scale: builtins.str = ...,
        recoverable_database_id: builtins.str = ...,
        recovery_services_recovery_point_id: builtins.str = ...,
        requested_backup_storage_redundancy: builtins.str = ...,
        restorable_dropped_database_id: builtins.str = ...,
        restore_point_in_time: builtins.str = ...,
        sample_name: builtins.str = ...,
        secondary_type: builtins.str = ...,
        source_database_deletion_date: builtins.str = ...,
        source_database_id: builtins.str = ...,
        zone_redundant: builtins.bool = ...,
        sku: global___Sku | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        servers_databases_ledger_digest_uploads: collections.abc.Iterable[global___ServersDatabasesLedgerDigestUploads] | None = ...,
        servers_databases_maintenance_windows: collections.abc.Iterable[global___ServersDatabasesMaintenanceWindows] | None = ...,
        servers_databases_workload_groups: collections.abc.Iterable[global___ServersDatabasesWorkloadGroups] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["identity", b"identity", "resource_info", b"resource_info", "sku", b"sku"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auto_pause_delay", b"auto_pause_delay", "catalog_collation", b"catalog_collation", "collation", b"collation", "create_mode", b"create_mode", "elastic_pool_id", b"elastic_pool_id", "federated_client_id", b"federated_client_id", "high_availability_replica_count", b"high_availability_replica_count", "identity", b"identity", "is_ledger_on", b"is_ledger_on", "license_type", b"license_type", "location", b"location", "long_term_retention_backup_resource_id", b"long_term_retention_backup_resource_id", "maintenance_configuration_id", b"maintenance_configuration_id", "max_size_bytes", b"max_size_bytes", "min_capacity", b"min_capacity", "name", b"name", "primary_delegated_identity_client_id", b"primary_delegated_identity_client_id", "read_scale", b"read_scale", "recoverable_database_id", b"recoverable_database_id", "recovery_services_recovery_point_id", b"recovery_services_recovery_point_id", "requested_backup_storage_redundancy", b"requested_backup_storage_redundancy", "resource_info", b"resource_info", "restorable_dropped_database_id", b"restorable_dropped_database_id", "restore_point_in_time", b"restore_point_in_time", "sample_name", b"sample_name", "secondary_type", b"secondary_type", "servers_databases_ledger_digest_uploads", b"servers_databases_ledger_digest_uploads", "servers_databases_maintenance_windows", b"servers_databases_maintenance_windows", "servers_databases_workload_groups", b"servers_databases_workload_groups", "sku", b"sku", "source_database_deletion_date", b"source_database_deletion_date", "source_database_id", b"source_database_id", "tags", b"tags", "zone_redundant", b"zone_redundant"]) -> None: ...

global___ServersDatabases = ServersDatabases

@typing_extensions.final
class Sku(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CAPACITY_FIELD_NUMBER: builtins.int
    FAMILY_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    SIZE_FIELD_NUMBER: builtins.int
    TIER_FIELD_NUMBER: builtins.int
    capacity: builtins.int
    family: builtins.str
    name: builtins.str
    size: builtins.str
    tier: builtins.str
    def __init__(
        self,
        *,
        capacity: builtins.int = ...,
        family: builtins.str = ...,
        name: builtins.str = ...,
        size: builtins.str = ...,
        tier: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["capacity", b"capacity", "family", b"family", "name", b"name", "size", b"size", "tier", b"tier"]) -> None: ...

global___Sku = Sku

@typing_extensions.final
class DatabaseIdentity(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class DelegatedResourcesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class UserAssignedIdentitiesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    DELEGATED_RESOURCES_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    USER_ASSIGNED_IDENTITIES_FIELD_NUMBER: builtins.int
    @property
    def delegated_resources(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    type: builtins.str
    @property
    def user_assigned_identities(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        delegated_resources: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        type: builtins.str = ...,
        user_assigned_identities: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["delegated_resources", b"delegated_resources", "type", b"type", "user_assigned_identities", b"user_assigned_identities"]) -> None: ...

global___DatabaseIdentity = DatabaseIdentity
