# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_compute_instance.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1egcp/gcp_compute_instance.proto\x12 oak9.tython.gcp.compute_instance\x1a\x13shared/shared.proto\"i\n\'ComputeInstanceXAdvancedMachineFeatures\x12$\n\x1c\x65nable_nested_virtualization\x18\x01 \x01(\x08\x12\x18\n\x10threads_per_core\x18\x02 \x01(\x01\"\xb1\x01\n\x1c\x43omputeInstanceXAttachedDisk\x12\x13\n\x0b\x64\x65vice_name\x18\x01 \x01(\t\x12\x1f\n\x17\x64isk_encryption_key_raw\x18\x02 \x01(\t\x12\"\n\x1a\x64isk_encryption_key_sha256\x18\x03 \x01(\t\x12\x19\n\x11kms_key_self_link\x18\x04 \x01(\t\x12\x0c\n\x04mode\x18\x05 \x01(\t\x12\x0e\n\x06source\x18\x06 \x01(\t\"\xee\x01\n)ComputeInstanceXBootDiskXInitializeParams\x12\r\n\x05image\x18\x01 \x01(\t\x12g\n\x06labels\x18\x02 \x03(\x0b\x32W.oak9.tython.gcp.compute_instance.ComputeInstanceXBootDiskXInitializeParams.LabelsEntry\x12\x0c\n\x04size\x18\x03 \x01(\x01\x12\x0c\n\x04type\x18\x04 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xaa\x02\n\x18\x43omputeInstanceXBootDisk\x12\x13\n\x0b\x61uto_delete\x18\x01 \x01(\x08\x12\x13\n\x0b\x64\x65vice_name\x18\x02 \x01(\t\x12\x1f\n\x17\x64isk_encryption_key_raw\x18\x03 \x01(\t\x12\"\n\x1a\x64isk_encryption_key_sha256\x18\x04 \x01(\t\x12\x19\n\x11kms_key_self_link\x18\x05 \x01(\t\x12\x0c\n\x04mode\x18\x06 \x01(\t\x12\x0e\n\x06source\x18\x07 \x01(\t\x12\x66\n\x11initialize_params\x18\x08 \x01(\x0b\x32K.oak9.tython.gcp.compute_instance.ComputeInstanceXBootDiskXInitializeParams\"Q\n*ComputeInstanceXConfidentialInstanceConfig\x12#\n\x1b\x65nable_confidential_compute\x18\x01 \x01(\x08\"u\n-ComputeInstanceXNetworkInterfaceXAccessConfig\x12\x0e\n\x06nat_ip\x18\x01 \x01(\t\x12\x14\n\x0cnetwork_tier\x18\x02 \x01(\t\x12\x1e\n\x16public_ptr_domain_name\x18\x03 \x01(\t\"e\n-ComputeInstanceXNetworkInterfaceXAliasIpRange\x12\x15\n\rip_cidr_range\x18\x01 \x01(\t\x12\x1d\n\x15subnetwork_range_name\x18\x02 \x01(\t\"\xa5\x01\n1ComputeInstanceXNetworkInterfaceXIpv6AccessConfig\x12\x15\n\rexternal_ipv6\x18\x01 \x01(\t\x12#\n\x1b\x65xternal_ipv6_prefix_length\x18\x02 \x01(\t\x12\x14\n\x0cnetwork_tier\x18\x03 \x01(\t\x12\x1e\n\x16public_ptr_domain_name\x18\x04 \x01(\t\"\x9c\x04\n ComputeInstanceXNetworkInterface\x12\x18\n\x10ipv6_access_type\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07network\x18\x03 \x01(\t\x12\x12\n\nnetwork_ip\x18\x04 \x01(\t\x12\x10\n\x08nic_type\x18\x05 \x01(\t\x12\x13\n\x0bqueue_count\x18\x06 \x01(\x01\x12\x12\n\nstack_type\x18\x07 \x01(\t\x12\x12\n\nsubnetwork\x18\x08 \x01(\t\x12\x1a\n\x12subnetwork_project\x18\t \x01(\t\x12\x66\n\raccess_config\x18\n \x03(\x0b\x32O.oak9.tython.gcp.compute_instance.ComputeInstanceXNetworkInterfaceXAccessConfig\x12g\n\x0e\x61lias_ip_range\x18\x0b \x03(\x0b\x32O.oak9.tython.gcp.compute_instance.ComputeInstanceXNetworkInterfaceXAliasIpRange\x12o\n\x12ipv6_access_config\x18\x0c \x03(\x0b\x32S.oak9.tython.gcp.compute_instance.ComputeInstanceXNetworkInterfaceXIpv6AccessConfig\"V\n7ComputeInstanceXReservationAffinityXSpecificReservation\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x0e\n\x06values\x18\x02 \x03(\t\"\xac\x01\n#ComputeInstanceXReservationAffinity\x12\x0c\n\x04type\x18\x01 \x01(\t\x12w\n\x14specific_reservation\x18\x02 \x01(\x0b\x32Y.oak9.tython.gcp.compute_instance.ComputeInstanceXReservationAffinityXSpecificReservation\"Z\n)ComputeInstanceXSchedulingXNodeAffinities\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x10\n\x08operator\x18\x02 \x01(\t\x12\x0e\n\x06values\x18\x03 \x03(\t\"\xa7\x02\n\x1a\x43omputeInstanceXScheduling\x12\x19\n\x11\x61utomatic_restart\x18\x01 \x01(\x08\x12#\n\x1binstance_termination_action\x18\x02 \x01(\t\x12\x15\n\rmin_node_cpus\x18\x03 \x01(\x01\x12\x1b\n\x13on_host_maintenance\x18\x04 \x01(\t\x12\x13\n\x0bpreemptible\x18\x05 \x01(\x08\x12\x1a\n\x12provisioning_model\x18\x06 \x01(\t\x12\x64\n\x0fnode_affinities\x18\x07 \x03(\x0b\x32K.oak9.tython.gcp.compute_instance.ComputeInstanceXSchedulingXNodeAffinities\"0\n\x1b\x43omputeInstanceXScratchDisk\x12\x11\n\tinterface\x18\x01 \x01(\t\"?\n\x1e\x43omputeInstanceXServiceAccount\x12\r\n\x05\x65mail\x18\x01 \x01(\t\x12\x0e\n\x06scopes\x18\x02 \x03(\t\"~\n&ComputeInstanceXShieldedInstanceConfig\x12#\n\x1b\x65nable_integrity_monitoring\x18\x01 \x01(\x08\x12\x1a\n\x12\x65nable_secure_boot\x18\x02 \x01(\x08\x12\x13\n\x0b\x65nable_vtpm\x18\x03 \x01(\x08\"J\n\x18\x43omputeInstanceXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xfc\x0f\n\x0f\x43omputeInstance\x12!\n\x19\x61llow_stopping_for_update\x18\x01 \x01(\x08\x12\x16\n\x0e\x63\x61n_ip_forward\x18\x02 \x01(\x08\x12\x14\n\x0c\x63pu_platform\x18\x03 \x01(\t\x12\x16\n\x0e\x63urrent_status\x18\x04 \x01(\t\x12\x1b\n\x13\x64\x65letion_protection\x18\x05 \x01(\x08\x12\x13\n\x0b\x64\x65scription\x18\x06 \x01(\t\x12\x16\n\x0e\x64\x65sired_status\x18\x07 \x01(\t\x12\x16\n\x0e\x65nable_display\x18\x08 \x01(\x08\x12\x62\n\x11guest_accelerator\x18\t \x03(\x0b\x32G.oak9.tython.gcp.compute_instance.ComputeInstance.GuestAcceleratorEntry\x12\x10\n\x08hostname\x18\n \x01(\t\x12\n\n\x02id\x18\x0b \x01(\t\x12\x13\n\x0binstance_id\x18\x0c \x01(\t\x12\x19\n\x11label_fingerprint\x18\r \x01(\t\x12M\n\x06labels\x18\x0e \x03(\x0b\x32=.oak9.tython.gcp.compute_instance.ComputeInstance.LabelsEntry\x12\x14\n\x0cmachine_type\x18\x0f \x01(\t\x12Q\n\x08metadata\x18\x10 \x03(\x0b\x32?.oak9.tython.gcp.compute_instance.ComputeInstance.MetadataEntry\x12\x1c\n\x14metadata_fingerprint\x18\x11 \x01(\t\x12\x1f\n\x17metadata_startup_script\x18\x12 \x01(\t\x12\x18\n\x10min_cpu_platform\x18\x13 \x01(\t\x12\x0c\n\x04name\x18\x14 \x01(\t\x12\x0f\n\x07project\x18\x15 \x01(\t\x12\x19\n\x11resource_policies\x18\x16 \x03(\t\x12\x11\n\tself_link\x18\x17 \x01(\t\x12\x0c\n\x04tags\x18\x18 \x03(\t\x12\x18\n\x10tags_fingerprint\x18\x19 \x01(\t\x12\x0c\n\x04zone\x18\x1a \x01(\t\x12l\n\x19\x61\x64vanced_machine_features\x18\x1b \x01(\x0b\x32I.oak9.tython.gcp.compute_instance.ComputeInstanceXAdvancedMachineFeatures\x12U\n\rattached_disk\x18\x1c \x03(\x0b\x32>.oak9.tython.gcp.compute_instance.ComputeInstanceXAttachedDisk\x12M\n\tboot_disk\x18\x1d \x01(\x0b\x32:.oak9.tython.gcp.compute_instance.ComputeInstanceXBootDisk\x12r\n\x1c\x63onfidential_instance_config\x18\x1e \x01(\x0b\x32L.oak9.tython.gcp.compute_instance.ComputeInstanceXConfidentialInstanceConfig\x12]\n\x11network_interface\x18\x1f \x03(\x0b\x32\x42.oak9.tython.gcp.compute_instance.ComputeInstanceXNetworkInterface\x12\x63\n\x14reservation_affinity\x18  \x01(\x0b\x32\x45.oak9.tython.gcp.compute_instance.ComputeInstanceXReservationAffinity\x12P\n\nscheduling\x18! \x01(\x0b\x32<.oak9.tython.gcp.compute_instance.ComputeInstanceXScheduling\x12S\n\x0cscratch_disk\x18\" \x03(\x0b\x32=.oak9.tython.gcp.compute_instance.ComputeInstanceXScratchDisk\x12Y\n\x0fservice_account\x18# \x01(\x0b\x32@.oak9.tython.gcp.compute_instance.ComputeInstanceXServiceAccount\x12j\n\x18shielded_instance_config\x18$ \x01(\x0b\x32H.oak9.tython.gcp.compute_instance.ComputeInstanceXShieldedInstanceConfig\x12L\n\x08timeouts\x18% \x01(\x0b\x32:.oak9.tython.gcp.compute_instance.ComputeInstanceXTimeouts\x12\x37\n\rresource_info\x18& \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a\x37\n\x15GuestAcceleratorEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"u\n3ComputeInstanceFromTemplateXAdvancedMachineFeatures\x12$\n\x1c\x65nable_nested_virtualization\x18\x01 \x01(\x08\x12\x18\n\x10threads_per_core\x18\x02 \x01(\x01\"\x86\x02\n5ComputeInstanceFromTemplateXBootDiskXInitializeParams\x12\r\n\x05image\x18\x01 \x01(\t\x12s\n\x06labels\x18\x02 \x03(\x0b\x32\x63.oak9.tython.gcp.compute_instance.ComputeInstanceFromTemplateXBootDiskXInitializeParams.LabelsEntry\x12\x0c\n\x04size\x18\x03 \x01(\x01\x12\x0c\n\x04type\x18\x04 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xc2\x02\n$ComputeInstanceFromTemplateXBootDisk\x12\x13\n\x0b\x61uto_delete\x18\x01 \x01(\x08\x12\x13\n\x0b\x64\x65vice_name\x18\x02 \x01(\t\x12\x1f\n\x17\x64isk_encryption_key_raw\x18\x03 \x01(\t\x12\"\n\x1a\x64isk_encryption_key_sha256\x18\x04 \x01(\t\x12\x19\n\x11kms_key_self_link\x18\x05 \x01(\t\x12\x0c\n\x04mode\x18\x06 \x01(\t\x12\x0e\n\x06source\x18\x07 \x01(\t\x12r\n\x11initialize_params\x18\x08 \x01(\x0b\x32W.oak9.tython.gcp.compute_instance.ComputeInstanceFromTemplateXBootDiskXInitializeParams\"]\n6ComputeInstanceFromTemplateXConfidentialInstanceConfig\x12#\n\x1b\x65nable_confidential_compute\x18\x01 \x01(\x08\"\xb1\x01\n=ComputeInstanceFromTemplateXNetworkInterfaceXIpv6AccessConfig\x12\x15\n\rexternal_ipv6\x18\x01 \x01(\t\x12#\n\x1b\x65xternal_ipv6_prefix_length\x18\x02 \x01(\t\x12\x14\n\x0cnetwork_tier\x18\x03 \x01(\t\x12\x1e\n\x16public_ptr_domain_name\x18\x04 \x01(\t\"\xc0\x05\n,ComputeInstanceFromTemplateXNetworkInterface\x12w\n\raccess_config\x18\x01 \x03(\x0b\x32`.oak9.tython.gcp.compute_instance.ComputeInstanceFromTemplateXNetworkInterface.AccessConfigEntry\x12x\n\x0e\x61lias_ip_range\x18\x02 \x03(\x0b\x32`.oak9.tython.gcp.compute_instance.ComputeInstanceFromTemplateXNetworkInterface.AliasIpRangeEntry\x12\x18\n\x10ipv6_access_type\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0f\n\x07network\x18\x05 \x01(\t\x12\x12\n\nnetwork_ip\x18\x06 \x01(\t\x12\x10\n\x08nic_type\x18\x07 \x01(\t\x12\x13\n\x0bqueue_count\x18\x08 \x01(\x01\x12\x12\n\nstack_type\x18\t \x01(\t\x12\x12\n\nsubnetwork\x18\n \x01(\t\x12\x1a\n\x12subnetwork_project\x18\x0b \x01(\t\x12{\n\x12ipv6_access_config\x18\x0c \x03(\x0b\x32_.oak9.tython.gcp.compute_instance.ComputeInstanceFromTemplateXNetworkInterfaceXIpv6AccessConfig\x1a\x33\n\x11\x41\x63\x63\x65ssConfigEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x33\n\x11\x41liasIpRangeEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"b\nCComputeInstanceFromTemplateXReservationAffinityXSpecificReservation\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x0e\n\x06values\x18\x02 \x03(\t\"\xc5\x01\n/ComputeInstanceFromTemplateXReservationAffinity\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x83\x01\n\x14specific_reservation\x18\x02 \x01(\x0b\x32\x65.oak9.tython.gcp.compute_instance.ComputeInstanceFromTemplateXReservationAffinityXSpecificReservation\"f\n5ComputeInstanceFromTemplateXSchedulingXNodeAffinities\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x10\n\x08operator\x18\x02 \x01(\t\x12\x0e\n\x06values\x18\x03 \x03(\t\"\xbf\x02\n&ComputeInstanceFromTemplateXScheduling\x12\x19\n\x11\x61utomatic_restart\x18\x01 \x01(\x08\x12#\n\x1binstance_termination_action\x18\x02 \x01(\t\x12\x15\n\rmin_node_cpus\x18\x03 \x01(\x01\x12\x1b\n\x13on_host_maintenance\x18\x04 \x01(\t\x12\x13\n\x0bpreemptible\x18\x05 \x01(\x08\x12\x1a\n\x12provisioning_model\x18\x06 \x01(\t\x12p\n\x0fnode_affinities\x18\x07 \x03(\x0b\x32W.oak9.tython.gcp.compute_instance.ComputeInstanceFromTemplateXSchedulingXNodeAffinities\"\x8a\x01\n2ComputeInstanceFromTemplateXShieldedInstanceConfig\x12#\n\x1b\x65nable_integrity_monitoring\x18\x01 \x01(\x08\x12\x1a\n\x12\x65nable_secure_boot\x18\x02 \x01(\x08\x12\x13\n\x0b\x65nable_vtpm\x18\x03 \x01(\x08\"V\n$ComputeInstanceFromTemplateXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\x81\x13\n\x1b\x43omputeInstanceFromTemplate\x12!\n\x19\x61llow_stopping_for_update\x18\x01 \x01(\x08\x12\x66\n\rattached_disk\x18\x02 \x03(\x0b\x32O.oak9.tython.gcp.compute_instance.ComputeInstanceFromTemplate.AttachedDiskEntry\x12\x16\n\x0e\x63\x61n_ip_forward\x18\x03 \x01(\x08\x12\x14\n\x0c\x63pu_platform\x18\x04 \x01(\t\x12\x16\n\x0e\x63urrent_status\x18\x05 \x01(\t\x12\x1b\n\x13\x64\x65letion_protection\x18\x06 \x01(\x08\x12\x13\n\x0b\x64\x65scription\x18\x07 \x01(\t\x12\x16\n\x0e\x64\x65sired_status\x18\x08 \x01(\t\x12\x16\n\x0e\x65nable_display\x18\t \x01(\x08\x12n\n\x11guest_accelerator\x18\n \x03(\x0b\x32S.oak9.tython.gcp.compute_instance.ComputeInstanceFromTemplate.GuestAcceleratorEntry\x12\x10\n\x08hostname\x18\x0b \x01(\t\x12\n\n\x02id\x18\x0c \x01(\t\x12\x13\n\x0binstance_id\x18\r \x01(\t\x12\x19\n\x11label_fingerprint\x18\x0e \x01(\t\x12Y\n\x06labels\x18\x0f \x03(\x0b\x32I.oak9.tython.gcp.compute_instance.ComputeInstanceFromTemplate.LabelsEntry\x12\x14\n\x0cmachine_type\x18\x10 \x01(\t\x12]\n\x08metadata\x18\x11 \x03(\x0b\x32K.oak9.tython.gcp.compute_instance.ComputeInstanceFromTemplate.MetadataEntry\x12\x1c\n\x14metadata_fingerprint\x18\x12 \x01(\t\x12\x1f\n\x17metadata_startup_script\x18\x13 \x01(\t\x12\x18\n\x10min_cpu_platform\x18\x14 \x01(\t\x12\x0c\n\x04name\x18\x15 \x01(\t\x12\x0f\n\x07project\x18\x16 \x01(\t\x12\x19\n\x11resource_policies\x18\x17 \x03(\t\x12\x64\n\x0cscratch_disk\x18\x18 \x03(\x0b\x32N.oak9.tython.gcp.compute_instance.ComputeInstanceFromTemplate.ScratchDiskEntry\x12\x11\n\tself_link\x18\x19 \x01(\t\x12j\n\x0fservice_account\x18\x1a \x03(\x0b\x32Q.oak9.tython.gcp.compute_instance.ComputeInstanceFromTemplate.ServiceAccountEntry\x12 \n\x18source_instance_template\x18\x1b \x01(\t\x12\x0c\n\x04tags\x18\x1c \x03(\t\x12\x18\n\x10tags_fingerprint\x18\x1d \x01(\t\x12\x0c\n\x04zone\x18\x1e \x01(\t\x12x\n\x19\x61\x64vanced_machine_features\x18\x1f \x01(\x0b\x32U.oak9.tython.gcp.compute_instance.ComputeInstanceFromTemplateXAdvancedMachineFeatures\x12Y\n\tboot_disk\x18  \x01(\x0b\x32\x46.oak9.tython.gcp.compute_instance.ComputeInstanceFromTemplateXBootDisk\x12~\n\x1c\x63onfidential_instance_config\x18! \x01(\x0b\x32X.oak9.tython.gcp.compute_instance.ComputeInstanceFromTemplateXConfidentialInstanceConfig\x12i\n\x11network_interface\x18\" \x03(\x0b\x32N.oak9.tython.gcp.compute_instance.ComputeInstanceFromTemplateXNetworkInterface\x12o\n\x14reservation_affinity\x18# \x01(\x0b\x32Q.oak9.tython.gcp.compute_instance.ComputeInstanceFromTemplateXReservationAffinity\x12\\\n\nscheduling\x18$ \x01(\x0b\x32H.oak9.tython.gcp.compute_instance.ComputeInstanceFromTemplateXScheduling\x12v\n\x18shielded_instance_config\x18% \x01(\x0b\x32T.oak9.tython.gcp.compute_instance.ComputeInstanceFromTemplateXShieldedInstanceConfig\x12X\n\x08timeouts\x18& \x01(\x0b\x32\x46.oak9.tython.gcp.compute_instance.ComputeInstanceFromTemplateXTimeouts\x12\x37\n\rresource_info\x18\' \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a\x33\n\x11\x41ttachedDiskEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x37\n\x15GuestAcceleratorEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x32\n\x10ScratchDiskEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x35\n\x13ServiceAccountEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"<\n\x1e\x43omputeInstanceGroupXNamedPort\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04port\x18\x02 \x01(\x01\"O\n\x1d\x43omputeInstanceGroupXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\x8b\x03\n\x14\x43omputeInstanceGroup\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x11\n\tinstances\x18\x03 \x03(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0f\n\x07network\x18\x05 \x01(\t\x12\x0f\n\x07project\x18\x06 \x01(\t\x12\x11\n\tself_link\x18\x07 \x01(\t\x12\x0c\n\x04size\x18\x08 \x01(\x01\x12\x0c\n\x04zone\x18\t \x01(\t\x12T\n\nnamed_port\x18\n \x03(\x0b\x32@.oak9.tython.gcp.compute_instance.ComputeInstanceGroupXNamedPort\x12Q\n\x08timeouts\x18\x0b \x01(\x0b\x32?.oak9.tython.gcp.compute_instance.ComputeInstanceGroupXTimeouts\x12\x37\n\rresource_info\x18\x0c \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"b\n/ComputeInstanceGroupManagerXAutoHealingPolicies\x12\x14\n\x0chealth_check\x18\x01 \x01(\t\x12\x19\n\x11initial_delay_sec\x18\x02 \x01(\x01\"C\n%ComputeInstanceGroupManagerXNamedPort\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04port\x18\x02 \x01(\x01\"T\n(ComputeInstanceGroupManagerXStatefulDisk\x12\x13\n\x0b\x64\x65lete_rule\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65vice_name\x18\x02 \x01(\t\"V\n$ComputeInstanceGroupManagerXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\x88\x02\n(ComputeInstanceGroupManagerXUpdatePolicy\x12\x17\n\x0fmax_surge_fixed\x18\x01 \x01(\x01\x12\x19\n\x11max_surge_percent\x18\x02 \x01(\x01\x12\x1d\n\x15max_unavailable_fixed\x18\x03 \x01(\x01\x12\x1f\n\x17max_unavailable_percent\x18\x04 \x01(\x01\x12\x16\n\x0eminimal_action\x18\x05 \x01(\t\x12&\n\x1emost_disruptive_allowed_action\x18\x06 \x01(\t\x12\x1a\n\x12replacement_method\x18\x07 \x01(\t\x12\x0c\n\x04type\x18\x08 \x01(\t\"P\n.ComputeInstanceGroupManagerXVersionXTargetSize\x12\r\n\x05\x66ixed\x18\x01 \x01(\x01\x12\x0f\n\x07percent\x18\x02 \x01(\x01\"\xb5\x01\n#ComputeInstanceGroupManagerXVersion\x12\x19\n\x11instance_template\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x65\n\x0btarget_size\x18\x03 \x01(\x0b\x32P.oak9.tython.gcp.compute_instance.ComputeInstanceGroupManagerXVersionXTargetSize\"\xce\x08\n\x1b\x43omputeInstanceGroupManager\x12\x1a\n\x12\x62\x61se_instance_name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x13\n\x0b\x66ingerprint\x18\x03 \x01(\t\x12\n\n\x02id\x18\x04 \x01(\t\x12\x16\n\x0einstance_group\x18\x05 \x01(\t\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x11\n\toperation\x18\x07 \x01(\t\x12\x0f\n\x07project\x18\x08 \x01(\t\x12\x11\n\tself_link\x18\t \x01(\t\x12Y\n\x06status\x18\n \x03(\x0b\x32I.oak9.tython.gcp.compute_instance.ComputeInstanceGroupManager.StatusEntry\x12\x14\n\x0ctarget_pools\x18\x0b \x03(\t\x12\x13\n\x0btarget_size\x18\x0c \x01(\x01\x12\x1a\n\x12wait_for_instances\x18\r \x01(\x08\x12!\n\x19wait_for_instances_status\x18\x0e \x01(\t\x12\x0c\n\x04zone\x18\x0f \x01(\t\x12p\n\x15\x61uto_healing_policies\x18\x10 \x01(\x0b\x32Q.oak9.tython.gcp.compute_instance.ComputeInstanceGroupManagerXAutoHealingPolicies\x12[\n\nnamed_port\x18\x11 \x03(\x0b\x32G.oak9.tython.gcp.compute_instance.ComputeInstanceGroupManagerXNamedPort\x12\x61\n\rstateful_disk\x18\x12 \x03(\x0b\x32J.oak9.tython.gcp.compute_instance.ComputeInstanceGroupManagerXStatefulDisk\x12X\n\x08timeouts\x18\x13 \x01(\x0b\x32\x46.oak9.tython.gcp.compute_instance.ComputeInstanceGroupManagerXTimeouts\x12\x61\n\rupdate_policy\x18\x14 \x01(\x0b\x32J.oak9.tython.gcp.compute_instance.ComputeInstanceGroupManagerXUpdatePolicy\x12V\n\x07version\x18\x15 \x03(\x0b\x32\x45.oak9.tython.gcp.compute_instance.ComputeInstanceGroupManagerXVersion\x12\x37\n\rresource_info\x18\x16 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a-\n\x0bStatusEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"H\n&ComputeInstanceGroupNamedPortXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\"\x8a\x02\n\x1d\x43omputeInstanceGroupNamedPort\x12\r\n\x05group\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0c\n\x04port\x18\x04 \x01(\x01\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x0c\n\x04zone\x18\x06 \x01(\t\x12Z\n\x08timeouts\x18\x07 \x01(\x0b\x32H.oak9.tython.gcp.compute_instance.ComputeInstanceGroupNamedPortXTimeouts\x12\x37\n\rresource_info\x18\x08 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"]\n#ComputeInstanceIamBindingXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\x9d\x02\n\x19\x43omputeInstanceIamBinding\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x15\n\rinstance_name\x18\x03 \x01(\t\x12\x0f\n\x07members\x18\x04 \x03(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x0c\n\x04role\x18\x06 \x01(\t\x12\x0c\n\x04zone\x18\x07 \x01(\t\x12X\n\tcondition\x18\x08 \x01(\x0b\x32\x45.oak9.tython.gcp.compute_instance.ComputeInstanceIamBindingXCondition\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\\\n\"ComputeInstanceIamMemberXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\x9a\x02\n\x18\x43omputeInstanceIamMember\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x15\n\rinstance_name\x18\x03 \x01(\t\x12\x0e\n\x06member\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x0c\n\x04role\x18\x06 \x01(\t\x12\x0c\n\x04zone\x18\x07 \x01(\t\x12W\n\tcondition\x18\x08 \x01(\x0b\x32\x44.oak9.tython.gcp.compute_instance.ComputeInstanceIamMemberXCondition\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xb8\x01\n\x18\x43omputeInstanceIamPolicy\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x15\n\rinstance_name\x18\x03 \x01(\t\x12\x13\n\x0bpolicy_data\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x0c\n\x04zone\x18\x06 \x01(\t\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"q\n/ComputeInstanceTemplateXAdvancedMachineFeatures\x12$\n\x1c\x65nable_nested_virtualization\x18\x01 \x01(\x08\x12\x18\n\x10threads_per_core\x18\x02 \x01(\x01\"Y\n2ComputeInstanceTemplateXConfidentialInstanceConfig\x12#\n\x1b\x65nable_confidential_compute\x18\x01 \x01(\x08\"K\n.ComputeInstanceTemplateXDiskXDiskEncryptionKey\x12\x19\n\x11kms_key_self_link\x18\x01 \x01(\t\"\xfc\x03\n\x1c\x43omputeInstanceTemplateXDisk\x12\x13\n\x0b\x61uto_delete\x18\x01 \x01(\x08\x12\x0c\n\x04\x62oot\x18\x02 \x01(\x08\x12\x13\n\x0b\x64\x65vice_name\x18\x03 \x01(\t\x12\x11\n\tdisk_name\x18\x04 \x01(\t\x12\x14\n\x0c\x64isk_size_gb\x18\x05 \x01(\x01\x12\x11\n\tdisk_type\x18\x06 \x01(\t\x12\x11\n\tinterface\x18\x07 \x01(\t\x12Z\n\x06labels\x18\x08 \x03(\x0b\x32J.oak9.tython.gcp.compute_instance.ComputeInstanceTemplateXDisk.LabelsEntry\x12\x0c\n\x04mode\x18\t \x01(\t\x12\x19\n\x11resource_policies\x18\n \x03(\t\x12\x0e\n\x06source\x18\x0b \x01(\t\x12\x14\n\x0csource_image\x18\x0c \x01(\t\x12\x0c\n\x04type\x18\r \x01(\t\x12m\n\x13\x64isk_encryption_key\x18\x0e \x01(\x0b\x32P.oak9.tython.gcp.compute_instance.ComputeInstanceTemplateXDiskXDiskEncryptionKey\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"G\n(ComputeInstanceTemplateXGuestAccelerator\x12\r\n\x05\x63ount\x18\x01 \x01(\x01\x12\x0c\n\x04type\x18\x02 \x01(\t\"}\n5ComputeInstanceTemplateXNetworkInterfaceXAccessConfig\x12\x0e\n\x06nat_ip\x18\x01 \x01(\t\x12\x14\n\x0cnetwork_tier\x18\x02 \x01(\t\x12\x1e\n\x16public_ptr_domain_name\x18\x03 \x01(\t\"m\n5ComputeInstanceTemplateXNetworkInterfaceXAliasIpRange\x12\x15\n\rip_cidr_range\x18\x01 \x01(\t\x12\x1d\n\x15subnetwork_range_name\x18\x02 \x01(\t\"\xad\x01\n9ComputeInstanceTemplateXNetworkInterfaceXIpv6AccessConfig\x12\x15\n\rexternal_ipv6\x18\x01 \x01(\t\x12#\n\x1b\x65xternal_ipv6_prefix_length\x18\x02 \x01(\t\x12\x14\n\x0cnetwork_tier\x18\x03 \x01(\t\x12\x1e\n\x16public_ptr_domain_name\x18\x04 \x01(\t\"\xbc\x04\n(ComputeInstanceTemplateXNetworkInterface\x12\x18\n\x10ipv6_access_type\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07network\x18\x03 \x01(\t\x12\x12\n\nnetwork_ip\x18\x04 \x01(\t\x12\x10\n\x08nic_type\x18\x05 \x01(\t\x12\x13\n\x0bqueue_count\x18\x06 \x01(\x01\x12\x12\n\nstack_type\x18\x07 \x01(\t\x12\x12\n\nsubnetwork\x18\x08 \x01(\t\x12\x1a\n\x12subnetwork_project\x18\t \x01(\t\x12n\n\raccess_config\x18\n \x03(\x0b\x32W.oak9.tython.gcp.compute_instance.ComputeInstanceTemplateXNetworkInterfaceXAccessConfig\x12o\n\x0e\x61lias_ip_range\x18\x0b \x03(\x0b\x32W.oak9.tython.gcp.compute_instance.ComputeInstanceTemplateXNetworkInterfaceXAliasIpRange\x12w\n\x12ipv6_access_config\x18\x0c \x03(\x0b\x32[.oak9.tython.gcp.compute_instance.ComputeInstanceTemplateXNetworkInterfaceXIpv6AccessConfig\"^\n?ComputeInstanceTemplateXReservationAffinityXSpecificReservation\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x0e\n\x06values\x18\x02 \x03(\t\"\xbc\x01\n+ComputeInstanceTemplateXReservationAffinity\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x7f\n\x14specific_reservation\x18\x02 \x01(\x0b\x32\x61.oak9.tython.gcp.compute_instance.ComputeInstanceTemplateXReservationAffinityXSpecificReservation\"b\n1ComputeInstanceTemplateXSchedulingXNodeAffinities\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x10\n\x08operator\x18\x02 \x01(\t\x12\x0e\n\x06values\x18\x03 \x03(\t\"\xb7\x02\n\"ComputeInstanceTemplateXScheduling\x12\x19\n\x11\x61utomatic_restart\x18\x01 \x01(\x08\x12#\n\x1binstance_termination_action\x18\x02 \x01(\t\x12\x15\n\rmin_node_cpus\x18\x03 \x01(\x01\x12\x1b\n\x13on_host_maintenance\x18\x04 \x01(\t\x12\x13\n\x0bpreemptible\x18\x05 \x01(\x08\x12\x1a\n\x12provisioning_model\x18\x06 \x01(\t\x12l\n\x0fnode_affinities\x18\x07 \x03(\x0b\x32S.oak9.tython.gcp.compute_instance.ComputeInstanceTemplateXSchedulingXNodeAffinities\"G\n&ComputeInstanceTemplateXServiceAccount\x12\r\n\x05\x65mail\x18\x01 \x01(\t\x12\x0e\n\x06scopes\x18\x02 \x03(\t\"\x86\x01\n.ComputeInstanceTemplateXShieldedInstanceConfig\x12#\n\x1b\x65nable_integrity_monitoring\x18\x01 \x01(\x08\x12\x1a\n\x12\x65nable_secure_boot\x18\x02 \x01(\x08\x12\x13\n\x0b\x65nable_vtpm\x18\x03 \x01(\x08\"B\n ComputeInstanceTemplateXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\"\xab\r\n\x17\x43omputeInstanceTemplate\x12\x16\n\x0e\x63\x61n_ip_forward\x18\x01 \x01(\x08\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x1c\n\x14instance_description\x18\x04 \x01(\t\x12U\n\x06labels\x18\x05 \x03(\x0b\x32\x45.oak9.tython.gcp.compute_instance.ComputeInstanceTemplate.LabelsEntry\x12\x14\n\x0cmachine_type\x18\x06 \x01(\t\x12Y\n\x08metadata\x18\x07 \x03(\x0b\x32G.oak9.tython.gcp.compute_instance.ComputeInstanceTemplate.MetadataEntry\x12\x1c\n\x14metadata_fingerprint\x18\x08 \x01(\t\x12\x1f\n\x17metadata_startup_script\x18\t \x01(\t\x12\x18\n\x10min_cpu_platform\x18\n \x01(\t\x12\x0c\n\x04name\x18\x0b \x01(\t\x12\x13\n\x0bname_prefix\x18\x0c \x01(\t\x12\x0f\n\x07project\x18\r \x01(\t\x12\x0e\n\x06region\x18\x0e \x01(\t\x12\x11\n\tself_link\x18\x0f \x01(\t\x12\x0c\n\x04tags\x18\x10 \x03(\t\x12\x18\n\x10tags_fingerprint\x18\x11 \x01(\t\x12t\n\x19\x61\x64vanced_machine_features\x18\x12 \x01(\x0b\x32Q.oak9.tython.gcp.compute_instance.ComputeInstanceTemplateXAdvancedMachineFeatures\x12z\n\x1c\x63onfidential_instance_config\x18\x13 \x01(\x0b\x32T.oak9.tython.gcp.compute_instance.ComputeInstanceTemplateXConfidentialInstanceConfig\x12L\n\x04\x64isk\x18\x14 \x03(\x0b\x32>.oak9.tython.gcp.compute_instance.ComputeInstanceTemplateXDisk\x12\x65\n\x11guest_accelerator\x18\x15 \x03(\x0b\x32J.oak9.tython.gcp.compute_instance.ComputeInstanceTemplateXGuestAccelerator\x12\x65\n\x11network_interface\x18\x16 \x03(\x0b\x32J.oak9.tython.gcp.compute_instance.ComputeInstanceTemplateXNetworkInterface\x12k\n\x14reservation_affinity\x18\x17 \x01(\x0b\x32M.oak9.tython.gcp.compute_instance.ComputeInstanceTemplateXReservationAffinity\x12X\n\nscheduling\x18\x18 \x01(\x0b\x32\x44.oak9.tython.gcp.compute_instance.ComputeInstanceTemplateXScheduling\x12\x61\n\x0fservice_account\x18\x19 \x01(\x0b\x32H.oak9.tython.gcp.compute_instance.ComputeInstanceTemplateXServiceAccount\x12r\n\x18shielded_instance_config\x18\x1a \x01(\x0b\x32P.oak9.tython.gcp.compute_instance.ComputeInstanceTemplateXShieldedInstanceConfig\x12T\n\x08timeouts\x18\x1b \x01(\x0b\x32\x42.oak9.tython.gcp.compute_instance.ComputeInstanceTemplateXTimeouts\x12\x37\n\rresource_info\x18\x1c \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_compute_instance_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMPUTEINSTANCEXBOOTDISKXINITIALIZEPARAMS_LABELSENTRY._options = None
  _COMPUTEINSTANCEXBOOTDISKXINITIALIZEPARAMS_LABELSENTRY._serialized_options = b'8\001'
  _COMPUTEINSTANCE_GUESTACCELERATORENTRY._options = None
  _COMPUTEINSTANCE_GUESTACCELERATORENTRY._serialized_options = b'8\001'
  _COMPUTEINSTANCE_LABELSENTRY._options = None
  _COMPUTEINSTANCE_LABELSENTRY._serialized_options = b'8\001'
  _COMPUTEINSTANCE_METADATAENTRY._options = None
  _COMPUTEINSTANCE_METADATAENTRY._serialized_options = b'8\001'
  _COMPUTEINSTANCEFROMTEMPLATEXBOOTDISKXINITIALIZEPARAMS_LABELSENTRY._options = None
  _COMPUTEINSTANCEFROMTEMPLATEXBOOTDISKXINITIALIZEPARAMS_LABELSENTRY._serialized_options = b'8\001'
  _COMPUTEINSTANCEFROMTEMPLATEXNETWORKINTERFACE_ACCESSCONFIGENTRY._options = None
  _COMPUTEINSTANCEFROMTEMPLATEXNETWORKINTERFACE_ACCESSCONFIGENTRY._serialized_options = b'8\001'
  _COMPUTEINSTANCEFROMTEMPLATEXNETWORKINTERFACE_ALIASIPRANGEENTRY._options = None
  _COMPUTEINSTANCEFROMTEMPLATEXNETWORKINTERFACE_ALIASIPRANGEENTRY._serialized_options = b'8\001'
  _COMPUTEINSTANCEFROMTEMPLATE_ATTACHEDDISKENTRY._options = None
  _COMPUTEINSTANCEFROMTEMPLATE_ATTACHEDDISKENTRY._serialized_options = b'8\001'
  _COMPUTEINSTANCEFROMTEMPLATE_GUESTACCELERATORENTRY._options = None
  _COMPUTEINSTANCEFROMTEMPLATE_GUESTACCELERATORENTRY._serialized_options = b'8\001'
  _COMPUTEINSTANCEFROMTEMPLATE_LABELSENTRY._options = None
  _COMPUTEINSTANCEFROMTEMPLATE_LABELSENTRY._serialized_options = b'8\001'
  _COMPUTEINSTANCEFROMTEMPLATE_METADATAENTRY._options = None
  _COMPUTEINSTANCEFROMTEMPLATE_METADATAENTRY._serialized_options = b'8\001'
  _COMPUTEINSTANCEFROMTEMPLATE_SCRATCHDISKENTRY._options = None
  _COMPUTEINSTANCEFROMTEMPLATE_SCRATCHDISKENTRY._serialized_options = b'8\001'
  _COMPUTEINSTANCEFROMTEMPLATE_SERVICEACCOUNTENTRY._options = None
  _COMPUTEINSTANCEFROMTEMPLATE_SERVICEACCOUNTENTRY._serialized_options = b'8\001'
  _COMPUTEINSTANCEGROUPMANAGER_STATUSENTRY._options = None
  _COMPUTEINSTANCEGROUPMANAGER_STATUSENTRY._serialized_options = b'8\001'
  _COMPUTEINSTANCETEMPLATEXDISK_LABELSENTRY._options = None
  _COMPUTEINSTANCETEMPLATEXDISK_LABELSENTRY._serialized_options = b'8\001'
  _COMPUTEINSTANCETEMPLATE_LABELSENTRY._options = None
  _COMPUTEINSTANCETEMPLATE_LABELSENTRY._serialized_options = b'8\001'
  _COMPUTEINSTANCETEMPLATE_METADATAENTRY._options = None
  _COMPUTEINSTANCETEMPLATE_METADATAENTRY._serialized_options = b'8\001'
  _COMPUTEINSTANCEXADVANCEDMACHINEFEATURES._serialized_start=89
  _COMPUTEINSTANCEXADVANCEDMACHINEFEATURES._serialized_end=194
  _COMPUTEINSTANCEXATTACHEDDISK._serialized_start=197
  _COMPUTEINSTANCEXATTACHEDDISK._serialized_end=374
  _COMPUTEINSTANCEXBOOTDISKXINITIALIZEPARAMS._serialized_start=377
  _COMPUTEINSTANCEXBOOTDISKXINITIALIZEPARAMS._serialized_end=615
  _COMPUTEINSTANCEXBOOTDISKXINITIALIZEPARAMS_LABELSENTRY._serialized_start=570
  _COMPUTEINSTANCEXBOOTDISKXINITIALIZEPARAMS_LABELSENTRY._serialized_end=615
  _COMPUTEINSTANCEXBOOTDISK._serialized_start=618
  _COMPUTEINSTANCEXBOOTDISK._serialized_end=916
  _COMPUTEINSTANCEXCONFIDENTIALINSTANCECONFIG._serialized_start=918
  _COMPUTEINSTANCEXCONFIDENTIALINSTANCECONFIG._serialized_end=999
  _COMPUTEINSTANCEXNETWORKINTERFACEXACCESSCONFIG._serialized_start=1001
  _COMPUTEINSTANCEXNETWORKINTERFACEXACCESSCONFIG._serialized_end=1118
  _COMPUTEINSTANCEXNETWORKINTERFACEXALIASIPRANGE._serialized_start=1120
  _COMPUTEINSTANCEXNETWORKINTERFACEXALIASIPRANGE._serialized_end=1221
  _COMPUTEINSTANCEXNETWORKINTERFACEXIPV6ACCESSCONFIG._serialized_start=1224
  _COMPUTEINSTANCEXNETWORKINTERFACEXIPV6ACCESSCONFIG._serialized_end=1389
  _COMPUTEINSTANCEXNETWORKINTERFACE._serialized_start=1392
  _COMPUTEINSTANCEXNETWORKINTERFACE._serialized_end=1932
  _COMPUTEINSTANCEXRESERVATIONAFFINITYXSPECIFICRESERVATION._serialized_start=1934
  _COMPUTEINSTANCEXRESERVATIONAFFINITYXSPECIFICRESERVATION._serialized_end=2020
  _COMPUTEINSTANCEXRESERVATIONAFFINITY._serialized_start=2023
  _COMPUTEINSTANCEXRESERVATIONAFFINITY._serialized_end=2195
  _COMPUTEINSTANCEXSCHEDULINGXNODEAFFINITIES._serialized_start=2197
  _COMPUTEINSTANCEXSCHEDULINGXNODEAFFINITIES._serialized_end=2287
  _COMPUTEINSTANCEXSCHEDULING._serialized_start=2290
  _COMPUTEINSTANCEXSCHEDULING._serialized_end=2585
  _COMPUTEINSTANCEXSCRATCHDISK._serialized_start=2587
  _COMPUTEINSTANCEXSCRATCHDISK._serialized_end=2635
  _COMPUTEINSTANCEXSERVICEACCOUNT._serialized_start=2637
  _COMPUTEINSTANCEXSERVICEACCOUNT._serialized_end=2700
  _COMPUTEINSTANCEXSHIELDEDINSTANCECONFIG._serialized_start=2702
  _COMPUTEINSTANCEXSHIELDEDINSTANCECONFIG._serialized_end=2828
  _COMPUTEINSTANCEXTIMEOUTS._serialized_start=2830
  _COMPUTEINSTANCEXTIMEOUTS._serialized_end=2904
  _COMPUTEINSTANCE._serialized_start=2907
  _COMPUTEINSTANCE._serialized_end=4951
  _COMPUTEINSTANCE_GUESTACCELERATORENTRY._serialized_start=4800
  _COMPUTEINSTANCE_GUESTACCELERATORENTRY._serialized_end=4855
  _COMPUTEINSTANCE_LABELSENTRY._serialized_start=570
  _COMPUTEINSTANCE_LABELSENTRY._serialized_end=615
  _COMPUTEINSTANCE_METADATAENTRY._serialized_start=4904
  _COMPUTEINSTANCE_METADATAENTRY._serialized_end=4951
  _COMPUTEINSTANCEFROMTEMPLATEXADVANCEDMACHINEFEATURES._serialized_start=4953
  _COMPUTEINSTANCEFROMTEMPLATEXADVANCEDMACHINEFEATURES._serialized_end=5070
  _COMPUTEINSTANCEFROMTEMPLATEXBOOTDISKXINITIALIZEPARAMS._serialized_start=5073
  _COMPUTEINSTANCEFROMTEMPLATEXBOOTDISKXINITIALIZEPARAMS._serialized_end=5335
  _COMPUTEINSTANCEFROMTEMPLATEXBOOTDISKXINITIALIZEPARAMS_LABELSENTRY._serialized_start=570
  _COMPUTEINSTANCEFROMTEMPLATEXBOOTDISKXINITIALIZEPARAMS_LABELSENTRY._serialized_end=615
  _COMPUTEINSTANCEFROMTEMPLATEXBOOTDISK._serialized_start=5338
  _COMPUTEINSTANCEFROMTEMPLATEXBOOTDISK._serialized_end=5660
  _COMPUTEINSTANCEFROMTEMPLATEXCONFIDENTIALINSTANCECONFIG._serialized_start=5662
  _COMPUTEINSTANCEFROMTEMPLATEXCONFIDENTIALINSTANCECONFIG._serialized_end=5755
  _COMPUTEINSTANCEFROMTEMPLATEXNETWORKINTERFACEXIPV6ACCESSCONFIG._serialized_start=5758
  _COMPUTEINSTANCEFROMTEMPLATEXNETWORKINTERFACEXIPV6ACCESSCONFIG._serialized_end=5935
  _COMPUTEINSTANCEFROMTEMPLATEXNETWORKINTERFACE._serialized_start=5938
  _COMPUTEINSTANCEFROMTEMPLATEXNETWORKINTERFACE._serialized_end=6642
  _COMPUTEINSTANCEFROMTEMPLATEXNETWORKINTERFACE_ACCESSCONFIGENTRY._serialized_start=6538
  _COMPUTEINSTANCEFROMTEMPLATEXNETWORKINTERFACE_ACCESSCONFIGENTRY._serialized_end=6589
  _COMPUTEINSTANCEFROMTEMPLATEXNETWORKINTERFACE_ALIASIPRANGEENTRY._serialized_start=6591
  _COMPUTEINSTANCEFROMTEMPLATEXNETWORKINTERFACE_ALIASIPRANGEENTRY._serialized_end=6642
  _COMPUTEINSTANCEFROMTEMPLATEXRESERVATIONAFFINITYXSPECIFICRESERVATION._serialized_start=6644
  _COMPUTEINSTANCEFROMTEMPLATEXRESERVATIONAFFINITYXSPECIFICRESERVATION._serialized_end=6742
  _COMPUTEINSTANCEFROMTEMPLATEXRESERVATIONAFFINITY._serialized_start=6745
  _COMPUTEINSTANCEFROMTEMPLATEXRESERVATIONAFFINITY._serialized_end=6942
  _COMPUTEINSTANCEFROMTEMPLATEXSCHEDULINGXNODEAFFINITIES._serialized_start=6944
  _COMPUTEINSTANCEFROMTEMPLATEXSCHEDULINGXNODEAFFINITIES._serialized_end=7046
  _COMPUTEINSTANCEFROMTEMPLATEXSCHEDULING._serialized_start=7049
  _COMPUTEINSTANCEFROMTEMPLATEXSCHEDULING._serialized_end=7368
  _COMPUTEINSTANCEFROMTEMPLATEXSHIELDEDINSTANCECONFIG._serialized_start=7371
  _COMPUTEINSTANCEFROMTEMPLATEXSHIELDEDINSTANCECONFIG._serialized_end=7509
  _COMPUTEINSTANCEFROMTEMPLATEXTIMEOUTS._serialized_start=7511
  _COMPUTEINSTANCEFROMTEMPLATEXTIMEOUTS._serialized_end=7597
  _COMPUTEINSTANCEFROMTEMPLATE._serialized_start=7600
  _COMPUTEINSTANCEFROMTEMPLATE._serialized_end=10033
  _COMPUTEINSTANCEFROMTEMPLATE_ATTACHEDDISKENTRY._serialized_start=9722
  _COMPUTEINSTANCEFROMTEMPLATE_ATTACHEDDISKENTRY._serialized_end=9773
  _COMPUTEINSTANCEFROMTEMPLATE_GUESTACCELERATORENTRY._serialized_start=4800
  _COMPUTEINSTANCEFROMTEMPLATE_GUESTACCELERATORENTRY._serialized_end=4855
  _COMPUTEINSTANCEFROMTEMPLATE_LABELSENTRY._serialized_start=570
  _COMPUTEINSTANCEFROMTEMPLATE_LABELSENTRY._serialized_end=615
  _COMPUTEINSTANCEFROMTEMPLATE_METADATAENTRY._serialized_start=4904
  _COMPUTEINSTANCEFROMTEMPLATE_METADATAENTRY._serialized_end=4951
  _COMPUTEINSTANCEFROMTEMPLATE_SCRATCHDISKENTRY._serialized_start=9928
  _COMPUTEINSTANCEFROMTEMPLATE_SCRATCHDISKENTRY._serialized_end=9978
  _COMPUTEINSTANCEFROMTEMPLATE_SERVICEACCOUNTENTRY._serialized_start=9980
  _COMPUTEINSTANCEFROMTEMPLATE_SERVICEACCOUNTENTRY._serialized_end=10033
  _COMPUTEINSTANCEGROUPXNAMEDPORT._serialized_start=10035
  _COMPUTEINSTANCEGROUPXNAMEDPORT._serialized_end=10095
  _COMPUTEINSTANCEGROUPXTIMEOUTS._serialized_start=10097
  _COMPUTEINSTANCEGROUPXTIMEOUTS._serialized_end=10176
  _COMPUTEINSTANCEGROUP._serialized_start=10179
  _COMPUTEINSTANCEGROUP._serialized_end=10574
  _COMPUTEINSTANCEGROUPMANAGERXAUTOHEALINGPOLICIES._serialized_start=10576
  _COMPUTEINSTANCEGROUPMANAGERXAUTOHEALINGPOLICIES._serialized_end=10674
  _COMPUTEINSTANCEGROUPMANAGERXNAMEDPORT._serialized_start=10676
  _COMPUTEINSTANCEGROUPMANAGERXNAMEDPORT._serialized_end=10743
  _COMPUTEINSTANCEGROUPMANAGERXSTATEFULDISK._serialized_start=10745
  _COMPUTEINSTANCEGROUPMANAGERXSTATEFULDISK._serialized_end=10829
  _COMPUTEINSTANCEGROUPMANAGERXTIMEOUTS._serialized_start=10831
  _COMPUTEINSTANCEGROUPMANAGERXTIMEOUTS._serialized_end=10917
  _COMPUTEINSTANCEGROUPMANAGERXUPDATEPOLICY._serialized_start=10920
  _COMPUTEINSTANCEGROUPMANAGERXUPDATEPOLICY._serialized_end=11184
  _COMPUTEINSTANCEGROUPMANAGERXVERSIONXTARGETSIZE._serialized_start=11186
  _COMPUTEINSTANCEGROUPMANAGERXVERSIONXTARGETSIZE._serialized_end=11266
  _COMPUTEINSTANCEGROUPMANAGERXVERSION._serialized_start=11269
  _COMPUTEINSTANCEGROUPMANAGERXVERSION._serialized_end=11450
  _COMPUTEINSTANCEGROUPMANAGER._serialized_start=11453
  _COMPUTEINSTANCEGROUPMANAGER._serialized_end=12555
  _COMPUTEINSTANCEGROUPMANAGER_STATUSENTRY._serialized_start=12510
  _COMPUTEINSTANCEGROUPMANAGER_STATUSENTRY._serialized_end=12555
  _COMPUTEINSTANCEGROUPNAMEDPORTXTIMEOUTS._serialized_start=12557
  _COMPUTEINSTANCEGROUPNAMEDPORTXTIMEOUTS._serialized_end=12629
  _COMPUTEINSTANCEGROUPNAMEDPORT._serialized_start=12632
  _COMPUTEINSTANCEGROUPNAMEDPORT._serialized_end=12898
  _COMPUTEINSTANCEIAMBINDINGXCONDITION._serialized_start=12900
  _COMPUTEINSTANCEIAMBINDINGXCONDITION._serialized_end=12993
  _COMPUTEINSTANCEIAMBINDING._serialized_start=12996
  _COMPUTEINSTANCEIAMBINDING._serialized_end=13281
  _COMPUTEINSTANCEIAMMEMBERXCONDITION._serialized_start=13283
  _COMPUTEINSTANCEIAMMEMBERXCONDITION._serialized_end=13375
  _COMPUTEINSTANCEIAMMEMBER._serialized_start=13378
  _COMPUTEINSTANCEIAMMEMBER._serialized_end=13660
  _COMPUTEINSTANCEIAMPOLICY._serialized_start=13663
  _COMPUTEINSTANCEIAMPOLICY._serialized_end=13847
  _COMPUTEINSTANCETEMPLATEXADVANCEDMACHINEFEATURES._serialized_start=13849
  _COMPUTEINSTANCETEMPLATEXADVANCEDMACHINEFEATURES._serialized_end=13962
  _COMPUTEINSTANCETEMPLATEXCONFIDENTIALINSTANCECONFIG._serialized_start=13964
  _COMPUTEINSTANCETEMPLATEXCONFIDENTIALINSTANCECONFIG._serialized_end=14053
  _COMPUTEINSTANCETEMPLATEXDISKXDISKENCRYPTIONKEY._serialized_start=14055
  _COMPUTEINSTANCETEMPLATEXDISKXDISKENCRYPTIONKEY._serialized_end=14130
  _COMPUTEINSTANCETEMPLATEXDISK._serialized_start=14133
  _COMPUTEINSTANCETEMPLATEXDISK._serialized_end=14641
  _COMPUTEINSTANCETEMPLATEXDISK_LABELSENTRY._serialized_start=570
  _COMPUTEINSTANCETEMPLATEXDISK_LABELSENTRY._serialized_end=615
  _COMPUTEINSTANCETEMPLATEXGUESTACCELERATOR._serialized_start=14643
  _COMPUTEINSTANCETEMPLATEXGUESTACCELERATOR._serialized_end=14714
  _COMPUTEINSTANCETEMPLATEXNETWORKINTERFACEXACCESSCONFIG._serialized_start=14716
  _COMPUTEINSTANCETEMPLATEXNETWORKINTERFACEXACCESSCONFIG._serialized_end=14841
  _COMPUTEINSTANCETEMPLATEXNETWORKINTERFACEXALIASIPRANGE._serialized_start=14843
  _COMPUTEINSTANCETEMPLATEXNETWORKINTERFACEXALIASIPRANGE._serialized_end=14952
  _COMPUTEINSTANCETEMPLATEXNETWORKINTERFACEXIPV6ACCESSCONFIG._serialized_start=14955
  _COMPUTEINSTANCETEMPLATEXNETWORKINTERFACEXIPV6ACCESSCONFIG._serialized_end=15128
  _COMPUTEINSTANCETEMPLATEXNETWORKINTERFACE._serialized_start=15131
  _COMPUTEINSTANCETEMPLATEXNETWORKINTERFACE._serialized_end=15703
  _COMPUTEINSTANCETEMPLATEXRESERVATIONAFFINITYXSPECIFICRESERVATION._serialized_start=15705
  _COMPUTEINSTANCETEMPLATEXRESERVATIONAFFINITYXSPECIFICRESERVATION._serialized_end=15799
  _COMPUTEINSTANCETEMPLATEXRESERVATIONAFFINITY._serialized_start=15802
  _COMPUTEINSTANCETEMPLATEXRESERVATIONAFFINITY._serialized_end=15990
  _COMPUTEINSTANCETEMPLATEXSCHEDULINGXNODEAFFINITIES._serialized_start=15992
  _COMPUTEINSTANCETEMPLATEXSCHEDULINGXNODEAFFINITIES._serialized_end=16090
  _COMPUTEINSTANCETEMPLATEXSCHEDULING._serialized_start=16093
  _COMPUTEINSTANCETEMPLATEXSCHEDULING._serialized_end=16404
  _COMPUTEINSTANCETEMPLATEXSERVICEACCOUNT._serialized_start=16406
  _COMPUTEINSTANCETEMPLATEXSERVICEACCOUNT._serialized_end=16477
  _COMPUTEINSTANCETEMPLATEXSHIELDEDINSTANCECONFIG._serialized_start=16480
  _COMPUTEINSTANCETEMPLATEXSHIELDEDINSTANCECONFIG._serialized_end=16614
  _COMPUTEINSTANCETEMPLATEXTIMEOUTS._serialized_start=16616
  _COMPUTEINSTANCETEMPLATEXTIMEOUTS._serialized_end=16682
  _COMPUTEINSTANCETEMPLATE._serialized_start=16685
  _COMPUTEINSTANCETEMPLATE._serialized_end=18392
  _COMPUTEINSTANCETEMPLATE_LABELSENTRY._serialized_start=570
  _COMPUTEINSTANCETEMPLATE_LABELSENTRY._serialized_end=615
  _COMPUTEINSTANCETEMPLATE_METADATAENTRY._serialized_start=4904
  _COMPUTEINSTANCETEMPLATE_METADATAENTRY._serialized_end=4951
# @@protoc_insertion_point(module_scope)
