"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ComputeNetworkXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___ComputeNetworkXTimeouts = ComputeNetworkXTimeouts

@typing_extensions.final
class ComputeNetwork(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUTO_CREATE_SUBNETWORKS_FIELD_NUMBER: builtins.int
    DELETE_DEFAULT_ROUTES_ON_CREATE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ENABLE_ULA_INTERNAL_IPV6_FIELD_NUMBER: builtins.int
    GATEWAY_IPV4_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    INTERNAL_IPV6_RANGE_FIELD_NUMBER: builtins.int
    MTU_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    ROUTING_MODE_FIELD_NUMBER: builtins.int
    SELF_LINK_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    auto_create_subnetworks: builtins.bool
    delete_default_routes_on_create: builtins.bool
    description: builtins.str
    enable_ula_internal_ipv6: builtins.bool
    gateway_ipv4: builtins.str
    id: builtins.str
    internal_ipv6_range: builtins.str
    mtu: builtins.float
    name: builtins.str
    project: builtins.str
    routing_mode: builtins.str
    self_link: builtins.str
    @property
    def timeouts(self) -> global___ComputeNetworkXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        auto_create_subnetworks: builtins.bool = ...,
        delete_default_routes_on_create: builtins.bool = ...,
        description: builtins.str = ...,
        enable_ula_internal_ipv6: builtins.bool = ...,
        gateway_ipv4: builtins.str = ...,
        id: builtins.str = ...,
        internal_ipv6_range: builtins.str = ...,
        mtu: builtins.float = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        routing_mode: builtins.str = ...,
        self_link: builtins.str = ...,
        timeouts: global___ComputeNetworkXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auto_create_subnetworks", b"auto_create_subnetworks", "delete_default_routes_on_create", b"delete_default_routes_on_create", "description", b"description", "enable_ula_internal_ipv6", b"enable_ula_internal_ipv6", "gateway_ipv4", b"gateway_ipv4", "id", b"id", "internal_ipv6_range", b"internal_ipv6_range", "mtu", b"mtu", "name", b"name", "project", b"project", "resource_info", b"resource_info", "routing_mode", b"routing_mode", "self_link", b"self_link", "timeouts", b"timeouts"]) -> None: ...

global___ComputeNetwork = ComputeNetwork

@typing_extensions.final
class ComputeNetworkEndpointXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete"]) -> None: ...

global___ComputeNetworkEndpointXTimeouts = ComputeNetworkEndpointXTimeouts

@typing_extensions.final
class ComputeNetworkEndpoint(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    INSTANCE_FIELD_NUMBER: builtins.int
    IP_ADDRESS_FIELD_NUMBER: builtins.int
    NETWORK_ENDPOINT_GROUP_FIELD_NUMBER: builtins.int
    PORT_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    ZONE_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    id: builtins.str
    instance: builtins.str
    ip_address: builtins.str
    network_endpoint_group: builtins.str
    port: builtins.float
    project: builtins.str
    zone: builtins.str
    @property
    def timeouts(self) -> global___ComputeNetworkEndpointXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        instance: builtins.str = ...,
        ip_address: builtins.str = ...,
        network_endpoint_group: builtins.str = ...,
        port: builtins.float = ...,
        project: builtins.str = ...,
        zone: builtins.str = ...,
        timeouts: global___ComputeNetworkEndpointXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "instance", b"instance", "ip_address", b"ip_address", "network_endpoint_group", b"network_endpoint_group", "port", b"port", "project", b"project", "resource_info", b"resource_info", "timeouts", b"timeouts", "zone", b"zone"]) -> None: ...

global___ComputeNetworkEndpoint = ComputeNetworkEndpoint

@typing_extensions.final
class ComputeNetworkEndpointGroupXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete"]) -> None: ...

global___ComputeNetworkEndpointGroupXTimeouts = ComputeNetworkEndpointGroupXTimeouts

@typing_extensions.final
class ComputeNetworkEndpointGroup(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEFAULT_PORT_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    NETWORK_FIELD_NUMBER: builtins.int
    NETWORK_ENDPOINT_TYPE_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    SELF_LINK_FIELD_NUMBER: builtins.int
    SIZE_FIELD_NUMBER: builtins.int
    SUBNETWORK_FIELD_NUMBER: builtins.int
    ZONE_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    default_port: builtins.float
    description: builtins.str
    id: builtins.str
    name: builtins.str
    network: builtins.str
    network_endpoint_type: builtins.str
    project: builtins.str
    self_link: builtins.str
    size: builtins.float
    subnetwork: builtins.str
    zone: builtins.str
    @property
    def timeouts(self) -> global___ComputeNetworkEndpointGroupXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        default_port: builtins.float = ...,
        description: builtins.str = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        network: builtins.str = ...,
        network_endpoint_type: builtins.str = ...,
        project: builtins.str = ...,
        self_link: builtins.str = ...,
        size: builtins.float = ...,
        subnetwork: builtins.str = ...,
        zone: builtins.str = ...,
        timeouts: global___ComputeNetworkEndpointGroupXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["default_port", b"default_port", "description", b"description", "id", b"id", "name", b"name", "network", b"network", "network_endpoint_type", b"network_endpoint_type", "project", b"project", "resource_info", b"resource_info", "self_link", b"self_link", "size", b"size", "subnetwork", b"subnetwork", "timeouts", b"timeouts", "zone", b"zone"]) -> None: ...

global___ComputeNetworkEndpointGroup = ComputeNetworkEndpointGroup

@typing_extensions.final
class ComputeNetworkPeeringXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___ComputeNetworkPeeringXTimeouts = ComputeNetworkPeeringXTimeouts

@typing_extensions.final
class ComputeNetworkPeering(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXPORT_CUSTOM_ROUTES_FIELD_NUMBER: builtins.int
    EXPORT_SUBNET_ROUTES_WITH_PUBLIC_IP_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    IMPORT_CUSTOM_ROUTES_FIELD_NUMBER: builtins.int
    IMPORT_SUBNET_ROUTES_WITH_PUBLIC_IP_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    NETWORK_FIELD_NUMBER: builtins.int
    PEER_NETWORK_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    STATE_DETAILS_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    export_custom_routes: builtins.bool
    export_subnet_routes_with_public_ip: builtins.bool
    id: builtins.str
    import_custom_routes: builtins.bool
    import_subnet_routes_with_public_ip: builtins.bool
    name: builtins.str
    network: builtins.str
    peer_network: builtins.str
    state: builtins.str
    state_details: builtins.str
    @property
    def timeouts(self) -> global___ComputeNetworkPeeringXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        export_custom_routes: builtins.bool = ...,
        export_subnet_routes_with_public_ip: builtins.bool = ...,
        id: builtins.str = ...,
        import_custom_routes: builtins.bool = ...,
        import_subnet_routes_with_public_ip: builtins.bool = ...,
        name: builtins.str = ...,
        network: builtins.str = ...,
        peer_network: builtins.str = ...,
        state: builtins.str = ...,
        state_details: builtins.str = ...,
        timeouts: global___ComputeNetworkPeeringXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["export_custom_routes", b"export_custom_routes", "export_subnet_routes_with_public_ip", b"export_subnet_routes_with_public_ip", "id", b"id", "import_custom_routes", b"import_custom_routes", "import_subnet_routes_with_public_ip", b"import_subnet_routes_with_public_ip", "name", b"name", "network", b"network", "peer_network", b"peer_network", "resource_info", b"resource_info", "state", b"state", "state_details", b"state_details", "timeouts", b"timeouts"]) -> None: ...

global___ComputeNetworkPeering = ComputeNetworkPeering

@typing_extensions.final
class ComputeNetworkPeeringRoutesConfigXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___ComputeNetworkPeeringRoutesConfigXTimeouts = ComputeNetworkPeeringRoutesConfigXTimeouts

@typing_extensions.final
class ComputeNetworkPeeringRoutesConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXPORT_CUSTOM_ROUTES_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    IMPORT_CUSTOM_ROUTES_FIELD_NUMBER: builtins.int
    NETWORK_FIELD_NUMBER: builtins.int
    PEERING_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    export_custom_routes: builtins.bool
    id: builtins.str
    import_custom_routes: builtins.bool
    network: builtins.str
    peering: builtins.str
    project: builtins.str
    @property
    def timeouts(self) -> global___ComputeNetworkPeeringRoutesConfigXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        export_custom_routes: builtins.bool = ...,
        id: builtins.str = ...,
        import_custom_routes: builtins.bool = ...,
        network: builtins.str = ...,
        peering: builtins.str = ...,
        project: builtins.str = ...,
        timeouts: global___ComputeNetworkPeeringRoutesConfigXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["export_custom_routes", b"export_custom_routes", "id", b"id", "import_custom_routes", b"import_custom_routes", "network", b"network", "peering", b"peering", "project", b"project", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> None: ...

global___ComputeNetworkPeeringRoutesConfig = ComputeNetworkPeeringRoutesConfig
