# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_dataflow.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16gcp/gcp_dataflow.proto\x12\x18oak9.tython.gcp.dataflow\x1a\x13shared/shared.proto\"&\n\x14\x44\x61taflowJobXTimeouts\x12\x0e\n\x06update\x18\x01 \x01(\t\"\xdb\x07\n\x0b\x44\x61taflowJob\x12\x1e\n\x16\x61\x64\x64itional_experiments\x18\x01 \x03(\t\x12\x1f\n\x17\x65nable_streaming_engine\x18\x02 \x01(\x08\x12\n\n\x02id\x18\x03 \x01(\t\x12\x18\n\x10ip_configuration\x18\x04 \x01(\t\x12\x0e\n\x06job_id\x18\x05 \x01(\t\x12\x14\n\x0ckms_key_name\x18\x06 \x01(\t\x12\x41\n\x06labels\x18\x07 \x03(\x0b\x32\x31.oak9.tython.gcp.dataflow.DataflowJob.LabelsEntry\x12\x14\n\x0cmachine_type\x18\x08 \x01(\t\x12\x13\n\x0bmax_workers\x18\t \x01(\x01\x12\x0c\n\x04name\x18\n \x01(\t\x12\x0f\n\x07network\x18\x0b \x01(\t\x12\x11\n\ton_delete\x18\x0c \x01(\t\x12I\n\nparameters\x18\r \x03(\x0b\x32\x35.oak9.tython.gcp.dataflow.DataflowJob.ParametersEntry\x12\x0f\n\x07project\x18\x0e \x01(\t\x12\x0e\n\x06region\x18\x0f \x01(\t\x12\x1d\n\x15service_account_email\x18\x10 \x01(\t\x12$\n\x1cskip_wait_on_job_termination\x18\x11 \x01(\x08\x12\r\n\x05state\x18\x12 \x01(\t\x12\x12\n\nsubnetwork\x18\x13 \x01(\t\x12\x19\n\x11temp_gcs_location\x18\x14 \x01(\t\x12\x19\n\x11template_gcs_path\x18\x15 \x01(\t\x12_\n\x16transform_name_mapping\x18\x16 \x03(\x0b\x32?.oak9.tython.gcp.dataflow.DataflowJob.TransformNameMappingEntry\x12\x0c\n\x04type\x18\x17 \x01(\t\x12\x0c\n\x04zone\x18\x18 \x01(\t\x12@\n\x08timeouts\x18\x19 \x01(\x0b\x32..oak9.tython.gcp.dataflow.DataflowJobXTimeouts\x12\x37\n\rresource_info\x18\x1a \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x31\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a;\n\x19TransformNameMappingEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_dataflow_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DATAFLOWJOB_LABELSENTRY._options = None
  _DATAFLOWJOB_LABELSENTRY._serialized_options = b'8\001'
  _DATAFLOWJOB_PARAMETERSENTRY._options = None
  _DATAFLOWJOB_PARAMETERSENTRY._serialized_options = b'8\001'
  _DATAFLOWJOB_TRANSFORMNAMEMAPPINGENTRY._options = None
  _DATAFLOWJOB_TRANSFORMNAMEMAPPINGENTRY._serialized_options = b'8\001'
  _DATAFLOWJOBXTIMEOUTS._serialized_start=73
  _DATAFLOWJOBXTIMEOUTS._serialized_end=111
  _DATAFLOWJOB._serialized_start=114
  _DATAFLOWJOB._serialized_end=1101
  _DATAFLOWJOB_LABELSENTRY._serialized_start=944
  _DATAFLOWJOB_LABELSENTRY._serialized_end=989
  _DATAFLOWJOB_PARAMETERSENTRY._serialized_start=991
  _DATAFLOWJOB_PARAMETERSENTRY._serialized_end=1040
  _DATAFLOWJOB_TRANSFORMNAMEMAPPINGENTRY._serialized_start=1042
  _DATAFLOWJOB_TRANSFORMNAMEMAPPINGENTRY._serialized_end=1101
# @@protoc_insertion_point(module_scope)
