# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_composer.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16gcp/gcp_composer.proto\x12\x18oak9.tython.gcp.composer\x1a\x13shared/shared.proto\"A\n)ComposerEnvironmentXConfigXDatabaseConfig\x12\x14\n\x0cmachine_type\x18\x01 \x01(\t\"C\n+ComposerEnvironmentXConfigXEncryptionConfig\x12\x14\n\x0ckms_key_name\x18\x01 \x01(\t\"h\n,ComposerEnvironmentXConfigXMaintenanceWindow\x12\x10\n\x08\x65nd_time\x18\x01 \x01(\t\x12\x12\n\nrecurrence\x18\x02 \x01(\t\x12\x12\n\nstart_time\x18\x03 \x01(\t\"p\nDComposerEnvironmentXConfigXMasterAuthorizedNetworksConfigXCidrBlocks\x12\x12\n\ncidr_block\x18\x01 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x02 \x01(\t\"\xc1\x01\n9ComposerEnvironmentXConfigXMasterAuthorizedNetworksConfig\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12s\n\x0b\x63idr_blocks\x18\x02 \x03(\x0b\x32^.oak9.tython.gcp.composer.ComposerEnvironmentXConfigXMasterAuthorizedNetworksConfigXCidrBlocks\"\x93\x03\n%ComposerEnvironmentXConfigXNodeConfig\x12\x14\n\x0c\x64isk_size_gb\x18\x01 \x01(\x01\x12\x1c\n\x14\x65nable_ip_masq_agent\x18\x02 \x01(\x08\x12u\n\x14ip_allocation_policy\x18\x03 \x03(\x0b\x32W.oak9.tython.gcp.composer.ComposerEnvironmentXConfigXNodeConfig.IpAllocationPolicyEntry\x12\x14\n\x0cmachine_type\x18\x04 \x01(\t\x12\x0f\n\x07network\x18\x05 \x01(\t\x12\x14\n\x0coauth_scopes\x18\x06 \x03(\t\x12\x17\n\x0fservice_account\x18\x07 \x01(\t\x12\x12\n\nsubnetwork\x18\x08 \x01(\t\x12\x0c\n\x04tags\x18\t \x03(\t\x12\x0c\n\x04zone\x18\n \x01(\t\x1a\x39\n\x17IpAllocationPolicyEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xc5\x02\n3ComposerEnvironmentXConfigXPrivateEnvironmentConfig\x12,\n$cloud_composer_connection_subnetwork\x18\x01 \x01(\t\x12.\n&cloud_composer_network_ipv4_cidr_block\x18\x02 \x01(\t\x12!\n\x19\x63loud_sql_ipv4_cidr_block\x18\x03 \x01(\t\x12\x1f\n\x17\x65nable_private_endpoint\x18\x04 \x01(\x08\x12(\n enable_privately_used_public_ips\x18\x05 \x01(\x08\x12\x1e\n\x16master_ipv4_cidr_block\x18\x06 \x01(\t\x12\"\n\x1aweb_server_ipv4_cidr_block\x18\x07 \x01(\t\"\xfc\x04\n)ComposerEnvironmentXConfigXSoftwareConfig\x12\x81\x01\n\x18\x61irflow_config_overrides\x18\x01 \x03(\x0b\x32_.oak9.tython.gcp.composer.ComposerEnvironmentXConfigXSoftwareConfig.AirflowConfigOverridesEntry\x12l\n\renv_variables\x18\x02 \x03(\x0b\x32U.oak9.tython.gcp.composer.ComposerEnvironmentXConfigXSoftwareConfig.EnvVariablesEntry\x12\x15\n\rimage_version\x18\x03 \x01(\t\x12l\n\rpypi_packages\x18\x04 \x03(\x0b\x32U.oak9.tython.gcp.composer.ComposerEnvironmentXConfigXSoftwareConfig.PypiPackagesEntry\x12\x16\n\x0epython_version\x18\x05 \x01(\t\x12\x17\n\x0fscheduler_count\x18\x06 \x01(\x01\x1a=\n\x1b\x41irflowConfigOverridesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x33\n\x11\x45nvVariablesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x33\n\x11PypiPackagesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"B\n*ComposerEnvironmentXConfigXWebServerConfig\x12\x14\n\x0cmachine_type\x18\x01 \x01(\t\"m\nGComposerEnvironmentXConfigXWebServerNetworkAccessControlXAllowedIpRange\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"\xb7\x01\n8ComposerEnvironmentXConfigXWebServerNetworkAccessControl\x12{\n\x10\x61llowed_ip_range\x18\x01 \x03(\x0b\x32\x61.oak9.tython.gcp.composer.ComposerEnvironmentXConfigXWebServerNetworkAccessControlXAllowedIpRange\"y\n4ComposerEnvironmentXConfigXWorkloadsConfigXScheduler\x12\r\n\x05\x63ount\x18\x01 \x01(\x01\x12\x0b\n\x03\x63pu\x18\x02 \x01(\x01\x12\x11\n\tmemory_gb\x18\x03 \x01(\x01\x12\x12\n\nstorage_gb\x18\x04 \x01(\x01\"j\n4ComposerEnvironmentXConfigXWorkloadsConfigXWebServer\x12\x0b\n\x03\x63pu\x18\x01 \x01(\x01\x12\x11\n\tmemory_gb\x18\x02 \x01(\x01\x12\x12\n\nstorage_gb\x18\x03 \x01(\x01\"\x8d\x01\n1ComposerEnvironmentXConfigXWorkloadsConfigXWorker\x12\x0b\n\x03\x63pu\x18\x01 \x01(\x01\x12\x11\n\tmax_count\x18\x02 \x01(\x01\x12\x11\n\tmemory_gb\x18\x03 \x01(\x01\x12\x11\n\tmin_count\x18\x04 \x01(\x01\x12\x12\n\nstorage_gb\x18\x05 \x01(\x01\"\xd0\x02\n*ComposerEnvironmentXConfigXWorkloadsConfig\x12\x61\n\tscheduler\x18\x01 \x01(\x0b\x32N.oak9.tython.gcp.composer.ComposerEnvironmentXConfigXWorkloadsConfigXScheduler\x12\x62\n\nweb_server\x18\x02 \x01(\x0b\x32N.oak9.tython.gcp.composer.ComposerEnvironmentXConfigXWorkloadsConfigXWebServer\x12[\n\x06worker\x18\x03 \x01(\x0b\x32K.oak9.tython.gcp.composer.ComposerEnvironmentXConfigXWorkloadsConfigXWorker\"\x97\t\n\x1a\x43omposerEnvironmentXConfig\x12\x13\n\x0b\x61irflow_uri\x18\x01 \x01(\t\x12\x16\n\x0e\x64\x61g_gcs_prefix\x18\x02 \x01(\t\x12\x18\n\x10\x65nvironment_size\x18\x03 \x01(\t\x12\x13\n\x0bgke_cluster\x18\x04 \x01(\t\x12\x12\n\nnode_count\x18\x05 \x01(\x01\x12\\\n\x0f\x64\x61tabase_config\x18\x06 \x01(\x0b\x32\x43.oak9.tython.gcp.composer.ComposerEnvironmentXConfigXDatabaseConfig\x12`\n\x11\x65ncryption_config\x18\x07 \x01(\x0b\x32\x45.oak9.tython.gcp.composer.ComposerEnvironmentXConfigXEncryptionConfig\x12\x62\n\x12maintenance_window\x18\x08 \x01(\x0b\x32\x46.oak9.tython.gcp.composer.ComposerEnvironmentXConfigXMaintenanceWindow\x12~\n!master_authorized_networks_config\x18\t \x01(\x0b\x32S.oak9.tython.gcp.composer.ComposerEnvironmentXConfigXMasterAuthorizedNetworksConfig\x12T\n\x0bnode_config\x18\n \x01(\x0b\x32?.oak9.tython.gcp.composer.ComposerEnvironmentXConfigXNodeConfig\x12q\n\x1aprivate_environment_config\x18\x0b \x01(\x0b\x32M.oak9.tython.gcp.composer.ComposerEnvironmentXConfigXPrivateEnvironmentConfig\x12\\\n\x0fsoftware_config\x18\x0c \x01(\x0b\x32\x43.oak9.tython.gcp.composer.ComposerEnvironmentXConfigXSoftwareConfig\x12_\n\x11web_server_config\x18\r \x01(\x0b\x32\x44.oak9.tython.gcp.composer.ComposerEnvironmentXConfigXWebServerConfig\x12}\n!web_server_network_access_control\x18\x0e \x01(\x0b\x32R.oak9.tython.gcp.composer.ComposerEnvironmentXConfigXWebServerNetworkAccessControl\x12^\n\x10workloads_config\x18\x0f \x01(\x0b\x32\x44.oak9.tython.gcp.composer.ComposerEnvironmentXConfigXWorkloadsConfig\"N\n\x1c\x43omposerEnvironmentXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\x93\x03\n\x13\x43omposerEnvironment\x12\n\n\x02id\x18\x01 \x01(\t\x12I\n\x06labels\x18\x02 \x03(\x0b\x32\x39.oak9.tython.gcp.composer.ComposerEnvironment.LabelsEntry\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0f\n\x07project\x18\x04 \x01(\t\x12\x0e\n\x06region\x18\x05 \x01(\t\x12\x44\n\x06\x63onfig\x18\x06 \x01(\x0b\x32\x34.oak9.tython.gcp.composer.ComposerEnvironmentXConfig\x12H\n\x08timeouts\x18\x07 \x01(\x0b\x32\x36.oak9.tython.gcp.composer.ComposerEnvironmentXTimeouts\x12\x37\n\rresource_info\x18\x08 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_composer_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMPOSERENVIRONMENTXCONFIGXNODECONFIG_IPALLOCATIONPOLICYENTRY._options = None
  _COMPOSERENVIRONMENTXCONFIGXNODECONFIG_IPALLOCATIONPOLICYENTRY._serialized_options = b'8\001'
  _COMPOSERENVIRONMENTXCONFIGXSOFTWARECONFIG_AIRFLOWCONFIGOVERRIDESENTRY._options = None
  _COMPOSERENVIRONMENTXCONFIGXSOFTWARECONFIG_AIRFLOWCONFIGOVERRIDESENTRY._serialized_options = b'8\001'
  _COMPOSERENVIRONMENTXCONFIGXSOFTWARECONFIG_ENVVARIABLESENTRY._options = None
  _COMPOSERENVIRONMENTXCONFIGXSOFTWARECONFIG_ENVVARIABLESENTRY._serialized_options = b'8\001'
  _COMPOSERENVIRONMENTXCONFIGXSOFTWARECONFIG_PYPIPACKAGESENTRY._options = None
  _COMPOSERENVIRONMENTXCONFIGXSOFTWARECONFIG_PYPIPACKAGESENTRY._serialized_options = b'8\001'
  _COMPOSERENVIRONMENT_LABELSENTRY._options = None
  _COMPOSERENVIRONMENT_LABELSENTRY._serialized_options = b'8\001'
  _COMPOSERENVIRONMENTXCONFIGXDATABASECONFIG._serialized_start=73
  _COMPOSERENVIRONMENTXCONFIGXDATABASECONFIG._serialized_end=138
  _COMPOSERENVIRONMENTXCONFIGXENCRYPTIONCONFIG._serialized_start=140
  _COMPOSERENVIRONMENTXCONFIGXENCRYPTIONCONFIG._serialized_end=207
  _COMPOSERENVIRONMENTXCONFIGXMAINTENANCEWINDOW._serialized_start=209
  _COMPOSERENVIRONMENTXCONFIGXMAINTENANCEWINDOW._serialized_end=313
  _COMPOSERENVIRONMENTXCONFIGXMASTERAUTHORIZEDNETWORKSCONFIGXCIDRBLOCKS._serialized_start=315
  _COMPOSERENVIRONMENTXCONFIGXMASTERAUTHORIZEDNETWORKSCONFIGXCIDRBLOCKS._serialized_end=427
  _COMPOSERENVIRONMENTXCONFIGXMASTERAUTHORIZEDNETWORKSCONFIG._serialized_start=430
  _COMPOSERENVIRONMENTXCONFIGXMASTERAUTHORIZEDNETWORKSCONFIG._serialized_end=623
  _COMPOSERENVIRONMENTXCONFIGXNODECONFIG._serialized_start=626
  _COMPOSERENVIRONMENTXCONFIGXNODECONFIG._serialized_end=1029
  _COMPOSERENVIRONMENTXCONFIGXNODECONFIG_IPALLOCATIONPOLICYENTRY._serialized_start=972
  _COMPOSERENVIRONMENTXCONFIGXNODECONFIG_IPALLOCATIONPOLICYENTRY._serialized_end=1029
  _COMPOSERENVIRONMENTXCONFIGXPRIVATEENVIRONMENTCONFIG._serialized_start=1032
  _COMPOSERENVIRONMENTXCONFIGXPRIVATEENVIRONMENTCONFIG._serialized_end=1357
  _COMPOSERENVIRONMENTXCONFIGXSOFTWARECONFIG._serialized_start=1360
  _COMPOSERENVIRONMENTXCONFIGXSOFTWARECONFIG._serialized_end=1996
  _COMPOSERENVIRONMENTXCONFIGXSOFTWARECONFIG_AIRFLOWCONFIGOVERRIDESENTRY._serialized_start=1829
  _COMPOSERENVIRONMENTXCONFIGXSOFTWARECONFIG_AIRFLOWCONFIGOVERRIDESENTRY._serialized_end=1890
  _COMPOSERENVIRONMENTXCONFIGXSOFTWARECONFIG_ENVVARIABLESENTRY._serialized_start=1892
  _COMPOSERENVIRONMENTXCONFIGXSOFTWARECONFIG_ENVVARIABLESENTRY._serialized_end=1943
  _COMPOSERENVIRONMENTXCONFIGXSOFTWARECONFIG_PYPIPACKAGESENTRY._serialized_start=1945
  _COMPOSERENVIRONMENTXCONFIGXSOFTWARECONFIG_PYPIPACKAGESENTRY._serialized_end=1996
  _COMPOSERENVIRONMENTXCONFIGXWEBSERVERCONFIG._serialized_start=1998
  _COMPOSERENVIRONMENTXCONFIGXWEBSERVERCONFIG._serialized_end=2064
  _COMPOSERENVIRONMENTXCONFIGXWEBSERVERNETWORKACCESSCONTROLXALLOWEDIPRANGE._serialized_start=2066
  _COMPOSERENVIRONMENTXCONFIGXWEBSERVERNETWORKACCESSCONTROLXALLOWEDIPRANGE._serialized_end=2175
  _COMPOSERENVIRONMENTXCONFIGXWEBSERVERNETWORKACCESSCONTROL._serialized_start=2178
  _COMPOSERENVIRONMENTXCONFIGXWEBSERVERNETWORKACCESSCONTROL._serialized_end=2361
  _COMPOSERENVIRONMENTXCONFIGXWORKLOADSCONFIGXSCHEDULER._serialized_start=2363
  _COMPOSERENVIRONMENTXCONFIGXWORKLOADSCONFIGXSCHEDULER._serialized_end=2484
  _COMPOSERENVIRONMENTXCONFIGXWORKLOADSCONFIGXWEBSERVER._serialized_start=2486
  _COMPOSERENVIRONMENTXCONFIGXWORKLOADSCONFIGXWEBSERVER._serialized_end=2592
  _COMPOSERENVIRONMENTXCONFIGXWORKLOADSCONFIGXWORKER._serialized_start=2595
  _COMPOSERENVIRONMENTXCONFIGXWORKLOADSCONFIGXWORKER._serialized_end=2736
  _COMPOSERENVIRONMENTXCONFIGXWORKLOADSCONFIG._serialized_start=2739
  _COMPOSERENVIRONMENTXCONFIGXWORKLOADSCONFIG._serialized_end=3075
  _COMPOSERENVIRONMENTXCONFIG._serialized_start=3078
  _COMPOSERENVIRONMENTXCONFIG._serialized_end=4253
  _COMPOSERENVIRONMENTXTIMEOUTS._serialized_start=4255
  _COMPOSERENVIRONMENTXTIMEOUTS._serialized_end=4333
  _COMPOSERENVIRONMENT._serialized_start=4336
  _COMPOSERENVIRONMENT._serialized_end=4739
  _COMPOSERENVIRONMENT_LABELSENTRY._serialized_start=4694
  _COMPOSERENVIRONMENT_LABELSENTRY._serialized_end=4739
# @@protoc_insertion_point(module_scope)
