"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class CertificateValidity(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    value: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        value: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "value", b"value"]) -> None: ...

global___CertificateValidity = CertificateValidity

@typing_extensions.final
class Certificate(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CERTIFICATE_AUTHORITY_ARN_FIELD_NUMBER: builtins.int
    CERTIFICATE_SIGNING_REQUEST_FIELD_NUMBER: builtins.int
    SIGNING_ALGORITHM_FIELD_NUMBER: builtins.int
    TEMPLATE_ARN_FIELD_NUMBER: builtins.int
    VALIDITY_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    certificate_authority_arn: builtins.str
    certificate_signing_request: builtins.str
    signing_algorithm: builtins.str
    template_arn: builtins.str
    @property
    def validity(self) -> global___CertificateValidity: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        certificate_authority_arn: builtins.str = ...,
        certificate_signing_request: builtins.str = ...,
        signing_algorithm: builtins.str = ...,
        template_arn: builtins.str = ...,
        validity: global___CertificateValidity | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "validity", b"validity"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["certificate_authority_arn", b"certificate_authority_arn", "certificate_signing_request", b"certificate_signing_request", "resource_info", b"resource_info", "signing_algorithm", b"signing_algorithm", "template_arn", b"template_arn", "validity", b"validity"]) -> None: ...

global___Certificate = Certificate

@typing_extensions.final
class ACMPCA(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CERTIFICATE_FIELD_NUMBER: builtins.int
    CERTIFICATE_AUTHORITY_FIELD_NUMBER: builtins.int
    CERTIFICATE_AUTHORITY_ACTIVATION_FIELD_NUMBER: builtins.int
    @property
    def certificate(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Certificate]: ...
    @property
    def certificate_authority(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CertificateAuthority]: ...
    @property
    def certificate_authority_activation(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CertificateAuthorityActivation]: ...
    def __init__(
        self,
        *,
        certificate: collections.abc.Iterable[global___Certificate] | None = ...,
        certificate_authority: collections.abc.Iterable[global___CertificateAuthority] | None = ...,
        certificate_authority_activation: collections.abc.Iterable[global___CertificateAuthorityActivation] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["certificate", b"certificate", "certificate_authority", b"certificate_authority", "certificate_authority_activation", b"certificate_authority_activation"]) -> None: ...

global___ACMPCA = ACMPCA

@typing_extensions.final
class CertificateAuthoritySubject(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    COUNTRY_FIELD_NUMBER: builtins.int
    ORGANIZATION_FIELD_NUMBER: builtins.int
    ORGANIZATIONAL_UNIT_FIELD_NUMBER: builtins.int
    DISTINGUISHED_NAME_QUALIFIER_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    COMMON_NAME_FIELD_NUMBER: builtins.int
    SERIAL_NUMBER_FIELD_NUMBER: builtins.int
    LOCALITY_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    SURNAME_FIELD_NUMBER: builtins.int
    GIVEN_NAME_FIELD_NUMBER: builtins.int
    INITIALS_FIELD_NUMBER: builtins.int
    PSEUDONYM_FIELD_NUMBER: builtins.int
    GENERATION_QUALIFIER_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    country: builtins.str
    organization: builtins.str
    organizational_unit: builtins.str
    distinguished_name_qualifier: builtins.str
    state: builtins.str
    common_name: builtins.str
    serial_number: builtins.str
    locality: builtins.str
    title: builtins.str
    surname: builtins.str
    given_name: builtins.str
    initials: builtins.str
    pseudonym: builtins.str
    generation_qualifier: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        country: builtins.str = ...,
        organization: builtins.str = ...,
        organizational_unit: builtins.str = ...,
        distinguished_name_qualifier: builtins.str = ...,
        state: builtins.str = ...,
        common_name: builtins.str = ...,
        serial_number: builtins.str = ...,
        locality: builtins.str = ...,
        title: builtins.str = ...,
        surname: builtins.str = ...,
        given_name: builtins.str = ...,
        initials: builtins.str = ...,
        pseudonym: builtins.str = ...,
        generation_qualifier: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["common_name", b"common_name", "country", b"country", "distinguished_name_qualifier", b"distinguished_name_qualifier", "generation_qualifier", b"generation_qualifier", "given_name", b"given_name", "initials", b"initials", "locality", b"locality", "organization", b"organization", "organizational_unit", b"organizational_unit", "pseudonym", b"pseudonym", "resource_info", b"resource_info", "serial_number", b"serial_number", "state", b"state", "surname", b"surname", "title", b"title"]) -> None: ...

global___CertificateAuthoritySubject = CertificateAuthoritySubject

@typing_extensions.final
class CertificateAuthorityCrlConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ENABLED_FIELD_NUMBER: builtins.int
    EXPIRATION_IN_DAYS_FIELD_NUMBER: builtins.int
    CUSTOM_CNAME_FIELD_NUMBER: builtins.int
    S3_BUCKET_NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    enabled: builtins.bool
    expiration_in_days: builtins.int
    custom_cname: builtins.str
    s3_bucket_name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        enabled: builtins.bool = ...,
        expiration_in_days: builtins.int = ...,
        custom_cname: builtins.str = ...,
        s3_bucket_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["custom_cname", b"custom_cname", "enabled", b"enabled", "expiration_in_days", b"expiration_in_days", "resource_info", b"resource_info", "s3_bucket_name", b"s3_bucket_name"]) -> None: ...

global___CertificateAuthorityCrlConfiguration = CertificateAuthorityCrlConfiguration

@typing_extensions.final
class CertificateAuthorityRevocationConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CRL_CONFIGURATION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def crl_configuration(self) -> global___CertificateAuthorityCrlConfiguration: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        crl_configuration: global___CertificateAuthorityCrlConfiguration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["crl_configuration", b"crl_configuration", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["crl_configuration", b"crl_configuration", "resource_info", b"resource_info"]) -> None: ...

global___CertificateAuthorityRevocationConfiguration = CertificateAuthorityRevocationConfiguration

@typing_extensions.final
class CertificateAuthority(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    KEY_ALGORITHM_FIELD_NUMBER: builtins.int
    SIGNING_ALGORITHM_FIELD_NUMBER: builtins.int
    SUBJECT_FIELD_NUMBER: builtins.int
    REVOCATION_CONFIGURATION_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    type: builtins.str
    key_algorithm: builtins.str
    signing_algorithm: builtins.str
    @property
    def subject(self) -> global___CertificateAuthoritySubject: ...
    @property
    def revocation_configuration(self) -> global___CertificateAuthorityRevocationConfiguration: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        type: builtins.str = ...,
        key_algorithm: builtins.str = ...,
        signing_algorithm: builtins.str = ...,
        subject: global___CertificateAuthoritySubject | None = ...,
        revocation_configuration: global___CertificateAuthorityRevocationConfiguration | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "revocation_configuration", b"revocation_configuration", "subject", b"subject"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["key_algorithm", b"key_algorithm", "resource_info", b"resource_info", "revocation_configuration", b"revocation_configuration", "signing_algorithm", b"signing_algorithm", "subject", b"subject", "tags", b"tags", "type", b"type"]) -> None: ...

global___CertificateAuthority = CertificateAuthority

@typing_extensions.final
class CertificateAuthorityActivation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CERTIFICATE_AUTHORITY_ARN_FIELD_NUMBER: builtins.int
    CERTIFICATE_FIELD_NUMBER: builtins.int
    CERTIFICATE_CHAIN_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    certificate_authority_arn: builtins.str
    certificate: builtins.str
    certificate_chain: builtins.str
    status: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        certificate_authority_arn: builtins.str = ...,
        certificate: builtins.str = ...,
        certificate_chain: builtins.str = ...,
        status: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["certificate", b"certificate", "certificate_authority_arn", b"certificate_authority_arn", "certificate_chain", b"certificate_chain", "resource_info", b"resource_info", "status", b"status"]) -> None: ...

global___CertificateAuthorityActivation = CertificateAuthorityActivation
