# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_certificatemanager.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n aws/aws_certificatemanager.proto\x12\"oak9.tython.aws.certificatemanager\x1a\x13shared/shared.proto\"\xa4\x01\n!CertificateDomainValidationOption\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64omain_name\x18\x02 \x01(\t\x12\x16\n\x0ehosted_zone_id\x18\x03 \x01(\t\x12\x19\n\x11validation_domain\x18\x04 \x01(\t\"\xd1\x03\n\x0b\x43\x65rtificate\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12!\n\x19\x63\x65rtificate_authority_arn\x18\x02 \x01(\t\x12\x33\n+certificate_transparency_logging_preference\x18\x03 \x01(\t\x12\x13\n\x0b\x64omain_name\x18\x04 \x01(\t\x12h\n\x19\x64omain_validation_options\x18\x05 \x03(\x0b\x32\x45.oak9.tython.aws.certificatemanager.CertificateDomainValidationOption\x12!\n\x19subject_alternative_names\x18\x06 \x03(\t\x12G\n\x04tags\x18\x07 \x03(\x0b\x32\x39.oak9.tython.aws.certificatemanager.Certificate.TagsEntry\x12\x19\n\x11validation_method\x18\x08 \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"Z\n\x12\x43\x65rtificateManager\x12\x44\n\x0b\x63\x65rtificate\x18\x01 \x01(\x0b\x32/.oak9.tython.aws.certificatemanager.Certificateb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_certificatemanager_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CERTIFICATE_TAGSENTRY._options = None
  _CERTIFICATE_TAGSENTRY._serialized_options = b'8\001'
  _CERTIFICATEDOMAINVALIDATIONOPTION._serialized_start=94
  _CERTIFICATEDOMAINVALIDATIONOPTION._serialized_end=258
  _CERTIFICATE._serialized_start=261
  _CERTIFICATE._serialized_end=726
  _CERTIFICATE_TAGSENTRY._serialized_start=683
  _CERTIFICATE_TAGSENTRY._serialized_end=726
  _CERTIFICATEMANAGER._serialized_start=728
  _CERTIFICATEMANAGER._serialized_end=818
# @@protoc_insertion_point(module_scope)
