# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_compute_image.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bgcp/gcp_compute_image.proto\x12\x1doak9.tython.gcp.compute_image\x1a\x13shared/shared.proto\",\n\x1c\x43omputeImageXGuestOsFeatures\x12\x0c\n\x04type\x18\x01 \x01(\t\"L\n\x14\x43omputeImageXRawDisk\x12\x16\n\x0e\x63ontainer_type\x18\x01 \x01(\t\x12\x0c\n\x04sha1\x18\x02 \x01(\t\x12\x0e\n\x06source\x18\x03 \x01(\t\"G\n\x15\x43omputeImageXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xc8\x05\n\x0c\x43omputeImage\x12\x1a\n\x12\x61rchive_size_bytes\x18\x01 \x01(\x01\x12\x1a\n\x12\x63reation_timestamp\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x14\n\x0c\x64isk_size_gb\x18\x04 \x01(\x01\x12\x0e\n\x06\x66\x61mily\x18\x05 \x01(\t\x12\n\n\x02id\x18\x06 \x01(\t\x12\x19\n\x11label_fingerprint\x18\x07 \x01(\t\x12G\n\x06labels\x18\x08 \x03(\x0b\x32\x37.oak9.tython.gcp.compute_image.ComputeImage.LabelsEntry\x12\x10\n\x08licenses\x18\t \x03(\t\x12\x0c\n\x04name\x18\n \x01(\t\x12\x0f\n\x07project\x18\x0b \x01(\t\x12\x11\n\tself_link\x18\x0c \x01(\t\x12\x13\n\x0bsource_disk\x18\r \x01(\t\x12\x14\n\x0csource_image\x18\x0e \x01(\t\x12\x17\n\x0fsource_snapshot\x18\x0f \x01(\t\x12V\n\x11guest_os_features\x18\x10 \x03(\x0b\x32;.oak9.tython.gcp.compute_image.ComputeImageXGuestOsFeatures\x12\x45\n\x08raw_disk\x18\x11 \x01(\x0b\x32\x33.oak9.tython.gcp.compute_image.ComputeImageXRawDisk\x12\x46\n\x08timeouts\x18\x12 \x01(\x0b\x32\x34.oak9.tython.gcp.compute_image.ComputeImageXTimeouts\x12\x37\n\rresource_info\x18\x13 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"Z\n ComputeImageIamBindingXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\xfe\x01\n\x16\x43omputeImageIamBinding\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\r\n\x05image\x18\x03 \x01(\t\x12\x0f\n\x07members\x18\x04 \x03(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x0c\n\x04role\x18\x06 \x01(\t\x12R\n\tcondition\x18\x07 \x01(\x0b\x32?.oak9.tython.gcp.compute_image.ComputeImageIamBindingXCondition\x12\x37\n\rresource_info\x18\x08 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"Y\n\x1f\x43omputeImageIamMemberXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\xfb\x01\n\x15\x43omputeImageIamMember\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\r\n\x05image\x18\x03 \x01(\t\x12\x0e\n\x06member\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x0c\n\x04role\x18\x06 \x01(\t\x12Q\n\tcondition\x18\x07 \x01(\x0b\x32>.oak9.tython.gcp.compute_image.ComputeImageIamMemberXCondition\x12\x37\n\rresource_info\x18\x08 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x9f\x01\n\x15\x43omputeImageIamPolicy\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\r\n\x05image\x18\x03 \x01(\t\x12\x13\n\x0bpolicy_data\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_compute_image_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMPUTEIMAGE_LABELSENTRY._options = None
  _COMPUTEIMAGE_LABELSENTRY._serialized_options = b'8\001'
  _COMPUTEIMAGEXGUESTOSFEATURES._serialized_start=83
  _COMPUTEIMAGEXGUESTOSFEATURES._serialized_end=127
  _COMPUTEIMAGEXRAWDISK._serialized_start=129
  _COMPUTEIMAGEXRAWDISK._serialized_end=205
  _COMPUTEIMAGEXTIMEOUTS._serialized_start=207
  _COMPUTEIMAGEXTIMEOUTS._serialized_end=278
  _COMPUTEIMAGE._serialized_start=281
  _COMPUTEIMAGE._serialized_end=993
  _COMPUTEIMAGE_LABELSENTRY._serialized_start=948
  _COMPUTEIMAGE_LABELSENTRY._serialized_end=993
  _COMPUTEIMAGEIAMBINDINGXCONDITION._serialized_start=995
  _COMPUTEIMAGEIAMBINDINGXCONDITION._serialized_end=1085
  _COMPUTEIMAGEIAMBINDING._serialized_start=1088
  _COMPUTEIMAGEIAMBINDING._serialized_end=1342
  _COMPUTEIMAGEIAMMEMBERXCONDITION._serialized_start=1344
  _COMPUTEIMAGEIAMMEMBERXCONDITION._serialized_end=1433
  _COMPUTEIMAGEIAMMEMBER._serialized_start=1436
  _COMPUTEIMAGEIAMMEMBER._serialized_end=1687
  _COMPUTEIMAGEIAMPOLICY._serialized_start=1690
  _COMPUTEIMAGEIAMPOLICY._serialized_end=1849
# @@protoc_insertion_point(module_scope)
