# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_gamelift.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16\x61ws/aws_gamelift.proto\x12\x18oak9.tython.aws.gamelift\x1a\x13shared/shared.proto\"r\n\x14\x41liasRoutingStrategy\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x10\n\x08\x66leet_id\x18\x03 \x01(\t\"\xad\x01\n\x05\x41lias\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12H\n\x10routing_strategy\x18\x04 \x01(\x0b\x32..oak9.tython.aws.gamelift.AliasRoutingStrategy\"\xfd\x03\n\x08GameLift\x12.\n\x05\x61lias\x18\x01 \x03(\x0b\x32\x1f.oak9.tython.aws.gamelift.Alias\x12.\n\x05\x62uild\x18\x02 \x03(\x0b\x32\x1f.oak9.tython.aws.gamelift.Build\x12.\n\x05\x66leet\x18\x03 \x03(\x0b\x32\x1f.oak9.tython.aws.gamelift.Fleet\x12\x44\n\x11game_server_group\x18\x04 \x03(\x0b\x32).oak9.tython.aws.gamelift.GameServerGroup\x12\x46\n\x12game_session_queue\x18\x05 \x03(\x0b\x32*.oak9.tython.aws.gamelift.GameSessionQueue\x12U\n\x19matchmaking_configuration\x18\x06 \x03(\x0b\x32\x32.oak9.tython.aws.gamelift.MatchmakingConfiguration\x12J\n\x14matchmaking_rule_set\x18\x07 \x03(\x0b\x32,.oak9.tython.aws.gamelift.MatchmakingRuleSet\x12\x30\n\x06script\x18\x08 \x03(\x0b\x32 .oak9.tython.aws.gamelift.Script\"\x91\x01\n\x0f\x42uildS3Location\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06\x62ucket\x18\x02 \x01(\t\x12\x0b\n\x03key\x18\x03 \x01(\t\x12\x16\n\x0eobject_version\x18\x04 \x01(\t\x12\x10\n\x08role_arn\x18\x05 \x01(\t\"\xbe\x01\n\x05\x42uild\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x18\n\x10operating_system\x18\x03 \x01(\t\x12\x43\n\x10storage_location\x18\x04 \x01(\x0b\x32).oak9.tython.aws.gamelift.BuildS3Location\x12\x0f\n\x07version\x18\x05 \x01(\t\"r\n\x1d\x46leetCertificateConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x18\n\x10\x63\x65rtificate_type\x18\x02 \x01(\t\"\x94\x01\n\x11\x46leetIpPermission\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\tfrom_port\x18\x02 \x01(\x05\x12\x10\n\x08ip_range\x18\x03 \x01(\t\x12\x10\n\x08protocol\x18\x04 \x01(\t\x12\x0f\n\x07to_port\x18\x05 \x01(\x05\"\xa4\x01\n FleetResourceCreationLimitPolicy\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12%\n\x1dnew_game_sessions_per_creator\x18\x02 \x01(\x05\x12 \n\x18policy_period_in_minutes\x18\x03 \x01(\x05\"\x95\x01\n\x12\x46leetServerProcess\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1d\n\x15\x63oncurrent_executions\x18\x02 \x01(\x05\x12\x13\n\x0blaunch_path\x18\x03 \x01(\t\x12\x12\n\nparameters\x18\x04 \x01(\t\"\xfe\x01\n\x19\x46leetRuntimeConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12/\n\'game_session_activation_timeout_seconds\x18\x02 \x01(\x05\x12/\n\'max_concurrent_game_session_activations\x18\x03 \x01(\x05\x12\x46\n\x10server_processes\x18\x04 \x03(\x0b\x32,.oak9.tython.aws.gamelift.FleetServerProcess\"\xc4\x06\n\x05\x46leet\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08\x62uild_id\x18\x02 \x01(\t\x12Z\n\x19\x63\x65rtificate_configuration\x18\x03 \x01(\x0b\x32\x37.oak9.tython.aws.gamelift.FleetCertificateConfiguration\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x1e\n\x16\x64\x65sired_e_c2_instances\x18\x05 \x01(\x05\x12M\n\x18\x65_c2_inbound_permissions\x18\x06 \x03(\x0b\x32+.oak9.tython.aws.gamelift.FleetIpPermission\x12\x1a\n\x12\x65_c2_instance_type\x18\x07 \x01(\t\x12\x12\n\nfleet_type\x18\x08 \x01(\t\x12\x19\n\x11instance_role_arn\x18\t \x01(\t\x12\x11\n\tlog_paths\x18\n \x03(\t\x12\x10\n\x08max_size\x18\x0b \x01(\x05\x12\x15\n\rmetric_groups\x18\x0c \x03(\t\x12\x10\n\x08min_size\x18\r \x01(\x05\x12\x0c\n\x04name\x18\x0e \x01(\t\x12*\n\"new_game_session_protection_policy\x18\x0f \x01(\t\x12\x1f\n\x17peer_vpc_aws_account_id\x18\x10 \x01(\t\x12\x13\n\x0bpeer_vpc_id\x18\x11 \x01(\t\x12\x62\n\x1eresource_creation_limit_policy\x18\x12 \x01(\x0b\x32:.oak9.tython.aws.gamelift.FleetResourceCreationLimitPolicy\x12R\n\x15runtime_configuration\x18\x13 \x01(\x0b\x32\x33.oak9.tython.aws.gamelift.FleetRuntimeConfiguration\x12\x11\n\tscript_id\x18\x14 \x01(\t\x12 \n\x18server_launch_parameters\x18\x15 \x01(\t\x12\x1a\n\x12server_launch_path\x18\x16 \x01(\t\"{\n*GameServerGroupTargetTrackingConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0ctarget_value\x18\x02 \x01(\x01\"\xeb\x01\n GameServerGroupAutoScalingPolicy\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12!\n\x19\x65stimated_instance_warmup\x18\x02 \x01(\x01\x12k\n\x1dtarget_tracking_configuration\x18\x03 \x01(\x0b\x32\x44.oak9.tython.aws.gamelift.GameServerGroupTargetTrackingConfiguration\"\x8e\x01\n!GameServerGroupInstanceDefinition\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rinstance_type\x18\x02 \x01(\t\x12\x19\n\x11weighted_capacity\x18\x03 \x01(\t\"\xb8\x01\n\"GameServerGroupInstanceDefinitions\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12Y\n\x14instance_definitions\x18\x02 \x03(\x0b\x32;.oak9.tython.aws.gamelift.GameServerGroupInstanceDefinition\"\xa3\x01\n\x1dGameServerGroupLaunchTemplate\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1a\n\x12launch_template_id\x18\x02 \x01(\t\x12\x1c\n\x14launch_template_name\x18\x03 \x01(\t\x12\x0f\n\x07version\x18\x04 \x01(\t\"\xc2\x01\n\x13GameServerGroupTags\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x45\n\x04tags\x18\x02 \x03(\x0b\x32\x37.oak9.tython.aws.gamelift.GameServerGroupTags.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"i\n\x19GameServerGroupVpcSubnets\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0bvpc_subnets\x18\x02 \x03(\t\"\x88\x05\n\x0fGameServerGroup\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12W\n\x13\x61uto_scaling_policy\x18\x02 \x01(\x0b\x32:.oak9.tython.aws.gamelift.GameServerGroupAutoScalingPolicy\x12\x1a\n\x12\x62\x61lancing_strategy\x18\x03 \x01(\t\x12\x15\n\rdelete_option\x18\x04 \x01(\t\x12\x1e\n\x16game_server_group_name\x18\x05 \x01(\t\x12%\n\x1dgame_server_protection_policy\x18\x06 \x01(\t\x12Z\n\x14instance_definitions\x18\x07 \x01(\x0b\x32<.oak9.tython.aws.gamelift.GameServerGroupInstanceDefinitions\x12P\n\x0flaunch_template\x18\x08 \x01(\x0b\x32\x37.oak9.tython.aws.gamelift.GameServerGroupLaunchTemplate\x12\x10\n\x08max_size\x18\t \x01(\x01\x12\x10\n\x08min_size\x18\n \x01(\x01\x12\x10\n\x08role_arn\x18\x0b \x01(\t\x12;\n\x04tags\x18\x0c \x01(\x0b\x32-.oak9.tython.aws.gamelift.GameServerGroupTags\x12H\n\x0bvpc_subnets\x18\r \x01(\x0b\x32\x33.oak9.tython.aws.gamelift.GameServerGroupVpcSubnets\"\xb7\x01\n#GameSessionQueuePlayerLatencyPolicy\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1f\n\x17policy_duration_seconds\x18\x02 \x01(\x05\x12\x36\n.maximum_individual_player_latency_milliseconds\x18\x03 \x01(\x05\"o\n\x1bGameSessionQueueDestination\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x17\n\x0f\x64\x65stination_arn\x18\x02 \x01(\t\"\xa2\x02\n\x10GameSessionQueue\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1a\n\x12timeout_in_seconds\x18\x02 \x01(\x05\x12^\n\x17player_latency_policies\x18\x03 \x03(\x0b\x32=.oak9.tython.aws.gamelift.GameSessionQueuePlayerLatencyPolicy\x12K\n\x0c\x64\x65stinations\x18\x04 \x03(\x0b\x32\x35.oak9.tython.aws.gamelift.GameSessionQueueDestination\x12\x0c\n\x04name\x18\x05 \x01(\t\"{\n$MatchmakingConfigurationGameProperty\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\r\n\x05value\x18\x02 \x01(\t\x12\x0b\n\x03key\x18\x03 \x01(\t\"\xf4\x03\n\x18MatchmakingConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12W\n\x0fgame_properties\x18\x02 \x03(\x0b\x32>.oak9.tython.aws.gamelift.MatchmakingConfigurationGameProperty\x12\x19\n\x11game_session_data\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\"\n\x1a\x61\x63\x63\x65ptance_timeout_seconds\x18\x05 \x01(\x05\x12\x1b\n\x13notification_target\x18\x06 \x01(\t\x12\x19\n\x11\x63ustom_event_data\x18\x07 \x01(\t\x12\x0c\n\x04name\x18\x08 \x01(\t\x12\x1f\n\x17\x61\x64\x64itional_player_count\x18\t \x01(\x05\x12\x15\n\rbackfill_mode\x18\n \x01(\t\x12\x1f\n\x17request_timeout_seconds\x18\x0b \x01(\x05\x12\x1b\n\x13\x61\x63\x63\x65ptance_required\x18\x0c \x01(\x08\x12\x15\n\rrule_set_name\x18\r \x01(\t\x12\x1f\n\x17game_session_queue_arns\x18\x0e \x03(\t\"r\n\x12MatchmakingRuleSet\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rrule_set_body\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\"\x92\x01\n\x10ScriptS3Location\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0eobject_version\x18\x02 \x01(\t\x12\x0e\n\x06\x62ucket\x18\x03 \x01(\t\x12\x0b\n\x03key\x18\x04 \x01(\t\x12\x10\n\x08role_arn\x18\x05 \x01(\t\"\xa6\x01\n\x06Script\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x44\n\x10storage_location\x18\x03 \x01(\x0b\x32*.oak9.tython.aws.gamelift.ScriptS3Location\x12\x0c\n\x04name\x18\x04 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_gamelift_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GAMESERVERGROUPTAGS_TAGSENTRY._options = None
  _GAMESERVERGROUPTAGS_TAGSENTRY._serialized_options = b'8\001'
  _ALIASROUTINGSTRATEGY._serialized_start=73
  _ALIASROUTINGSTRATEGY._serialized_end=187
  _ALIAS._serialized_start=190
  _ALIAS._serialized_end=363
  _GAMELIFT._serialized_start=366
  _GAMELIFT._serialized_end=875
  _BUILDS3LOCATION._serialized_start=878
  _BUILDS3LOCATION._serialized_end=1023
  _BUILD._serialized_start=1026
  _BUILD._serialized_end=1216
  _FLEETCERTIFICATECONFIGURATION._serialized_start=1218
  _FLEETCERTIFICATECONFIGURATION._serialized_end=1332
  _FLEETIPPERMISSION._serialized_start=1335
  _FLEETIPPERMISSION._serialized_end=1483
  _FLEETRESOURCECREATIONLIMITPOLICY._serialized_start=1486
  _FLEETRESOURCECREATIONLIMITPOLICY._serialized_end=1650
  _FLEETSERVERPROCESS._serialized_start=1653
  _FLEETSERVERPROCESS._serialized_end=1802
  _FLEETRUNTIMECONFIGURATION._serialized_start=1805
  _FLEETRUNTIMECONFIGURATION._serialized_end=2059
  _FLEET._serialized_start=2062
  _FLEET._serialized_end=2898
  _GAMESERVERGROUPTARGETTRACKINGCONFIGURATION._serialized_start=2900
  _GAMESERVERGROUPTARGETTRACKINGCONFIGURATION._serialized_end=3023
  _GAMESERVERGROUPAUTOSCALINGPOLICY._serialized_start=3026
  _GAMESERVERGROUPAUTOSCALINGPOLICY._serialized_end=3261
  _GAMESERVERGROUPINSTANCEDEFINITION._serialized_start=3264
  _GAMESERVERGROUPINSTANCEDEFINITION._serialized_end=3406
  _GAMESERVERGROUPINSTANCEDEFINITIONS._serialized_start=3409
  _GAMESERVERGROUPINSTANCEDEFINITIONS._serialized_end=3593
  _GAMESERVERGROUPLAUNCHTEMPLATE._serialized_start=3596
  _GAMESERVERGROUPLAUNCHTEMPLATE._serialized_end=3759
  _GAMESERVERGROUPTAGS._serialized_start=3762
  _GAMESERVERGROUPTAGS._serialized_end=3956
  _GAMESERVERGROUPTAGS_TAGSENTRY._serialized_start=3913
  _GAMESERVERGROUPTAGS_TAGSENTRY._serialized_end=3956
  _GAMESERVERGROUPVPCSUBNETS._serialized_start=3958
  _GAMESERVERGROUPVPCSUBNETS._serialized_end=4063
  _GAMESERVERGROUP._serialized_start=4066
  _GAMESERVERGROUP._serialized_end=4714
  _GAMESESSIONQUEUEPLAYERLATENCYPOLICY._serialized_start=4717
  _GAMESESSIONQUEUEPLAYERLATENCYPOLICY._serialized_end=4900
  _GAMESESSIONQUEUEDESTINATION._serialized_start=4902
  _GAMESESSIONQUEUEDESTINATION._serialized_end=5013
  _GAMESESSIONQUEUE._serialized_start=5016
  _GAMESESSIONQUEUE._serialized_end=5306
  _MATCHMAKINGCONFIGURATIONGAMEPROPERTY._serialized_start=5308
  _MATCHMAKINGCONFIGURATIONGAMEPROPERTY._serialized_end=5431
  _MATCHMAKINGCONFIGURATION._serialized_start=5434
  _MATCHMAKINGCONFIGURATION._serialized_end=5934
  _MATCHMAKINGRULESET._serialized_start=5936
  _MATCHMAKINGRULESET._serialized_end=6050
  _SCRIPTS3LOCATION._serialized_start=6053
  _SCRIPTS3LOCATION._serialized_end=6199
  _SCRIPT._serialized_start=6202
  _SCRIPT._serialized_end=6368
# @@protoc_insertion_point(module_scope)
