# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_macie.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13\x61ws/aws_macie.proto\x12\x15oak9.tython.aws.macie\x1a\x13shared/shared.proto\"\xc9\x01\n\x14\x43ustomDataIdentifier\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\r\n\x05regex\x18\x04 \x01(\t\x12\x1e\n\x16maximum_match_distance\x18\x05 \x01(\x05\x12\x10\n\x08keywords\x18\x06 \x03(\t\x12\x14\n\x0cignore_words\x18\x07 \x03(\t\"\xb5\x02\n\x05Macie\x12K\n\x16\x63ustom_data_identifier\x18\x01 \x03(\x0b\x32+.oak9.tython.aws.macie.CustomDataIdentifier\x12>\n\x0f\x66indings_filter\x18\x02 \x03(\x0b\x32%.oak9.tython.aws.macie.FindingsFilter\x12/\n\x07session\x18\x03 \x03(\x0b\x32\x1e.oak9.tython.aws.macie.Session\x12n\n)findings_filter_findings_filter_list_item\x18\x04 \x03(\x0b\x32;.oak9.tython.aws.macie.FindingsFilterFindingsFilterListItem\"R\n\x17\x46indingsFilterCriterion\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x9b\x01\n\x1d\x46indingsFilterFindingCriteria\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x41\n\tcriterion\x18\x02 \x01(\x0b\x32..oak9.tython.aws.macie.FindingsFilterCriterion\"\xde\x01\n\x0e\x46indingsFilter\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12N\n\x10\x66inding_criteria\x18\x04 \x01(\x0b\x32\x34.oak9.tython.aws.macie.FindingsFilterFindingCriteria\x12\x0e\n\x06\x61\x63tion\x18\x05 \x01(\t\x12\x10\n\x08position\x18\x06 \x01(\x05\"x\n\x07Session\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06status\x18\x02 \x01(\t\x12$\n\x1c\x66inding_publishing_frequency\x18\x03 \x01(\t\"y\n$FindingsFilterFindingsFilterListItem\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_macie_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CUSTOMDATAIDENTIFIER._serialized_start=68
  _CUSTOMDATAIDENTIFIER._serialized_end=269
  _MACIE._serialized_start=272
  _MACIE._serialized_end=581
  _FINDINGSFILTERCRITERION._serialized_start=583
  _FINDINGSFILTERCRITERION._serialized_end=665
  _FINDINGSFILTERFINDINGCRITERIA._serialized_start=668
  _FINDINGSFILTERFINDINGCRITERIA._serialized_end=823
  _FINDINGSFILTER._serialized_start=826
  _FINDINGSFILTER._serialized_end=1048
  _SESSION._serialized_start=1050
  _SESSION._serialized_end=1170
  _FINDINGSFILTERFINDINGSFILTERLISTITEM._serialized_start=1172
  _FINDINGSFILTERFINDINGSFILTERLISTITEM._serialized_end=1293
# @@protoc_insertion_point(module_scope)
