# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kubernetes/kubernetes_io.k8s.api.node.v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2
from oak9.tython.models.kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta import v1_pb2 as kubernetes_dot_kubernetes__io_dot_k8s_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1__pb2
from oak9.tython.models.kubernetes.kubernetes_io.k8s.api.core import v1_pb2 as kubernetes_dot_kubernetes__io_dot_k8s_dot_api_dot_core_dot_v1__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.kubernetes/kubernetes_io.k8s.api.node.v1.proto\x12\x1boak9.tython.k8s.api.node.v1\x1a\x13shared/shared.proto\x1a@kubernetes/kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1.proto\x1a.kubernetes/kubernetes_io.k8s.api.core.v1.proto\"\xbc\x01\n\x08Overhead\x12\x46\n\tpod_fixed\x18\x01 \x03(\x0b\x32\x33.oak9.tython.k8s.api.node.v1.Overhead.PodFixedEntry\x12\x37\n\rresource_info\x18\x02 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a/\n\rPodFixedEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xbe\x02\n\x0cRuntimeClass\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x0f\n\x07handler\x18\x02 \x01(\t\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12K\n\x08metadata\x18\x04 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12\x37\n\x08overhead\x18\x05 \x01(\x0b\x32%.oak9.tython.k8s.api.node.v1.Overhead\x12;\n\nscheduling\x18\x06 \x01(\x0b\x32\'.oak9.tython.k8s.api.node.v1.Scheduling\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xf3\x01\n\x10RuntimeClassList\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x38\n\x05items\x18\x02 \x03(\x0b\x32).oak9.tython.k8s.api.node.v1.RuntimeClass\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12I\n\x08metadata\x18\x04 \x01(\x0b\x32\x37.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ListMeta\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x8a\x02\n\nScheduling\x12P\n\rnode_selector\x18\x01 \x03(\x0b\x32\x39.oak9.tython.k8s.api.node.v1.Scheduling.NodeSelectorEntry\x12<\n\x0btolerations\x18\x02 \x03(\x0b\x32\'.oak9.tython.k8s.api.core.v1.Toleration\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a\x33\n\x11NodeSelectorEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'kubernetes.kubernetes_io.k8s.api.node.v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _OVERHEAD_PODFIXEDENTRY._options = None
  _OVERHEAD_PODFIXEDENTRY._serialized_options = b'8\001'
  _SCHEDULING_NODESELECTORENTRY._options = None
  _SCHEDULING_NODESELECTORENTRY._serialized_options = b'8\001'
  _OVERHEAD._serialized_start=215
  _OVERHEAD._serialized_end=403
  _OVERHEAD_PODFIXEDENTRY._serialized_start=356
  _OVERHEAD_PODFIXEDENTRY._serialized_end=403
  _RUNTIMECLASS._serialized_start=406
  _RUNTIMECLASS._serialized_end=724
  _RUNTIMECLASSLIST._serialized_start=727
  _RUNTIMECLASSLIST._serialized_end=970
  _SCHEDULING._serialized_start=973
  _SCHEDULING._serialized_end=1239
  _SCHEDULING_NODESELECTORENTRY._serialized_start=1188
  _SCHEDULING_NODESELECTORENTRY._serialized_end=1239
# @@protoc_insertion_point(module_scope)
