# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_deployment.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18gcp/gcp_deployment.proto\x12\x1aoak9.tython.gcp.deployment\x1a\x13shared/shared.proto\"@\n\"DeploymentManagerDeploymentXLabels\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"<\n)DeploymentManagerDeploymentXTargetXConfig\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\t\"K\n*DeploymentManagerDeploymentXTargetXImports\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\xd4\x01\n\"DeploymentManagerDeploymentXTarget\x12U\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x45.oak9.tython.gcp.deployment.DeploymentManagerDeploymentXTargetXConfig\x12W\n\x07imports\x18\x02 \x03(\x0b\x32\x46.oak9.tython.gcp.deployment.DeploymentManagerDeploymentXTargetXImports\"V\n$DeploymentManagerDeploymentXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\x85\x04\n\x1b\x44\x65ploymentManagerDeployment\x12\x15\n\rcreate_policy\x18\x01 \x01(\t\x12\x15\n\rdelete_policy\x18\x02 \x01(\t\x12\x15\n\rdeployment_id\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\n\n\x02id\x18\x05 \x01(\t\x12\x10\n\x08manifest\x18\x06 \x01(\t\x12\x0c\n\x04name\x18\x07 \x01(\t\x12\x0f\n\x07preview\x18\x08 \x01(\x08\x12\x0f\n\x07project\x18\t \x01(\t\x12\x11\n\tself_link\x18\n \x01(\t\x12N\n\x06labels\x18\x0b \x03(\x0b\x32>.oak9.tython.gcp.deployment.DeploymentManagerDeploymentXLabels\x12N\n\x06target\x18\x0c \x01(\x0b\x32>.oak9.tython.gcp.deployment.DeploymentManagerDeploymentXTarget\x12R\n\x08timeouts\x18\r \x01(\x0b\x32@.oak9.tython.gcp.deployment.DeploymentManagerDeploymentXTimeouts\x12\x37\n\rresource_info\x18\x0e \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_deployment_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DEPLOYMENTMANAGERDEPLOYMENTXLABELS._serialized_start=77
  _DEPLOYMENTMANAGERDEPLOYMENTXLABELS._serialized_end=141
  _DEPLOYMENTMANAGERDEPLOYMENTXTARGETXCONFIG._serialized_start=143
  _DEPLOYMENTMANAGERDEPLOYMENTXTARGETXCONFIG._serialized_end=203
  _DEPLOYMENTMANAGERDEPLOYMENTXTARGETXIMPORTS._serialized_start=205
  _DEPLOYMENTMANAGERDEPLOYMENTXTARGETXIMPORTS._serialized_end=280
  _DEPLOYMENTMANAGERDEPLOYMENTXTARGET._serialized_start=283
  _DEPLOYMENTMANAGERDEPLOYMENTXTARGET._serialized_end=495
  _DEPLOYMENTMANAGERDEPLOYMENTXTIMEOUTS._serialized_start=497
  _DEPLOYMENTMANAGERDEPLOYMENTXTIMEOUTS._serialized_end=583
  _DEPLOYMENTMANAGERDEPLOYMENT._serialized_start=586
  _DEPLOYMENTMANAGERDEPLOYMENT._serialized_end=1103
# @@protoc_insertion_point(module_scope)
