# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kubernetes/kubernetes_io.k8s.api.apps.v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2
from oak9.tython.models.kubernetes.kubernetes_io.k8s.apimachinery.pkg import runtime_pb2 as kubernetes_dot_kubernetes__io_dot_k8s_dot_apimachinery_dot_pkg_dot_runtime__pb2
from oak9.tython.models.kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta import v1_pb2 as kubernetes_dot_kubernetes__io_dot_k8s_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1__pb2
from oak9.tython.models.kubernetes.kubernetes_io.k8s.api.core import v1_pb2 as kubernetes_dot_kubernetes__io_dot_k8s_dot_api_dot_core_dot_v1__pb2
from oak9.tython.models.kubernetes.kubernetes_io.k8s.apimachinery.pkg.util import intstr_pb2 as kubernetes_dot_kubernetes__io_dot_k8s_dot_apimachinery_dot_pkg_dot_util_dot_intstr__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.kubernetes/kubernetes_io.k8s.api.apps.v1.proto\x12\x1boak9.tython.k8s.api.apps.v1\x1a\x13shared/shared.proto\x1a;kubernetes/kubernetes_io.k8s.apimachinery.pkg.runtime.proto\x1a@kubernetes/kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1.proto\x1a.kubernetes/kubernetes_io.k8s.api.core.v1.proto\x1a?kubernetes/kubernetes_io.k8s.apimachinery.pkg.util.intstr.proto\"\x95\x02\n\x12\x43ontrollerRevision\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x44\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x36.oak9.tython.k8s.apimachinery.pkg.runtime.RawExtension\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12K\n\x08metadata\x18\x04 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12\x10\n\x08revision\x18\x05 \x01(\x05\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xff\x01\n\x16\x43ontrollerRevisionList\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12>\n\x05items\x18\x02 \x03(\x0b\x32/.oak9.tython.k8s.api.apps.v1.ControllerRevision\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12I\n\x08metadata\x18\x04 \x01(\x0b\x32\x37.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ListMeta\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xac\x02\n\tDaemonSet\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12K\n\x08metadata\x18\x03 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12\x38\n\x04spec\x18\x04 \x01(\x0b\x32*.oak9.tython.k8s.api.apps.v1.DaemonSetSpec\x12<\n\x06status\x18\x05 \x01(\x0b\x32,.oak9.tython.k8s.api.apps.v1.DaemonSetStatus\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xdf\x01\n\x12\x44\x61\x65monSetCondition\x12Q\n\x14last_transition_time\x18\x01 \x01(\x0b\x32\x33.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.Time\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x0e\n\x06reason\x18\x03 \x01(\t\x12\x0e\n\x06status\x18\x04 \x01(\t\x12\x0c\n\x04type\x18\x05 \x01(\t\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xed\x01\n\rDaemonSetList\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x35\n\x05items\x18\x02 \x03(\x0b\x32&.oak9.tython.k8s.api.apps.v1.DaemonSet\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12I\n\x08metadata\x18\x04 \x01(\x0b\x32\x37.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ListMeta\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xe2\x02\n\rDaemonSetSpec\x12\x19\n\x11min_ready_seconds\x18\x01 \x01(\x05\x12\x1e\n\x16revision_history_limit\x18\x02 \x01(\x05\x12N\n\x08selector\x18\x03 \x01(\x0b\x32<.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.LabelSelector\x12>\n\x08template\x18\x04 \x01(\x0b\x32,.oak9.tython.k8s.api.core.v1.PodTemplateSpec\x12M\n\x0fupdate_strategy\x18\x05 \x01(\x0b\x32\x34.oak9.tython.k8s.api.apps.v1.DaemonSetUpdateStrategy\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x94\x03\n\x0f\x44\x61\x65monSetStatus\x12\x17\n\x0f\x63ollision_count\x18\x01 \x01(\x05\x12\x43\n\nconditions\x18\x02 \x03(\x0b\x32/.oak9.tython.k8s.api.apps.v1.DaemonSetCondition\x12 \n\x18\x63urrent_number_scheduled\x18\x03 \x01(\x05\x12 \n\x18\x64\x65sired_number_scheduled\x18\x04 \x01(\x05\x12\x18\n\x10number_available\x18\x05 \x01(\x05\x12\x1b\n\x13number_misscheduled\x18\x06 \x01(\x05\x12\x14\n\x0cnumber_ready\x18\x07 \x01(\x05\x12\x1a\n\x12number_unavailable\x18\x08 \x01(\x05\x12\x1b\n\x13observed_generation\x18\t \x01(\x05\x12 \n\x18updated_number_scheduled\x18\n \x01(\x05\x12\x37\n\rresource_info\x18\x0b \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xad\x01\n\x17\x44\x61\x65monSetUpdateStrategy\x12K\n\x0erolling_update\x18\x01 \x01(\x0b\x32\x33.oak9.tython.k8s.api.apps.v1.RollingUpdateDaemonSet\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xaf\x02\n\nDeployment\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12K\n\x08metadata\x18\x03 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12\x39\n\x04spec\x18\x04 \x01(\x0b\x32+.oak9.tython.k8s.api.apps.v1.DeploymentSpec\x12=\n\x06status\x18\x05 \x01(\x0b\x32-.oak9.tython.k8s.api.apps.v1.DeploymentStatus\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xaf\x02\n\x13\x44\x65ploymentCondition\x12Q\n\x14last_transition_time\x18\x01 \x01(\x0b\x32\x33.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.Time\x12M\n\x10last_update_time\x18\x02 \x01(\x0b\x32\x33.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.Time\x12\x0f\n\x07message\x18\x03 \x01(\t\x12\x0e\n\x06reason\x18\x04 \x01(\t\x12\x0e\n\x06status\x18\x05 \x01(\t\x12\x0c\n\x04type\x18\x06 \x01(\t\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xef\x01\n\x0e\x44\x65ploymentList\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x36\n\x05items\x18\x02 \x03(\x0b\x32\'.oak9.tython.k8s.api.apps.v1.Deployment\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12I\n\x08metadata\x18\x04 \x01(\x0b\x32\x37.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ListMeta\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x9c\x03\n\x0e\x44\x65ploymentSpec\x12\x19\n\x11min_ready_seconds\x18\x01 \x01(\x05\x12\x0e\n\x06paused\x18\x02 \x01(\x08\x12!\n\x19progress_deadline_seconds\x18\x03 \x01(\x05\x12\x10\n\x08replicas\x18\x04 \x01(\x05\x12\x1e\n\x16revision_history_limit\x18\x05 \x01(\x05\x12N\n\x08selector\x18\x06 \x01(\x0b\x32<.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.LabelSelector\x12\x41\n\x08strategy\x18\x07 \x01(\x0b\x32/.oak9.tython.k8s.api.apps.v1.DeploymentStrategy\x12>\n\x08template\x18\x08 \x01(\x0b\x32,.oak9.tython.k8s.api.core.v1.PodTemplateSpec\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xc5\x02\n\x10\x44\x65ploymentStatus\x12\x1a\n\x12\x61vailable_replicas\x18\x01 \x01(\x05\x12\x17\n\x0f\x63ollision_count\x18\x02 \x01(\x05\x12\x44\n\nconditions\x18\x03 \x03(\x0b\x32\x30.oak9.tython.k8s.api.apps.v1.DeploymentCondition\x12\x1b\n\x13observed_generation\x18\x04 \x01(\x05\x12\x16\n\x0eready_replicas\x18\x05 \x01(\x05\x12\x10\n\x08replicas\x18\x06 \x01(\x05\x12\x1c\n\x14unavailable_replicas\x18\x07 \x01(\x05\x12\x18\n\x10updated_replicas\x18\x08 \x01(\x05\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xa9\x01\n\x12\x44\x65ploymentStrategy\x12L\n\x0erolling_update\x18\x01 \x01(\x0b\x32\x34.oak9.tython.k8s.api.apps.v1.RollingUpdateDeployment\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xaf\x02\n\nReplicaSet\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12K\n\x08metadata\x18\x03 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12\x39\n\x04spec\x18\x04 \x01(\x0b\x32+.oak9.tython.k8s.api.apps.v1.ReplicaSetSpec\x12=\n\x06status\x18\x05 \x01(\x0b\x32-.oak9.tython.k8s.api.apps.v1.ReplicaSetStatus\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xe0\x01\n\x13ReplicaSetCondition\x12Q\n\x14last_transition_time\x18\x01 \x01(\x0b\x32\x33.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.Time\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x0e\n\x06reason\x18\x03 \x01(\t\x12\x0e\n\x06status\x18\x04 \x01(\t\x12\x0c\n\x04type\x18\x05 \x01(\t\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xef\x01\n\x0eReplicaSetList\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x36\n\x05items\x18\x02 \x03(\x0b\x32\'.oak9.tython.k8s.api.apps.v1.ReplicaSet\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12I\n\x08metadata\x18\x04 \x01(\x0b\x32\x37.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ListMeta\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x86\x02\n\x0eReplicaSetSpec\x12\x19\n\x11min_ready_seconds\x18\x01 \x01(\x05\x12\x10\n\x08replicas\x18\x02 \x01(\x05\x12N\n\x08selector\x18\x03 \x01(\x0b\x32<.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.LabelSelector\x12>\n\x08template\x18\x04 \x01(\x0b\x32,.oak9.tython.k8s.api.core.v1.PodTemplateSpec\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x94\x02\n\x10ReplicaSetStatus\x12\x1a\n\x12\x61vailable_replicas\x18\x01 \x01(\x05\x12\x44\n\nconditions\x18\x02 \x03(\x0b\x32\x30.oak9.tython.k8s.api.apps.v1.ReplicaSetCondition\x12\x1e\n\x16\x66ully_labeled_replicas\x18\x03 \x01(\x05\x12\x1b\n\x13observed_generation\x18\x04 \x01(\x05\x12\x16\n\x0eready_replicas\x18\x05 \x01(\x05\x12\x10\n\x08replicas\x18\x06 \x01(\x05\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xf3\x01\n\x16RollingUpdateDaemonSet\x12L\n\tmax_surge\x18\x01 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.util.intstr.IntOrString\x12R\n\x0fmax_unavailable\x18\x02 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.util.intstr.IntOrString\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xf4\x01\n\x17RollingUpdateDeployment\x12L\n\tmax_surge\x18\x01 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.util.intstr.IntOrString\x12R\n\x0fmax_unavailable\x18\x02 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.util.intstr.IntOrString\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xc2\x01\n RollingUpdateStatefulSetStrategy\x12R\n\x0fmax_unavailable\x18\x01 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.util.intstr.IntOrString\x12\x11\n\tpartition\x18\x02 \x01(\x05\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xb2\x02\n\x0bStatefulSet\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12K\n\x08metadata\x18\x03 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12:\n\x04spec\x18\x04 \x01(\x0b\x32,.oak9.tython.k8s.api.apps.v1.StatefulSetSpec\x12>\n\x06status\x18\x05 \x01(\x0b\x32..oak9.tython.k8s.api.apps.v1.StatefulSetStatus\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xe1\x01\n\x14StatefulSetCondition\x12Q\n\x14last_transition_time\x18\x01 \x01(\x0b\x32\x33.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.Time\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x0e\n\x06reason\x18\x03 \x01(\t\x12\x0e\n\x06status\x18\x04 \x01(\t\x12\x0c\n\x04type\x18\x05 \x01(\t\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xf1\x01\n\x0fStatefulSetList\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x37\n\x05items\x18\x02 \x03(\x0b\x32(.oak9.tython.k8s.api.apps.v1.StatefulSet\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12I\n\x08metadata\x18\x04 \x01(\x0b\x32\x37.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ListMeta\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"]\n\x13StatefulSetOrdinals\x12\r\n\x05start\x18\x01 \x01(\x05\x12\x37\n\rresource_info\x18\x02 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x95\x01\n/StatefulSetPersistentVolumeClaimRetentionPolicy\x12\x14\n\x0cwhen_deleted\x18\x01 \x01(\t\x12\x13\n\x0bwhen_scaled\x18\x02 \x01(\t\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xc5\x05\n\x0fStatefulSetSpec\x12\x19\n\x11min_ready_seconds\x18\x01 \x01(\x05\x12\x42\n\x08ordinals\x18\x02 \x01(\x0b\x32\x30.oak9.tython.k8s.api.apps.v1.StatefulSetOrdinals\x12~\n(persistent_volume_claim_retention_policy\x18\x03 \x01(\x0b\x32L.oak9.tython.k8s.api.apps.v1.StatefulSetPersistentVolumeClaimRetentionPolicy\x12\x1d\n\x15pod_management_policy\x18\x04 \x01(\t\x12\x10\n\x08replicas\x18\x05 \x01(\x05\x12\x1e\n\x16revision_history_limit\x18\x06 \x01(\x05\x12N\n\x08selector\x18\x07 \x01(\x0b\x32<.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.LabelSelector\x12\x14\n\x0cservice_name\x18\x08 \x01(\t\x12>\n\x08template\x18\t \x01(\x0b\x32,.oak9.tython.k8s.api.core.v1.PodTemplateSpec\x12O\n\x0fupdate_strategy\x18\n \x01(\x0b\x32\x36.oak9.tython.k8s.api.apps.v1.StatefulSetUpdateStrategy\x12R\n\x16volume_claim_templates\x18\x0b \x03(\x0b\x32\x32.oak9.tython.k8s.api.core.v1.PersistentVolumeClaim\x12\x37\n\rresource_info\x18\x0c \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xf6\x02\n\x11StatefulSetStatus\x12\x1a\n\x12\x61vailable_replicas\x18\x01 \x01(\x05\x12\x17\n\x0f\x63ollision_count\x18\x02 \x01(\x05\x12\x45\n\nconditions\x18\x03 \x03(\x0b\x32\x31.oak9.tython.k8s.api.apps.v1.StatefulSetCondition\x12\x18\n\x10\x63urrent_replicas\x18\x04 \x01(\x05\x12\x18\n\x10\x63urrent_revision\x18\x05 \x01(\t\x12\x1b\n\x13observed_generation\x18\x06 \x01(\x05\x12\x16\n\x0eready_replicas\x18\x07 \x01(\x05\x12\x10\n\x08replicas\x18\x08 \x01(\x05\x12\x17\n\x0fupdate_revision\x18\t \x01(\t\x12\x18\n\x10updated_replicas\x18\n \x01(\x05\x12\x37\n\rresource_info\x18\x0b \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xb9\x01\n\x19StatefulSetUpdateStrategy\x12U\n\x0erolling_update\x18\x01 \x01(\x0b\x32=.oak9.tython.k8s.api.apps.v1.RollingUpdateStatefulSetStrategy\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'kubernetes.kubernetes_io.k8s.api.apps.v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CONTROLLERREVISION._serialized_start=341
  _CONTROLLERREVISION._serialized_end=618
  _CONTROLLERREVISIONLIST._serialized_start=621
  _CONTROLLERREVISIONLIST._serialized_end=876
  _DAEMONSET._serialized_start=879
  _DAEMONSET._serialized_end=1179
  _DAEMONSETCONDITION._serialized_start=1182
  _DAEMONSETCONDITION._serialized_end=1405
  _DAEMONSETLIST._serialized_start=1408
  _DAEMONSETLIST._serialized_end=1645
  _DAEMONSETSPEC._serialized_start=1648
  _DAEMONSETSPEC._serialized_end=2002
  _DAEMONSETSTATUS._serialized_start=2005
  _DAEMONSETSTATUS._serialized_end=2409
  _DAEMONSETUPDATESTRATEGY._serialized_start=2412
  _DAEMONSETUPDATESTRATEGY._serialized_end=2585
  _DEPLOYMENT._serialized_start=2588
  _DEPLOYMENT._serialized_end=2891
  _DEPLOYMENTCONDITION._serialized_start=2894
  _DEPLOYMENTCONDITION._serialized_end=3197
  _DEPLOYMENTLIST._serialized_start=3200
  _DEPLOYMENTLIST._serialized_end=3439
  _DEPLOYMENTSPEC._serialized_start=3442
  _DEPLOYMENTSPEC._serialized_end=3854
  _DEPLOYMENTSTATUS._serialized_start=3857
  _DEPLOYMENTSTATUS._serialized_end=4182
  _DEPLOYMENTSTRATEGY._serialized_start=4185
  _DEPLOYMENTSTRATEGY._serialized_end=4354
  _REPLICASET._serialized_start=4357
  _REPLICASET._serialized_end=4660
  _REPLICASETCONDITION._serialized_start=4663
  _REPLICASETCONDITION._serialized_end=4887
  _REPLICASETLIST._serialized_start=4890
  _REPLICASETLIST._serialized_end=5129
  _REPLICASETSPEC._serialized_start=5132
  _REPLICASETSPEC._serialized_end=5394
  _REPLICASETSTATUS._serialized_start=5397
  _REPLICASETSTATUS._serialized_end=5673
  _ROLLINGUPDATEDAEMONSET._serialized_start=5676
  _ROLLINGUPDATEDAEMONSET._serialized_end=5919
  _ROLLINGUPDATEDEPLOYMENT._serialized_start=5922
  _ROLLINGUPDATEDEPLOYMENT._serialized_end=6166
  _ROLLINGUPDATESTATEFULSETSTRATEGY._serialized_start=6169
  _ROLLINGUPDATESTATEFULSETSTRATEGY._serialized_end=6363
  _STATEFULSET._serialized_start=6366
  _STATEFULSET._serialized_end=6672
  _STATEFULSETCONDITION._serialized_start=6675
  _STATEFULSETCONDITION._serialized_end=6900
  _STATEFULSETLIST._serialized_start=6903
  _STATEFULSETLIST._serialized_end=7144
  _STATEFULSETORDINALS._serialized_start=7146
  _STATEFULSETORDINALS._serialized_end=7239
  _STATEFULSETPERSISTENTVOLUMECLAIMRETENTIONPOLICY._serialized_start=7242
  _STATEFULSETPERSISTENTVOLUMECLAIMRETENTIONPOLICY._serialized_end=7391
  _STATEFULSETSPEC._serialized_start=7394
  _STATEFULSETSPEC._serialized_end=8103
  _STATEFULSETSTATUS._serialized_start=8106
  _STATEFULSETSTATUS._serialized_end=8480
  _STATEFULSETUPDATESTRATEGY._serialized_start=8483
  _STATEFULSETUPDATESTRATEGY._serialized_end=8668
# @@protoc_insertion_point(module_scope)
