# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_google_cloudarmor_bundle.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2
from oak9.tython.models.gcp import gcp_compute_security_pb2 as gcp_dot_gcp__compute__security__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&gcp/gcp_google_cloudarmor_bundle.proto\x12(oak9.tython.gcp.google_cloudarmor_bundle\x1a\x13shared/shared.proto\x1a\x1egcp/gcp_compute_security.proto\"l\n\x10GoogleCloudarmor\x12X\n\x17\x63ompute_security_policy\x18\x01 \x01(\x0b\x32\x37.oak9.tython.gcp.compute_security.ComputeSecurityPolicyb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_google_cloudarmor_bundle_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GOOGLECLOUDARMOR._serialized_start=137
  _GOOGLECLOUDARMOR._serialized_end=245
# @@protoc_insertion_point(module_scope)
