# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_apigee.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14gcp/gcp_apigee.proto\x12\x16oak9.tython.gcp.apigee\x1a\x13shared/shared.proto\"C\n!ApigeeEndpointAttachmentXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\"\xa6\x02\n\x18\x41pigeeEndpointAttachment\x12\x1e\n\x16\x65ndpoint_attachment_id\x18\x01 \x01(\t\x12\x0c\n\x04host\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x10\n\x08location\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x0e\n\x06org_id\x18\x06 \x01(\t\x12\x1a\n\x12service_attachment\x18\x07 \x01(\t\x12K\n\x08timeouts\x18\x08 \x01(\x0b\x32\x39.oak9.tython.gcp.apigee.ApigeeEndpointAttachmentXTimeouts\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"I\n\x17\x41pigeeEnvgroupXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xc9\x01\n\x0e\x41pigeeEnvgroup\x12\x11\n\thostnames\x18\x01 \x03(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0e\n\x06org_id\x18\x04 \x01(\t\x12\x41\n\x08timeouts\x18\x05 \x01(\x0b\x32/.oak9.tython.gcp.apigee.ApigeeEnvgroupXTimeouts\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"C\n!ApigeeEnvgroupAttachmentXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\"\xe4\x01\n\x18\x41pigeeEnvgroupAttachment\x12\x13\n\x0b\x65nvgroup_id\x18\x01 \x01(\t\x12\x13\n\x0b\x65nvironment\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12K\n\x08timeouts\x18\x05 \x01(\x0b\x32\x39.oak9.tython.gcp.apigee.ApigeeEnvgroupAttachmentXTimeouts\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"L\n\x1a\x41pigeeEnvironmentXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\x98\x02\n\x11\x41pigeeEnvironment\x12\x16\n\x0e\x61pi_proxy_type\x18\x01 \x01(\t\x12\x17\n\x0f\x64\x65ployment_type\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x04 \x01(\t\x12\n\n\x02id\x18\x05 \x01(\t\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x0e\n\x06org_id\x18\x07 \x01(\t\x12\x44\n\x08timeouts\x18\x08 \x01(\x0b\x32\x32.oak9.tython.gcp.apigee.ApigeeEnvironmentXTimeouts\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"_\n%ApigeeEnvironmentIamBindingXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\x81\x02\n\x1b\x41pigeeEnvironmentIamBinding\x12\x0e\n\x06\x65nv_id\x18\x01 \x01(\t\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0f\n\x07members\x18\x04 \x03(\t\x12\x0e\n\x06org_id\x18\x05 \x01(\t\x12\x0c\n\x04role\x18\x06 \x01(\t\x12P\n\tcondition\x18\x07 \x01(\x0b\x32=.oak9.tython.gcp.apigee.ApigeeEnvironmentIamBindingXCondition\x12\x37\n\rresource_info\x18\x08 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"^\n$ApigeeEnvironmentIamMemberXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\xfe\x01\n\x1a\x41pigeeEnvironmentIamMember\x12\x0e\n\x06\x65nv_id\x18\x01 \x01(\t\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0e\n\x06member\x18\x04 \x01(\t\x12\x0e\n\x06org_id\x18\x05 \x01(\t\x12\x0c\n\x04role\x18\x06 \x01(\t\x12O\n\tcondition\x18\x07 \x01(\x0b\x32<.oak9.tython.gcp.apigee.ApigeeEnvironmentIamMemberXCondition\x12\x37\n\rresource_info\x18\x08 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xa4\x01\n\x1a\x41pigeeEnvironmentIamPolicy\x12\x0e\n\x06\x65nv_id\x18\x01 \x01(\t\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0e\n\x06org_id\x18\x04 \x01(\t\x12\x13\n\x0bpolicy_data\x18\x05 \x01(\t\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"9\n\x17\x41pigeeInstanceXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\"\x99\x03\n\x0e\x41pigeeInstance\x12\x1c\n\x14\x63onsumer_accept_list\x18\x01 \x03(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12 \n\x18\x64isk_encryption_key_name\x18\x03 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x04 \x01(\t\x12\x0c\n\x04host\x18\x05 \x01(\t\x12\n\n\x02id\x18\x06 \x01(\t\x12\x10\n\x08ip_range\x18\x07 \x01(\t\x12\x10\n\x08location\x18\x08 \x01(\t\x12\x0c\n\x04name\x18\t \x01(\t\x12\x0e\n\x06org_id\x18\n \x01(\t\x12\x1a\n\x12peering_cidr_range\x18\x0b \x01(\t\x12\x0c\n\x04port\x18\x0c \x01(\t\x12\x1a\n\x12service_attachment\x18\r \x01(\t\x12\x41\n\x08timeouts\x18\x0e \x01(\x0b\x32/.oak9.tython.gcp.apigee.ApigeeInstanceXTimeouts\x12\x37\n\rresource_info\x18\x0f \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"C\n!ApigeeInstanceAttachmentXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\"\xe4\x01\n\x18\x41pigeeInstanceAttachment\x12\x13\n\x0b\x65nvironment\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x13\n\x0binstance_id\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12K\n\x08timeouts\x18\x05 \x01(\x0b\x32\x39.oak9.tython.gcp.apigee.ApigeeInstanceAttachmentXTimeouts\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"M\n\x1b\x41pigeeOrganizationXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xb0\x03\n\x12\x41pigeeOrganization\x12\x18\n\x10\x61nalytics_region\x18\x01 \x01(\t\x12\x1a\n\x12\x61uthorized_network\x18\x02 \x01(\t\x12\x14\n\x0c\x62illing_type\x18\x03 \x01(\t\x12\x16\n\x0e\x63\x61_certificate\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x06 \x01(\t\x12\n\n\x02id\x18\x07 \x01(\t\x12\x0c\n\x04name\x18\x08 \x01(\t\x12\x12\n\nproject_id\x18\t \x01(\t\x12,\n$runtime_database_encryption_key_name\x18\n \x01(\t\x12\x14\n\x0cruntime_type\x18\x0b \x01(\t\x12\x19\n\x11subscription_type\x18\x0c \x01(\t\x12\x45\n\x08timeouts\x18\r \x01(\x0b\x32\x33.oak9.tython.gcp.apigee.ApigeeOrganizationXTimeouts\x12\x37\n\rresource_info\x18\x0e \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_apigee_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _APIGEEENDPOINTATTACHMENTXTIMEOUTS._serialized_start=69
  _APIGEEENDPOINTATTACHMENTXTIMEOUTS._serialized_end=136
  _APIGEEENDPOINTATTACHMENT._serialized_start=139
  _APIGEEENDPOINTATTACHMENT._serialized_end=433
  _APIGEEENVGROUPXTIMEOUTS._serialized_start=435
  _APIGEEENVGROUPXTIMEOUTS._serialized_end=508
  _APIGEEENVGROUP._serialized_start=511
  _APIGEEENVGROUP._serialized_end=712
  _APIGEEENVGROUPATTACHMENTXTIMEOUTS._serialized_start=714
  _APIGEEENVGROUPATTACHMENTXTIMEOUTS._serialized_end=781
  _APIGEEENVGROUPATTACHMENT._serialized_start=784
  _APIGEEENVGROUPATTACHMENT._serialized_end=1012
  _APIGEEENVIRONMENTXTIMEOUTS._serialized_start=1014
  _APIGEEENVIRONMENTXTIMEOUTS._serialized_end=1090
  _APIGEEENVIRONMENT._serialized_start=1093
  _APIGEEENVIRONMENT._serialized_end=1373
  _APIGEEENVIRONMENTIAMBINDINGXCONDITION._serialized_start=1375
  _APIGEEENVIRONMENTIAMBINDINGXCONDITION._serialized_end=1470
  _APIGEEENVIRONMENTIAMBINDING._serialized_start=1473
  _APIGEEENVIRONMENTIAMBINDING._serialized_end=1730
  _APIGEEENVIRONMENTIAMMEMBERXCONDITION._serialized_start=1732
  _APIGEEENVIRONMENTIAMMEMBERXCONDITION._serialized_end=1826
  _APIGEEENVIRONMENTIAMMEMBER._serialized_start=1829
  _APIGEEENVIRONMENTIAMMEMBER._serialized_end=2083
  _APIGEEENVIRONMENTIAMPOLICY._serialized_start=2086
  _APIGEEENVIRONMENTIAMPOLICY._serialized_end=2250
  _APIGEEINSTANCEXTIMEOUTS._serialized_start=2252
  _APIGEEINSTANCEXTIMEOUTS._serialized_end=2309
  _APIGEEINSTANCE._serialized_start=2312
  _APIGEEINSTANCE._serialized_end=2721
  _APIGEEINSTANCEATTACHMENTXTIMEOUTS._serialized_start=2723
  _APIGEEINSTANCEATTACHMENTXTIMEOUTS._serialized_end=2790
  _APIGEEINSTANCEATTACHMENT._serialized_start=2793
  _APIGEEINSTANCEATTACHMENT._serialized_end=3021
  _APIGEEORGANIZATIONXTIMEOUTS._serialized_start=3023
  _APIGEEORGANIZATIONXTIMEOUTS._serialized_end=3100
  _APIGEEORGANIZATION._serialized_start=3103
  _APIGEEORGANIZATION._serialized_end=3535
# @@protoc_insertion_point(module_scope)
