"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class JobTemplateAccelerationSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    MODE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    mode: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        mode: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["mode", b"mode", "resource_info", b"resource_info"]) -> None: ...

global___JobTemplateAccelerationSettings = JobTemplateAccelerationSettings

@typing_extensions.final
class JobTemplateHopDestination(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    WAIT_MINUTES_FIELD_NUMBER: builtins.int
    PRIORITY_FIELD_NUMBER: builtins.int
    QUEUE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    wait_minutes: builtins.int
    priority: builtins.int
    queue: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        wait_minutes: builtins.int = ...,
        priority: builtins.int = ...,
        queue: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["priority", b"priority", "queue", b"queue", "resource_info", b"resource_info", "wait_minutes", b"wait_minutes"]) -> None: ...

global___JobTemplateHopDestination = JobTemplateHopDestination

@typing_extensions.final
class JobTemplate(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class SettingsJsonEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CATEGORY_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ACCELERATION_SETTINGS_FIELD_NUMBER: builtins.int
    PRIORITY_FIELD_NUMBER: builtins.int
    STATUS_UPDATE_INTERVAL_FIELD_NUMBER: builtins.int
    SETTINGS_JSON_FIELD_NUMBER: builtins.int
    QUEUE_FIELD_NUMBER: builtins.int
    HOP_DESTINATIONS_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    category: builtins.str
    description: builtins.str
    @property
    def acceleration_settings(self) -> global___JobTemplateAccelerationSettings: ...
    priority: builtins.int
    status_update_interval: builtins.str
    @property
    def settings_json(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    queue: builtins.str
    @property
    def hop_destinations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___JobTemplateHopDestination]: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        category: builtins.str = ...,
        description: builtins.str = ...,
        acceleration_settings: global___JobTemplateAccelerationSettings | None = ...,
        priority: builtins.int = ...,
        status_update_interval: builtins.str = ...,
        settings_json: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        queue: builtins.str = ...,
        hop_destinations: collections.abc.Iterable[global___JobTemplateHopDestination] | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["acceleration_settings", b"acceleration_settings", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["acceleration_settings", b"acceleration_settings", "category", b"category", "description", b"description", "hop_destinations", b"hop_destinations", "name", b"name", "priority", b"priority", "queue", b"queue", "resource_info", b"resource_info", "settings_json", b"settings_json", "status_update_interval", b"status_update_interval", "tags", b"tags"]) -> None: ...

global___JobTemplate = JobTemplate

@typing_extensions.final
class MediaConvert(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JOB_TEMPLATE_FIELD_NUMBER: builtins.int
    PRESET_FIELD_NUMBER: builtins.int
    QUEUE_FIELD_NUMBER: builtins.int
    @property
    def job_template(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___JobTemplate]: ...
    @property
    def preset(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Preset]: ...
    @property
    def queue(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Queue]: ...
    def __init__(
        self,
        *,
        job_template: collections.abc.Iterable[global___JobTemplate] | None = ...,
        preset: collections.abc.Iterable[global___Preset] | None = ...,
        queue: collections.abc.Iterable[global___Queue] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["job_template", b"job_template", "preset", b"preset", "queue", b"queue"]) -> None: ...

global___MediaConvert = MediaConvert

@typing_extensions.final
class Preset(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class SettingsJsonEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CATEGORY_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    SETTINGS_JSON_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    category: builtins.str
    description: builtins.str
    @property
    def settings_json(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        category: builtins.str = ...,
        description: builtins.str = ...,
        settings_json: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["category", b"category", "description", b"description", "name", b"name", "resource_info", b"resource_info", "settings_json", b"settings_json", "tags", b"tags"]) -> None: ...

global___Preset = Preset

@typing_extensions.final
class Queue(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    PRICING_PLAN_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    status: builtins.str
    description: builtins.str
    pricing_plan: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        status: builtins.str = ...,
        description: builtins.str = ...,
        pricing_plan: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "name", b"name", "pricing_plan", b"pricing_plan", "resource_info", b"resource_info", "status", b"status", "tags", b"tags"]) -> None: ...

global___Queue = Queue
