"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class SecretManagerSecretXReplicationXUserManagedXReplicasXCustomerManagedEncryption(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KMS_KEY_NAME_FIELD_NUMBER: builtins.int
    kms_key_name: builtins.str
    def __init__(
        self,
        *,
        kms_key_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["kms_key_name", b"kms_key_name"]) -> None: ...

global___SecretManagerSecretXReplicationXUserManagedXReplicasXCustomerManagedEncryption = SecretManagerSecretXReplicationXUserManagedXReplicasXCustomerManagedEncryption

@typing_extensions.final
class SecretManagerSecretXReplicationXUserManagedXReplicas(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOCATION_FIELD_NUMBER: builtins.int
    CUSTOMER_MANAGED_ENCRYPTION_FIELD_NUMBER: builtins.int
    location: builtins.str
    @property
    def customer_managed_encryption(self) -> global___SecretManagerSecretXReplicationXUserManagedXReplicasXCustomerManagedEncryption: ...
    def __init__(
        self,
        *,
        location: builtins.str = ...,
        customer_managed_encryption: global___SecretManagerSecretXReplicationXUserManagedXReplicasXCustomerManagedEncryption | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["customer_managed_encryption", b"customer_managed_encryption"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["customer_managed_encryption", b"customer_managed_encryption", "location", b"location"]) -> None: ...

global___SecretManagerSecretXReplicationXUserManagedXReplicas = SecretManagerSecretXReplicationXUserManagedXReplicas

@typing_extensions.final
class SecretManagerSecretXReplicationXUserManaged(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REPLICAS_FIELD_NUMBER: builtins.int
    @property
    def replicas(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SecretManagerSecretXReplicationXUserManagedXReplicas]: ...
    def __init__(
        self,
        *,
        replicas: collections.abc.Iterable[global___SecretManagerSecretXReplicationXUserManagedXReplicas] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["replicas", b"replicas"]) -> None: ...

global___SecretManagerSecretXReplicationXUserManaged = SecretManagerSecretXReplicationXUserManaged

@typing_extensions.final
class SecretManagerSecretXReplication(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUTOMATIC_FIELD_NUMBER: builtins.int
    USER_MANAGED_FIELD_NUMBER: builtins.int
    automatic: builtins.bool
    @property
    def user_managed(self) -> global___SecretManagerSecretXReplicationXUserManaged: ...
    def __init__(
        self,
        *,
        automatic: builtins.bool = ...,
        user_managed: global___SecretManagerSecretXReplicationXUserManaged | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["user_managed", b"user_managed"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["automatic", b"automatic", "user_managed", b"user_managed"]) -> None: ...

global___SecretManagerSecretXReplication = SecretManagerSecretXReplication

@typing_extensions.final
class SecretManagerSecretXRotation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NEXT_ROTATION_TIME_FIELD_NUMBER: builtins.int
    ROTATION_PERIOD_FIELD_NUMBER: builtins.int
    next_rotation_time: builtins.str
    rotation_period: builtins.str
    def __init__(
        self,
        *,
        next_rotation_time: builtins.str = ...,
        rotation_period: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["next_rotation_time", b"next_rotation_time", "rotation_period", b"rotation_period"]) -> None: ...

global___SecretManagerSecretXRotation = SecretManagerSecretXRotation

@typing_extensions.final
class SecretManagerSecretXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___SecretManagerSecretXTimeouts = SecretManagerSecretXTimeouts

@typing_extensions.final
class SecretManagerSecretXTopics(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___SecretManagerSecretXTopics = SecretManagerSecretXTopics

@typing_extensions.final
class SecretManagerSecret(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    CREATE_TIME_FIELD_NUMBER: builtins.int
    EXPIRE_TIME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    SECRET_ID_FIELD_NUMBER: builtins.int
    TTL_FIELD_NUMBER: builtins.int
    REPLICATION_FIELD_NUMBER: builtins.int
    ROTATION_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    TOPICS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    create_time: builtins.str
    expire_time: builtins.str
    id: builtins.str
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    name: builtins.str
    project: builtins.str
    secret_id: builtins.str
    ttl: builtins.str
    @property
    def replication(self) -> global___SecretManagerSecretXReplication: ...
    @property
    def rotation(self) -> global___SecretManagerSecretXRotation: ...
    @property
    def timeouts(self) -> global___SecretManagerSecretXTimeouts: ...
    @property
    def topics(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SecretManagerSecretXTopics]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        create_time: builtins.str = ...,
        expire_time: builtins.str = ...,
        id: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        secret_id: builtins.str = ...,
        ttl: builtins.str = ...,
        replication: global___SecretManagerSecretXReplication | None = ...,
        rotation: global___SecretManagerSecretXRotation | None = ...,
        timeouts: global___SecretManagerSecretXTimeouts | None = ...,
        topics: collections.abc.Iterable[global___SecretManagerSecretXTopics] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["replication", b"replication", "resource_info", b"resource_info", "rotation", b"rotation", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["create_time", b"create_time", "expire_time", b"expire_time", "id", b"id", "labels", b"labels", "name", b"name", "project", b"project", "replication", b"replication", "resource_info", b"resource_info", "rotation", b"rotation", "secret_id", b"secret_id", "timeouts", b"timeouts", "topics", b"topics", "ttl", b"ttl"]) -> None: ...

global___SecretManagerSecret = SecretManagerSecret

@typing_extensions.final
class SecretManagerSecretIamBindingXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___SecretManagerSecretIamBindingXCondition = SecretManagerSecretIamBindingXCondition

@typing_extensions.final
class SecretManagerSecretIamBinding(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    MEMBERS_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    SECRET_ID_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    @property
    def members(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    project: builtins.str
    role: builtins.str
    secret_id: builtins.str
    @property
    def condition(self) -> global___SecretManagerSecretIamBindingXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        members: collections.abc.Iterable[builtins.str] | None = ...,
        project: builtins.str = ...,
        role: builtins.str = ...,
        secret_id: builtins.str = ...,
        condition: global___SecretManagerSecretIamBindingXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "etag", b"etag", "id", b"id", "members", b"members", "project", b"project", "resource_info", b"resource_info", "role", b"role", "secret_id", b"secret_id"]) -> None: ...

global___SecretManagerSecretIamBinding = SecretManagerSecretIamBinding

@typing_extensions.final
class SecretManagerSecretIamMemberXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___SecretManagerSecretIamMemberXCondition = SecretManagerSecretIamMemberXCondition

@typing_extensions.final
class SecretManagerSecretIamMember(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    MEMBER_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    SECRET_ID_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    member: builtins.str
    project: builtins.str
    role: builtins.str
    secret_id: builtins.str
    @property
    def condition(self) -> global___SecretManagerSecretIamMemberXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        member: builtins.str = ...,
        project: builtins.str = ...,
        role: builtins.str = ...,
        secret_id: builtins.str = ...,
        condition: global___SecretManagerSecretIamMemberXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "etag", b"etag", "id", b"id", "member", b"member", "project", b"project", "resource_info", b"resource_info", "role", b"role", "secret_id", b"secret_id"]) -> None: ...

global___SecretManagerSecretIamMember = SecretManagerSecretIamMember

@typing_extensions.final
class SecretManagerSecretIamPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    POLICY_DATA_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    SECRET_ID_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    policy_data: builtins.str
    project: builtins.str
    secret_id: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        policy_data: builtins.str = ...,
        project: builtins.str = ...,
        secret_id: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["etag", b"etag", "id", b"id", "policy_data", b"policy_data", "project", b"project", "resource_info", b"resource_info", "secret_id", b"secret_id"]) -> None: ...

global___SecretManagerSecretIamPolicy = SecretManagerSecretIamPolicy

@typing_extensions.final
class SecretManagerSecretVersionXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete"]) -> None: ...

global___SecretManagerSecretVersionXTimeouts = SecretManagerSecretVersionXTimeouts

@typing_extensions.final
class SecretManagerSecretVersion(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_TIME_FIELD_NUMBER: builtins.int
    DESTROY_TIME_FIELD_NUMBER: builtins.int
    ENABLED_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    SECRET_FIELD_NUMBER: builtins.int
    SECRET_DATA_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    create_time: builtins.str
    destroy_time: builtins.str
    enabled: builtins.bool
    id: builtins.str
    name: builtins.str
    secret: builtins.str
    secret_data: builtins.str
    @property
    def timeouts(self) -> global___SecretManagerSecretVersionXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        create_time: builtins.str = ...,
        destroy_time: builtins.str = ...,
        enabled: builtins.bool = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        secret: builtins.str = ...,
        secret_data: builtins.str = ...,
        timeouts: global___SecretManagerSecretVersionXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["create_time", b"create_time", "destroy_time", b"destroy_time", "enabled", b"enabled", "id", b"id", "name", b"name", "resource_info", b"resource_info", "secret", b"secret", "secret_data", b"secret_data", "timeouts", b"timeouts"]) -> None: ...

global___SecretManagerSecretVersion = SecretManagerSecretVersion
