"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class DialogflowAgentXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___DialogflowAgentXTimeouts = DialogflowAgentXTimeouts

@typing_extensions.final
class DialogflowAgent(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    AVATAR_URI_FIELD_NUMBER: builtins.int
    AVATAR_URI_BACKEND_FIELD_NUMBER: builtins.int
    CLASSIFICATION_THRESHOLD_FIELD_NUMBER: builtins.int
    DEFAULT_LANGUAGE_CODE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    ENABLE_LOGGING_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    MATCH_MODE_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    SUPPORTED_LANGUAGE_CODES_FIELD_NUMBER: builtins.int
    TIER_FIELD_NUMBER: builtins.int
    TIME_ZONE_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    avatar_uri: builtins.str
    avatar_uri_backend: builtins.str
    classification_threshold: builtins.float
    default_language_code: builtins.str
    description: builtins.str
    display_name: builtins.str
    enable_logging: builtins.bool
    id: builtins.str
    match_mode: builtins.str
    project: builtins.str
    @property
    def supported_language_codes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    tier: builtins.str
    time_zone: builtins.str
    @property
    def timeouts(self) -> global___DialogflowAgentXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        avatar_uri: builtins.str = ...,
        avatar_uri_backend: builtins.str = ...,
        classification_threshold: builtins.float = ...,
        default_language_code: builtins.str = ...,
        description: builtins.str = ...,
        display_name: builtins.str = ...,
        enable_logging: builtins.bool = ...,
        id: builtins.str = ...,
        match_mode: builtins.str = ...,
        project: builtins.str = ...,
        supported_language_codes: collections.abc.Iterable[builtins.str] | None = ...,
        tier: builtins.str = ...,
        time_zone: builtins.str = ...,
        timeouts: global___DialogflowAgentXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "avatar_uri", b"avatar_uri", "avatar_uri_backend", b"avatar_uri_backend", "classification_threshold", b"classification_threshold", "default_language_code", b"default_language_code", "description", b"description", "display_name", b"display_name", "enable_logging", b"enable_logging", "id", b"id", "match_mode", b"match_mode", "project", b"project", "resource_info", b"resource_info", "supported_language_codes", b"supported_language_codes", "tier", b"tier", "time_zone", b"time_zone", "timeouts", b"timeouts"]) -> None: ...

global___DialogflowAgent = DialogflowAgent

@typing_extensions.final
class DialogflowCxAgentXSpeechToTextSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLE_SPEECH_ADAPTATION_FIELD_NUMBER: builtins.int
    enable_speech_adaptation: builtins.bool
    def __init__(
        self,
        *,
        enable_speech_adaptation: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["enable_speech_adaptation", b"enable_speech_adaptation"]) -> None: ...

global___DialogflowCxAgentXSpeechToTextSettings = DialogflowCxAgentXSpeechToTextSettings

@typing_extensions.final
class DialogflowCxAgentXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___DialogflowCxAgentXTimeouts = DialogflowCxAgentXTimeouts

@typing_extensions.final
class DialogflowCxAgent(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AVATAR_URI_FIELD_NUMBER: builtins.int
    DEFAULT_LANGUAGE_CODE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    ENABLE_SPELL_CORRECTION_FIELD_NUMBER: builtins.int
    ENABLE_STACKDRIVER_LOGGING_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    SECURITY_SETTINGS_FIELD_NUMBER: builtins.int
    START_FLOW_FIELD_NUMBER: builtins.int
    SUPPORTED_LANGUAGE_CODES_FIELD_NUMBER: builtins.int
    TIME_ZONE_FIELD_NUMBER: builtins.int
    SPEECH_TO_TEXT_SETTINGS_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    avatar_uri: builtins.str
    default_language_code: builtins.str
    description: builtins.str
    display_name: builtins.str
    enable_spell_correction: builtins.bool
    enable_stackdriver_logging: builtins.bool
    id: builtins.str
    location: builtins.str
    name: builtins.str
    project: builtins.str
    security_settings: builtins.str
    start_flow: builtins.str
    @property
    def supported_language_codes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    time_zone: builtins.str
    @property
    def speech_to_text_settings(self) -> global___DialogflowCxAgentXSpeechToTextSettings: ...
    @property
    def timeouts(self) -> global___DialogflowCxAgentXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        avatar_uri: builtins.str = ...,
        default_language_code: builtins.str = ...,
        description: builtins.str = ...,
        display_name: builtins.str = ...,
        enable_spell_correction: builtins.bool = ...,
        enable_stackdriver_logging: builtins.bool = ...,
        id: builtins.str = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        security_settings: builtins.str = ...,
        start_flow: builtins.str = ...,
        supported_language_codes: collections.abc.Iterable[builtins.str] | None = ...,
        time_zone: builtins.str = ...,
        speech_to_text_settings: global___DialogflowCxAgentXSpeechToTextSettings | None = ...,
        timeouts: global___DialogflowCxAgentXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "speech_to_text_settings", b"speech_to_text_settings", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["avatar_uri", b"avatar_uri", "default_language_code", b"default_language_code", "description", b"description", "display_name", b"display_name", "enable_spell_correction", b"enable_spell_correction", "enable_stackdriver_logging", b"enable_stackdriver_logging", "id", b"id", "location", b"location", "name", b"name", "project", b"project", "resource_info", b"resource_info", "security_settings", b"security_settings", "speech_to_text_settings", b"speech_to_text_settings", "start_flow", b"start_flow", "supported_language_codes", b"supported_language_codes", "time_zone", b"time_zone", "timeouts", b"timeouts"]) -> None: ...

global___DialogflowCxAgent = DialogflowCxAgent

@typing_extensions.final
class DialogflowCxEntityTypeXEntities(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SYNONYMS_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    @property
    def synonyms(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    value: builtins.str
    def __init__(
        self,
        *,
        synonyms: collections.abc.Iterable[builtins.str] | None = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["synonyms", b"synonyms", "value", b"value"]) -> None: ...

global___DialogflowCxEntityTypeXEntities = DialogflowCxEntityTypeXEntities

@typing_extensions.final
class DialogflowCxEntityTypeXExcludedPhrases(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALUE_FIELD_NUMBER: builtins.int
    value: builtins.str
    def __init__(
        self,
        *,
        value: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["value", b"value"]) -> None: ...

global___DialogflowCxEntityTypeXExcludedPhrases = DialogflowCxEntityTypeXExcludedPhrases

@typing_extensions.final
class DialogflowCxEntityTypeXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___DialogflowCxEntityTypeXTimeouts = DialogflowCxEntityTypeXTimeouts

@typing_extensions.final
class DialogflowCxEntityType(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUTO_EXPANSION_MODE_FIELD_NUMBER: builtins.int
    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    ENABLE_FUZZY_EXTRACTION_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    LANGUAGE_CODE_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PARENT_FIELD_NUMBER: builtins.int
    REDACT_FIELD_NUMBER: builtins.int
    ENTITIES_FIELD_NUMBER: builtins.int
    EXCLUDED_PHRASES_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    auto_expansion_mode: builtins.str
    display_name: builtins.str
    enable_fuzzy_extraction: builtins.bool
    id: builtins.str
    kind: builtins.str
    language_code: builtins.str
    name: builtins.str
    parent: builtins.str
    redact: builtins.bool
    @property
    def entities(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DialogflowCxEntityTypeXEntities]: ...
    @property
    def excluded_phrases(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DialogflowCxEntityTypeXExcludedPhrases]: ...
    @property
    def timeouts(self) -> global___DialogflowCxEntityTypeXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        auto_expansion_mode: builtins.str = ...,
        display_name: builtins.str = ...,
        enable_fuzzy_extraction: builtins.bool = ...,
        id: builtins.str = ...,
        kind: builtins.str = ...,
        language_code: builtins.str = ...,
        name: builtins.str = ...,
        parent: builtins.str = ...,
        redact: builtins.bool = ...,
        entities: collections.abc.Iterable[global___DialogflowCxEntityTypeXEntities] | None = ...,
        excluded_phrases: collections.abc.Iterable[global___DialogflowCxEntityTypeXExcludedPhrases] | None = ...,
        timeouts: global___DialogflowCxEntityTypeXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auto_expansion_mode", b"auto_expansion_mode", "display_name", b"display_name", "enable_fuzzy_extraction", b"enable_fuzzy_extraction", "entities", b"entities", "excluded_phrases", b"excluded_phrases", "id", b"id", "kind", b"kind", "language_code", b"language_code", "name", b"name", "parent", b"parent", "redact", b"redact", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> None: ...

global___DialogflowCxEntityType = DialogflowCxEntityType

@typing_extensions.final
class DialogflowCxEnvironmentXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___DialogflowCxEnvironmentXTimeouts = DialogflowCxEnvironmentXTimeouts

@typing_extensions.final
class DialogflowCxEnvironmentXVersionConfigs(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VERSION_FIELD_NUMBER: builtins.int
    version: builtins.str
    def __init__(
        self,
        *,
        version: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["version", b"version"]) -> None: ...

global___DialogflowCxEnvironmentXVersionConfigs = DialogflowCxEnvironmentXVersionConfigs

@typing_extensions.final
class DialogflowCxEnvironment(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PARENT_FIELD_NUMBER: builtins.int
    UPDATE_TIME_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    VERSION_CONFIGS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    description: builtins.str
    display_name: builtins.str
    id: builtins.str
    name: builtins.str
    parent: builtins.str
    update_time: builtins.str
    @property
    def timeouts(self) -> global___DialogflowCxEnvironmentXTimeouts: ...
    @property
    def version_configs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DialogflowCxEnvironmentXVersionConfigs]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        display_name: builtins.str = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        parent: builtins.str = ...,
        update_time: builtins.str = ...,
        timeouts: global___DialogflowCxEnvironmentXTimeouts | None = ...,
        version_configs: collections.abc.Iterable[global___DialogflowCxEnvironmentXVersionConfigs] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "display_name", b"display_name", "id", b"id", "name", b"name", "parent", b"parent", "resource_info", b"resource_info", "timeouts", b"timeouts", "update_time", b"update_time", "version_configs", b"version_configs"]) -> None: ...

global___DialogflowCxEnvironment = DialogflowCxEnvironment

@typing_extensions.final
class DialogflowCxFlowXEventHandlersXTriggerFulfillmentXMessagesXText(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALLOW_PLAYBACK_INTERRUPTION_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    allow_playback_interruption: builtins.bool
    @property
    def text(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        allow_playback_interruption: builtins.bool = ...,
        text: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["allow_playback_interruption", b"allow_playback_interruption", "text", b"text"]) -> None: ...

global___DialogflowCxFlowXEventHandlersXTriggerFulfillmentXMessagesXText = DialogflowCxFlowXEventHandlersXTriggerFulfillmentXMessagesXText

@typing_extensions.final
class DialogflowCxFlowXEventHandlersXTriggerFulfillmentXMessages(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_FIELD_NUMBER: builtins.int
    @property
    def text(self) -> global___DialogflowCxFlowXEventHandlersXTriggerFulfillmentXMessagesXText: ...
    def __init__(
        self,
        *,
        text: global___DialogflowCxFlowXEventHandlersXTriggerFulfillmentXMessagesXText | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["text", b"text"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["text", b"text"]) -> None: ...

global___DialogflowCxFlowXEventHandlersXTriggerFulfillmentXMessages = DialogflowCxFlowXEventHandlersXTriggerFulfillmentXMessages

@typing_extensions.final
class DialogflowCxFlowXEventHandlersXTriggerFulfillment(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RETURN_PARTIAL_RESPONSES_FIELD_NUMBER: builtins.int
    TAG_FIELD_NUMBER: builtins.int
    WEBHOOK_FIELD_NUMBER: builtins.int
    MESSAGES_FIELD_NUMBER: builtins.int
    return_partial_responses: builtins.bool
    tag: builtins.str
    webhook: builtins.str
    @property
    def messages(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DialogflowCxFlowXEventHandlersXTriggerFulfillmentXMessages]: ...
    def __init__(
        self,
        *,
        return_partial_responses: builtins.bool = ...,
        tag: builtins.str = ...,
        webhook: builtins.str = ...,
        messages: collections.abc.Iterable[global___DialogflowCxFlowXEventHandlersXTriggerFulfillmentXMessages] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["messages", b"messages", "return_partial_responses", b"return_partial_responses", "tag", b"tag", "webhook", b"webhook"]) -> None: ...

global___DialogflowCxFlowXEventHandlersXTriggerFulfillment = DialogflowCxFlowXEventHandlersXTriggerFulfillment

@typing_extensions.final
class DialogflowCxFlowXEventHandlers(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EVENT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    TARGET_FLOW_FIELD_NUMBER: builtins.int
    TARGET_PAGE_FIELD_NUMBER: builtins.int
    TRIGGER_FULFILLMENT_FIELD_NUMBER: builtins.int
    event: builtins.str
    name: builtins.str
    target_flow: builtins.str
    target_page: builtins.str
    @property
    def trigger_fulfillment(self) -> global___DialogflowCxFlowXEventHandlersXTriggerFulfillment: ...
    def __init__(
        self,
        *,
        event: builtins.str = ...,
        name: builtins.str = ...,
        target_flow: builtins.str = ...,
        target_page: builtins.str = ...,
        trigger_fulfillment: global___DialogflowCxFlowXEventHandlersXTriggerFulfillment | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["trigger_fulfillment", b"trigger_fulfillment"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["event", b"event", "name", b"name", "target_flow", b"target_flow", "target_page", b"target_page", "trigger_fulfillment", b"trigger_fulfillment"]) -> None: ...

global___DialogflowCxFlowXEventHandlers = DialogflowCxFlowXEventHandlers

@typing_extensions.final
class DialogflowCxFlowXNluSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLASSIFICATION_THRESHOLD_FIELD_NUMBER: builtins.int
    MODEL_TRAINING_MODE_FIELD_NUMBER: builtins.int
    MODEL_TYPE_FIELD_NUMBER: builtins.int
    classification_threshold: builtins.float
    model_training_mode: builtins.str
    model_type: builtins.str
    def __init__(
        self,
        *,
        classification_threshold: builtins.float = ...,
        model_training_mode: builtins.str = ...,
        model_type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["classification_threshold", b"classification_threshold", "model_training_mode", b"model_training_mode", "model_type", b"model_type"]) -> None: ...

global___DialogflowCxFlowXNluSettings = DialogflowCxFlowXNluSettings

@typing_extensions.final
class DialogflowCxFlowXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___DialogflowCxFlowXTimeouts = DialogflowCxFlowXTimeouts

@typing_extensions.final
class DialogflowCxFlowXTransitionRoutesXTriggerFulfillmentXMessagesXText(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALLOW_PLAYBACK_INTERRUPTION_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    allow_playback_interruption: builtins.bool
    @property
    def text(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        allow_playback_interruption: builtins.bool = ...,
        text: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["allow_playback_interruption", b"allow_playback_interruption", "text", b"text"]) -> None: ...

global___DialogflowCxFlowXTransitionRoutesXTriggerFulfillmentXMessagesXText = DialogflowCxFlowXTransitionRoutesXTriggerFulfillmentXMessagesXText

@typing_extensions.final
class DialogflowCxFlowXTransitionRoutesXTriggerFulfillmentXMessages(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_FIELD_NUMBER: builtins.int
    @property
    def text(self) -> global___DialogflowCxFlowXTransitionRoutesXTriggerFulfillmentXMessagesXText: ...
    def __init__(
        self,
        *,
        text: global___DialogflowCxFlowXTransitionRoutesXTriggerFulfillmentXMessagesXText | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["text", b"text"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["text", b"text"]) -> None: ...

global___DialogflowCxFlowXTransitionRoutesXTriggerFulfillmentXMessages = DialogflowCxFlowXTransitionRoutesXTriggerFulfillmentXMessages

@typing_extensions.final
class DialogflowCxFlowXTransitionRoutesXTriggerFulfillment(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RETURN_PARTIAL_RESPONSES_FIELD_NUMBER: builtins.int
    TAG_FIELD_NUMBER: builtins.int
    WEBHOOK_FIELD_NUMBER: builtins.int
    MESSAGES_FIELD_NUMBER: builtins.int
    return_partial_responses: builtins.bool
    tag: builtins.str
    webhook: builtins.str
    @property
    def messages(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DialogflowCxFlowXTransitionRoutesXTriggerFulfillmentXMessages]: ...
    def __init__(
        self,
        *,
        return_partial_responses: builtins.bool = ...,
        tag: builtins.str = ...,
        webhook: builtins.str = ...,
        messages: collections.abc.Iterable[global___DialogflowCxFlowXTransitionRoutesXTriggerFulfillmentXMessages] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["messages", b"messages", "return_partial_responses", b"return_partial_responses", "tag", b"tag", "webhook", b"webhook"]) -> None: ...

global___DialogflowCxFlowXTransitionRoutesXTriggerFulfillment = DialogflowCxFlowXTransitionRoutesXTriggerFulfillment

@typing_extensions.final
class DialogflowCxFlowXTransitionRoutes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONDITION_FIELD_NUMBER: builtins.int
    INTENT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    TARGET_FLOW_FIELD_NUMBER: builtins.int
    TARGET_PAGE_FIELD_NUMBER: builtins.int
    TRIGGER_FULFILLMENT_FIELD_NUMBER: builtins.int
    condition: builtins.str
    intent: builtins.str
    name: builtins.str
    target_flow: builtins.str
    target_page: builtins.str
    @property
    def trigger_fulfillment(self) -> global___DialogflowCxFlowXTransitionRoutesXTriggerFulfillment: ...
    def __init__(
        self,
        *,
        condition: builtins.str = ...,
        intent: builtins.str = ...,
        name: builtins.str = ...,
        target_flow: builtins.str = ...,
        target_page: builtins.str = ...,
        trigger_fulfillment: global___DialogflowCxFlowXTransitionRoutesXTriggerFulfillment | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["trigger_fulfillment", b"trigger_fulfillment"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "intent", b"intent", "name", b"name", "target_flow", b"target_flow", "target_page", b"target_page", "trigger_fulfillment", b"trigger_fulfillment"]) -> None: ...

global___DialogflowCxFlowXTransitionRoutes = DialogflowCxFlowXTransitionRoutes

@typing_extensions.final
class DialogflowCxFlow(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LANGUAGE_CODE_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PARENT_FIELD_NUMBER: builtins.int
    TRANSITION_ROUTE_GROUPS_FIELD_NUMBER: builtins.int
    EVENT_HANDLERS_FIELD_NUMBER: builtins.int
    NLU_SETTINGS_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    TRANSITION_ROUTES_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    description: builtins.str
    display_name: builtins.str
    id: builtins.str
    language_code: builtins.str
    name: builtins.str
    parent: builtins.str
    @property
    def transition_route_groups(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def event_handlers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DialogflowCxFlowXEventHandlers]: ...
    @property
    def nlu_settings(self) -> global___DialogflowCxFlowXNluSettings: ...
    @property
    def timeouts(self) -> global___DialogflowCxFlowXTimeouts: ...
    @property
    def transition_routes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DialogflowCxFlowXTransitionRoutes]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        display_name: builtins.str = ...,
        id: builtins.str = ...,
        language_code: builtins.str = ...,
        name: builtins.str = ...,
        parent: builtins.str = ...,
        transition_route_groups: collections.abc.Iterable[builtins.str] | None = ...,
        event_handlers: collections.abc.Iterable[global___DialogflowCxFlowXEventHandlers] | None = ...,
        nlu_settings: global___DialogflowCxFlowXNluSettings | None = ...,
        timeouts: global___DialogflowCxFlowXTimeouts | None = ...,
        transition_routes: collections.abc.Iterable[global___DialogflowCxFlowXTransitionRoutes] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["nlu_settings", b"nlu_settings", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "display_name", b"display_name", "event_handlers", b"event_handlers", "id", b"id", "language_code", b"language_code", "name", b"name", "nlu_settings", b"nlu_settings", "parent", b"parent", "resource_info", b"resource_info", "timeouts", b"timeouts", "transition_route_groups", b"transition_route_groups", "transition_routes", b"transition_routes"]) -> None: ...

global___DialogflowCxFlow = DialogflowCxFlow

@typing_extensions.final
class DialogflowCxIntentXParameters(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENTITY_TYPE_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    IS_LIST_FIELD_NUMBER: builtins.int
    REDACT_FIELD_NUMBER: builtins.int
    entity_type: builtins.str
    id: builtins.str
    is_list: builtins.bool
    redact: builtins.bool
    def __init__(
        self,
        *,
        entity_type: builtins.str = ...,
        id: builtins.str = ...,
        is_list: builtins.bool = ...,
        redact: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["entity_type", b"entity_type", "id", b"id", "is_list", b"is_list", "redact", b"redact"]) -> None: ...

global___DialogflowCxIntentXParameters = DialogflowCxIntentXParameters

@typing_extensions.final
class DialogflowCxIntentXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___DialogflowCxIntentXTimeouts = DialogflowCxIntentXTimeouts

@typing_extensions.final
class DialogflowCxIntentXTrainingPhrasesXParts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PARAMETER_ID_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    parameter_id: builtins.str
    text: builtins.str
    def __init__(
        self,
        *,
        parameter_id: builtins.str = ...,
        text: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["parameter_id", b"parameter_id", "text", b"text"]) -> None: ...

global___DialogflowCxIntentXTrainingPhrasesXParts = DialogflowCxIntentXTrainingPhrasesXParts

@typing_extensions.final
class DialogflowCxIntentXTrainingPhrases(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    REPEAT_COUNT_FIELD_NUMBER: builtins.int
    PARTS_FIELD_NUMBER: builtins.int
    id: builtins.str
    repeat_count: builtins.float
    @property
    def parts(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DialogflowCxIntentXTrainingPhrasesXParts]: ...
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        repeat_count: builtins.float = ...,
        parts: collections.abc.Iterable[global___DialogflowCxIntentXTrainingPhrasesXParts] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "parts", b"parts", "repeat_count", b"repeat_count"]) -> None: ...

global___DialogflowCxIntentXTrainingPhrases = DialogflowCxIntentXTrainingPhrases

@typing_extensions.final
class DialogflowCxIntent(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    DESCRIPTION_FIELD_NUMBER: builtins.int
    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    IS_FALLBACK_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    LANGUAGE_CODE_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PARENT_FIELD_NUMBER: builtins.int
    PRIORITY_FIELD_NUMBER: builtins.int
    PARAMETERS_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    TRAINING_PHRASES_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    description: builtins.str
    display_name: builtins.str
    id: builtins.str
    is_fallback: builtins.bool
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    language_code: builtins.str
    name: builtins.str
    parent: builtins.str
    priority: builtins.float
    @property
    def parameters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DialogflowCxIntentXParameters]: ...
    @property
    def timeouts(self) -> global___DialogflowCxIntentXTimeouts: ...
    @property
    def training_phrases(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DialogflowCxIntentXTrainingPhrases]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        display_name: builtins.str = ...,
        id: builtins.str = ...,
        is_fallback: builtins.bool = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        language_code: builtins.str = ...,
        name: builtins.str = ...,
        parent: builtins.str = ...,
        priority: builtins.float = ...,
        parameters: collections.abc.Iterable[global___DialogflowCxIntentXParameters] | None = ...,
        timeouts: global___DialogflowCxIntentXTimeouts | None = ...,
        training_phrases: collections.abc.Iterable[global___DialogflowCxIntentXTrainingPhrases] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "display_name", b"display_name", "id", b"id", "is_fallback", b"is_fallback", "labels", b"labels", "language_code", b"language_code", "name", b"name", "parameters", b"parameters", "parent", b"parent", "priority", b"priority", "resource_info", b"resource_info", "timeouts", b"timeouts", "training_phrases", b"training_phrases"]) -> None: ...

global___DialogflowCxIntent = DialogflowCxIntent

@typing_extensions.final
class DialogflowCxPageXEntryFulfillmentXMessagesXText(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALLOW_PLAYBACK_INTERRUPTION_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    allow_playback_interruption: builtins.bool
    @property
    def text(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        allow_playback_interruption: builtins.bool = ...,
        text: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["allow_playback_interruption", b"allow_playback_interruption", "text", b"text"]) -> None: ...

global___DialogflowCxPageXEntryFulfillmentXMessagesXText = DialogflowCxPageXEntryFulfillmentXMessagesXText

@typing_extensions.final
class DialogflowCxPageXEntryFulfillmentXMessages(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_FIELD_NUMBER: builtins.int
    @property
    def text(self) -> global___DialogflowCxPageXEntryFulfillmentXMessagesXText: ...
    def __init__(
        self,
        *,
        text: global___DialogflowCxPageXEntryFulfillmentXMessagesXText | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["text", b"text"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["text", b"text"]) -> None: ...

global___DialogflowCxPageXEntryFulfillmentXMessages = DialogflowCxPageXEntryFulfillmentXMessages

@typing_extensions.final
class DialogflowCxPageXEntryFulfillment(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RETURN_PARTIAL_RESPONSES_FIELD_NUMBER: builtins.int
    TAG_FIELD_NUMBER: builtins.int
    WEBHOOK_FIELD_NUMBER: builtins.int
    MESSAGES_FIELD_NUMBER: builtins.int
    return_partial_responses: builtins.bool
    tag: builtins.str
    webhook: builtins.str
    @property
    def messages(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DialogflowCxPageXEntryFulfillmentXMessages]: ...
    def __init__(
        self,
        *,
        return_partial_responses: builtins.bool = ...,
        tag: builtins.str = ...,
        webhook: builtins.str = ...,
        messages: collections.abc.Iterable[global___DialogflowCxPageXEntryFulfillmentXMessages] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["messages", b"messages", "return_partial_responses", b"return_partial_responses", "tag", b"tag", "webhook", b"webhook"]) -> None: ...

global___DialogflowCxPageXEntryFulfillment = DialogflowCxPageXEntryFulfillment

@typing_extensions.final
class DialogflowCxPageXEventHandlersXTriggerFulfillmentXMessagesXText(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALLOW_PLAYBACK_INTERRUPTION_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    allow_playback_interruption: builtins.bool
    @property
    def text(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        allow_playback_interruption: builtins.bool = ...,
        text: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["allow_playback_interruption", b"allow_playback_interruption", "text", b"text"]) -> None: ...

global___DialogflowCxPageXEventHandlersXTriggerFulfillmentXMessagesXText = DialogflowCxPageXEventHandlersXTriggerFulfillmentXMessagesXText

@typing_extensions.final
class DialogflowCxPageXEventHandlersXTriggerFulfillmentXMessages(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_FIELD_NUMBER: builtins.int
    @property
    def text(self) -> global___DialogflowCxPageXEventHandlersXTriggerFulfillmentXMessagesXText: ...
    def __init__(
        self,
        *,
        text: global___DialogflowCxPageXEventHandlersXTriggerFulfillmentXMessagesXText | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["text", b"text"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["text", b"text"]) -> None: ...

global___DialogflowCxPageXEventHandlersXTriggerFulfillmentXMessages = DialogflowCxPageXEventHandlersXTriggerFulfillmentXMessages

@typing_extensions.final
class DialogflowCxPageXEventHandlersXTriggerFulfillment(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RETURN_PARTIAL_RESPONSES_FIELD_NUMBER: builtins.int
    TAG_FIELD_NUMBER: builtins.int
    WEBHOOK_FIELD_NUMBER: builtins.int
    MESSAGES_FIELD_NUMBER: builtins.int
    return_partial_responses: builtins.bool
    tag: builtins.str
    webhook: builtins.str
    @property
    def messages(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DialogflowCxPageXEventHandlersXTriggerFulfillmentXMessages]: ...
    def __init__(
        self,
        *,
        return_partial_responses: builtins.bool = ...,
        tag: builtins.str = ...,
        webhook: builtins.str = ...,
        messages: collections.abc.Iterable[global___DialogflowCxPageXEventHandlersXTriggerFulfillmentXMessages] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["messages", b"messages", "return_partial_responses", b"return_partial_responses", "tag", b"tag", "webhook", b"webhook"]) -> None: ...

global___DialogflowCxPageXEventHandlersXTriggerFulfillment = DialogflowCxPageXEventHandlersXTriggerFulfillment

@typing_extensions.final
class DialogflowCxPageXEventHandlers(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EVENT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    TARGET_FLOW_FIELD_NUMBER: builtins.int
    TARGET_PAGE_FIELD_NUMBER: builtins.int
    TRIGGER_FULFILLMENT_FIELD_NUMBER: builtins.int
    event: builtins.str
    name: builtins.str
    target_flow: builtins.str
    target_page: builtins.str
    @property
    def trigger_fulfillment(self) -> global___DialogflowCxPageXEventHandlersXTriggerFulfillment: ...
    def __init__(
        self,
        *,
        event: builtins.str = ...,
        name: builtins.str = ...,
        target_flow: builtins.str = ...,
        target_page: builtins.str = ...,
        trigger_fulfillment: global___DialogflowCxPageXEventHandlersXTriggerFulfillment | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["trigger_fulfillment", b"trigger_fulfillment"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["event", b"event", "name", b"name", "target_flow", b"target_flow", "target_page", b"target_page", "trigger_fulfillment", b"trigger_fulfillment"]) -> None: ...

global___DialogflowCxPageXEventHandlers = DialogflowCxPageXEventHandlers

@typing_extensions.final
class DialogflowCxPageXFormXParametersXFillBehaviorXInitialPromptFulfillmentXMessagesXText(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALLOW_PLAYBACK_INTERRUPTION_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    allow_playback_interruption: builtins.bool
    @property
    def text(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        allow_playback_interruption: builtins.bool = ...,
        text: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["allow_playback_interruption", b"allow_playback_interruption", "text", b"text"]) -> None: ...

global___DialogflowCxPageXFormXParametersXFillBehaviorXInitialPromptFulfillmentXMessagesXText = DialogflowCxPageXFormXParametersXFillBehaviorXInitialPromptFulfillmentXMessagesXText

@typing_extensions.final
class DialogflowCxPageXFormXParametersXFillBehaviorXInitialPromptFulfillmentXMessages(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_FIELD_NUMBER: builtins.int
    @property
    def text(self) -> global___DialogflowCxPageXFormXParametersXFillBehaviorXInitialPromptFulfillmentXMessagesXText: ...
    def __init__(
        self,
        *,
        text: global___DialogflowCxPageXFormXParametersXFillBehaviorXInitialPromptFulfillmentXMessagesXText | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["text", b"text"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["text", b"text"]) -> None: ...

global___DialogflowCxPageXFormXParametersXFillBehaviorXInitialPromptFulfillmentXMessages = DialogflowCxPageXFormXParametersXFillBehaviorXInitialPromptFulfillmentXMessages

@typing_extensions.final
class DialogflowCxPageXFormXParametersXFillBehaviorXInitialPromptFulfillment(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RETURN_PARTIAL_RESPONSES_FIELD_NUMBER: builtins.int
    TAG_FIELD_NUMBER: builtins.int
    WEBHOOK_FIELD_NUMBER: builtins.int
    MESSAGES_FIELD_NUMBER: builtins.int
    return_partial_responses: builtins.bool
    tag: builtins.str
    webhook: builtins.str
    @property
    def messages(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DialogflowCxPageXFormXParametersXFillBehaviorXInitialPromptFulfillmentXMessages]: ...
    def __init__(
        self,
        *,
        return_partial_responses: builtins.bool = ...,
        tag: builtins.str = ...,
        webhook: builtins.str = ...,
        messages: collections.abc.Iterable[global___DialogflowCxPageXFormXParametersXFillBehaviorXInitialPromptFulfillmentXMessages] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["messages", b"messages", "return_partial_responses", b"return_partial_responses", "tag", b"tag", "webhook", b"webhook"]) -> None: ...

global___DialogflowCxPageXFormXParametersXFillBehaviorXInitialPromptFulfillment = DialogflowCxPageXFormXParametersXFillBehaviorXInitialPromptFulfillment

@typing_extensions.final
class DialogflowCxPageXFormXParametersXFillBehavior(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INITIAL_PROMPT_FULFILLMENT_FIELD_NUMBER: builtins.int
    @property
    def initial_prompt_fulfillment(self) -> global___DialogflowCxPageXFormXParametersXFillBehaviorXInitialPromptFulfillment: ...
    def __init__(
        self,
        *,
        initial_prompt_fulfillment: global___DialogflowCxPageXFormXParametersXFillBehaviorXInitialPromptFulfillment | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["initial_prompt_fulfillment", b"initial_prompt_fulfillment"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["initial_prompt_fulfillment", b"initial_prompt_fulfillment"]) -> None: ...

global___DialogflowCxPageXFormXParametersXFillBehavior = DialogflowCxPageXFormXParametersXFillBehavior

@typing_extensions.final
class DialogflowCxPageXFormXParameters(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    ENTITY_TYPE_FIELD_NUMBER: builtins.int
    IS_LIST_FIELD_NUMBER: builtins.int
    REDACT_FIELD_NUMBER: builtins.int
    REQUIRED_FIELD_NUMBER: builtins.int
    FILL_BEHAVIOR_FIELD_NUMBER: builtins.int
    display_name: builtins.str
    entity_type: builtins.str
    is_list: builtins.bool
    redact: builtins.bool
    required: builtins.bool
    @property
    def fill_behavior(self) -> global___DialogflowCxPageXFormXParametersXFillBehavior: ...
    def __init__(
        self,
        *,
        display_name: builtins.str = ...,
        entity_type: builtins.str = ...,
        is_list: builtins.bool = ...,
        redact: builtins.bool = ...,
        required: builtins.bool = ...,
        fill_behavior: global___DialogflowCxPageXFormXParametersXFillBehavior | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["fill_behavior", b"fill_behavior"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["display_name", b"display_name", "entity_type", b"entity_type", "fill_behavior", b"fill_behavior", "is_list", b"is_list", "redact", b"redact", "required", b"required"]) -> None: ...

global___DialogflowCxPageXFormXParameters = DialogflowCxPageXFormXParameters

@typing_extensions.final
class DialogflowCxPageXForm(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PARAMETERS_FIELD_NUMBER: builtins.int
    @property
    def parameters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DialogflowCxPageXFormXParameters]: ...
    def __init__(
        self,
        *,
        parameters: collections.abc.Iterable[global___DialogflowCxPageXFormXParameters] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["parameters", b"parameters"]) -> None: ...

global___DialogflowCxPageXForm = DialogflowCxPageXForm

@typing_extensions.final
class DialogflowCxPageXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___DialogflowCxPageXTimeouts = DialogflowCxPageXTimeouts

@typing_extensions.final
class DialogflowCxPageXTransitionRoutesXTriggerFulfillmentXMessagesXText(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALLOW_PLAYBACK_INTERRUPTION_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    allow_playback_interruption: builtins.bool
    @property
    def text(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        allow_playback_interruption: builtins.bool = ...,
        text: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["allow_playback_interruption", b"allow_playback_interruption", "text", b"text"]) -> None: ...

global___DialogflowCxPageXTransitionRoutesXTriggerFulfillmentXMessagesXText = DialogflowCxPageXTransitionRoutesXTriggerFulfillmentXMessagesXText

@typing_extensions.final
class DialogflowCxPageXTransitionRoutesXTriggerFulfillmentXMessages(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_FIELD_NUMBER: builtins.int
    @property
    def text(self) -> global___DialogflowCxPageXTransitionRoutesXTriggerFulfillmentXMessagesXText: ...
    def __init__(
        self,
        *,
        text: global___DialogflowCxPageXTransitionRoutesXTriggerFulfillmentXMessagesXText | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["text", b"text"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["text", b"text"]) -> None: ...

global___DialogflowCxPageXTransitionRoutesXTriggerFulfillmentXMessages = DialogflowCxPageXTransitionRoutesXTriggerFulfillmentXMessages

@typing_extensions.final
class DialogflowCxPageXTransitionRoutesXTriggerFulfillment(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RETURN_PARTIAL_RESPONSES_FIELD_NUMBER: builtins.int
    TAG_FIELD_NUMBER: builtins.int
    WEBHOOK_FIELD_NUMBER: builtins.int
    MESSAGES_FIELD_NUMBER: builtins.int
    return_partial_responses: builtins.bool
    tag: builtins.str
    webhook: builtins.str
    @property
    def messages(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DialogflowCxPageXTransitionRoutesXTriggerFulfillmentXMessages]: ...
    def __init__(
        self,
        *,
        return_partial_responses: builtins.bool = ...,
        tag: builtins.str = ...,
        webhook: builtins.str = ...,
        messages: collections.abc.Iterable[global___DialogflowCxPageXTransitionRoutesXTriggerFulfillmentXMessages] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["messages", b"messages", "return_partial_responses", b"return_partial_responses", "tag", b"tag", "webhook", b"webhook"]) -> None: ...

global___DialogflowCxPageXTransitionRoutesXTriggerFulfillment = DialogflowCxPageXTransitionRoutesXTriggerFulfillment

@typing_extensions.final
class DialogflowCxPageXTransitionRoutes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONDITION_FIELD_NUMBER: builtins.int
    INTENT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    TARGET_FLOW_FIELD_NUMBER: builtins.int
    TARGET_PAGE_FIELD_NUMBER: builtins.int
    TRIGGER_FULFILLMENT_FIELD_NUMBER: builtins.int
    condition: builtins.str
    intent: builtins.str
    name: builtins.str
    target_flow: builtins.str
    target_page: builtins.str
    @property
    def trigger_fulfillment(self) -> global___DialogflowCxPageXTransitionRoutesXTriggerFulfillment: ...
    def __init__(
        self,
        *,
        condition: builtins.str = ...,
        intent: builtins.str = ...,
        name: builtins.str = ...,
        target_flow: builtins.str = ...,
        target_page: builtins.str = ...,
        trigger_fulfillment: global___DialogflowCxPageXTransitionRoutesXTriggerFulfillment | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["trigger_fulfillment", b"trigger_fulfillment"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "intent", b"intent", "name", b"name", "target_flow", b"target_flow", "target_page", b"target_page", "trigger_fulfillment", b"trigger_fulfillment"]) -> None: ...

global___DialogflowCxPageXTransitionRoutes = DialogflowCxPageXTransitionRoutes

@typing_extensions.final
class DialogflowCxPage(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LANGUAGE_CODE_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PARENT_FIELD_NUMBER: builtins.int
    TRANSITION_ROUTE_GROUPS_FIELD_NUMBER: builtins.int
    ENTRY_FULFILLMENT_FIELD_NUMBER: builtins.int
    EVENT_HANDLERS_FIELD_NUMBER: builtins.int
    FORM_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    TRANSITION_ROUTES_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    display_name: builtins.str
    id: builtins.str
    language_code: builtins.str
    name: builtins.str
    parent: builtins.str
    @property
    def transition_route_groups(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def entry_fulfillment(self) -> global___DialogflowCxPageXEntryFulfillment: ...
    @property
    def event_handlers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DialogflowCxPageXEventHandlers]: ...
    @property
    def form(self) -> global___DialogflowCxPageXForm: ...
    @property
    def timeouts(self) -> global___DialogflowCxPageXTimeouts: ...
    @property
    def transition_routes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DialogflowCxPageXTransitionRoutes]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        display_name: builtins.str = ...,
        id: builtins.str = ...,
        language_code: builtins.str = ...,
        name: builtins.str = ...,
        parent: builtins.str = ...,
        transition_route_groups: collections.abc.Iterable[builtins.str] | None = ...,
        entry_fulfillment: global___DialogflowCxPageXEntryFulfillment | None = ...,
        event_handlers: collections.abc.Iterable[global___DialogflowCxPageXEventHandlers] | None = ...,
        form: global___DialogflowCxPageXForm | None = ...,
        timeouts: global___DialogflowCxPageXTimeouts | None = ...,
        transition_routes: collections.abc.Iterable[global___DialogflowCxPageXTransitionRoutes] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["entry_fulfillment", b"entry_fulfillment", "form", b"form", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["display_name", b"display_name", "entry_fulfillment", b"entry_fulfillment", "event_handlers", b"event_handlers", "form", b"form", "id", b"id", "language_code", b"language_code", "name", b"name", "parent", b"parent", "resource_info", b"resource_info", "timeouts", b"timeouts", "transition_route_groups", b"transition_route_groups", "transition_routes", b"transition_routes"]) -> None: ...

global___DialogflowCxPage = DialogflowCxPage

@typing_extensions.final
class DialogflowCxVersionXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___DialogflowCxVersionXTimeouts = DialogflowCxVersionXTimeouts

@typing_extensions.final
class DialogflowCxVersion(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class NluSettingsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    CREATE_TIME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    NLU_SETTINGS_FIELD_NUMBER: builtins.int
    PARENT_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    create_time: builtins.str
    description: builtins.str
    display_name: builtins.str
    id: builtins.str
    name: builtins.str
    @property
    def nlu_settings(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    parent: builtins.str
    state: builtins.str
    @property
    def timeouts(self) -> global___DialogflowCxVersionXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        create_time: builtins.str = ...,
        description: builtins.str = ...,
        display_name: builtins.str = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        nlu_settings: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        parent: builtins.str = ...,
        state: builtins.str = ...,
        timeouts: global___DialogflowCxVersionXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["create_time", b"create_time", "description", b"description", "display_name", b"display_name", "id", b"id", "name", b"name", "nlu_settings", b"nlu_settings", "parent", b"parent", "resource_info", b"resource_info", "state", b"state", "timeouts", b"timeouts"]) -> None: ...

global___DialogflowCxVersion = DialogflowCxVersion

@typing_extensions.final
class DialogflowEntityTypeXEntities(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SYNONYMS_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    @property
    def synonyms(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    value: builtins.str
    def __init__(
        self,
        *,
        synonyms: collections.abc.Iterable[builtins.str] | None = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["synonyms", b"synonyms", "value", b"value"]) -> None: ...

global___DialogflowEntityTypeXEntities = DialogflowEntityTypeXEntities

@typing_extensions.final
class DialogflowEntityTypeXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___DialogflowEntityTypeXTimeouts = DialogflowEntityTypeXTimeouts

@typing_extensions.final
class DialogflowEntityType(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    ENABLE_FUZZY_EXTRACTION_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    ENTITIES_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    display_name: builtins.str
    enable_fuzzy_extraction: builtins.bool
    id: builtins.str
    kind: builtins.str
    name: builtins.str
    project: builtins.str
    @property
    def entities(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DialogflowEntityTypeXEntities]: ...
    @property
    def timeouts(self) -> global___DialogflowEntityTypeXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        display_name: builtins.str = ...,
        enable_fuzzy_extraction: builtins.bool = ...,
        id: builtins.str = ...,
        kind: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        entities: collections.abc.Iterable[global___DialogflowEntityTypeXEntities] | None = ...,
        timeouts: global___DialogflowEntityTypeXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["display_name", b"display_name", "enable_fuzzy_extraction", b"enable_fuzzy_extraction", "entities", b"entities", "id", b"id", "kind", b"kind", "name", b"name", "project", b"project", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> None: ...

global___DialogflowEntityType = DialogflowEntityType

@typing_extensions.final
class DialogflowFulfillmentXFeatures(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    type: builtins.str
    def __init__(
        self,
        *,
        type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["type", b"type"]) -> None: ...

global___DialogflowFulfillmentXFeatures = DialogflowFulfillmentXFeatures

@typing_extensions.final
class DialogflowFulfillmentXGenericWebService(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class RequestHeadersEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    PASSWORD_FIELD_NUMBER: builtins.int
    REQUEST_HEADERS_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    USERNAME_FIELD_NUMBER: builtins.int
    password: builtins.str
    @property
    def request_headers(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    uri: builtins.str
    username: builtins.str
    def __init__(
        self,
        *,
        password: builtins.str = ...,
        request_headers: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        uri: builtins.str = ...,
        username: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["password", b"password", "request_headers", b"request_headers", "uri", b"uri", "username", b"username"]) -> None: ...

global___DialogflowFulfillmentXGenericWebService = DialogflowFulfillmentXGenericWebService

@typing_extensions.final
class DialogflowFulfillmentXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___DialogflowFulfillmentXTimeouts = DialogflowFulfillmentXTimeouts

@typing_extensions.final
class DialogflowFulfillment(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    ENABLED_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    FEATURES_FIELD_NUMBER: builtins.int
    GENERIC_WEB_SERVICE_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    display_name: builtins.str
    enabled: builtins.bool
    id: builtins.str
    name: builtins.str
    project: builtins.str
    @property
    def features(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DialogflowFulfillmentXFeatures]: ...
    @property
    def generic_web_service(self) -> global___DialogflowFulfillmentXGenericWebService: ...
    @property
    def timeouts(self) -> global___DialogflowFulfillmentXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        display_name: builtins.str = ...,
        enabled: builtins.bool = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        features: collections.abc.Iterable[global___DialogflowFulfillmentXFeatures] | None = ...,
        generic_web_service: global___DialogflowFulfillmentXGenericWebService | None = ...,
        timeouts: global___DialogflowFulfillmentXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["generic_web_service", b"generic_web_service", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["display_name", b"display_name", "enabled", b"enabled", "features", b"features", "generic_web_service", b"generic_web_service", "id", b"id", "name", b"name", "project", b"project", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> None: ...

global___DialogflowFulfillment = DialogflowFulfillment

@typing_extensions.final
class DialogflowIntentXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___DialogflowIntentXTimeouts = DialogflowIntentXTimeouts

@typing_extensions.final
class DialogflowIntent(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class FollowupIntentInfoEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    ACTION_FIELD_NUMBER: builtins.int
    DEFAULT_RESPONSE_PLATFORMS_FIELD_NUMBER: builtins.int
    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    EVENTS_FIELD_NUMBER: builtins.int
    FOLLOWUP_INTENT_INFO_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    INPUT_CONTEXT_NAMES_FIELD_NUMBER: builtins.int
    IS_FALLBACK_FIELD_NUMBER: builtins.int
    ML_DISABLED_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PARENT_FOLLOWUP_INTENT_NAME_FIELD_NUMBER: builtins.int
    PRIORITY_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    RESET_CONTEXTS_FIELD_NUMBER: builtins.int
    ROOT_FOLLOWUP_INTENT_NAME_FIELD_NUMBER: builtins.int
    WEBHOOK_STATE_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    action: builtins.str
    @property
    def default_response_platforms(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    display_name: builtins.str
    @property
    def events(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def followup_intent_info(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    id: builtins.str
    @property
    def input_context_names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    is_fallback: builtins.bool
    ml_disabled: builtins.bool
    name: builtins.str
    parent_followup_intent_name: builtins.str
    priority: builtins.float
    project: builtins.str
    reset_contexts: builtins.bool
    root_followup_intent_name: builtins.str
    webhook_state: builtins.str
    @property
    def timeouts(self) -> global___DialogflowIntentXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        action: builtins.str = ...,
        default_response_platforms: collections.abc.Iterable[builtins.str] | None = ...,
        display_name: builtins.str = ...,
        events: collections.abc.Iterable[builtins.str] | None = ...,
        followup_intent_info: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        id: builtins.str = ...,
        input_context_names: collections.abc.Iterable[builtins.str] | None = ...,
        is_fallback: builtins.bool = ...,
        ml_disabled: builtins.bool = ...,
        name: builtins.str = ...,
        parent_followup_intent_name: builtins.str = ...,
        priority: builtins.float = ...,
        project: builtins.str = ...,
        reset_contexts: builtins.bool = ...,
        root_followup_intent_name: builtins.str = ...,
        webhook_state: builtins.str = ...,
        timeouts: global___DialogflowIntentXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["action", b"action", "default_response_platforms", b"default_response_platforms", "display_name", b"display_name", "events", b"events", "followup_intent_info", b"followup_intent_info", "id", b"id", "input_context_names", b"input_context_names", "is_fallback", b"is_fallback", "ml_disabled", b"ml_disabled", "name", b"name", "parent_followup_intent_name", b"parent_followup_intent_name", "priority", b"priority", "project", b"project", "reset_contexts", b"reset_contexts", "resource_info", b"resource_info", "root_followup_intent_name", b"root_followup_intent_name", "timeouts", b"timeouts", "webhook_state", b"webhook_state"]) -> None: ...

global___DialogflowIntent = DialogflowIntent
