# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_compute_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dgcp/gcp_compute_service.proto\x12\x1foak9.tython.gcp.compute_service\x1a\x13shared/shared.proto\"c\n,ComputeServiceAttachmentXConsumerAcceptLists\x12\x18\n\x10\x63onnection_limit\x18\x01 \x01(\x01\x12\x19\n\x11project_id_or_num\x18\x02 \x01(\t\"S\n!ComputeServiceAttachmentXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xda\x05\n\x18\x43omputeServiceAttachment\x12n\n\x13\x63onnected_endpoints\x18\x01 \x03(\x0b\x32Q.oak9.tython.gcp.compute_service.ComputeServiceAttachment.ConnectedEndpointsEntry\x12\x1d\n\x15\x63onnection_preference\x18\x02 \x01(\t\x12\x1d\n\x15\x63onsumer_reject_lists\x18\x03 \x03(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x14\n\x0c\x64omain_names\x18\x05 \x03(\t\x12\x1d\n\x15\x65nable_proxy_protocol\x18\x06 \x01(\x08\x12\x13\n\x0b\x66ingerprint\x18\x07 \x01(\t\x12\n\n\x02id\x18\x08 \x01(\t\x12\x0c\n\x04name\x18\t \x01(\t\x12\x13\n\x0bnat_subnets\x18\n \x03(\t\x12\x0f\n\x07project\x18\x0b \x01(\t\x12\x0e\n\x06region\x18\x0c \x01(\t\x12\x11\n\tself_link\x18\r \x01(\t\x12\x16\n\x0etarget_service\x18\x0e \x01(\t\x12l\n\x15\x63onsumer_accept_lists\x18\x0f \x03(\x0b\x32M.oak9.tython.gcp.compute_service.ComputeServiceAttachmentXConsumerAcceptLists\x12T\n\x08timeouts\x18\x10 \x01(\x0b\x32\x42.oak9.tython.gcp.compute_service.ComputeServiceAttachmentXTimeouts\x12\x37\n\rresource_info\x18\x11 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a\x39\n\x17\x43onnectedEndpointsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_compute_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMPUTESERVICEATTACHMENT_CONNECTEDENDPOINTSENTRY._options = None
  _COMPUTESERVICEATTACHMENT_CONNECTEDENDPOINTSENTRY._serialized_options = b'8\001'
  _COMPUTESERVICEATTACHMENTXCONSUMERACCEPTLISTS._serialized_start=87
  _COMPUTESERVICEATTACHMENTXCONSUMERACCEPTLISTS._serialized_end=186
  _COMPUTESERVICEATTACHMENTXTIMEOUTS._serialized_start=188
  _COMPUTESERVICEATTACHMENTXTIMEOUTS._serialized_end=271
  _COMPUTESERVICEATTACHMENT._serialized_start=274
  _COMPUTESERVICEATTACHMENT._serialized_end=1004
  _COMPUTESERVICEATTACHMENT_CONNECTEDENDPOINTSENTRY._serialized_start=947
  _COMPUTESERVICEATTACHMENT_CONNECTEDENDPOINTSENTRY._serialized_end=1004
# @@protoc_insertion_point(module_scope)
