"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import gcp.gcp_secret_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class GoogleSecretManager(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SECRET_MANAGER_SECRET_FIELD_NUMBER: builtins.int
    SECRET_MANAGER_SECRET_IAM_BINDING_FIELD_NUMBER: builtins.int
    SECRET_MANAGER_SECRET_IAM_MEMBER_FIELD_NUMBER: builtins.int
    SECRET_MANAGER_SECRET_IAM_POLICY_FIELD_NUMBER: builtins.int
    SECRET_MANAGER_SECRET_VERSION_FIELD_NUMBER: builtins.int
    @property
    def secret_manager_secret(self) -> gcp.gcp_secret_pb2.SecretManagerSecret: ...
    @property
    def secret_manager_secret_iam_binding(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[gcp.gcp_secret_pb2.SecretManagerSecretIamBinding]: ...
    @property
    def secret_manager_secret_iam_member(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[gcp.gcp_secret_pb2.SecretManagerSecretIamMember]: ...
    @property
    def secret_manager_secret_iam_policy(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[gcp.gcp_secret_pb2.SecretManagerSecretIamPolicy]: ...
    @property
    def secret_manager_secret_version(self) -> gcp.gcp_secret_pb2.SecretManagerSecretVersion: ...
    def __init__(
        self,
        *,
        secret_manager_secret: gcp.gcp_secret_pb2.SecretManagerSecret | None = ...,
        secret_manager_secret_iam_binding: collections.abc.Iterable[gcp.gcp_secret_pb2.SecretManagerSecretIamBinding] | None = ...,
        secret_manager_secret_iam_member: collections.abc.Iterable[gcp.gcp_secret_pb2.SecretManagerSecretIamMember] | None = ...,
        secret_manager_secret_iam_policy: collections.abc.Iterable[gcp.gcp_secret_pb2.SecretManagerSecretIamPolicy] | None = ...,
        secret_manager_secret_version: gcp.gcp_secret_pb2.SecretManagerSecretVersion | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["secret_manager_secret", b"secret_manager_secret", "secret_manager_secret_version", b"secret_manager_secret_version"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["secret_manager_secret", b"secret_manager_secret", "secret_manager_secret_iam_binding", b"secret_manager_secret_iam_binding", "secret_manager_secret_iam_member", b"secret_manager_secret_iam_member", "secret_manager_secret_iam_policy", b"secret_manager_secret_iam_policy", "secret_manager_secret_version", b"secret_manager_secret_version"]) -> None: ...

global___GoogleSecretManager = GoogleSecretManager
