# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: azure/azure_microsoft_network_privateendpoints.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4azure/azure_microsoft_network_privateendpoints.proto\x12\x34oak9.tython.azure.microsoft_network_privateendpoints\x1a\x13shared/shared.proto\"\x97\x02\n\"Microsoft_Network_privateEndpoints\x12\x61\n\x11private_endpoints\x18\x01 \x01(\x0b\x32\x46.oak9.tython.azure.microsoft_network_privateendpoints.PrivateEndpoints\x12\x8d\x01\n)private_endpoints_private_dns_zone_groups\x18\x02 \x03(\x0b\x32Z.oak9.tython.azure.microsoft_network_privateendpoints.PrivateEndpointsPrivateDnsZoneGroups\"\x14\n\x06Subnet\x12\n\n\x02id\x18\x01 \x01(\t\"\xdb\x01\n$PrivateEndpointsPrivateDnsZoneGroups\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12l\n\x18private_dns_zone_configs\x18\x03 \x03(\x0b\x32J.oak9.tython.azure.microsoft_network_privateendpoints.PrivateDnsZoneConfig\"A\n\x14PrivateDnsZoneConfig\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x1b\n\x13private_dns_zone_id\x18\x02 \x01(\t\"\xa0\x06\n\x10PrivateEndpoints\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12^\n\x04tags\x18\x04 \x03(\x0b\x32P.oak9.tython.azure.microsoft_network_privateendpoints.PrivateEndpoints.TagsEntry\x12\x61\n\x11\x65xtended_location\x18\x05 \x01(\x0b\x32\x46.oak9.tython.azure.microsoft_network_privateendpoints.ExtendedLocation\x12L\n\x06subnet\x18\x06 \x01(\x0b\x32<.oak9.tython.azure.microsoft_network_privateendpoints.Subnet\x12|\n private_link_service_connections\x18\x07 \x03(\x0b\x32R.oak9.tython.azure.microsoft_network_privateendpoints.PrivateLinkServiceConnection\x12\x83\x01\n\'manual_private_link_service_connections\x18\x08 \x03(\x0b\x32R.oak9.tython.azure.microsoft_network_privateendpoints.PrivateLinkServiceConnection\x12q\n\x12\x63ustom_dns_configs\x18\t \x03(\x0b\x32U.oak9.tython.azure.microsoft_network_privateendpoints.CustomDnsConfigPropertiesFormat\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"E\n\x1f\x43ustomDnsConfigPropertiesFormat\x12\x0c\n\x04\x66qdn\x18\x01 \x01(\t\x12\x14\n\x0cip_addresses\x18\x02 \x03(\t\"\x82\x02\n\x1cPrivateLinkServiceConnection\x12\x1f\n\x17private_link_service_id\x18\x01 \x01(\t\x12\x11\n\tgroup_ids\x18\x02 \x03(\t\x12\x17\n\x0frequest_message\x18\x03 \x01(\t\x12\x86\x01\n%private_link_service_connection_state\x18\x04 \x01(\x0b\x32W.oak9.tython.azure.microsoft_network_privateendpoints.PrivateLinkServiceConnectionState\x12\x0c\n\x04name\x18\x05 \x01(\t\"b\n!PrivateLinkServiceConnectionState\x12\x0e\n\x06status\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x18\n\x10\x61\x63tions_required\x18\x03 \x01(\t\".\n\x10\x45xtendedLocation\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'azure.azure_microsoft_network_privateendpoints_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _PRIVATEENDPOINTS_TAGSENTRY._options = None
  _PRIVATEENDPOINTS_TAGSENTRY._serialized_options = b'8\001'
  _MICROSOFT_NETWORK_PRIVATEENDPOINTS._serialized_start=132
  _MICROSOFT_NETWORK_PRIVATEENDPOINTS._serialized_end=411
  _SUBNET._serialized_start=413
  _SUBNET._serialized_end=433
  _PRIVATEENDPOINTSPRIVATEDNSZONEGROUPS._serialized_start=436
  _PRIVATEENDPOINTSPRIVATEDNSZONEGROUPS._serialized_end=655
  _PRIVATEDNSZONECONFIG._serialized_start=657
  _PRIVATEDNSZONECONFIG._serialized_end=722
  _PRIVATEENDPOINTS._serialized_start=725
  _PRIVATEENDPOINTS._serialized_end=1525
  _PRIVATEENDPOINTS_TAGSENTRY._serialized_start=1482
  _PRIVATEENDPOINTS_TAGSENTRY._serialized_end=1525
  _CUSTOMDNSCONFIGPROPERTIESFORMAT._serialized_start=1527
  _CUSTOMDNSCONFIGPROPERTIESFORMAT._serialized_end=1596
  _PRIVATELINKSERVICECONNECTION._serialized_start=1599
  _PRIVATELINKSERVICECONNECTION._serialized_end=1857
  _PRIVATELINKSERVICECONNECTIONSTATE._serialized_start=1859
  _PRIVATELINKSERVICECONNECTIONSTATE._serialized_end=1957
  _EXTENDEDLOCATION._serialized_start=1959
  _EXTENDEDLOCATION._serialized_end=2005
# @@protoc_insertion_point(module_scope)
