"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Route(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DESTINATION_CIDR_BLOCK_FIELD_NUMBER: builtins.int
    DESTINATION_IPV6_CIDR_BLOCK_FIELD_NUMBER: builtins.int
    EGRESS_ONLY_INTERNET_GATEWAY_ID_FIELD_NUMBER: builtins.int
    GATEWAY_ID_FIELD_NUMBER: builtins.int
    INSTANCE_ID_FIELD_NUMBER: builtins.int
    NAT_GATEWAY_ID_FIELD_NUMBER: builtins.int
    NETWORK_INTERFACE_ID_FIELD_NUMBER: builtins.int
    ROUTE_TABLE_ID_FIELD_NUMBER: builtins.int
    TRANSIT_GATEWAY_ID_FIELD_NUMBER: builtins.int
    VPC_PEERING_CONNECTION_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    destination_cidr_block: builtins.str
    destination_ipv6_cidr_block: builtins.str
    egress_only_internet_gateway_id: builtins.str
    gateway_id: builtins.str
    instance_id: builtins.str
    nat_gateway_id: builtins.str
    network_interface_id: builtins.str
    route_table_id: builtins.str
    transit_gateway_id: builtins.str
    vpc_peering_connection_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        destination_cidr_block: builtins.str = ...,
        destination_ipv6_cidr_block: builtins.str = ...,
        egress_only_internet_gateway_id: builtins.str = ...,
        gateway_id: builtins.str = ...,
        instance_id: builtins.str = ...,
        nat_gateway_id: builtins.str = ...,
        network_interface_id: builtins.str = ...,
        route_table_id: builtins.str = ...,
        transit_gateway_id: builtins.str = ...,
        vpc_peering_connection_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["destination_cidr_block", b"destination_cidr_block", "destination_ipv6_cidr_block", b"destination_ipv6_cidr_block", "egress_only_internet_gateway_id", b"egress_only_internet_gateway_id", "gateway_id", b"gateway_id", "instance_id", b"instance_id", "nat_gateway_id", b"nat_gateway_id", "network_interface_id", b"network_interface_id", "resource_info", b"resource_info", "route_table_id", b"route_table_id", "transit_gateway_id", b"transit_gateway_id", "vpc_peering_connection_id", b"vpc_peering_connection_id"]) -> None: ...

global___Route = Route

@typing_extensions.final
class EC2_Route(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ROUTE_FIELD_NUMBER: builtins.int
    ROUTE_TABLE_FIELD_NUMBER: builtins.int
    @property
    def route(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Route]: ...
    @property
    def route_table(self) -> global___RouteTable: ...
    def __init__(
        self,
        *,
        route: collections.abc.Iterable[global___Route] | None = ...,
        route_table: global___RouteTable | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["route_table", b"route_table"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["route", b"route", "route_table", b"route_table"]) -> None: ...

global___EC2_Route = EC2_Route

@typing_extensions.final
class RouteTable(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    VPC_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    vpc_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        vpc_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "tags", b"tags", "vpc_id", b"vpc_id"]) -> None: ...

global___RouteTable = RouteTable
