# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_compute_node.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1agcp/gcp_compute_node.proto\x12\x1coak9.tython.gcp.compute_node\x1a\x13shared/shared.proto\"X\n\"ComputeNodeGroupXAutoscalingPolicy\x12\x11\n\tmax_nodes\x18\x01 \x01(\x01\x12\x11\n\tmin_nodes\x18\x02 \x01(\x01\x12\x0c\n\x04mode\x18\x03 \x01(\t\"8\n\"ComputeNodeGroupXMaintenanceWindow\x12\x12\n\nstart_time\x18\x01 \x01(\t\"K\n\x19\x43omputeNodeGroupXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xa6\x04\n\x10\x43omputeNodeGroup\x12\x1a\n\x12\x63reation_timestamp\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x14\n\x0cinitial_size\x18\x04 \x01(\x01\x12\x1a\n\x12maintenance_policy\x18\x05 \x01(\t\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x15\n\rnode_template\x18\x07 \x01(\t\x12\x0f\n\x07project\x18\x08 \x01(\t\x12\x11\n\tself_link\x18\t \x01(\t\x12\x0c\n\x04size\x18\n \x01(\x01\x12\x0c\n\x04zone\x18\x0b \x01(\t\x12\\\n\x12\x61utoscaling_policy\x18\x0c \x01(\x0b\x32@.oak9.tython.gcp.compute_node.ComputeNodeGroupXAutoscalingPolicy\x12\\\n\x12maintenance_window\x18\r \x01(\x0b\x32@.oak9.tython.gcp.compute_node.ComputeNodeGroupXMaintenanceWindow\x12I\n\x08timeouts\x18\x0e \x01(\x0b\x32\x37.oak9.tython.gcp.compute_node.ComputeNodeGroupXTimeouts\x12\x37\n\rresource_info\x18\x0f \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"Z\n\'ComputeNodeTemplateXNodeTypeFlexibility\x12\x0c\n\x04\x63pus\x18\x01 \x01(\t\x12\x11\n\tlocal_ssd\x18\x02 \x01(\t\x12\x0e\n\x06memory\x18\x03 \x01(\t\"1\n!ComputeNodeTemplateXServerBinding\x12\x0c\n\x04type\x18\x01 \x01(\t\">\n\x1c\x43omputeNodeTemplateXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\"\xae\x05\n\x13\x43omputeNodeTemplate\x12\x1b\n\x13\x63pu_overcommit_type\x18\x01 \x01(\t\x12\x1a\n\x12\x63reation_timestamp\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\n\n\x02id\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12g\n\x14node_affinity_labels\x18\x06 \x03(\x0b\x32I.oak9.tython.gcp.compute_node.ComputeNodeTemplate.NodeAffinityLabelsEntry\x12\x11\n\tnode_type\x18\x07 \x01(\t\x12\x0f\n\x07project\x18\x08 \x01(\t\x12\x0e\n\x06region\x18\t \x01(\t\x12\x11\n\tself_link\x18\n \x01(\t\x12\x64\n\x15node_type_flexibility\x18\x0b \x01(\x0b\x32\x45.oak9.tython.gcp.compute_node.ComputeNodeTemplateXNodeTypeFlexibility\x12W\n\x0eserver_binding\x18\x0c \x01(\x0b\x32?.oak9.tython.gcp.compute_node.ComputeNodeTemplateXServerBinding\x12L\n\x08timeouts\x18\r \x01(\x0b\x32:.oak9.tython.gcp.compute_node.ComputeNodeTemplateXTimeouts\x12\x37\n\rresource_info\x18\x0e \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a\x39\n\x17NodeAffinityLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_compute_node_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMPUTENODETEMPLATE_NODEAFFINITYLABELSENTRY._options = None
  _COMPUTENODETEMPLATE_NODEAFFINITYLABELSENTRY._serialized_options = b'8\001'
  _COMPUTENODEGROUPXAUTOSCALINGPOLICY._serialized_start=81
  _COMPUTENODEGROUPXAUTOSCALINGPOLICY._serialized_end=169
  _COMPUTENODEGROUPXMAINTENANCEWINDOW._serialized_start=171
  _COMPUTENODEGROUPXMAINTENANCEWINDOW._serialized_end=227
  _COMPUTENODEGROUPXTIMEOUTS._serialized_start=229
  _COMPUTENODEGROUPXTIMEOUTS._serialized_end=304
  _COMPUTENODEGROUP._serialized_start=307
  _COMPUTENODEGROUP._serialized_end=857
  _COMPUTENODETEMPLATEXNODETYPEFLEXIBILITY._serialized_start=859
  _COMPUTENODETEMPLATEXNODETYPEFLEXIBILITY._serialized_end=949
  _COMPUTENODETEMPLATEXSERVERBINDING._serialized_start=951
  _COMPUTENODETEMPLATEXSERVERBINDING._serialized_end=1000
  _COMPUTENODETEMPLATEXTIMEOUTS._serialized_start=1002
  _COMPUTENODETEMPLATEXTIMEOUTS._serialized_end=1064
  _COMPUTENODETEMPLATE._serialized_start=1067
  _COMPUTENODETEMPLATE._serialized_end=1753
  _COMPUTENODETEMPLATE_NODEAFFINITYLABELSENTRY._serialized_start=1696
  _COMPUTENODETEMPLATE_NODEAFFINITYLABELSENTRY._serialized_end=1753
# @@protoc_insertion_point(module_scope)
