"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class AppSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    PASSWORD_FIELD_NUMBER: builtins.int
    REVISION_FIELD_NUMBER: builtins.int
    SSH_KEY_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    USERNAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    password: builtins.str
    revision: builtins.str
    ssh_key: builtins.str
    url: builtins.str
    username: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        password: builtins.str = ...,
        revision: builtins.str = ...,
        ssh_key: builtins.str = ...,
        url: builtins.str = ...,
        username: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["password", b"password", "resource_info", b"resource_info", "revision", b"revision", "ssh_key", b"ssh_key", "url", b"url", "username", b"username"]) -> None: ...

global___AppSource = AppSource

@typing_extensions.final
class AppDataSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ARN_FIELD_NUMBER: builtins.int
    DATABASE_NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    arn: builtins.str
    database_name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        arn: builtins.str = ...,
        database_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["arn", b"arn", "database_name", b"database_name", "resource_info", b"resource_info"]) -> None: ...

global___AppDataSource = AppDataSource

@typing_extensions.final
class AppEnvironmentVariable(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    SECURE_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    key: builtins.str
    secure: builtins.bool
    value: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        key: builtins.str = ...,
        secure: builtins.bool = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "resource_info", b"resource_info", "secure", b"secure", "value", b"value"]) -> None: ...

global___AppEnvironmentVariable = AppEnvironmentVariable

@typing_extensions.final
class AppSslConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CERTIFICATE_FIELD_NUMBER: builtins.int
    CHAIN_FIELD_NUMBER: builtins.int
    PRIVATE_KEY_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    certificate: builtins.str
    chain: builtins.str
    private_key: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        certificate: builtins.str = ...,
        chain: builtins.str = ...,
        private_key: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["certificate", b"certificate", "chain", b"chain", "private_key", b"private_key", "resource_info", b"resource_info"]) -> None: ...

global___AppSslConfiguration = AppSslConfiguration

@typing_extensions.final
class App(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class AttributesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    APP_SOURCE_FIELD_NUMBER: builtins.int
    ATTRIBUTES_FIELD_NUMBER: builtins.int
    DATA_SOURCES_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    DOMAINS_FIELD_NUMBER: builtins.int
    ENABLE_SSL_FIELD_NUMBER: builtins.int
    ENVIRONMENT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    SHORTNAME_FIELD_NUMBER: builtins.int
    SSL_CONFIGURATION_FIELD_NUMBER: builtins.int
    STACK_ID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def app_source(self) -> global___AppSource: ...
    @property
    def attributes(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def data_sources(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AppDataSource]: ...
    description: builtins.str
    @property
    def domains(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    enable_ssl: builtins.bool
    @property
    def environment(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AppEnvironmentVariable]: ...
    name: builtins.str
    shortname: builtins.str
    @property
    def ssl_configuration(self) -> global___AppSslConfiguration: ...
    stack_id: builtins.str
    type: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        app_source: global___AppSource | None = ...,
        attributes: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        data_sources: collections.abc.Iterable[global___AppDataSource] | None = ...,
        description: builtins.str = ...,
        domains: collections.abc.Iterable[builtins.str] | None = ...,
        enable_ssl: builtins.bool = ...,
        environment: collections.abc.Iterable[global___AppEnvironmentVariable] | None = ...,
        name: builtins.str = ...,
        shortname: builtins.str = ...,
        ssl_configuration: global___AppSslConfiguration | None = ...,
        stack_id: builtins.str = ...,
        type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["app_source", b"app_source", "resource_info", b"resource_info", "ssl_configuration", b"ssl_configuration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["app_source", b"app_source", "attributes", b"attributes", "data_sources", b"data_sources", "description", b"description", "domains", b"domains", "enable_ssl", b"enable_ssl", "environment", b"environment", "name", b"name", "resource_info", b"resource_info", "shortname", b"shortname", "ssl_configuration", b"ssl_configuration", "stack_id", b"stack_id", "type", b"type"]) -> None: ...

global___App = App

@typing_extensions.final
class OpsWorks(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APP_FIELD_NUMBER: builtins.int
    ELASTIC_LOAD_BALANCER_ATTACHMENT_FIELD_NUMBER: builtins.int
    INSTANCE_FIELD_NUMBER: builtins.int
    LAYER_FIELD_NUMBER: builtins.int
    STACK_FIELD_NUMBER: builtins.int
    USER_PROFILE_FIELD_NUMBER: builtins.int
    VOLUME_FIELD_NUMBER: builtins.int
    @property
    def app(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___App]: ...
    @property
    def elastic_load_balancer_attachment(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ElasticLoadBalancerAttachment]: ...
    @property
    def instance(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Instance]: ...
    @property
    def layer(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Layer]: ...
    @property
    def stack(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Stack]: ...
    @property
    def user_profile(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___UserProfile]: ...
    @property
    def volume(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Volume]: ...
    def __init__(
        self,
        *,
        app: collections.abc.Iterable[global___App] | None = ...,
        elastic_load_balancer_attachment: collections.abc.Iterable[global___ElasticLoadBalancerAttachment] | None = ...,
        instance: collections.abc.Iterable[global___Instance] | None = ...,
        layer: collections.abc.Iterable[global___Layer] | None = ...,
        stack: collections.abc.Iterable[global___Stack] | None = ...,
        user_profile: collections.abc.Iterable[global___UserProfile] | None = ...,
        volume: collections.abc.Iterable[global___Volume] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["app", b"app", "elastic_load_balancer_attachment", b"elastic_load_balancer_attachment", "instance", b"instance", "layer", b"layer", "stack", b"stack", "user_profile", b"user_profile", "volume", b"volume"]) -> None: ...

global___OpsWorks = OpsWorks

@typing_extensions.final
class ElasticLoadBalancerAttachment(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ELASTIC_LOAD_BALANCER_NAME_FIELD_NUMBER: builtins.int
    LAYER_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    elastic_load_balancer_name: builtins.str
    layer_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        elastic_load_balancer_name: builtins.str = ...,
        layer_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["elastic_load_balancer_name", b"elastic_load_balancer_name", "layer_id", b"layer_id", "resource_info", b"resource_info"]) -> None: ...

global___ElasticLoadBalancerAttachment = ElasticLoadBalancerAttachment

@typing_extensions.final
class InstanceEbsBlockDevice(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DELETE_ON_TERMINATION_FIELD_NUMBER: builtins.int
    IOPS_FIELD_NUMBER: builtins.int
    SNAPSHOT_ID_FIELD_NUMBER: builtins.int
    VOLUME_SIZE_FIELD_NUMBER: builtins.int
    VOLUME_TYPE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    delete_on_termination: builtins.bool
    iops: builtins.int
    snapshot_id: builtins.str
    volume_size: builtins.int
    volume_type: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        delete_on_termination: builtins.bool = ...,
        iops: builtins.int = ...,
        snapshot_id: builtins.str = ...,
        volume_size: builtins.int = ...,
        volume_type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["delete_on_termination", b"delete_on_termination", "iops", b"iops", "resource_info", b"resource_info", "snapshot_id", b"snapshot_id", "volume_size", b"volume_size", "volume_type", b"volume_type"]) -> None: ...

global___InstanceEbsBlockDevice = InstanceEbsBlockDevice

@typing_extensions.final
class InstanceBlockDeviceMapping(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DEVICE_NAME_FIELD_NUMBER: builtins.int
    EBS_FIELD_NUMBER: builtins.int
    NO_DEVICE_FIELD_NUMBER: builtins.int
    VIRTUAL_NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    device_name: builtins.str
    @property
    def ebs(self) -> global___InstanceEbsBlockDevice: ...
    no_device: builtins.str
    virtual_name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        device_name: builtins.str = ...,
        ebs: global___InstanceEbsBlockDevice | None = ...,
        no_device: builtins.str = ...,
        virtual_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["ebs", b"ebs", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["device_name", b"device_name", "ebs", b"ebs", "no_device", b"no_device", "resource_info", b"resource_info", "virtual_name", b"virtual_name"]) -> None: ...

global___InstanceBlockDeviceMapping = InstanceBlockDeviceMapping

@typing_extensions.final
class InstanceTimeBasedAutoScaling(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class FridayEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class MondayEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class SaturdayEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class SundayEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class ThursdayEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class TuesdayEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class WednesdayEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    FRIDAY_FIELD_NUMBER: builtins.int
    MONDAY_FIELD_NUMBER: builtins.int
    SATURDAY_FIELD_NUMBER: builtins.int
    SUNDAY_FIELD_NUMBER: builtins.int
    THURSDAY_FIELD_NUMBER: builtins.int
    TUESDAY_FIELD_NUMBER: builtins.int
    WEDNESDAY_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def friday(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def monday(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def saturday(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def sunday(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def thursday(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def tuesday(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def wednesday(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        friday: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        monday: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        saturday: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        sunday: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        thursday: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        tuesday: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        wednesday: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["friday", b"friday", "monday", b"monday", "resource_info", b"resource_info", "saturday", b"saturday", "sunday", b"sunday", "thursday", b"thursday", "tuesday", b"tuesday", "wednesday", b"wednesday"]) -> None: ...

global___InstanceTimeBasedAutoScaling = InstanceTimeBasedAutoScaling

@typing_extensions.final
class Instance(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    AGENT_VERSION_FIELD_NUMBER: builtins.int
    AMI_ID_FIELD_NUMBER: builtins.int
    ARCHITECTURE_FIELD_NUMBER: builtins.int
    AUTO_SCALING_TYPE_FIELD_NUMBER: builtins.int
    AVAILABILITY_ZONE_FIELD_NUMBER: builtins.int
    BLOCK_DEVICE_MAPPINGS_FIELD_NUMBER: builtins.int
    EBS_OPTIMIZED_FIELD_NUMBER: builtins.int
    ELASTIC_IPS_FIELD_NUMBER: builtins.int
    HOSTNAME_FIELD_NUMBER: builtins.int
    INSTALL_UPDATES_ON_BOOT_FIELD_NUMBER: builtins.int
    INSTANCE_TYPE_FIELD_NUMBER: builtins.int
    LAYER_IDS_FIELD_NUMBER: builtins.int
    OS_FIELD_NUMBER: builtins.int
    ROOT_DEVICE_TYPE_FIELD_NUMBER: builtins.int
    SSH_KEY_NAME_FIELD_NUMBER: builtins.int
    STACK_ID_FIELD_NUMBER: builtins.int
    SUBNET_ID_FIELD_NUMBER: builtins.int
    TENANCY_FIELD_NUMBER: builtins.int
    TIME_BASED_AUTO_SCALING_FIELD_NUMBER: builtins.int
    VIRTUALIZATION_TYPE_FIELD_NUMBER: builtins.int
    VOLUMES_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    agent_version: builtins.str
    ami_id: builtins.str
    architecture: builtins.str
    auto_scaling_type: builtins.str
    availability_zone: builtins.str
    @property
    def block_device_mappings(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___InstanceBlockDeviceMapping]: ...
    ebs_optimized: builtins.bool
    @property
    def elastic_ips(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    hostname: builtins.str
    install_updates_on_boot: builtins.bool
    instance_type: builtins.str
    @property
    def layer_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    os: builtins.str
    root_device_type: builtins.str
    ssh_key_name: builtins.str
    stack_id: builtins.str
    subnet_id: builtins.str
    tenancy: builtins.str
    @property
    def time_based_auto_scaling(self) -> global___InstanceTimeBasedAutoScaling: ...
    virtualization_type: builtins.str
    @property
    def volumes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        agent_version: builtins.str = ...,
        ami_id: builtins.str = ...,
        architecture: builtins.str = ...,
        auto_scaling_type: builtins.str = ...,
        availability_zone: builtins.str = ...,
        block_device_mappings: collections.abc.Iterable[global___InstanceBlockDeviceMapping] | None = ...,
        ebs_optimized: builtins.bool = ...,
        elastic_ips: collections.abc.Iterable[builtins.str] | None = ...,
        hostname: builtins.str = ...,
        install_updates_on_boot: builtins.bool = ...,
        instance_type: builtins.str = ...,
        layer_ids: collections.abc.Iterable[builtins.str] | None = ...,
        os: builtins.str = ...,
        root_device_type: builtins.str = ...,
        ssh_key_name: builtins.str = ...,
        stack_id: builtins.str = ...,
        subnet_id: builtins.str = ...,
        tenancy: builtins.str = ...,
        time_based_auto_scaling: global___InstanceTimeBasedAutoScaling | None = ...,
        virtualization_type: builtins.str = ...,
        volumes: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "time_based_auto_scaling", b"time_based_auto_scaling"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["agent_version", b"agent_version", "ami_id", b"ami_id", "architecture", b"architecture", "auto_scaling_type", b"auto_scaling_type", "availability_zone", b"availability_zone", "block_device_mappings", b"block_device_mappings", "ebs_optimized", b"ebs_optimized", "elastic_ips", b"elastic_ips", "hostname", b"hostname", "install_updates_on_boot", b"install_updates_on_boot", "instance_type", b"instance_type", "layer_ids", b"layer_ids", "os", b"os", "resource_info", b"resource_info", "root_device_type", b"root_device_type", "ssh_key_name", b"ssh_key_name", "stack_id", b"stack_id", "subnet_id", b"subnet_id", "tenancy", b"tenancy", "time_based_auto_scaling", b"time_based_auto_scaling", "virtualization_type", b"virtualization_type", "volumes", b"volumes"]) -> None: ...

global___Instance = Instance

@typing_extensions.final
class LayerRecipes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CONFIGURE_FIELD_NUMBER: builtins.int
    DEPLOY_FIELD_NUMBER: builtins.int
    SETUP_FIELD_NUMBER: builtins.int
    SHUTDOWN_FIELD_NUMBER: builtins.int
    UNDEPLOY_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def configure(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def deploy(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def setup(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def shutdown(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def undeploy(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        configure: collections.abc.Iterable[builtins.str] | None = ...,
        deploy: collections.abc.Iterable[builtins.str] | None = ...,
        setup: collections.abc.Iterable[builtins.str] | None = ...,
        shutdown: collections.abc.Iterable[builtins.str] | None = ...,
        undeploy: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["configure", b"configure", "deploy", b"deploy", "resource_info", b"resource_info", "setup", b"setup", "shutdown", b"shutdown", "undeploy", b"undeploy"]) -> None: ...

global___LayerRecipes = LayerRecipes

@typing_extensions.final
class LayerShutdownEventConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DELAY_UNTIL_ELB_CONNECTIONS_DRAINED_FIELD_NUMBER: builtins.int
    EXECUTION_TIMEOUT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    delay_until_elb_connections_drained: builtins.bool
    execution_timeout: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        delay_until_elb_connections_drained: builtins.bool = ...,
        execution_timeout: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["delay_until_elb_connections_drained", b"delay_until_elb_connections_drained", "execution_timeout", b"execution_timeout", "resource_info", b"resource_info"]) -> None: ...

global___LayerShutdownEventConfiguration = LayerShutdownEventConfiguration

@typing_extensions.final
class LayerLifecycleEventConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    SHUTDOWN_EVENT_CONFIGURATION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def shutdown_event_configuration(self) -> global___LayerShutdownEventConfiguration: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        shutdown_event_configuration: global___LayerShutdownEventConfiguration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "shutdown_event_configuration", b"shutdown_event_configuration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "shutdown_event_configuration", b"shutdown_event_configuration"]) -> None: ...

global___LayerLifecycleEventConfiguration = LayerLifecycleEventConfiguration

@typing_extensions.final
class LayerAutoScalingThresholds(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CPU_THRESHOLD_FIELD_NUMBER: builtins.int
    IGNORE_METRICS_TIME_FIELD_NUMBER: builtins.int
    INSTANCE_COUNT_FIELD_NUMBER: builtins.int
    LOAD_THRESHOLD_FIELD_NUMBER: builtins.int
    MEMORY_THRESHOLD_FIELD_NUMBER: builtins.int
    THRESHOLDS_WAIT_TIME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    cpu_threshold: builtins.float
    ignore_metrics_time: builtins.int
    instance_count: builtins.int
    load_threshold: builtins.float
    memory_threshold: builtins.float
    thresholds_wait_time: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        cpu_threshold: builtins.float = ...,
        ignore_metrics_time: builtins.int = ...,
        instance_count: builtins.int = ...,
        load_threshold: builtins.float = ...,
        memory_threshold: builtins.float = ...,
        thresholds_wait_time: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cpu_threshold", b"cpu_threshold", "ignore_metrics_time", b"ignore_metrics_time", "instance_count", b"instance_count", "load_threshold", b"load_threshold", "memory_threshold", b"memory_threshold", "resource_info", b"resource_info", "thresholds_wait_time", b"thresholds_wait_time"]) -> None: ...

global___LayerAutoScalingThresholds = LayerAutoScalingThresholds

@typing_extensions.final
class LayerLoadBasedAutoScaling(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DOWN_SCALING_FIELD_NUMBER: builtins.int
    ENABLE_FIELD_NUMBER: builtins.int
    UP_SCALING_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def down_scaling(self) -> global___LayerAutoScalingThresholds: ...
    enable: builtins.bool
    @property
    def up_scaling(self) -> global___LayerAutoScalingThresholds: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        down_scaling: global___LayerAutoScalingThresholds | None = ...,
        enable: builtins.bool = ...,
        up_scaling: global___LayerAutoScalingThresholds | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["down_scaling", b"down_scaling", "resource_info", b"resource_info", "up_scaling", b"up_scaling"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["down_scaling", b"down_scaling", "enable", b"enable", "resource_info", b"resource_info", "up_scaling", b"up_scaling"]) -> None: ...

global___LayerLoadBasedAutoScaling = LayerLoadBasedAutoScaling

@typing_extensions.final
class LayerVolumeConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ENCRYPTED_FIELD_NUMBER: builtins.int
    IOPS_FIELD_NUMBER: builtins.int
    MOUNT_POINT_FIELD_NUMBER: builtins.int
    NUMBER_OF_DISKS_FIELD_NUMBER: builtins.int
    RAID_LEVEL_FIELD_NUMBER: builtins.int
    SIZE_FIELD_NUMBER: builtins.int
    VOLUME_TYPE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    encrypted: builtins.bool
    iops: builtins.int
    mount_point: builtins.str
    number_of_disks: builtins.int
    raid_level: builtins.int
    size: builtins.int
    volume_type: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        encrypted: builtins.bool = ...,
        iops: builtins.int = ...,
        mount_point: builtins.str = ...,
        number_of_disks: builtins.int = ...,
        raid_level: builtins.int = ...,
        size: builtins.int = ...,
        volume_type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["encrypted", b"encrypted", "iops", b"iops", "mount_point", b"mount_point", "number_of_disks", b"number_of_disks", "raid_level", b"raid_level", "resource_info", b"resource_info", "size", b"size", "volume_type", b"volume_type"]) -> None: ...

global___LayerVolumeConfiguration = LayerVolumeConfiguration

@typing_extensions.final
class Layer(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class AttributesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class CustomJsonEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ATTRIBUTES_FIELD_NUMBER: builtins.int
    AUTO_ASSIGN_ELASTIC_IPS_FIELD_NUMBER: builtins.int
    AUTO_ASSIGN_PUBLIC_IPS_FIELD_NUMBER: builtins.int
    CUSTOM_INSTANCE_PROFILE_ARN_FIELD_NUMBER: builtins.int
    CUSTOM_JSON_FIELD_NUMBER: builtins.int
    CUSTOM_RECIPES_FIELD_NUMBER: builtins.int
    CUSTOM_SECURITY_GROUP_IDS_FIELD_NUMBER: builtins.int
    ENABLE_AUTO_HEALING_FIELD_NUMBER: builtins.int
    INSTALL_UPDATES_ON_BOOT_FIELD_NUMBER: builtins.int
    LIFECYCLE_EVENT_CONFIGURATION_FIELD_NUMBER: builtins.int
    LOAD_BASED_AUTO_SCALING_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PACKAGES_FIELD_NUMBER: builtins.int
    SHORTNAME_FIELD_NUMBER: builtins.int
    STACK_ID_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    USE_EBS_OPTIMIZED_INSTANCES_FIELD_NUMBER: builtins.int
    VOLUME_CONFIGURATIONS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def attributes(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    auto_assign_elastic_ips: builtins.bool
    auto_assign_public_ips: builtins.bool
    custom_instance_profile_arn: builtins.str
    @property
    def custom_json(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def custom_recipes(self) -> global___LayerRecipes: ...
    @property
    def custom_security_group_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    enable_auto_healing: builtins.bool
    install_updates_on_boot: builtins.bool
    @property
    def lifecycle_event_configuration(self) -> global___LayerLifecycleEventConfiguration: ...
    @property
    def load_based_auto_scaling(self) -> global___LayerLoadBasedAutoScaling: ...
    name: builtins.str
    @property
    def packages(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    shortname: builtins.str
    stack_id: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    type: builtins.str
    use_ebs_optimized_instances: builtins.bool
    @property
    def volume_configurations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___LayerVolumeConfiguration]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        attributes: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        auto_assign_elastic_ips: builtins.bool = ...,
        auto_assign_public_ips: builtins.bool = ...,
        custom_instance_profile_arn: builtins.str = ...,
        custom_json: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        custom_recipes: global___LayerRecipes | None = ...,
        custom_security_group_ids: collections.abc.Iterable[builtins.str] | None = ...,
        enable_auto_healing: builtins.bool = ...,
        install_updates_on_boot: builtins.bool = ...,
        lifecycle_event_configuration: global___LayerLifecycleEventConfiguration | None = ...,
        load_based_auto_scaling: global___LayerLoadBasedAutoScaling | None = ...,
        name: builtins.str = ...,
        packages: collections.abc.Iterable[builtins.str] | None = ...,
        shortname: builtins.str = ...,
        stack_id: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        type: builtins.str = ...,
        use_ebs_optimized_instances: builtins.bool = ...,
        volume_configurations: collections.abc.Iterable[global___LayerVolumeConfiguration] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["custom_recipes", b"custom_recipes", "lifecycle_event_configuration", b"lifecycle_event_configuration", "load_based_auto_scaling", b"load_based_auto_scaling", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["attributes", b"attributes", "auto_assign_elastic_ips", b"auto_assign_elastic_ips", "auto_assign_public_ips", b"auto_assign_public_ips", "custom_instance_profile_arn", b"custom_instance_profile_arn", "custom_json", b"custom_json", "custom_recipes", b"custom_recipes", "custom_security_group_ids", b"custom_security_group_ids", "enable_auto_healing", b"enable_auto_healing", "install_updates_on_boot", b"install_updates_on_boot", "lifecycle_event_configuration", b"lifecycle_event_configuration", "load_based_auto_scaling", b"load_based_auto_scaling", "name", b"name", "packages", b"packages", "resource_info", b"resource_info", "shortname", b"shortname", "stack_id", b"stack_id", "tags", b"tags", "type", b"type", "use_ebs_optimized_instances", b"use_ebs_optimized_instances", "volume_configurations", b"volume_configurations"]) -> None: ...

global___Layer = Layer

@typing_extensions.final
class StackChefConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    BERKSHELF_VERSION_FIELD_NUMBER: builtins.int
    MANAGE_BERKSHELF_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    berkshelf_version: builtins.str
    manage_berkshelf: builtins.bool
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        berkshelf_version: builtins.str = ...,
        manage_berkshelf: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["berkshelf_version", b"berkshelf_version", "manage_berkshelf", b"manage_berkshelf", "resource_info", b"resource_info"]) -> None: ...

global___StackChefConfiguration = StackChefConfiguration

@typing_extensions.final
class StackStackConfigurationManager(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    version: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        version: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info", "version", b"version"]) -> None: ...

global___StackStackConfigurationManager = StackStackConfigurationManager

@typing_extensions.final
class StackSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    PASSWORD_FIELD_NUMBER: builtins.int
    REVISION_FIELD_NUMBER: builtins.int
    SSH_KEY_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    USERNAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    password: builtins.str
    revision: builtins.str
    ssh_key: builtins.str
    url: builtins.str
    username: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        password: builtins.str = ...,
        revision: builtins.str = ...,
        ssh_key: builtins.str = ...,
        url: builtins.str = ...,
        username: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["password", b"password", "resource_info", b"resource_info", "revision", b"revision", "ssh_key", b"ssh_key", "url", b"url", "username", b"username"]) -> None: ...

global___StackSource = StackSource

@typing_extensions.final
class StackElasticIp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    IP_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    ip: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        ip: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ip", b"ip", "name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___StackElasticIp = StackElasticIp

@typing_extensions.final
class StackRdsDbInstance(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DB_PASSWORD_FIELD_NUMBER: builtins.int
    DB_USER_FIELD_NUMBER: builtins.int
    RDS_DB_INSTANCE_ARN_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    db_password: builtins.str
    db_user: builtins.str
    rds_db_instance_arn: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        db_password: builtins.str = ...,
        db_user: builtins.str = ...,
        rds_db_instance_arn: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["db_password", b"db_password", "db_user", b"db_user", "rds_db_instance_arn", b"rds_db_instance_arn", "resource_info", b"resource_info"]) -> None: ...

global___StackRdsDbInstance = StackRdsDbInstance

@typing_extensions.final
class Stack(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class AttributesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class CustomJsonEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    AGENT_VERSION_FIELD_NUMBER: builtins.int
    ATTRIBUTES_FIELD_NUMBER: builtins.int
    CHEF_CONFIGURATION_FIELD_NUMBER: builtins.int
    CLONE_APP_IDS_FIELD_NUMBER: builtins.int
    CLONE_PERMISSIONS_FIELD_NUMBER: builtins.int
    CONFIGURATION_MANAGER_FIELD_NUMBER: builtins.int
    CUSTOM_COOKBOOKS_SOURCE_FIELD_NUMBER: builtins.int
    CUSTOM_JSON_FIELD_NUMBER: builtins.int
    DEFAULT_AVAILABILITY_ZONE_FIELD_NUMBER: builtins.int
    DEFAULT_INSTANCE_PROFILE_ARN_FIELD_NUMBER: builtins.int
    DEFAULT_OS_FIELD_NUMBER: builtins.int
    DEFAULT_ROOT_DEVICE_TYPE_FIELD_NUMBER: builtins.int
    DEFAULT_SSH_KEY_NAME_FIELD_NUMBER: builtins.int
    DEFAULT_SUBNET_ID_FIELD_NUMBER: builtins.int
    ECS_CLUSTER_ARN_FIELD_NUMBER: builtins.int
    ELASTIC_IPS_FIELD_NUMBER: builtins.int
    HOSTNAME_THEME_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    RDS_DB_INSTANCES_FIELD_NUMBER: builtins.int
    SERVICE_ROLE_ARN_FIELD_NUMBER: builtins.int
    SOURCE_STACK_ID_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    USE_CUSTOM_COOKBOOKS_FIELD_NUMBER: builtins.int
    USE_OPSWORKS_SECURITY_GROUPS_FIELD_NUMBER: builtins.int
    VPC_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    agent_version: builtins.str
    @property
    def attributes(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def chef_configuration(self) -> global___StackChefConfiguration: ...
    @property
    def clone_app_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    clone_permissions: builtins.bool
    @property
    def configuration_manager(self) -> global___StackStackConfigurationManager: ...
    @property
    def custom_cookbooks_source(self) -> global___StackSource: ...
    @property
    def custom_json(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    default_availability_zone: builtins.str
    default_instance_profile_arn: builtins.str
    default_os: builtins.str
    default_root_device_type: builtins.str
    default_ssh_key_name: builtins.str
    default_subnet_id: builtins.str
    ecs_cluster_arn: builtins.str
    @property
    def elastic_ips(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___StackElasticIp]: ...
    hostname_theme: builtins.str
    name: builtins.str
    @property
    def rds_db_instances(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___StackRdsDbInstance]: ...
    service_role_arn: builtins.str
    source_stack_id: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    use_custom_cookbooks: builtins.bool
    use_opsworks_security_groups: builtins.bool
    vpc_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        agent_version: builtins.str = ...,
        attributes: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        chef_configuration: global___StackChefConfiguration | None = ...,
        clone_app_ids: collections.abc.Iterable[builtins.str] | None = ...,
        clone_permissions: builtins.bool = ...,
        configuration_manager: global___StackStackConfigurationManager | None = ...,
        custom_cookbooks_source: global___StackSource | None = ...,
        custom_json: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        default_availability_zone: builtins.str = ...,
        default_instance_profile_arn: builtins.str = ...,
        default_os: builtins.str = ...,
        default_root_device_type: builtins.str = ...,
        default_ssh_key_name: builtins.str = ...,
        default_subnet_id: builtins.str = ...,
        ecs_cluster_arn: builtins.str = ...,
        elastic_ips: collections.abc.Iterable[global___StackElasticIp] | None = ...,
        hostname_theme: builtins.str = ...,
        name: builtins.str = ...,
        rds_db_instances: collections.abc.Iterable[global___StackRdsDbInstance] | None = ...,
        service_role_arn: builtins.str = ...,
        source_stack_id: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        use_custom_cookbooks: builtins.bool = ...,
        use_opsworks_security_groups: builtins.bool = ...,
        vpc_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["chef_configuration", b"chef_configuration", "configuration_manager", b"configuration_manager", "custom_cookbooks_source", b"custom_cookbooks_source", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["agent_version", b"agent_version", "attributes", b"attributes", "chef_configuration", b"chef_configuration", "clone_app_ids", b"clone_app_ids", "clone_permissions", b"clone_permissions", "configuration_manager", b"configuration_manager", "custom_cookbooks_source", b"custom_cookbooks_source", "custom_json", b"custom_json", "default_availability_zone", b"default_availability_zone", "default_instance_profile_arn", b"default_instance_profile_arn", "default_os", b"default_os", "default_root_device_type", b"default_root_device_type", "default_ssh_key_name", b"default_ssh_key_name", "default_subnet_id", b"default_subnet_id", "ecs_cluster_arn", b"ecs_cluster_arn", "elastic_ips", b"elastic_ips", "hostname_theme", b"hostname_theme", "name", b"name", "rds_db_instances", b"rds_db_instances", "resource_info", b"resource_info", "service_role_arn", b"service_role_arn", "source_stack_id", b"source_stack_id", "tags", b"tags", "use_custom_cookbooks", b"use_custom_cookbooks", "use_opsworks_security_groups", b"use_opsworks_security_groups", "vpc_id", b"vpc_id"]) -> None: ...

global___Stack = Stack

@typing_extensions.final
class UserProfile(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ALLOW_SELF_MANAGEMENT_FIELD_NUMBER: builtins.int
    IAM_USER_ARN_FIELD_NUMBER: builtins.int
    SSH_PUBLIC_KEY_FIELD_NUMBER: builtins.int
    SSH_USERNAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    allow_self_management: builtins.bool
    iam_user_arn: builtins.str
    ssh_public_key: builtins.str
    ssh_username: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        allow_self_management: builtins.bool = ...,
        iam_user_arn: builtins.str = ...,
        ssh_public_key: builtins.str = ...,
        ssh_username: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["allow_self_management", b"allow_self_management", "iam_user_arn", b"iam_user_arn", "resource_info", b"resource_info", "ssh_public_key", b"ssh_public_key", "ssh_username", b"ssh_username"]) -> None: ...

global___UserProfile = UserProfile

@typing_extensions.final
class Volume(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    EC2_VOLUME_ID_FIELD_NUMBER: builtins.int
    MOUNT_POINT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    STACK_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    ec2_volume_id: builtins.str
    mount_point: builtins.str
    name: builtins.str
    stack_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        ec2_volume_id: builtins.str = ...,
        mount_point: builtins.str = ...,
        name: builtins.str = ...,
        stack_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ec2_volume_id", b"ec2_volume_id", "mount_point", b"mount_point", "name", b"name", "resource_info", b"resource_info", "stack_id", b"stack_id"]) -> None: ...

global___Volume = Volume
