# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_guardduty.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17\x61ws/aws_guardduty.proto\x12\x19oak9.tython.aws.guardduty\x1a\x13shared/shared.proto\"i\n\x1e\x44\x65tectorCFNS3LogsConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06\x65nable\x18\x02 \x01(\x08\"\xaa\x01\n#DetectorCFNDataSourceConfigurations\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12J\n\x07s3_logs\x18\x02 \x01(\x0b\x32\x39.oak9.tython.aws.guardduty.DetectorCFNS3LogsConfiguration\"\xcf\x01\n\x08\x44\x65tector\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12$\n\x1c\x66inding_publishing_frequency\x18\x02 \x01(\t\x12T\n\x0c\x64\x61ta_sources\x18\x03 \x01(\x0b\x32>.oak9.tython.aws.guardduty.DetectorCFNDataSourceConfigurations\x12\x0e\n\x06\x65nable\x18\x04 \x01(\x08\"\xd2\x02\n\tGuardDuty\x12\x35\n\x08\x64\x65tector\x18\x01 \x03(\x0b\x32#.oak9.tython.aws.guardduty.Detector\x12\x31\n\x06\x66ilter\x18\x02 \x03(\x0b\x32!.oak9.tython.aws.guardduty.Filter\x12\x30\n\x06ip_set\x18\x03 \x03(\x0b\x32 .oak9.tython.aws.guardduty.IPSet\x12\x31\n\x06master\x18\x04 \x03(\x0b\x32!.oak9.tython.aws.guardduty.Master\x12\x31\n\x06member\x18\x05 \x03(\x0b\x32!.oak9.tython.aws.guardduty.Member\x12\x43\n\x10threat_intel_set\x18\x06 \x03(\x0b\x32).oak9.tython.aws.guardduty.ThreatIntelSet\"\x89\x01\n\x0f\x46ilterCondition\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\n\n\x02lt\x18\x02 \x01(\x05\x12\x0b\n\x03gte\x18\x03 \x01(\x05\x12\x0b\n\x03neq\x18\x04 \x03(\t\x12\n\n\x02\x65q\x18\x05 \x03(\t\x12\x0b\n\x03lte\x18\x06 \x01(\x05\"\x95\x02\n\x15\x46ilterFindingCriteria\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12R\n\tcriterion\x18\x02 \x03(\x0b\x32?.oak9.tython.aws.guardduty.FilterFindingCriteria.CriterionEntry\x12=\n\titem_type\x18\x03 \x01(\x0b\x32*.oak9.tython.aws.guardduty.FilterCondition\x1a\x30\n\x0e\x43riterionEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xe3\x01\n\x06\x46ilter\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06\x61\x63tion\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65tector_id\x18\x04 \x01(\t\x12J\n\x10\x66inding_criteria\x18\x05 \x01(\x0b\x32\x30.oak9.tython.aws.guardduty.FilterFindingCriteria\x12\x0c\n\x04rank\x18\x06 \x01(\x05\x12\x0c\n\x04name\x18\x07 \x01(\t\"\x97\x01\n\x05IPSet\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06\x66ormat\x18\x02 \x01(\t\x12\x10\n\x08\x61\x63tivate\x18\x03 \x01(\x08\x12\x13\n\x0b\x64\x65tector_id\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x10\n\x08location\x18\x06 \x01(\t\"\x80\x01\n\x06Master\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65tector_id\x18\x02 \x01(\t\x12\x11\n\tmaster_id\x18\x03 \x01(\t\x12\x15\n\rinvitation_id\x18\x04 \x01(\t\"\xbd\x01\n\x06Member\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06status\x18\x02 \x01(\t\x12\x11\n\tmember_id\x18\x03 \x01(\t\x12\r\n\x05\x65mail\x18\x04 \x01(\t\x12\x0f\n\x07message\x18\x05 \x01(\t\x12\"\n\x1a\x64isable_email_notification\x18\x06 \x01(\x08\x12\x13\n\x0b\x64\x65tector_id\x18\x07 \x01(\t\"\xa0\x01\n\x0eThreatIntelSet\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06\x66ormat\x18\x02 \x01(\t\x12\x10\n\x08\x61\x63tivate\x18\x03 \x01(\x08\x12\x13\n\x0b\x64\x65tector_id\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x10\n\x08location\x18\x06 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_guardduty_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _FILTERFINDINGCRITERIA_CRITERIONENTRY._options = None
  _FILTERFINDINGCRITERIA_CRITERIONENTRY._serialized_options = b'8\001'
  _DETECTORCFNS3LOGSCONFIGURATION._serialized_start=75
  _DETECTORCFNS3LOGSCONFIGURATION._serialized_end=180
  _DETECTORCFNDATASOURCECONFIGURATIONS._serialized_start=183
  _DETECTORCFNDATASOURCECONFIGURATIONS._serialized_end=353
  _DETECTOR._serialized_start=356
  _DETECTOR._serialized_end=563
  _GUARDDUTY._serialized_start=566
  _GUARDDUTY._serialized_end=904
  _FILTERCONDITION._serialized_start=907
  _FILTERCONDITION._serialized_end=1044
  _FILTERFINDINGCRITERIA._serialized_start=1047
  _FILTERFINDINGCRITERIA._serialized_end=1324
  _FILTERFINDINGCRITERIA_CRITERIONENTRY._serialized_start=1276
  _FILTERFINDINGCRITERIA_CRITERIONENTRY._serialized_end=1324
  _FILTER._serialized_start=1327
  _FILTER._serialized_end=1554
  _IPSET._serialized_start=1557
  _IPSET._serialized_end=1708
  _MASTER._serialized_start=1711
  _MASTER._serialized_end=1839
  _MEMBER._serialized_start=1842
  _MEMBER._serialized_end=2031
  _THREATINTELSET._serialized_start=2034
  _THREATINTELSET._serialized_end=2194
# @@protoc_insertion_point(module_scope)
