# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: azure/azure_microsoft_app.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x61zure/azure_microsoft_app.proto\x12\x1foak9.tython.azure.microsoft_app\x1a\x13shared/shared.proto\"\xbb\x01\n\rMicrosoft_App\x12V\n\x16\x63onnected_environments\x18\x01 \x03(\x0b\x32\x36.oak9.tython.azure.microsoft_app.ConnectedEnvironments\x12R\n\x14managed_environments\x18\x02 \x03(\x0b\x32\x34.oak9.tython.azure.microsoft_app.ManagedEnvironments\"\xae\x01\n\x1bManagedEnvironmentsStorages\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12H\n\nazure_file\x18\x03 \x01(\x0b\x32\x34.oak9.tython.azure.microsoft_app.AzureFileProperties\"\xeb\x02\n!ManagedEnvironmentsDaprComponents\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x16\n\x0e\x63omponent_type\x18\x03 \x01(\t\x12\x15\n\rignore_errors\x18\x04 \x01(\x08\x12\x14\n\x0cinit_timeout\x18\x05 \x01(\t\x12?\n\x08metadata\x18\x06 \x03(\x0b\x32-.oak9.tython.azure.microsoft_app.DaprMetadata\x12\x0e\n\x06scopes\x18\x07 \x03(\t\x12\x38\n\x07secrets\x18\x08 \x03(\x0b\x32\'.oak9.tython.azure.microsoft_app.Secret\x12\x1e\n\x16secret_store_component\x18\t \x01(\t\x12\x0f\n\x07version\x18\n \x01(\t\"\xa2\x02\n\x1fManagedEnvironmentsCertificates\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08location\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x10\n\x08password\x18\x04 \x01(\t\x12\r\n\x05value\x18\x05 \x01(\t\x12X\n\x04tags\x18\x06 \x03(\x0b\x32J.oak9.tython.azure.microsoft_app.ManagedEnvironmentsCertificates.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xac\x08\n\x13ManagedEnvironments\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08location\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12U\n\x16\x61pp_logs_configuration\x18\x04 \x01(\x0b\x32\x35.oak9.tython.azure.microsoft_app.AppLogsConfiguration\x12_\n\x1b\x63ustom_domain_configuration\x18\x05 \x01(\x0b\x32:.oak9.tython.azure.microsoft_app.CustomDomainConfiguration\x12\"\n\x1a\x64\x61pr_a_i_connection_string\x18\x06 \x01(\t\x12$\n\x1c\x64\x61pr_a_i_instrumentation_key\x18\x07 \x01(\t\x12N\n\x12vnet_configuration\x18\x08 \x01(\x0b\x32\x32.oak9.tython.azure.microsoft_app.VnetConfiguration\x12K\n\x11workload_profiles\x18\t \x03(\x0b\x32\x30.oak9.tython.azure.microsoft_app.WorkloadProfile\x12\x16\n\x0ezone_redundant\x18\n \x01(\x08\x12\x46\n\x03sku\x18\x0b \x01(\x0b\x32\x39.oak9.tython.azure.microsoft_app.EnvironmentSkuProperties\x12L\n\x04tags\x18\x0c \x03(\x0b\x32>.oak9.tython.azure.microsoft_app.ManagedEnvironments.TagsEntry\x12p\n$managed_environments_dapr_components\x18\r \x03(\x0b\x32\x42.oak9.tython.azure.microsoft_app.ManagedEnvironmentsDaprComponents\x12k\n!managed_environments_certificates\x18\x0e \x03(\x0b\x32@.oak9.tython.azure.microsoft_app.ManagedEnvironmentsCertificates\x12\x63\n\x1dmanaged_environments_storages\x18\x0f \x03(\x0b\x32<.oak9.tython.azure.microsoft_app.ManagedEnvironmentsStorages\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"(\n\x18\x45nvironmentSkuProperties\x12\x0c\n\x04name\x18\x01 \x01(\t\"^\n\x0fWorkloadProfile\x12\x15\n\rmaximum_count\x18\x01 \x01(\x05\x12\x15\n\rminimum_count\x18\x02 \x01(\x05\x12\x1d\n\x15workload_profile_type\x18\x03 \x01(\t\"\xa0\x02\n\x11VnetConfiguration\x12\x1a\n\x12\x64ocker_bridge_cidr\x18\x01 \x01(\t\x12 \n\x18infrastructure_subnet_id\x18\x02 \x01(\t\x12\x10\n\x08internal\x18\x03 \x01(\x08\x12^\n\x11outbound_settings\x18\x04 \x01(\x0b\x32\x43.oak9.tython.azure.microsoft_app.ManagedEnvironmentOutboundSettings\x12\x1e\n\x16platform_reserved_cidr\x18\x05 \x01(\t\x12 \n\x18platform_reserved_dns_ip\x18\x06 \x01(\t\x12\x19\n\x11runtime_subnet_id\x18\x07 \x01(\t\"b\n\"ManagedEnvironmentOutboundSettings\x12\x16\n\x0eout_bound_type\x18\x01 \x01(\t\x12$\n\x1cvirtual_network_appliance_ip\x18\x02 \x01(\t\"\x8c\x01\n\x14\x41ppLogsConfiguration\x12\x13\n\x0b\x64\x65stination\x18\x01 \x01(\t\x12_\n\x1blog_analytics_configuration\x18\x02 \x01(\x0b\x32:.oak9.tython.azure.microsoft_app.LogAnalyticsConfiguration\"D\n\x19LogAnalyticsConfiguration\x12\x13\n\x0b\x63ustomer_id\x18\x01 \x01(\t\x12\x12\n\nshared_key\x18\x02 \x01(\t\"\xb0\x01\n\x1d\x43onnectedEnvironmentsStorages\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12H\n\nazure_file\x18\x03 \x01(\x0b\x32\x34.oak9.tython.azure.microsoft_app.AzureFileProperties\"i\n\x13\x41zureFileProperties\x12\x13\n\x0b\x61\x63\x63\x65ss_mode\x18\x01 \x01(\t\x12\x13\n\x0b\x61\x63\x63ount_key\x18\x02 \x01(\t\x12\x14\n\x0c\x61\x63\x63ount_name\x18\x03 \x01(\t\x12\x12\n\nshare_name\x18\x04 \x01(\t\"\xed\x02\n#ConnectedEnvironmentsDaprComponents\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x16\n\x0e\x63omponent_type\x18\x03 \x01(\t\x12\x15\n\rignore_errors\x18\x04 \x01(\x08\x12\x14\n\x0cinit_timeout\x18\x05 \x01(\t\x12?\n\x08metadata\x18\x06 \x03(\x0b\x32-.oak9.tython.azure.microsoft_app.DaprMetadata\x12\x0e\n\x06scopes\x18\x07 \x03(\t\x12\x38\n\x07secrets\x18\x08 \x03(\x0b\x32\'.oak9.tython.azure.microsoft_app.Secret\x12\x1e\n\x16secret_store_component\x18\t \x01(\t\x12\x0f\n\x07version\x18\n \x01(\t\"%\n\x06Secret\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"?\n\x0c\x44\x61prMetadata\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\nsecret_ref\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\"\xa6\x02\n!ConnectedEnvironmentsCertificates\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08location\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x10\n\x08password\x18\x04 \x01(\t\x12\r\n\x05value\x18\x05 \x01(\t\x12Z\n\x04tags\x18\x06 \x03(\x0b\x32L.oak9.tython.azure.microsoft_app.ConnectedEnvironmentsCertificates.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa3\x06\n\x15\x43onnectedEnvironments\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12L\n\x11\x65xtended_location\x18\x02 \x01(\x0b\x32\x31.oak9.tython.azure.microsoft_app.ExtendedLocation\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12_\n\x1b\x63ustom_domain_configuration\x18\x05 \x01(\x0b\x32:.oak9.tython.azure.microsoft_app.CustomDomainConfiguration\x12\"\n\x1a\x64\x61pr_a_i_connection_string\x18\x06 \x01(\t\x12\x11\n\tstatic_ip\x18\x07 \x01(\t\x12N\n\x04tags\x18\x08 \x03(\x0b\x32@.oak9.tython.azure.microsoft_app.ConnectedEnvironments.TagsEntry\x12o\n#connected_environments_certificates\x18\t \x03(\x0b\x32\x42.oak9.tython.azure.microsoft_app.ConnectedEnvironmentsCertificates\x12t\n&connected_environments_dapr_components\x18\n \x03(\x0b\x32\x44.oak9.tython.azure.microsoft_app.ConnectedEnvironmentsDaprComponents\x12g\n\x1f\x63onnected_environments_storages\x18\x0b \x03(\x0b\x32>.oak9.tython.azure.microsoft_app.ConnectedEnvironmentsStorages\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"h\n\x19\x43ustomDomainConfiguration\x12\x1c\n\x14\x63\x65rtificate_password\x18\x01 \x01(\t\x12\x19\n\x11\x63\x65rtificate_value\x18\x02 \x01(\t\x12\x12\n\ndns_suffix\x18\x03 \x01(\t\".\n\x10\x45xtendedLocation\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'azure.azure_microsoft_app_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _MANAGEDENVIRONMENTSCERTIFICATES_TAGSENTRY._options = None
  _MANAGEDENVIRONMENTSCERTIFICATES_TAGSENTRY._serialized_options = b'8\001'
  _MANAGEDENVIRONMENTS_TAGSENTRY._options = None
  _MANAGEDENVIRONMENTS_TAGSENTRY._serialized_options = b'8\001'
  _CONNECTEDENVIRONMENTSCERTIFICATES_TAGSENTRY._options = None
  _CONNECTEDENVIRONMENTSCERTIFICATES_TAGSENTRY._serialized_options = b'8\001'
  _CONNECTEDENVIRONMENTS_TAGSENTRY._options = None
  _CONNECTEDENVIRONMENTS_TAGSENTRY._serialized_options = b'8\001'
  _MICROSOFT_APP._serialized_start=90
  _MICROSOFT_APP._serialized_end=277
  _MANAGEDENVIRONMENTSSTORAGES._serialized_start=280
  _MANAGEDENVIRONMENTSSTORAGES._serialized_end=454
  _MANAGEDENVIRONMENTSDAPRCOMPONENTS._serialized_start=457
  _MANAGEDENVIRONMENTSDAPRCOMPONENTS._serialized_end=820
  _MANAGEDENVIRONMENTSCERTIFICATES._serialized_start=823
  _MANAGEDENVIRONMENTSCERTIFICATES._serialized_end=1113
  _MANAGEDENVIRONMENTSCERTIFICATES_TAGSENTRY._serialized_start=1070
  _MANAGEDENVIRONMENTSCERTIFICATES_TAGSENTRY._serialized_end=1113
  _MANAGEDENVIRONMENTS._serialized_start=1116
  _MANAGEDENVIRONMENTS._serialized_end=2184
  _MANAGEDENVIRONMENTS_TAGSENTRY._serialized_start=1070
  _MANAGEDENVIRONMENTS_TAGSENTRY._serialized_end=1113
  _ENVIRONMENTSKUPROPERTIES._serialized_start=2186
  _ENVIRONMENTSKUPROPERTIES._serialized_end=2226
  _WORKLOADPROFILE._serialized_start=2228
  _WORKLOADPROFILE._serialized_end=2322
  _VNETCONFIGURATION._serialized_start=2325
  _VNETCONFIGURATION._serialized_end=2613
  _MANAGEDENVIRONMENTOUTBOUNDSETTINGS._serialized_start=2615
  _MANAGEDENVIRONMENTOUTBOUNDSETTINGS._serialized_end=2713
  _APPLOGSCONFIGURATION._serialized_start=2716
  _APPLOGSCONFIGURATION._serialized_end=2856
  _LOGANALYTICSCONFIGURATION._serialized_start=2858
  _LOGANALYTICSCONFIGURATION._serialized_end=2926
  _CONNECTEDENVIRONMENTSSTORAGES._serialized_start=2929
  _CONNECTEDENVIRONMENTSSTORAGES._serialized_end=3105
  _AZUREFILEPROPERTIES._serialized_start=3107
  _AZUREFILEPROPERTIES._serialized_end=3212
  _CONNECTEDENVIRONMENTSDAPRCOMPONENTS._serialized_start=3215
  _CONNECTEDENVIRONMENTSDAPRCOMPONENTS._serialized_end=3580
  _SECRET._serialized_start=3582
  _SECRET._serialized_end=3619
  _DAPRMETADATA._serialized_start=3621
  _DAPRMETADATA._serialized_end=3684
  _CONNECTEDENVIRONMENTSCERTIFICATES._serialized_start=3687
  _CONNECTEDENVIRONMENTSCERTIFICATES._serialized_end=3981
  _CONNECTEDENVIRONMENTSCERTIFICATES_TAGSENTRY._serialized_start=1070
  _CONNECTEDENVIRONMENTSCERTIFICATES_TAGSENTRY._serialized_end=1113
  _CONNECTEDENVIRONMENTS._serialized_start=3984
  _CONNECTEDENVIRONMENTS._serialized_end=4787
  _CONNECTEDENVIRONMENTS_TAGSENTRY._serialized_start=1070
  _CONNECTEDENVIRONMENTS_TAGSENTRY._serialized_end=1113
  _CUSTOMDOMAINCONFIGURATION._serialized_start=4789
  _CUSTOMDOMAINCONFIGURATION._serialized_end=4893
  _EXTENDEDLOCATION._serialized_start=4895
  _EXTENDEDLOCATION._serialized_end=4941
# @@protoc_insertion_point(module_scope)
