# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_chatbot.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15\x61ws/aws_chatbot.proto\x12\x17oak9.tython.aws.chatbot\x1a\x13shared/shared.proto\"\xeb\x01\n\x19SlackChannelConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1a\n\x12slack_workspace_id\x18\x02 \x01(\t\x12\x18\n\x10slack_channel_id\x18\x03 \x01(\t\x12\x1a\n\x12\x63onfiguration_name\x18\x04 \x01(\t\x12\x14\n\x0ciam_role_arn\x18\x05 \x01(\t\x12\x16\n\x0esns_topic_arns\x18\x06 \x03(\t\x12\x15\n\rlogging_level\x18\x07 \x01(\t\"b\n\x07\x43hatbot\x12W\n\x1bslack_channel_configuration\x18\x01 \x03(\x0b\x32\x32.oak9.tython.aws.chatbot.SlackChannelConfigurationb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_chatbot_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SLACKCHANNELCONFIGURATION._serialized_start=72
  _SLACKCHANNELCONFIGURATION._serialized_end=307
  _CHATBOT._serialized_start=309
  _CHATBOT._serialized_end=407
# @@protoc_insertion_point(module_scope)
