# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_route53.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15\x61ws/aws_route53.proto\x12\x17oak9.tython.aws.route53\x1a\x13shared/shared.proto\"p\n\x19HealthCheckHealthCheckTag\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\"\xa9\x02\n\x0bHealthCheck\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12X\n\x13health_check_config\x18\x02 \x03(\x0b\x32;.oak9.tython.aws.route53.HealthCheck.HealthCheckConfigEntry\x12M\n\x11health_check_tags\x18\x03 \x03(\x0b\x32\x32.oak9.tython.aws.route53.HealthCheckHealthCheckTag\x1a\x38\n\x16HealthCheckConfigEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xfa\x01\n\x07Route53\x12:\n\x0chealth_check\x18\x01 \x03(\x0b\x32$.oak9.tython.aws.route53.HealthCheck\x12\x38\n\x0bhosted_zone\x18\x02 \x01(\x0b\x32#.oak9.tython.aws.route53.HostedZone\x12\x36\n\nrecord_set\x18\x03 \x03(\x0b\x32\".oak9.tython.aws.route53.RecordSet\x12\x41\n\x10record_set_group\x18\x04 \x01(\x0b\x32\'.oak9.tython.aws.route53.RecordSetGroup\"f\n\x1aHostedZoneHostedZoneConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07\x63omment\x18\x02 \x01(\t\"n\n\x17HostedZoneHostedZoneTag\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\"\x7f\n\x1cHostedZoneQueryLoggingConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12&\n\x1e\x63loud_watch_logs_log_group_arn\x18\x02 \x01(\t\"l\n\rHostedZoneVPC\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06vpc_id\x18\x02 \x01(\t\x12\x12\n\nvpc_region\x18\x03 \x01(\t\"\xfb\x02\n\nHostedZone\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12O\n\x12hosted_zone_config\x18\x02 \x01(\x0b\x32\x33.oak9.tython.aws.route53.HostedZoneHostedZoneConfig\x12J\n\x10hosted_zone_tags\x18\x03 \x03(\x0b\x32\x30.oak9.tython.aws.route53.HostedZoneHostedZoneTag\x12\x0c\n\x04name\x18\x04 \x01(\t\x12S\n\x14query_logging_config\x18\x05 \x01(\x0b\x32\x35.oak9.tython.aws.route53.HostedZoneQueryLoggingConfig\x12\x34\n\x04vpcs\x18\x06 \x03(\x0b\x32&.oak9.tython.aws.route53.HostedZoneVPC\"\x99\x01\n\x14RecordSetAliasTarget\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08\x64ns_name\x18\x02 \x01(\t\x12\x1e\n\x16\x65valuate_target_health\x18\x03 \x01(\x08\x12\x16\n\x0ehosted_zone_id\x18\x04 \x01(\t\"\x97\x01\n\x14RecordSetGeoLocation\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0e\x63ontinent_code\x18\x02 \x01(\t\x12\x14\n\x0c\x63ountry_code\x18\x03 \x01(\t\x12\x18\n\x10subdivision_code\x18\x04 \x01(\t\"\xd3\x03\n\tRecordSet\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x43\n\x0c\x61lias_target\x18\x02 \x01(\x0b\x32-.oak9.tython.aws.route53.RecordSetAliasTarget\x12\x0f\n\x07\x63omment\x18\x03 \x01(\t\x12\x10\n\x08\x66\x61ilover\x18\x04 \x01(\t\x12\x43\n\x0cgeo_location\x18\x05 \x01(\x0b\x32-.oak9.tython.aws.route53.RecordSetGeoLocation\x12\x17\n\x0fhealth_check_id\x18\x06 \x01(\t\x12\x16\n\x0ehosted_zone_id\x18\x07 \x01(\t\x12\x18\n\x10hosted_zone_name\x18\x08 \x01(\t\x12\x1a\n\x12multi_value_answer\x18\t \x01(\x08\x12\x0c\n\x04name\x18\n \x01(\t\x12\x0e\n\x06region\x18\x0b \x01(\t\x12\x18\n\x10resource_records\x18\x0c \x03(\t\x12\x16\n\x0eset_identifier\x18\r \x01(\t\x12\x0b\n\x03ttl\x18\x0e \x01(\t\x12\x0c\n\x04type\x18\x0f \x01(\t\x12\x0e\n\x06weight\x18\x10 \x01(\x05\"\x9e\x01\n\x19RecordSetGroupAliasTarget\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08\x64ns_name\x18\x02 \x01(\t\x12\x1e\n\x16\x65valuate_target_health\x18\x03 \x01(\x08\x12\x16\n\x0ehosted_zone_id\x18\x04 \x01(\t\"\x9c\x01\n\x19RecordSetGroupGeoLocation\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0e\x63ontinent_code\x18\x02 \x01(\t\x12\x14\n\x0c\x63ountry_code\x18\x03 \x01(\t\x12\x18\n\x10subdivision_code\x18\x04 \x01(\t\"\xdd\x03\n\x17RecordSetGroupRecordSet\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12H\n\x0c\x61lias_target\x18\x02 \x01(\x0b\x32\x32.oak9.tython.aws.route53.RecordSetGroupAliasTarget\x12\x0f\n\x07\x63omment\x18\x03 \x01(\t\x12\x10\n\x08\x66\x61ilover\x18\x04 \x01(\t\x12H\n\x0cgeo_location\x18\x05 \x01(\x0b\x32\x32.oak9.tython.aws.route53.RecordSetGroupGeoLocation\x12\x17\n\x0fhealth_check_id\x18\x06 \x01(\t\x12\x16\n\x0ehosted_zone_id\x18\x07 \x01(\t\x12\x18\n\x10hosted_zone_name\x18\x08 \x01(\t\x12\x1a\n\x12multi_value_answer\x18\t \x01(\x08\x12\x0c\n\x04name\x18\n \x01(\t\x12\x0e\n\x06region\x18\x0b \x01(\t\x12\x18\n\x10resource_records\x18\x0c \x03(\t\x12\x16\n\x0eset_identifier\x18\r \x01(\t\x12\x0b\n\x03ttl\x18\x0e \x01(\t\x12\x0e\n\x06weight\x18\x0f \x01(\x05\"\xd3\x01\n\x0eRecordSetGroup\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07\x63omment\x18\x02 \x01(\t\x12\x16\n\x0ehosted_zone_id\x18\x03 \x01(\t\x12\x18\n\x10hosted_zone_name\x18\x04 \x01(\t\x12\x45\n\x0brecord_sets\x18\x05 \x03(\x0b\x32\x30.oak9.tython.aws.route53.RecordSetGroupRecordSetb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_route53_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _HEALTHCHECK_HEALTHCHECKCONFIGENTRY._options = None
  _HEALTHCHECK_HEALTHCHECKCONFIGENTRY._serialized_options = b'8\001'
  _HEALTHCHECKHEALTHCHECKTAG._serialized_start=71
  _HEALTHCHECKHEALTHCHECKTAG._serialized_end=183
  _HEALTHCHECK._serialized_start=186
  _HEALTHCHECK._serialized_end=483
  _HEALTHCHECK_HEALTHCHECKCONFIGENTRY._serialized_start=427
  _HEALTHCHECK_HEALTHCHECKCONFIGENTRY._serialized_end=483
  _ROUTE53._serialized_start=486
  _ROUTE53._serialized_end=736
  _HOSTEDZONEHOSTEDZONECONFIG._serialized_start=738
  _HOSTEDZONEHOSTEDZONECONFIG._serialized_end=840
  _HOSTEDZONEHOSTEDZONETAG._serialized_start=842
  _HOSTEDZONEHOSTEDZONETAG._serialized_end=952
  _HOSTEDZONEQUERYLOGGINGCONFIG._serialized_start=954
  _HOSTEDZONEQUERYLOGGINGCONFIG._serialized_end=1081
  _HOSTEDZONEVPC._serialized_start=1083
  _HOSTEDZONEVPC._serialized_end=1191
  _HOSTEDZONE._serialized_start=1194
  _HOSTEDZONE._serialized_end=1573
  _RECORDSETALIASTARGET._serialized_start=1576
  _RECORDSETALIASTARGET._serialized_end=1729
  _RECORDSETGEOLOCATION._serialized_start=1732
  _RECORDSETGEOLOCATION._serialized_end=1883
  _RECORDSET._serialized_start=1886
  _RECORDSET._serialized_end=2353
  _RECORDSETGROUPALIASTARGET._serialized_start=2356
  _RECORDSETGROUPALIASTARGET._serialized_end=2514
  _RECORDSETGROUPGEOLOCATION._serialized_start=2517
  _RECORDSETGROUPGEOLOCATION._serialized_end=2673
  _RECORDSETGROUPRECORDSET._serialized_start=2676
  _RECORDSETGROUPRECORDSET._serialized_end=3153
  _RECORDSETGROUP._serialized_start=3156
  _RECORDSETGROUP._serialized_end=3367
# @@protoc_insertion_point(module_scope)
