"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import gcp.gcp_compute_subnetwork_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class GoogleComputeSubnetwork(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMPUTE_SUBNETWORK_FIELD_NUMBER: builtins.int
    COMPUTE_SUBNETWORK_IAM_BINDING_FIELD_NUMBER: builtins.int
    COMPUTE_SUBNETWORK_IAM_MEMBER_FIELD_NUMBER: builtins.int
    COMPUTE_SUBNETWORK_IAM_POLICY_FIELD_NUMBER: builtins.int
    @property
    def compute_subnetwork(self) -> gcp.gcp_compute_subnetwork_pb2.ComputeSubnetwork: ...
    @property
    def compute_subnetwork_iam_binding(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[gcp.gcp_compute_subnetwork_pb2.ComputeSubnetworkIamBinding]: ...
    @property
    def compute_subnetwork_iam_member(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[gcp.gcp_compute_subnetwork_pb2.ComputeSubnetworkIamMember]: ...
    @property
    def compute_subnetwork_iam_policy(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[gcp.gcp_compute_subnetwork_pb2.ComputeSubnetworkIamPolicy]: ...
    def __init__(
        self,
        *,
        compute_subnetwork: gcp.gcp_compute_subnetwork_pb2.ComputeSubnetwork | None = ...,
        compute_subnetwork_iam_binding: collections.abc.Iterable[gcp.gcp_compute_subnetwork_pb2.ComputeSubnetworkIamBinding] | None = ...,
        compute_subnetwork_iam_member: collections.abc.Iterable[gcp.gcp_compute_subnetwork_pb2.ComputeSubnetworkIamMember] | None = ...,
        compute_subnetwork_iam_policy: collections.abc.Iterable[gcp.gcp_compute_subnetwork_pb2.ComputeSubnetworkIamPolicy] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["compute_subnetwork", b"compute_subnetwork"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["compute_subnetwork", b"compute_subnetwork", "compute_subnetwork_iam_binding", b"compute_subnetwork_iam_binding", "compute_subnetwork_iam_member", b"compute_subnetwork_iam_member", "compute_subnetwork_iam_policy", b"compute_subnetwork_iam_policy"]) -> None: ...

global___GoogleComputeSubnetwork = GoogleComputeSubnetwork
