# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_google_compute_firewall_bundle.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2
from oak9.tython.models.gcp import gcp_compute_firewall_pb2 as gcp_dot_gcp__compute__firewall__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,gcp/gcp_google_compute_firewall_bundle.proto\x12.oak9.tython.gcp.google_compute_firewall_bundle\x1a\x13shared/shared.proto\x1a\x1egcp/gcp_compute_firewall.proto\"d\n\x15GoogleComputeFirewall\x12K\n\x10\x63ompute_firewall\x18\x01 \x01(\x0b\x32\x31.oak9.tython.gcp.compute_firewall.ComputeFirewallb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_google_compute_firewall_bundle_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GOOGLECOMPUTEFIREWALL._serialized_start=149
  _GOOGLECOMPUTEFIREWALL._serialized_end=249
# @@protoc_insertion_point(module_scope)
