"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ActiveDirectoryDomainXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___ActiveDirectoryDomainXTimeouts = ActiveDirectoryDomainXTimeouts

@typing_extensions.final
class ActiveDirectoryDomain(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    ADMIN_FIELD_NUMBER: builtins.int
    AUTHORIZED_NETWORKS_FIELD_NUMBER: builtins.int
    DOMAIN_NAME_FIELD_NUMBER: builtins.int
    FQDN_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    LOCATIONS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    RESERVED_IP_RANGE_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    admin: builtins.str
    @property
    def authorized_networks(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    domain_name: builtins.str
    fqdn: builtins.str
    id: builtins.str
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def locations(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    name: builtins.str
    project: builtins.str
    reserved_ip_range: builtins.str
    @property
    def timeouts(self) -> global___ActiveDirectoryDomainXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        admin: builtins.str = ...,
        authorized_networks: collections.abc.Iterable[builtins.str] | None = ...,
        domain_name: builtins.str = ...,
        fqdn: builtins.str = ...,
        id: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        locations: collections.abc.Iterable[builtins.str] | None = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        reserved_ip_range: builtins.str = ...,
        timeouts: global___ActiveDirectoryDomainXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["admin", b"admin", "authorized_networks", b"authorized_networks", "domain_name", b"domain_name", "fqdn", b"fqdn", "id", b"id", "labels", b"labels", "locations", b"locations", "name", b"name", "project", b"project", "reserved_ip_range", b"reserved_ip_range", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> None: ...

global___ActiveDirectoryDomain = ActiveDirectoryDomain

@typing_extensions.final
class ActiveDirectoryDomainTrustXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___ActiveDirectoryDomainTrustXTimeouts = ActiveDirectoryDomainTrustXTimeouts

@typing_extensions.final
class ActiveDirectoryDomainTrust(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DOMAIN_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    SELECTIVE_AUTHENTICATION_FIELD_NUMBER: builtins.int
    TARGET_DNS_IP_ADDRESSES_FIELD_NUMBER: builtins.int
    TARGET_DOMAIN_NAME_FIELD_NUMBER: builtins.int
    TRUST_DIRECTION_FIELD_NUMBER: builtins.int
    TRUST_HANDSHAKE_SECRET_FIELD_NUMBER: builtins.int
    TRUST_TYPE_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    domain: builtins.str
    id: builtins.str
    project: builtins.str
    selective_authentication: builtins.bool
    @property
    def target_dns_ip_addresses(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    target_domain_name: builtins.str
    trust_direction: builtins.str
    trust_handshake_secret: builtins.str
    trust_type: builtins.str
    @property
    def timeouts(self) -> global___ActiveDirectoryDomainTrustXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        domain: builtins.str = ...,
        id: builtins.str = ...,
        project: builtins.str = ...,
        selective_authentication: builtins.bool = ...,
        target_dns_ip_addresses: collections.abc.Iterable[builtins.str] | None = ...,
        target_domain_name: builtins.str = ...,
        trust_direction: builtins.str = ...,
        trust_handshake_secret: builtins.str = ...,
        trust_type: builtins.str = ...,
        timeouts: global___ActiveDirectoryDomainTrustXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["domain", b"domain", "id", b"id", "project", b"project", "resource_info", b"resource_info", "selective_authentication", b"selective_authentication", "target_dns_ip_addresses", b"target_dns_ip_addresses", "target_domain_name", b"target_domain_name", "timeouts", b"timeouts", "trust_direction", b"trust_direction", "trust_handshake_secret", b"trust_handshake_secret", "trust_type", b"trust_type"]) -> None: ...

global___ActiveDirectoryDomainTrust = ActiveDirectoryDomainTrust
