"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class IdentityPlatformDefaultSupportedIdpConfigXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___IdentityPlatformDefaultSupportedIdpConfigXTimeouts = IdentityPlatformDefaultSupportedIdpConfigXTimeouts

@typing_extensions.final
class IdentityPlatformDefaultSupportedIdpConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLIENT_ID_FIELD_NUMBER: builtins.int
    CLIENT_SECRET_FIELD_NUMBER: builtins.int
    ENABLED_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    IDP_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    client_id: builtins.str
    client_secret: builtins.str
    enabled: builtins.bool
    id: builtins.str
    idp_id: builtins.str
    name: builtins.str
    project: builtins.str
    @property
    def timeouts(self) -> global___IdentityPlatformDefaultSupportedIdpConfigXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        client_id: builtins.str = ...,
        client_secret: builtins.str = ...,
        enabled: builtins.bool = ...,
        id: builtins.str = ...,
        idp_id: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        timeouts: global___IdentityPlatformDefaultSupportedIdpConfigXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["client_id", b"client_id", "client_secret", b"client_secret", "enabled", b"enabled", "id", b"id", "idp_id", b"idp_id", "name", b"name", "project", b"project", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> None: ...

global___IdentityPlatformDefaultSupportedIdpConfig = IdentityPlatformDefaultSupportedIdpConfig

@typing_extensions.final
class IdentityPlatformInboundSamlConfigXIdpConfigXIdpCertificates(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    X509_CERTIFICATE_FIELD_NUMBER: builtins.int
    x509_certificate: builtins.str
    def __init__(
        self,
        *,
        x509_certificate: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["x509_certificate", b"x509_certificate"]) -> None: ...

global___IdentityPlatformInboundSamlConfigXIdpConfigXIdpCertificates = IdentityPlatformInboundSamlConfigXIdpConfigXIdpCertificates

@typing_extensions.final
class IdentityPlatformInboundSamlConfigXIdpConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IDP_ENTITY_ID_FIELD_NUMBER: builtins.int
    SIGN_REQUEST_FIELD_NUMBER: builtins.int
    SSO_URL_FIELD_NUMBER: builtins.int
    IDP_CERTIFICATES_FIELD_NUMBER: builtins.int
    idp_entity_id: builtins.str
    sign_request: builtins.bool
    sso_url: builtins.str
    @property
    def idp_certificates(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___IdentityPlatformInboundSamlConfigXIdpConfigXIdpCertificates]: ...
    def __init__(
        self,
        *,
        idp_entity_id: builtins.str = ...,
        sign_request: builtins.bool = ...,
        sso_url: builtins.str = ...,
        idp_certificates: collections.abc.Iterable[global___IdentityPlatformInboundSamlConfigXIdpConfigXIdpCertificates] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["idp_certificates", b"idp_certificates", "idp_entity_id", b"idp_entity_id", "sign_request", b"sign_request", "sso_url", b"sso_url"]) -> None: ...

global___IdentityPlatformInboundSamlConfigXIdpConfig = IdentityPlatformInboundSamlConfigXIdpConfig

@typing_extensions.final
class IdentityPlatformInboundSamlConfigXSpConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class SpCertificatesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    CALLBACK_URI_FIELD_NUMBER: builtins.int
    SP_CERTIFICATES_FIELD_NUMBER: builtins.int
    SP_ENTITY_ID_FIELD_NUMBER: builtins.int
    callback_uri: builtins.str
    @property
    def sp_certificates(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    sp_entity_id: builtins.str
    def __init__(
        self,
        *,
        callback_uri: builtins.str = ...,
        sp_certificates: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        sp_entity_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["callback_uri", b"callback_uri", "sp_certificates", b"sp_certificates", "sp_entity_id", b"sp_entity_id"]) -> None: ...

global___IdentityPlatformInboundSamlConfigXSpConfig = IdentityPlatformInboundSamlConfigXSpConfig

@typing_extensions.final
class IdentityPlatformInboundSamlConfigXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___IdentityPlatformInboundSamlConfigXTimeouts = IdentityPlatformInboundSamlConfigXTimeouts

@typing_extensions.final
class IdentityPlatformInboundSamlConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    ENABLED_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    IDP_CONFIG_FIELD_NUMBER: builtins.int
    SP_CONFIG_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    display_name: builtins.str
    enabled: builtins.bool
    id: builtins.str
    name: builtins.str
    project: builtins.str
    @property
    def idp_config(self) -> global___IdentityPlatformInboundSamlConfigXIdpConfig: ...
    @property
    def sp_config(self) -> global___IdentityPlatformInboundSamlConfigXSpConfig: ...
    @property
    def timeouts(self) -> global___IdentityPlatformInboundSamlConfigXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        display_name: builtins.str = ...,
        enabled: builtins.bool = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        idp_config: global___IdentityPlatformInboundSamlConfigXIdpConfig | None = ...,
        sp_config: global___IdentityPlatformInboundSamlConfigXSpConfig | None = ...,
        timeouts: global___IdentityPlatformInboundSamlConfigXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["idp_config", b"idp_config", "resource_info", b"resource_info", "sp_config", b"sp_config", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["display_name", b"display_name", "enabled", b"enabled", "id", b"id", "idp_config", b"idp_config", "name", b"name", "project", b"project", "resource_info", b"resource_info", "sp_config", b"sp_config", "timeouts", b"timeouts"]) -> None: ...

global___IdentityPlatformInboundSamlConfig = IdentityPlatformInboundSamlConfig

@typing_extensions.final
class IdentityPlatformOauthIdpConfigXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___IdentityPlatformOauthIdpConfigXTimeouts = IdentityPlatformOauthIdpConfigXTimeouts

@typing_extensions.final
class IdentityPlatformOauthIdpConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLIENT_ID_FIELD_NUMBER: builtins.int
    CLIENT_SECRET_FIELD_NUMBER: builtins.int
    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    ENABLED_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    ISSUER_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    client_id: builtins.str
    client_secret: builtins.str
    display_name: builtins.str
    enabled: builtins.bool
    id: builtins.str
    issuer: builtins.str
    name: builtins.str
    project: builtins.str
    @property
    def timeouts(self) -> global___IdentityPlatformOauthIdpConfigXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        client_id: builtins.str = ...,
        client_secret: builtins.str = ...,
        display_name: builtins.str = ...,
        enabled: builtins.bool = ...,
        id: builtins.str = ...,
        issuer: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        timeouts: global___IdentityPlatformOauthIdpConfigXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["client_id", b"client_id", "client_secret", b"client_secret", "display_name", b"display_name", "enabled", b"enabled", "id", b"id", "issuer", b"issuer", "name", b"name", "project", b"project", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> None: ...

global___IdentityPlatformOauthIdpConfig = IdentityPlatformOauthIdpConfig

@typing_extensions.final
class IdentityPlatformTenantXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___IdentityPlatformTenantXTimeouts = IdentityPlatformTenantXTimeouts

@typing_extensions.final
class IdentityPlatformTenant(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALLOW_PASSWORD_SIGNUP_FIELD_NUMBER: builtins.int
    DISABLE_AUTH_FIELD_NUMBER: builtins.int
    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    ENABLE_EMAIL_LINK_SIGNIN_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    allow_password_signup: builtins.bool
    disable_auth: builtins.bool
    display_name: builtins.str
    enable_email_link_signin: builtins.bool
    id: builtins.str
    name: builtins.str
    project: builtins.str
    @property
    def timeouts(self) -> global___IdentityPlatformTenantXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        allow_password_signup: builtins.bool = ...,
        disable_auth: builtins.bool = ...,
        display_name: builtins.str = ...,
        enable_email_link_signin: builtins.bool = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        timeouts: global___IdentityPlatformTenantXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["allow_password_signup", b"allow_password_signup", "disable_auth", b"disable_auth", "display_name", b"display_name", "enable_email_link_signin", b"enable_email_link_signin", "id", b"id", "name", b"name", "project", b"project", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> None: ...

global___IdentityPlatformTenant = IdentityPlatformTenant

@typing_extensions.final
class IdentityPlatformTenantDefaultSupportedIdpConfigXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___IdentityPlatformTenantDefaultSupportedIdpConfigXTimeouts = IdentityPlatformTenantDefaultSupportedIdpConfigXTimeouts

@typing_extensions.final
class IdentityPlatformTenantDefaultSupportedIdpConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLIENT_ID_FIELD_NUMBER: builtins.int
    CLIENT_SECRET_FIELD_NUMBER: builtins.int
    ENABLED_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    IDP_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    TENANT_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    client_id: builtins.str
    client_secret: builtins.str
    enabled: builtins.bool
    id: builtins.str
    idp_id: builtins.str
    name: builtins.str
    project: builtins.str
    tenant: builtins.str
    @property
    def timeouts(self) -> global___IdentityPlatformTenantDefaultSupportedIdpConfigXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        client_id: builtins.str = ...,
        client_secret: builtins.str = ...,
        enabled: builtins.bool = ...,
        id: builtins.str = ...,
        idp_id: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        tenant: builtins.str = ...,
        timeouts: global___IdentityPlatformTenantDefaultSupportedIdpConfigXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["client_id", b"client_id", "client_secret", b"client_secret", "enabled", b"enabled", "id", b"id", "idp_id", b"idp_id", "name", b"name", "project", b"project", "resource_info", b"resource_info", "tenant", b"tenant", "timeouts", b"timeouts"]) -> None: ...

global___IdentityPlatformTenantDefaultSupportedIdpConfig = IdentityPlatformTenantDefaultSupportedIdpConfig

@typing_extensions.final
class IdentityPlatformTenantInboundSamlConfigXIdpConfigXIdpCertificates(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    X509_CERTIFICATE_FIELD_NUMBER: builtins.int
    x509_certificate: builtins.str
    def __init__(
        self,
        *,
        x509_certificate: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["x509_certificate", b"x509_certificate"]) -> None: ...

global___IdentityPlatformTenantInboundSamlConfigXIdpConfigXIdpCertificates = IdentityPlatformTenantInboundSamlConfigXIdpConfigXIdpCertificates

@typing_extensions.final
class IdentityPlatformTenantInboundSamlConfigXIdpConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IDP_ENTITY_ID_FIELD_NUMBER: builtins.int
    SIGN_REQUEST_FIELD_NUMBER: builtins.int
    SSO_URL_FIELD_NUMBER: builtins.int
    IDP_CERTIFICATES_FIELD_NUMBER: builtins.int
    idp_entity_id: builtins.str
    sign_request: builtins.bool
    sso_url: builtins.str
    @property
    def idp_certificates(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___IdentityPlatformTenantInboundSamlConfigXIdpConfigXIdpCertificates]: ...
    def __init__(
        self,
        *,
        idp_entity_id: builtins.str = ...,
        sign_request: builtins.bool = ...,
        sso_url: builtins.str = ...,
        idp_certificates: collections.abc.Iterable[global___IdentityPlatformTenantInboundSamlConfigXIdpConfigXIdpCertificates] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["idp_certificates", b"idp_certificates", "idp_entity_id", b"idp_entity_id", "sign_request", b"sign_request", "sso_url", b"sso_url"]) -> None: ...

global___IdentityPlatformTenantInboundSamlConfigXIdpConfig = IdentityPlatformTenantInboundSamlConfigXIdpConfig

@typing_extensions.final
class IdentityPlatformTenantInboundSamlConfigXSpConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class SpCertificatesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    CALLBACK_URI_FIELD_NUMBER: builtins.int
    SP_CERTIFICATES_FIELD_NUMBER: builtins.int
    SP_ENTITY_ID_FIELD_NUMBER: builtins.int
    callback_uri: builtins.str
    @property
    def sp_certificates(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    sp_entity_id: builtins.str
    def __init__(
        self,
        *,
        callback_uri: builtins.str = ...,
        sp_certificates: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        sp_entity_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["callback_uri", b"callback_uri", "sp_certificates", b"sp_certificates", "sp_entity_id", b"sp_entity_id"]) -> None: ...

global___IdentityPlatformTenantInboundSamlConfigXSpConfig = IdentityPlatformTenantInboundSamlConfigXSpConfig

@typing_extensions.final
class IdentityPlatformTenantInboundSamlConfigXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___IdentityPlatformTenantInboundSamlConfigXTimeouts = IdentityPlatformTenantInboundSamlConfigXTimeouts

@typing_extensions.final
class IdentityPlatformTenantInboundSamlConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    ENABLED_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    TENANT_FIELD_NUMBER: builtins.int
    IDP_CONFIG_FIELD_NUMBER: builtins.int
    SP_CONFIG_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    display_name: builtins.str
    enabled: builtins.bool
    id: builtins.str
    name: builtins.str
    project: builtins.str
    tenant: builtins.str
    @property
    def idp_config(self) -> global___IdentityPlatformTenantInboundSamlConfigXIdpConfig: ...
    @property
    def sp_config(self) -> global___IdentityPlatformTenantInboundSamlConfigXSpConfig: ...
    @property
    def timeouts(self) -> global___IdentityPlatformTenantInboundSamlConfigXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        display_name: builtins.str = ...,
        enabled: builtins.bool = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        tenant: builtins.str = ...,
        idp_config: global___IdentityPlatformTenantInboundSamlConfigXIdpConfig | None = ...,
        sp_config: global___IdentityPlatformTenantInboundSamlConfigXSpConfig | None = ...,
        timeouts: global___IdentityPlatformTenantInboundSamlConfigXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["idp_config", b"idp_config", "resource_info", b"resource_info", "sp_config", b"sp_config", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["display_name", b"display_name", "enabled", b"enabled", "id", b"id", "idp_config", b"idp_config", "name", b"name", "project", b"project", "resource_info", b"resource_info", "sp_config", b"sp_config", "tenant", b"tenant", "timeouts", b"timeouts"]) -> None: ...

global___IdentityPlatformTenantInboundSamlConfig = IdentityPlatformTenantInboundSamlConfig

@typing_extensions.final
class IdentityPlatformTenantOauthIdpConfigXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___IdentityPlatformTenantOauthIdpConfigXTimeouts = IdentityPlatformTenantOauthIdpConfigXTimeouts

@typing_extensions.final
class IdentityPlatformTenantOauthIdpConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLIENT_ID_FIELD_NUMBER: builtins.int
    CLIENT_SECRET_FIELD_NUMBER: builtins.int
    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    ENABLED_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    ISSUER_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    TENANT_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    client_id: builtins.str
    client_secret: builtins.str
    display_name: builtins.str
    enabled: builtins.bool
    id: builtins.str
    issuer: builtins.str
    name: builtins.str
    project: builtins.str
    tenant: builtins.str
    @property
    def timeouts(self) -> global___IdentityPlatformTenantOauthIdpConfigXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        client_id: builtins.str = ...,
        client_secret: builtins.str = ...,
        display_name: builtins.str = ...,
        enabled: builtins.bool = ...,
        id: builtins.str = ...,
        issuer: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        tenant: builtins.str = ...,
        timeouts: global___IdentityPlatformTenantOauthIdpConfigXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["client_id", b"client_id", "client_secret", b"client_secret", "display_name", b"display_name", "enabled", b"enabled", "id", b"id", "issuer", b"issuer", "name", b"name", "project", b"project", "resource_info", b"resource_info", "tenant", b"tenant", "timeouts", b"timeouts"]) -> None: ...

global___IdentityPlatformTenantOauthIdpConfig = IdentityPlatformTenantOauthIdpConfig
