# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: azure/azure_microsoft_containerservice.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,azure/azure_microsoft_containerservice.proto\x12,oak9.tython.azure.microsoft_containerservice\x1a\x13shared/shared.proto\"\xe4\x01\n\x1aMicrosoft_ContainerService\x12W\n\x10managed_clusters\x18\x01 \x01(\x0b\x32=.oak9.tython.azure.microsoft_containerservice.ManagedClusters\x12m\n\x1cmanaged_clusters_agent_pools\x18\x02 \x03(\x0b\x32G.oak9.tython.azure.microsoft_containerservice.ManagedClustersAgentPools\"\xcc\x02\n\tSnapshots\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08location\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12Q\n\rcreation_data\x18\x04 \x01(\x0b\x32:.oak9.tython.azure.microsoft_containerservice.CreationData\x12\x15\n\rsnapshot_type\x18\x05 \x01(\t\x12O\n\x04tags\x18\x06 \x03(\x0b\x32\x41.oak9.tython.azure.microsoft_containerservice.Snapshots.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xcb\x02\n)ManagedClustersPrivateEndpointConnections\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12W\n\x10private_endpoint\x18\x03 \x01(\x0b\x32=.oak9.tython.azure.microsoft_containerservice.PrivateEndpoint\x12~\n%private_link_service_connection_state\x18\x04 \x01(\x0b\x32O.oak9.tython.azure.microsoft_containerservice.PrivateLinkServiceConnectionState\"H\n!PrivateLinkServiceConnectionState\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x0e\n\x06status\x18\x02 \x01(\t\"\x1d\n\x0fPrivateEndpoint\x12\n\n\x02id\x18\x01 \x01(\t\"\x93\x02\n(ManagedClustersMaintenanceConfigurations\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12P\n\x10not_allowed_time\x18\x03 \x03(\x0b\x32\x36.oak9.tython.azure.microsoft_containerservice.TimeSpan\x12N\n\x0ctime_in_week\x18\x04 \x03(\x0b\x32\x38.oak9.tython.azure.microsoft_containerservice.TimeInWeek\"-\n\nTimeInWeek\x12\x0b\n\x03\x64\x61y\x18\x01 \x01(\t\x12\x12\n\nhour_slots\x18\x02 \x03(\x05\"&\n\x08TimeSpan\x12\x0b\n\x03\x65nd\x18\x01 \x01(\t\x12\r\n\x05start\x18\x02 \x01(\t\"\xf5\x0c\n\x19ManagedClustersAgentPools\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x1a\n\x12\x61vailability_zones\x18\x03 \x03(\t\x12%\n\x1d\x63\x61pacity_reservation_group_id\x18\x04 \x01(\t\x12\r\n\x05\x63ount\x18\x05 \x01(\x05\x12Q\n\rcreation_data\x18\x06 \x01(\x0b\x32:.oak9.tython.azure.microsoft_containerservice.CreationData\x12\x1b\n\x13\x65nable_auto_scaling\x18\x07 \x01(\x08\x12!\n\x19\x65nable_encryption_at_host\x18\x08 \x01(\x08\x12\x13\n\x0b\x65nable_fips\x18\t \x01(\x08\x12\x1d\n\x15\x65nable_node_public_ip\x18\n \x01(\x08\x12\x18\n\x10\x65nable_ultra_ssd\x18\x0b \x01(\x08\x12\x1c\n\x14gpu_instance_profile\x18\x0c \x01(\t\x12\x15\n\rhost_group_id\x18\r \x01(\t\x12S\n\x0ekubelet_config\x18\x0e \x01(\x0b\x32;.oak9.tython.azure.microsoft_containerservice.KubeletConfig\x12\x19\n\x11kubelet_disk_type\x18\x0f \x01(\t\x12T\n\x0flinux_os_config\x18\x10 \x01(\x0b\x32;.oak9.tython.azure.microsoft_containerservice.LinuxOSConfig\x12\x11\n\tmax_count\x18\x11 \x01(\x05\x12\x10\n\x08max_pods\x18\x12 \x01(\x05\x12\x1a\n\x12message_of_the_day\x18\x13 \x01(\t\x12\x11\n\tmin_count\x18\x14 \x01(\x05\x12\x0c\n\x04mode\x18\x15 \x01(\t\x12l\n\x0bnode_labels\x18\x16 \x03(\x0b\x32W.oak9.tython.azure.microsoft_containerservice.ManagedClustersAgentPools.NodeLabelsEntry\x12 \n\x18node_public_ip_prefix_id\x18\x17 \x01(\t\x12\x13\n\x0bnode_taints\x18\x18 \x03(\t\x12\x1c\n\x14orchestrator_version\x18\x19 \x01(\t\x12\x17\n\x0fos_disk_size_gb\x18\x1a \x01(\x05\x12\x14\n\x0cos_disk_type\x18\x1b \x01(\t\x12\x0e\n\x06os_sku\x18\x1c \x01(\t\x12\x0f\n\x07os_type\x18\x1d \x01(\t\x12\x15\n\rpod_subnet_id\x18\x1e \x01(\t\x12M\n\x0bpower_state\x18\x1f \x01(\x0b\x32\x38.oak9.tython.azure.microsoft_containerservice.PowerState\x12$\n\x1cproximity_placement_group_id\x18  \x01(\t\x12\x17\n\x0fscale_down_mode\x18! \x01(\t\x12!\n\x19scale_set_eviction_policy\x18\" \x01(\t\x12\x1a\n\x12scale_set_priority\x18# \x01(\t\x12\x16\n\x0espot_max_price\x18$ \x01(\x01\x12_\n\x04tags\x18% \x03(\x0b\x32Q.oak9.tython.azure.microsoft_containerservice.ManagedClustersAgentPools.TagsEntry\x12\x0c\n\x04type\x18& \x01(\t\x12`\n\x10upgrade_settings\x18\' \x01(\x0b\x32\x46.oak9.tython.azure.microsoft_containerservice.AgentPoolUpgradeSettings\x12\x0f\n\x07vm_size\x18( \x01(\t\x12\x16\n\x0evnet_subnet_id\x18) \x01(\t\x12\x18\n\x10workload_runtime\x18* \x01(\t\x1a\x31\n\x0fNodeLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xcb\x16\n\x0fManagedClusters\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12Y\n\x11\x65xtended_location\x18\x02 \x01(\x0b\x32>.oak9.tython.azure.microsoft_containerservice.ExtendedLocation\x12V\n\x08identity\x18\x03 \x01(\x0b\x32\x44.oak9.tython.azure.microsoft_containerservice.ManagedClusterIdentity\x12\x10\n\x08location\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12[\n\x0b\x61\x61\x64_profile\x18\x06 \x01(\x0b\x32\x46.oak9.tython.azure.microsoft_containerservice.ManagedClusterAADProfile\x12h\n\x0e\x61\x64\x64on_profiles\x18\x07 \x03(\x0b\x32P.oak9.tython.azure.microsoft_containerservice.ManagedClusters.AddonProfilesEntry\x12i\n\x13\x61gent_pool_profiles\x18\x08 \x03(\x0b\x32L.oak9.tython.azure.microsoft_containerservice.ManagedClusterAgentPoolProfile\x12u\n\x19\x61pi_server_access_profile\x18\t \x01(\x0b\x32R.oak9.tython.azure.microsoft_containerservice.ManagedClusterAPIServerAccessProfile\x12t\n\x13\x61uto_scaler_profile\x18\n \x01(\x0b\x32W.oak9.tython.azure.microsoft_containerservice.ManagedClusterPropertiesAutoScalerProfile\x12l\n\x14\x61uto_upgrade_profile\x18\x0b \x01(\x0b\x32N.oak9.tython.azure.microsoft_containerservice.ManagedClusterAutoUpgradeProfile\x12\x1e\n\x16\x64isable_local_accounts\x18\x0c \x01(\x08\x12\x1e\n\x16\x64isk_encryption_set_id\x18\r \x01(\t\x12\x12\n\ndns_prefix\x18\x0e \x01(\t\x12\"\n\x1a\x65nable_namespace_resources\x18\x0f \x01(\x08\x12\"\n\x1a\x65nable_pod_security_policy\x18\x10 \x01(\x08\x12\x13\n\x0b\x65nable_rbac\x18\x11 \x01(\x08\x12\x16\n\x0e\x66qdn_subdomain\x18\x12 \x01(\t\x12\x66\n\x11http_proxy_config\x18\x13 \x01(\x0b\x32K.oak9.tython.azure.microsoft_containerservice.ManagedClusterHTTPProxyConfig\x12l\n\x10identity_profile\x18\x14 \x03(\x0b\x32R.oak9.tython.azure.microsoft_containerservice.ManagedClusters.IdentityProfileEntry\x12\x1a\n\x12kubernetes_version\x18\x15 \x01(\t\x12\x61\n\rlinux_profile\x18\x16 \x01(\x0b\x32J.oak9.tython.azure.microsoft_containerservice.ContainerServiceLinuxProfile\x12\x65\n\x0fnetwork_profile\x18\x17 \x01(\x0b\x32L.oak9.tython.azure.microsoft_containerservice.ContainerServiceNetworkProfile\x12\x1b\n\x13node_resource_group\x18\x18 \x01(\t\x12j\n\x13oidc_issuer_profile\x18\x19 \x01(\x0b\x32M.oak9.tython.azure.microsoft_containerservice.ManagedClusterOIDCIssuerProfile\x12l\n\x14pod_identity_profile\x18\x1a \x01(\x0b\x32N.oak9.tython.azure.microsoft_containerservice.ManagedClusterPodIdentityProfile\x12\x61\n\x16private_link_resources\x18\x1b \x03(\x0b\x32\x41.oak9.tython.azure.microsoft_containerservice.PrivateLinkResource\x12\x1d\n\x15public_network_access\x18\x1c \x01(\t\x12\x65\n\x10security_profile\x18\x1d \x01(\x0b\x32K.oak9.tython.azure.microsoft_containerservice.ManagedClusterSecurityProfile\x12v\n\x19service_principal_profile\x18\x1e \x01(\x0b\x32S.oak9.tython.azure.microsoft_containerservice.ManagedClusterServicePrincipalProfile\x12\x63\n\x0fwindows_profile\x18\x1f \x01(\x0b\x32J.oak9.tython.azure.microsoft_containerservice.ManagedClusterWindowsProfile\x12L\n\x03sku\x18  \x01(\x0b\x32?.oak9.tython.azure.microsoft_containerservice.ManagedClusterSKU\x12U\n\x04tags\x18! \x03(\x0b\x32G.oak9.tython.azure.microsoft_containerservice.ManagedClusters.TagsEntry\x12\x8b\x01\n+managed_clusters_maintenance_configurations\x18\" \x03(\x0b\x32V.oak9.tython.azure.microsoft_containerservice.ManagedClustersMaintenanceConfigurations\x12\x8e\x01\n-managed_clusters_private_endpoint_connections\x18# \x03(\x0b\x32W.oak9.tython.azure.microsoft_containerservice.ManagedClustersPrivateEndpointConnections\x1a\x34\n\x12\x41\x64\x64onProfilesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x36\n\x14IdentityProfileEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"/\n\x11ManagedClusterSKU\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04tier\x18\x02 \x01(\t\"\xd6\x01\n\x1cManagedClusterWindowsProfile\x12\x16\n\x0e\x61\x64min_password\x18\x01 \x01(\t\x12\x16\n\x0e\x61\x64min_username\x18\x02 \x01(\t\x12\x18\n\x10\x65nable_cs_iproxy\x18\x03 \x01(\x08\x12V\n\x0cgmsa_profile\x18\x04 \x01(\x0b\x32@.oak9.tython.azure.microsoft_containerservice.WindowsGmsaProfile\x12\x14\n\x0clicense_type\x18\x05 \x01(\t\"S\n\x12WindowsGmsaProfile\x12\x12\n\ndns_server\x18\x01 \x01(\t\x12\x0f\n\x07\x65nabled\x18\x02 \x01(\x08\x12\x18\n\x10root_domain_name\x18\x03 \x01(\t\"J\n%ManagedClusterServicePrincipalProfile\x12\x11\n\tclient_id\x18\x01 \x01(\t\x12\x0e\n\x06secret\x18\x02 \x01(\t\"\x91\x01\n\x1dManagedClusterSecurityProfile\x12p\n\x0e\x61zure_defender\x18\x01 \x01(\x0b\x32X.oak9.tython.azure.microsoft_containerservice.ManagedClusterSecurityProfileAzureDefender\"j\n*ManagedClusterSecurityProfileAzureDefender\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12+\n#log_analytics_workspace_resource_id\x18\x02 \x01(\t\"i\n\x13PrivateLinkResource\x12\x10\n\x08group_id\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x18\n\x10required_members\x18\x04 \x03(\t\x12\x0c\n\x04type\x18\x05 \x01(\t\"\xc1\x02\n ManagedClusterPodIdentityProfile\x12$\n\x1c\x61llow_network_plugin_kubenet\x18\x01 \x01(\x08\x12\x0f\n\x07\x65nabled\x18\x02 \x01(\x08\x12i\n\x18user_assigned_identities\x18\x03 \x03(\x0b\x32G.oak9.tython.azure.microsoft_containerservice.ManagedClusterPodIdentity\x12{\n!user_assigned_identity_exceptions\x18\x04 \x03(\x0b\x32P.oak9.tython.azure.microsoft_containerservice.ManagedClusterPodIdentityException\"\xec\x01\n\"ManagedClusterPodIdentityException\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\tnamespace\x18\x02 \x01(\t\x12s\n\npod_labels\x18\x03 \x03(\x0b\x32_.oak9.tython.azure.microsoft_containerservice.ManagedClusterPodIdentityException.PodLabelsEntry\x1a\x30\n\x0ePodLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xac\x01\n\x19ManagedClusterPodIdentity\x12\x18\n\x10\x62inding_selector\x18\x01 \x01(\t\x12T\n\x08identity\x18\x02 \x01(\x0b\x32\x42.oak9.tython.azure.microsoft_containerservice.UserAssignedIdentity\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x11\n\tnamespace\x18\x04 \x01(\t\"Q\n\x14UserAssignedIdentity\x12\x11\n\tclient_id\x18\x01 \x01(\t\x12\x11\n\tobject_id\x18\x02 \x01(\t\x12\x13\n\x0bresource_id\x18\x03 \x01(\t\"2\n\x1fManagedClusterOIDCIssuerProfile\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\"\x8f\x04\n\x1e\x43ontainerServiceNetworkProfile\x12\x16\n\x0e\x64ns_service_ip\x18\x01 \x01(\t\x12\x1a\n\x12\x64ocker_bridge_cidr\x18\x02 \x01(\t\x12\x13\n\x0bip_families\x18\x03 \x03(\t\x12n\n\x15load_balancer_profile\x18\x04 \x01(\x0b\x32O.oak9.tython.azure.microsoft_containerservice.ManagedClusterLoadBalancerProfile\x12\x19\n\x11load_balancer_sku\x18\x05 \x01(\t\x12j\n\x13nat_gateway_profile\x18\x06 \x01(\x0b\x32M.oak9.tython.azure.microsoft_containerservice.ManagedClusterNATGatewayProfile\x12\x14\n\x0cnetwork_mode\x18\x07 \x01(\t\x12\x16\n\x0enetwork_plugin\x18\x08 \x01(\t\x12\x16\n\x0enetwork_policy\x18\t \x01(\t\x12\x15\n\routbound_type\x18\n \x01(\t\x12\x10\n\x08pod_cidr\x18\x0b \x01(\t\x12\x11\n\tpod_cidrs\x18\x0c \x03(\t\x12\x14\n\x0cservice_cidr\x18\r \x01(\t\x12\x15\n\rservice_cidrs\x18\x0e \x03(\t\"\x9e\x02\n\x1fManagedClusterNATGatewayProfile\x12_\n\x16\x65\x66\x66\x65\x63tive_outbound_ips\x18\x01 \x03(\x0b\x32?.oak9.tython.azure.microsoft_containerservice.ResourceReference\x12\x1f\n\x17idle_timeout_in_minutes\x18\x02 \x01(\x05\x12y\n\x1bmanaged_outbound_ip_profile\x18\x03 \x01(\x0b\x32T.oak9.tython.azure.microsoft_containerservice.ManagedClusterManagedOutboundIPProfile\"7\n&ManagedClusterManagedOutboundIPProfile\x12\r\n\x05\x63ount\x18\x01 \x01(\x05\"\xec\x04\n!ManagedClusterLoadBalancerProfile\x12 \n\x18\x61llocated_outbound_ports\x18\x01 \x01(\x05\x12_\n\x16\x65\x66\x66\x65\x63tive_outbound_ips\x18\x02 \x03(\x0b\x32?.oak9.tython.azure.microsoft_containerservice.ResourceReference\x12/\n\'enable_multiple_standard_load_balancers\x18\x03 \x01(\x08\x12\x1f\n\x17idle_timeout_in_minutes\x18\x04 \x01(\x05\x12\x7f\n\x14managed_outbound_ips\x18\x05 \x01(\x0b\x32\x61.oak9.tython.azure.microsoft_containerservice.ManagedClusterLoadBalancerProfileManagedOutboundIPs\x12\x7f\n\x14outbound_ip_prefixes\x18\x06 \x01(\x0b\x32\x61.oak9.tython.azure.microsoft_containerservice.ManagedClusterLoadBalancerProfileOutboundIPPrefixes\x12p\n\x0coutbound_ips\x18\x07 \x01(\x0b\x32Z.oak9.tython.azure.microsoft_containerservice.ManagedClusterLoadBalancerProfileOutboundIPs\"\x83\x01\n,ManagedClusterLoadBalancerProfileOutboundIPs\x12S\n\npublic_ips\x18\x01 \x03(\x0b\x32?.oak9.tython.azure.microsoft_containerservice.ResourceReference\"\x92\x01\n3ManagedClusterLoadBalancerProfileOutboundIPPrefixes\x12[\n\x12public_ip_prefixes\x18\x01 \x03(\x0b\x32?.oak9.tython.azure.microsoft_containerservice.ResourceReference\"X\n3ManagedClusterLoadBalancerProfileManagedOutboundIPs\x12\r\n\x05\x63ount\x18\x01 \x01(\x05\x12\x12\n\ncount_ipv6\x18\x02 \x01(\x05\"\x1f\n\x11ResourceReference\x12\n\n\x02id\x18\x01 \x01(\t\"\x93\x01\n\x1c\x43ontainerServiceLinuxProfile\x12\x16\n\x0e\x61\x64min_username\x18\x01 \x01(\t\x12[\n\x03ssh\x18\x02 \x01(\x0b\x32N.oak9.tython.azure.microsoft_containerservice.ContainerServiceSshConfiguration\"\x83\x01\n ContainerServiceSshConfiguration\x12_\n\x0bpublic_keys\x18\x01 \x03(\x0b\x32J.oak9.tython.azure.microsoft_containerservice.ContainerServiceSshPublicKey\"0\n\x1c\x43ontainerServiceSshPublicKey\x12\x10\n\x08key_data\x18\x01 \x01(\t\"n\n\x1dManagedClusterHTTPProxyConfig\x12\x12\n\nhttp_proxy\x18\x01 \x01(\t\x12\x13\n\x0bhttps_proxy\x18\x02 \x01(\t\x12\x10\n\x08no_proxy\x18\x03 \x03(\t\x12\x12\n\ntrusted_ca\x18\x04 \x01(\t\";\n ManagedClusterAutoUpgradeProfile\x12\x17\n\x0fupgrade_channel\x18\x01 \x01(\t\"\xf1\x04\n)ManagedClusterPropertiesAutoScalerProfile\x12#\n\x1b\x62\x61lance_similar_node_groups\x18\x01 \x01(\t\x12\x10\n\x08\x65xpander\x18\x02 \x01(\t\x12\x1d\n\x15max_empty_bulk_delete\x18\x03 \x01(\t\x12$\n\x1cmax_graceful_termination_sec\x18\x04 \x01(\t\x12\x1f\n\x17max_node_provision_time\x18\x05 \x01(\t\x12$\n\x1cmax_total_unready_percentage\x18\x06 \x01(\t\x12\x1e\n\x16new_pod_scale_up_delay\x18\x07 \x01(\t\x12\x1e\n\x16ok_total_unready_count\x18\x08 \x01(\t\x12\"\n\x1ascale_down_delay_after_add\x18\t \x01(\t\x12%\n\x1dscale_down_delay_after_delete\x18\n \x01(\t\x12&\n\x1escale_down_delay_after_failure\x18\x0b \x01(\t\x12 \n\x18scale_down_unneeded_time\x18\x0c \x01(\t\x12\x1f\n\x17scale_down_unready_time\x18\r \x01(\t\x12(\n scale_down_utilization_threshold\x18\x0e \x01(\t\x12\x15\n\rscan_interval\x18\x0f \x01(\t\x12%\n\x1dskip_nodes_with_local_storage\x18\x10 \x01(\t\x12#\n\x1bskip_nodes_with_system_pods\x18\x11 \x01(\t\"\xc7\x01\n$ManagedClusterAPIServerAccessProfile\x12\x1c\n\x14\x61uthorized_ip_ranges\x18\x01 \x03(\t\x12\x1b\n\x13\x64isable_run_command\x18\x02 \x01(\x08\x12\x1e\n\x16\x65nable_private_cluster\x18\x03 \x01(\x08\x12*\n\"enable_private_cluster_public_fqdn\x18\x04 \x01(\x08\x12\x18\n\x10private_dns_zone\x18\x05 \x01(\t\"\xcb\x0c\n\x1eManagedClusterAgentPoolProfile\x12\x1a\n\x12\x61vailability_zones\x18\x01 \x03(\t\x12%\n\x1d\x63\x61pacity_reservation_group_id\x18\x02 \x01(\t\x12\r\n\x05\x63ount\x18\x03 \x01(\x05\x12Q\n\rcreation_data\x18\x04 \x01(\x0b\x32:.oak9.tython.azure.microsoft_containerservice.CreationData\x12\x1b\n\x13\x65nable_auto_scaling\x18\x05 \x01(\x08\x12!\n\x19\x65nable_encryption_at_host\x18\x06 \x01(\x08\x12\x13\n\x0b\x65nable_fips\x18\x07 \x01(\x08\x12\x1d\n\x15\x65nable_node_public_ip\x18\x08 \x01(\x08\x12\x18\n\x10\x65nable_ultra_ssd\x18\t \x01(\x08\x12\x1c\n\x14gpu_instance_profile\x18\n \x01(\t\x12\x15\n\rhost_group_id\x18\x0b \x01(\t\x12S\n\x0ekubelet_config\x18\x0c \x01(\x0b\x32;.oak9.tython.azure.microsoft_containerservice.KubeletConfig\x12\x19\n\x11kubelet_disk_type\x18\r \x01(\t\x12T\n\x0flinux_os_config\x18\x0e \x01(\x0b\x32;.oak9.tython.azure.microsoft_containerservice.LinuxOSConfig\x12\x11\n\tmax_count\x18\x0f \x01(\x05\x12\x10\n\x08max_pods\x18\x10 \x01(\x05\x12\x1a\n\x12message_of_the_day\x18\x11 \x01(\t\x12\x11\n\tmin_count\x18\x12 \x01(\x05\x12\x0c\n\x04mode\x18\x13 \x01(\t\x12\x0c\n\x04name\x18\x14 \x01(\t\x12q\n\x0bnode_labels\x18\x15 \x03(\x0b\x32\\.oak9.tython.azure.microsoft_containerservice.ManagedClusterAgentPoolProfile.NodeLabelsEntry\x12 \n\x18node_public_ip_prefix_id\x18\x16 \x01(\t\x12\x13\n\x0bnode_taints\x18\x17 \x03(\t\x12\x1c\n\x14orchestrator_version\x18\x18 \x01(\t\x12\x17\n\x0fos_disk_size_gb\x18\x19 \x01(\x05\x12\x14\n\x0cos_disk_type\x18\x1a \x01(\t\x12\x0e\n\x06os_sku\x18\x1b \x01(\t\x12\x0f\n\x07os_type\x18\x1c \x01(\t\x12\x15\n\rpod_subnet_id\x18\x1d \x01(\t\x12M\n\x0bpower_state\x18\x1e \x01(\x0b\x32\x38.oak9.tython.azure.microsoft_containerservice.PowerState\x12$\n\x1cproximity_placement_group_id\x18\x1f \x01(\t\x12\x17\n\x0fscale_down_mode\x18  \x01(\t\x12!\n\x19scale_set_eviction_policy\x18! \x01(\t\x12\x1a\n\x12scale_set_priority\x18\" \x01(\t\x12\x16\n\x0espot_max_price\x18# \x01(\x01\x12\x64\n\x04tags\x18$ \x03(\x0b\x32V.oak9.tython.azure.microsoft_containerservice.ManagedClusterAgentPoolProfile.TagsEntry\x12\x0c\n\x04type\x18% \x01(\t\x12`\n\x10upgrade_settings\x18& \x01(\x0b\x32\x46.oak9.tython.azure.microsoft_containerservice.AgentPoolUpgradeSettings\x12\x0f\n\x07vm_size\x18\' \x01(\t\x12\x16\n\x0evnet_subnet_id\x18( \x01(\t\x12\x18\n\x10workload_runtime\x18) \x01(\t\x1a\x31\n\x0fNodeLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"-\n\x18\x41gentPoolUpgradeSettings\x12\x11\n\tmax_surge\x18\x01 \x01(\t\"\x1a\n\nPowerState\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\"\xc4\x01\n\rLinuxOSConfig\x12\x19\n\x11swap_file_size_mb\x18\x01 \x01(\x05\x12K\n\x07sysctls\x18\x02 \x01(\x0b\x32:.oak9.tython.azure.microsoft_containerservice.SysctlConfig\x12$\n\x1ctransparent_huge_page_defrag\x18\x03 \x01(\t\x12%\n\x1dtransparent_huge_page_enabled\x18\x04 \x01(\t\"\xa9\x07\n\x0cSysctlConfig\x12\x15\n\rfs_aio_max_nr\x18\x01 \x01(\x05\x12\x13\n\x0b\x66s_file_max\x18\x02 \x01(\x05\x12#\n\x1b\x66s_inotify_max_user_watches\x18\x03 \x01(\x05\x12\x12\n\nfs_nr_open\x18\x04 \x01(\x05\x12\x1a\n\x12kernel_threads_max\x18\x05 \x01(\x05\x12#\n\x1bnet_core_netdev_max_backlog\x18\x06 \x01(\x05\x12\x1b\n\x13net_core_optmem_max\x18\x07 \x01(\x05\x12\x1d\n\x15net_core_rmem_default\x18\x08 \x01(\x05\x12\x19\n\x11net_core_rmem_max\x18\t \x01(\x05\x12\x1a\n\x12net_core_somaxconn\x18\n \x01(\x05\x12\x1d\n\x15net_core_wmem_default\x18\x0b \x01(\x05\x12\x19\n\x11net_core_wmem_max\x18\x0c \x01(\x05\x12$\n\x1cnet_ipv4_ip_local_port_range\x18\r \x01(\t\x12)\n!net_ipv4_neigh_default_gc_thresh1\x18\x0e \x01(\x05\x12)\n!net_ipv4_neigh_default_gc_thresh2\x18\x0f \x01(\x05\x12)\n!net_ipv4_neigh_default_gc_thresh3\x18\x10 \x01(\x05\x12 \n\x18net_ipv4_tcp_fin_timeout\x18\x11 \x01(\x05\x12#\n\x1bnet_ipv4_tcpkeepalive_intvl\x18\x12 \x01(\x05\x12%\n\x1dnet_ipv4_tcp_keepalive_probes\x18\x13 \x01(\x05\x12#\n\x1bnet_ipv4_tcp_keepalive_time\x18\x14 \x01(\x05\x12$\n\x1cnet_ipv4_tcp_max_syn_backlog\x18\x15 \x01(\x05\x12#\n\x1bnet_ipv4_tcp_max_tw_buckets\x18\x16 \x01(\x05\x12\x1d\n\x15net_ipv4_tcp_tw_reuse\x18\x17 \x01(\x08\x12*\n\"net_netfilter_nf_conntrack_buckets\x18\x18 \x01(\x05\x12&\n\x1enet_netfilter_nf_conntrack_max\x18\x19 \x01(\x05\x12\x18\n\x10vm_max_map_count\x18\x1a \x01(\x05\x12\x15\n\rvm_swappiness\x18\x1b \x01(\x05\x12\x1d\n\x15vm_vfs_cache_pressure\x18\x1c \x01(\x05\"\xd2\x02\n\rKubeletConfig\x12\x1e\n\x16\x61llowed_unsafe_sysctls\x18\x01 \x03(\t\x12\x1f\n\x17\x63ontainer_log_max_files\x18\x02 \x01(\x05\x12!\n\x19\x63ontainer_log_max_size_mb\x18\x03 \x01(\x05\x12\x15\n\rcpu_cfs_quota\x18\x04 \x01(\x08\x12\x1c\n\x14\x63pu_cfs_quota_period\x18\x05 \x01(\t\x12\x1a\n\x12\x63pu_manager_policy\x18\x06 \x01(\t\x12\x14\n\x0c\x66\x61il_swap_on\x18\x07 \x01(\x08\x12\x1f\n\x17image_gc_high_threshold\x18\x08 \x01(\x05\x12\x1e\n\x16image_gc_low_threshold\x18\t \x01(\x05\x12\x14\n\x0cpod_max_pids\x18\n \x01(\x05\x12\x1f\n\x17topology_manager_policy\x18\x0b \x01(\t\"*\n\x0c\x43reationData\x12\x1a\n\x12source_resource_id\x18\x01 \x01(\t\"\xc2\x01\n\x18ManagedClusterAADProfile\x12\x1e\n\x16\x61\x64min_group_object_ids\x18\x01 \x03(\t\x12\x15\n\rclient_app_id\x18\x02 \x01(\t\x12\x19\n\x11\x65nable_azure_rbac\x18\x03 \x01(\x08\x12\x0f\n\x07managed\x18\x04 \x01(\x08\x12\x15\n\rserver_app_id\x18\x05 \x01(\t\x12\x19\n\x11server_app_secret\x18\x06 \x01(\t\x12\x11\n\ttenant_id\x18\x07 \x01(\t\"\xea\x01\n\x16ManagedClusterIdentity\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x82\x01\n\x18user_assigned_identities\x18\x02 \x03(\x0b\x32`.oak9.tython.azure.microsoft_containerservice.ManagedClusterIdentity.UserAssignedIdentitiesEntry\x1a=\n\x1bUserAssignedIdentitiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\".\n\x10\x45xtendedLocation\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'azure.azure_microsoft_containerservice_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SNAPSHOTS_TAGSENTRY._options = None
  _SNAPSHOTS_TAGSENTRY._serialized_options = b'8\001'
  _MANAGEDCLUSTERSAGENTPOOLS_NODELABELSENTRY._options = None
  _MANAGEDCLUSTERSAGENTPOOLS_NODELABELSENTRY._serialized_options = b'8\001'
  _MANAGEDCLUSTERSAGENTPOOLS_TAGSENTRY._options = None
  _MANAGEDCLUSTERSAGENTPOOLS_TAGSENTRY._serialized_options = b'8\001'
  _MANAGEDCLUSTERS_ADDONPROFILESENTRY._options = None
  _MANAGEDCLUSTERS_ADDONPROFILESENTRY._serialized_options = b'8\001'
  _MANAGEDCLUSTERS_IDENTITYPROFILEENTRY._options = None
  _MANAGEDCLUSTERS_IDENTITYPROFILEENTRY._serialized_options = b'8\001'
  _MANAGEDCLUSTERS_TAGSENTRY._options = None
  _MANAGEDCLUSTERS_TAGSENTRY._serialized_options = b'8\001'
  _MANAGEDCLUSTERPODIDENTITYEXCEPTION_PODLABELSENTRY._options = None
  _MANAGEDCLUSTERPODIDENTITYEXCEPTION_PODLABELSENTRY._serialized_options = b'8\001'
  _MANAGEDCLUSTERAGENTPOOLPROFILE_NODELABELSENTRY._options = None
  _MANAGEDCLUSTERAGENTPOOLPROFILE_NODELABELSENTRY._serialized_options = b'8\001'
  _MANAGEDCLUSTERAGENTPOOLPROFILE_TAGSENTRY._options = None
  _MANAGEDCLUSTERAGENTPOOLPROFILE_TAGSENTRY._serialized_options = b'8\001'
  _MANAGEDCLUSTERIDENTITY_USERASSIGNEDIDENTITIESENTRY._options = None
  _MANAGEDCLUSTERIDENTITY_USERASSIGNEDIDENTITIESENTRY._serialized_options = b'8\001'
  _MICROSOFT_CONTAINERSERVICE._serialized_start=116
  _MICROSOFT_CONTAINERSERVICE._serialized_end=344
  _SNAPSHOTS._serialized_start=347
  _SNAPSHOTS._serialized_end=679
  _SNAPSHOTS_TAGSENTRY._serialized_start=636
  _SNAPSHOTS_TAGSENTRY._serialized_end=679
  _MANAGEDCLUSTERSPRIVATEENDPOINTCONNECTIONS._serialized_start=682
  _MANAGEDCLUSTERSPRIVATEENDPOINTCONNECTIONS._serialized_end=1013
  _PRIVATELINKSERVICECONNECTIONSTATE._serialized_start=1015
  _PRIVATELINKSERVICECONNECTIONSTATE._serialized_end=1087
  _PRIVATEENDPOINT._serialized_start=1089
  _PRIVATEENDPOINT._serialized_end=1118
  _MANAGEDCLUSTERSMAINTENANCECONFIGURATIONS._serialized_start=1121
  _MANAGEDCLUSTERSMAINTENANCECONFIGURATIONS._serialized_end=1396
  _TIMEINWEEK._serialized_start=1398
  _TIMEINWEEK._serialized_end=1443
  _TIMESPAN._serialized_start=1445
  _TIMESPAN._serialized_end=1483
  _MANAGEDCLUSTERSAGENTPOOLS._serialized_start=1486
  _MANAGEDCLUSTERSAGENTPOOLS._serialized_end=3139
  _MANAGEDCLUSTERSAGENTPOOLS_NODELABELSENTRY._serialized_start=3045
  _MANAGEDCLUSTERSAGENTPOOLS_NODELABELSENTRY._serialized_end=3094
  _MANAGEDCLUSTERSAGENTPOOLS_TAGSENTRY._serialized_start=636
  _MANAGEDCLUSTERSAGENTPOOLS_TAGSENTRY._serialized_end=679
  _MANAGEDCLUSTERS._serialized_start=3142
  _MANAGEDCLUSTERS._serialized_end=6033
  _MANAGEDCLUSTERS_ADDONPROFILESENTRY._serialized_start=5880
  _MANAGEDCLUSTERS_ADDONPROFILESENTRY._serialized_end=5932
  _MANAGEDCLUSTERS_IDENTITYPROFILEENTRY._serialized_start=5934
  _MANAGEDCLUSTERS_IDENTITYPROFILEENTRY._serialized_end=5988
  _MANAGEDCLUSTERS_TAGSENTRY._serialized_start=636
  _MANAGEDCLUSTERS_TAGSENTRY._serialized_end=679
  _MANAGEDCLUSTERSKU._serialized_start=6035
  _MANAGEDCLUSTERSKU._serialized_end=6082
  _MANAGEDCLUSTERWINDOWSPROFILE._serialized_start=6085
  _MANAGEDCLUSTERWINDOWSPROFILE._serialized_end=6299
  _WINDOWSGMSAPROFILE._serialized_start=6301
  _WINDOWSGMSAPROFILE._serialized_end=6384
  _MANAGEDCLUSTERSERVICEPRINCIPALPROFILE._serialized_start=6386
  _MANAGEDCLUSTERSERVICEPRINCIPALPROFILE._serialized_end=6460
  _MANAGEDCLUSTERSECURITYPROFILE._serialized_start=6463
  _MANAGEDCLUSTERSECURITYPROFILE._serialized_end=6608
  _MANAGEDCLUSTERSECURITYPROFILEAZUREDEFENDER._serialized_start=6610
  _MANAGEDCLUSTERSECURITYPROFILEAZUREDEFENDER._serialized_end=6716
  _PRIVATELINKRESOURCE._serialized_start=6718
  _PRIVATELINKRESOURCE._serialized_end=6823
  _MANAGEDCLUSTERPODIDENTITYPROFILE._serialized_start=6826
  _MANAGEDCLUSTERPODIDENTITYPROFILE._serialized_end=7147
  _MANAGEDCLUSTERPODIDENTITYEXCEPTION._serialized_start=7150
  _MANAGEDCLUSTERPODIDENTITYEXCEPTION._serialized_end=7386
  _MANAGEDCLUSTERPODIDENTITYEXCEPTION_PODLABELSENTRY._serialized_start=7338
  _MANAGEDCLUSTERPODIDENTITYEXCEPTION_PODLABELSENTRY._serialized_end=7386
  _MANAGEDCLUSTERPODIDENTITY._serialized_start=7389
  _MANAGEDCLUSTERPODIDENTITY._serialized_end=7561
  _USERASSIGNEDIDENTITY._serialized_start=7563
  _USERASSIGNEDIDENTITY._serialized_end=7644
  _MANAGEDCLUSTEROIDCISSUERPROFILE._serialized_start=7646
  _MANAGEDCLUSTEROIDCISSUERPROFILE._serialized_end=7696
  _CONTAINERSERVICENETWORKPROFILE._serialized_start=7699
  _CONTAINERSERVICENETWORKPROFILE._serialized_end=8226
  _MANAGEDCLUSTERNATGATEWAYPROFILE._serialized_start=8229
  _MANAGEDCLUSTERNATGATEWAYPROFILE._serialized_end=8515
  _MANAGEDCLUSTERMANAGEDOUTBOUNDIPPROFILE._serialized_start=8517
  _MANAGEDCLUSTERMANAGEDOUTBOUNDIPPROFILE._serialized_end=8572
  _MANAGEDCLUSTERLOADBALANCERPROFILE._serialized_start=8575
  _MANAGEDCLUSTERLOADBALANCERPROFILE._serialized_end=9195
  _MANAGEDCLUSTERLOADBALANCERPROFILEOUTBOUNDIPS._serialized_start=9198
  _MANAGEDCLUSTERLOADBALANCERPROFILEOUTBOUNDIPS._serialized_end=9329
  _MANAGEDCLUSTERLOADBALANCERPROFILEOUTBOUNDIPPREFIXES._serialized_start=9332
  _MANAGEDCLUSTERLOADBALANCERPROFILEOUTBOUNDIPPREFIXES._serialized_end=9478
  _MANAGEDCLUSTERLOADBALANCERPROFILEMANAGEDOUTBOUNDIPS._serialized_start=9480
  _MANAGEDCLUSTERLOADBALANCERPROFILEMANAGEDOUTBOUNDIPS._serialized_end=9568
  _RESOURCEREFERENCE._serialized_start=9570
  _RESOURCEREFERENCE._serialized_end=9601
  _CONTAINERSERVICELINUXPROFILE._serialized_start=9604
  _CONTAINERSERVICELINUXPROFILE._serialized_end=9751
  _CONTAINERSERVICESSHCONFIGURATION._serialized_start=9754
  _CONTAINERSERVICESSHCONFIGURATION._serialized_end=9885
  _CONTAINERSERVICESSHPUBLICKEY._serialized_start=9887
  _CONTAINERSERVICESSHPUBLICKEY._serialized_end=9935
  _MANAGEDCLUSTERHTTPPROXYCONFIG._serialized_start=9937
  _MANAGEDCLUSTERHTTPPROXYCONFIG._serialized_end=10047
  _MANAGEDCLUSTERAUTOUPGRADEPROFILE._serialized_start=10049
  _MANAGEDCLUSTERAUTOUPGRADEPROFILE._serialized_end=10108
  _MANAGEDCLUSTERPROPERTIESAUTOSCALERPROFILE._serialized_start=10111
  _MANAGEDCLUSTERPROPERTIESAUTOSCALERPROFILE._serialized_end=10736
  _MANAGEDCLUSTERAPISERVERACCESSPROFILE._serialized_start=10739
  _MANAGEDCLUSTERAPISERVERACCESSPROFILE._serialized_end=10938
  _MANAGEDCLUSTERAGENTPOOLPROFILE._serialized_start=10941
  _MANAGEDCLUSTERAGENTPOOLPROFILE._serialized_end=12552
  _MANAGEDCLUSTERAGENTPOOLPROFILE_NODELABELSENTRY._serialized_start=3045
  _MANAGEDCLUSTERAGENTPOOLPROFILE_NODELABELSENTRY._serialized_end=3094
  _MANAGEDCLUSTERAGENTPOOLPROFILE_TAGSENTRY._serialized_start=636
  _MANAGEDCLUSTERAGENTPOOLPROFILE_TAGSENTRY._serialized_end=679
  _AGENTPOOLUPGRADESETTINGS._serialized_start=12554
  _AGENTPOOLUPGRADESETTINGS._serialized_end=12599
  _POWERSTATE._serialized_start=12601
  _POWERSTATE._serialized_end=12627
  _LINUXOSCONFIG._serialized_start=12630
  _LINUXOSCONFIG._serialized_end=12826
  _SYSCTLCONFIG._serialized_start=12829
  _SYSCTLCONFIG._serialized_end=13766
  _KUBELETCONFIG._serialized_start=13769
  _KUBELETCONFIG._serialized_end=14107
  _CREATIONDATA._serialized_start=14109
  _CREATIONDATA._serialized_end=14151
  _MANAGEDCLUSTERAADPROFILE._serialized_start=14154
  _MANAGEDCLUSTERAADPROFILE._serialized_end=14348
  _MANAGEDCLUSTERIDENTITY._serialized_start=14351
  _MANAGEDCLUSTERIDENTITY._serialized_end=14585
  _MANAGEDCLUSTERIDENTITY_USERASSIGNEDIDENTITIESENTRY._serialized_start=14524
  _MANAGEDCLUSTERIDENTITY_USERASSIGNEDIDENTITIESENTRY._serialized_end=14585
  _EXTENDEDLOCATION._serialized_start=14587
  _EXTENDEDLOCATION._serialized_end=14633
# @@protoc_insertion_point(module_scope)
