"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ApplicationRecordColumn(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    MAPPING_FIELD_NUMBER: builtins.int
    SQL_TYPE_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    mapping: builtins.str
    sql_type: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        mapping: builtins.str = ...,
        sql_type: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["mapping", b"mapping", "name", b"name", "resource_info", b"resource_info", "sql_type", b"sql_type"]) -> None: ...

global___ApplicationRecordColumn = ApplicationRecordColumn

@typing_extensions.final
class ApplicationJSONMappingParameters(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    RECORD_ROW_PATH_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    record_row_path: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        record_row_path: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["record_row_path", b"record_row_path", "resource_info", b"resource_info"]) -> None: ...

global___ApplicationJSONMappingParameters = ApplicationJSONMappingParameters

@typing_extensions.final
class ApplicationCSVMappingParameters(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    RECORD_ROW_DELIMITER_FIELD_NUMBER: builtins.int
    RECORD_COLUMN_DELIMITER_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    record_row_delimiter: builtins.str
    record_column_delimiter: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        record_row_delimiter: builtins.str = ...,
        record_column_delimiter: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["record_column_delimiter", b"record_column_delimiter", "record_row_delimiter", b"record_row_delimiter", "resource_info", b"resource_info"]) -> None: ...

global___ApplicationCSVMappingParameters = ApplicationCSVMappingParameters

@typing_extensions.final
class ApplicationMappingParameters(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    JSON_MAPPING_PARAMETERS_FIELD_NUMBER: builtins.int
    CS_V_MAPPING_PARAMETERS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def json_mapping_parameters(self) -> global___ApplicationJSONMappingParameters: ...
    @property
    def cs_v_mapping_parameters(self) -> global___ApplicationCSVMappingParameters: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        json_mapping_parameters: global___ApplicationJSONMappingParameters | None = ...,
        cs_v_mapping_parameters: global___ApplicationCSVMappingParameters | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cs_v_mapping_parameters", b"cs_v_mapping_parameters", "json_mapping_parameters", b"json_mapping_parameters", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cs_v_mapping_parameters", b"cs_v_mapping_parameters", "json_mapping_parameters", b"json_mapping_parameters", "resource_info", b"resource_info"]) -> None: ...

global___ApplicationMappingParameters = ApplicationMappingParameters

@typing_extensions.final
class ApplicationRecordFormat(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    MAPPING_PARAMETERS_FIELD_NUMBER: builtins.int
    RECORD_FORMAT_TYPE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def mapping_parameters(self) -> global___ApplicationMappingParameters: ...
    record_format_type: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        mapping_parameters: global___ApplicationMappingParameters | None = ...,
        record_format_type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["mapping_parameters", b"mapping_parameters", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["mapping_parameters", b"mapping_parameters", "record_format_type", b"record_format_type", "resource_info", b"resource_info"]) -> None: ...

global___ApplicationRecordFormat = ApplicationRecordFormat

@typing_extensions.final
class ApplicationInputSchema(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    RECORD_ENCODING_FIELD_NUMBER: builtins.int
    RECORD_COLUMNS_FIELD_NUMBER: builtins.int
    RECORD_FORMAT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    record_encoding: builtins.str
    @property
    def record_columns(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApplicationRecordColumn]: ...
    @property
    def record_format(self) -> global___ApplicationRecordFormat: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        record_encoding: builtins.str = ...,
        record_columns: collections.abc.Iterable[global___ApplicationRecordColumn] | None = ...,
        record_format: global___ApplicationRecordFormat | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["record_format", b"record_format", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["record_columns", b"record_columns", "record_encoding", b"record_encoding", "record_format", b"record_format", "resource_info", b"resource_info"]) -> None: ...

global___ApplicationInputSchema = ApplicationInputSchema

@typing_extensions.final
class ApplicationKinesisStreamsInput(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    RESOURCE_ARN_FIELD_NUMBER: builtins.int
    ROLE_ARN_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    resource_arn: builtins.str
    role_arn: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        resource_arn: builtins.str = ...,
        role_arn: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_arn", b"resource_arn", "resource_info", b"resource_info", "role_arn", b"role_arn"]) -> None: ...

global___ApplicationKinesisStreamsInput = ApplicationKinesisStreamsInput

@typing_extensions.final
class ApplicationKinesisFirehoseInput(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    RESOURCE_ARN_FIELD_NUMBER: builtins.int
    ROLE_ARN_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    resource_arn: builtins.str
    role_arn: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        resource_arn: builtins.str = ...,
        role_arn: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_arn", b"resource_arn", "resource_info", b"resource_info", "role_arn", b"role_arn"]) -> None: ...

global___ApplicationKinesisFirehoseInput = ApplicationKinesisFirehoseInput

@typing_extensions.final
class ApplicationInputLambdaProcessor(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    RESOURCE_ARN_FIELD_NUMBER: builtins.int
    ROLE_ARN_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    resource_arn: builtins.str
    role_arn: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        resource_arn: builtins.str = ...,
        role_arn: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_arn", b"resource_arn", "resource_info", b"resource_info", "role_arn", b"role_arn"]) -> None: ...

global___ApplicationInputLambdaProcessor = ApplicationInputLambdaProcessor

@typing_extensions.final
class ApplicationInputProcessingConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    INPUT_LAMBDA_PROCESSOR_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def input_lambda_processor(self) -> global___ApplicationInputLambdaProcessor: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        input_lambda_processor: global___ApplicationInputLambdaProcessor | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["input_lambda_processor", b"input_lambda_processor", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["input_lambda_processor", b"input_lambda_processor", "resource_info", b"resource_info"]) -> None: ...

global___ApplicationInputProcessingConfiguration = ApplicationInputProcessingConfiguration

@typing_extensions.final
class ApplicationInputParallelism(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    COUNT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    count: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        count: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["count", b"count", "resource_info", b"resource_info"]) -> None: ...

global___ApplicationInputParallelism = ApplicationInputParallelism

@typing_extensions.final
class ApplicationInput(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_PREFIX_FIELD_NUMBER: builtins.int
    INPUT_SCHEMA_FIELD_NUMBER: builtins.int
    KINESIS_STREAMS_INPUT_FIELD_NUMBER: builtins.int
    KINESIS_FIREHOSE_INPUT_FIELD_NUMBER: builtins.int
    INPUT_PROCESSING_CONFIGURATION_FIELD_NUMBER: builtins.int
    INPUT_PARALLELISM_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name_prefix: builtins.str
    @property
    def input_schema(self) -> global___ApplicationInputSchema: ...
    @property
    def kinesis_streams_input(self) -> global___ApplicationKinesisStreamsInput: ...
    @property
    def kinesis_firehose_input(self) -> global___ApplicationKinesisFirehoseInput: ...
    @property
    def input_processing_configuration(self) -> global___ApplicationInputProcessingConfiguration: ...
    @property
    def input_parallelism(self) -> global___ApplicationInputParallelism: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name_prefix: builtins.str = ...,
        input_schema: global___ApplicationInputSchema | None = ...,
        kinesis_streams_input: global___ApplicationKinesisStreamsInput | None = ...,
        kinesis_firehose_input: global___ApplicationKinesisFirehoseInput | None = ...,
        input_processing_configuration: global___ApplicationInputProcessingConfiguration | None = ...,
        input_parallelism: global___ApplicationInputParallelism | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["input_parallelism", b"input_parallelism", "input_processing_configuration", b"input_processing_configuration", "input_schema", b"input_schema", "kinesis_firehose_input", b"kinesis_firehose_input", "kinesis_streams_input", b"kinesis_streams_input", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["input_parallelism", b"input_parallelism", "input_processing_configuration", b"input_processing_configuration", "input_schema", b"input_schema", "kinesis_firehose_input", b"kinesis_firehose_input", "kinesis_streams_input", b"kinesis_streams_input", "name_prefix", b"name_prefix", "resource_info", b"resource_info"]) -> None: ...

global___ApplicationInput = ApplicationInput

@typing_extensions.final
class Application(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    APPLICATION_NAME_FIELD_NUMBER: builtins.int
    INPUTS_FIELD_NUMBER: builtins.int
    APPLICATION_DESCRIPTION_FIELD_NUMBER: builtins.int
    APPLICATION_CODE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    application_name: builtins.str
    @property
    def inputs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApplicationInput]: ...
    application_description: builtins.str
    application_code: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        application_name: builtins.str = ...,
        inputs: collections.abc.Iterable[global___ApplicationInput] | None = ...,
        application_description: builtins.str = ...,
        application_code: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["application_code", b"application_code", "application_description", b"application_description", "application_name", b"application_name", "inputs", b"inputs", "resource_info", b"resource_info"]) -> None: ...

global___Application = Application

@typing_extensions.final
class KinesisAnalytics(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLICATION_FIELD_NUMBER: builtins.int
    APPLICATION_OUTPUT_FIELD_NUMBER: builtins.int
    APPLICATION_REFERENCE_DATA_SOURCE_FIELD_NUMBER: builtins.int
    @property
    def application(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Application]: ...
    @property
    def application_output(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApplicationOutput]: ...
    @property
    def application_reference_data_source(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApplicationReferenceDataSource]: ...
    def __init__(
        self,
        *,
        application: collections.abc.Iterable[global___Application] | None = ...,
        application_output: collections.abc.Iterable[global___ApplicationOutput] | None = ...,
        application_reference_data_source: collections.abc.Iterable[global___ApplicationReferenceDataSource] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["application", b"application", "application_output", b"application_output", "application_reference_data_source", b"application_reference_data_source"]) -> None: ...

global___KinesisAnalytics = KinesisAnalytics

@typing_extensions.final
class ApplicationOutputDestinationSchema(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    RECORD_FORMAT_TYPE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    record_format_type: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        record_format_type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["record_format_type", b"record_format_type", "resource_info", b"resource_info"]) -> None: ...

global___ApplicationOutputDestinationSchema = ApplicationOutputDestinationSchema

@typing_extensions.final
class ApplicationOutputLambdaOutput(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    RESOURCE_ARN_FIELD_NUMBER: builtins.int
    ROLE_ARN_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    resource_arn: builtins.str
    role_arn: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        resource_arn: builtins.str = ...,
        role_arn: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_arn", b"resource_arn", "resource_info", b"resource_info", "role_arn", b"role_arn"]) -> None: ...

global___ApplicationOutputLambdaOutput = ApplicationOutputLambdaOutput

@typing_extensions.final
class ApplicationOutputKinesisFirehoseOutput(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    RESOURCE_ARN_FIELD_NUMBER: builtins.int
    ROLE_ARN_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    resource_arn: builtins.str
    role_arn: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        resource_arn: builtins.str = ...,
        role_arn: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_arn", b"resource_arn", "resource_info", b"resource_info", "role_arn", b"role_arn"]) -> None: ...

global___ApplicationOutputKinesisFirehoseOutput = ApplicationOutputKinesisFirehoseOutput

@typing_extensions.final
class ApplicationOutputKinesisStreamsOutput(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    RESOURCE_ARN_FIELD_NUMBER: builtins.int
    ROLE_ARN_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    resource_arn: builtins.str
    role_arn: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        resource_arn: builtins.str = ...,
        role_arn: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_arn", b"resource_arn", "resource_info", b"resource_info", "role_arn", b"role_arn"]) -> None: ...

global___ApplicationOutputKinesisStreamsOutput = ApplicationOutputKinesisStreamsOutput

@typing_extensions.final
class ApplicationOutputOutput(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DESTINATION_SCHEMA_FIELD_NUMBER: builtins.int
    LAMBDA_OUTPUT_FIELD_NUMBER: builtins.int
    KINESIS_FIREHOSE_OUTPUT_FIELD_NUMBER: builtins.int
    KINESIS_STREAMS_OUTPUT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def destination_schema(self) -> global___ApplicationOutputDestinationSchema: ...
    @property
    def lambda_output(self) -> global___ApplicationOutputLambdaOutput: ...
    @property
    def kinesis_firehose_output(self) -> global___ApplicationOutputKinesisFirehoseOutput: ...
    @property
    def kinesis_streams_output(self) -> global___ApplicationOutputKinesisStreamsOutput: ...
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        destination_schema: global___ApplicationOutputDestinationSchema | None = ...,
        lambda_output: global___ApplicationOutputLambdaOutput | None = ...,
        kinesis_firehose_output: global___ApplicationOutputKinesisFirehoseOutput | None = ...,
        kinesis_streams_output: global___ApplicationOutputKinesisStreamsOutput | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["destination_schema", b"destination_schema", "kinesis_firehose_output", b"kinesis_firehose_output", "kinesis_streams_output", b"kinesis_streams_output", "lambda_output", b"lambda_output", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["destination_schema", b"destination_schema", "kinesis_firehose_output", b"kinesis_firehose_output", "kinesis_streams_output", b"kinesis_streams_output", "lambda_output", b"lambda_output", "name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___ApplicationOutputOutput = ApplicationOutputOutput

@typing_extensions.final
class ApplicationOutput(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    APPLICATION_NAME_FIELD_NUMBER: builtins.int
    OUTPUT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    application_name: builtins.str
    @property
    def output(self) -> global___ApplicationOutputOutput: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        application_name: builtins.str = ...,
        output: global___ApplicationOutputOutput | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["output", b"output", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["application_name", b"application_name", "output", b"output", "resource_info", b"resource_info"]) -> None: ...

global___ApplicationOutput = ApplicationOutput

@typing_extensions.final
class ApplicationReferenceDataSourceRecordColumn(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    MAPPING_FIELD_NUMBER: builtins.int
    SQL_TYPE_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    mapping: builtins.str
    sql_type: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        mapping: builtins.str = ...,
        sql_type: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["mapping", b"mapping", "name", b"name", "resource_info", b"resource_info", "sql_type", b"sql_type"]) -> None: ...

global___ApplicationReferenceDataSourceRecordColumn = ApplicationReferenceDataSourceRecordColumn

@typing_extensions.final
class ApplicationReferenceDataSourceJSONMappingParameters(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    RECORD_ROW_PATH_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    record_row_path: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        record_row_path: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["record_row_path", b"record_row_path", "resource_info", b"resource_info"]) -> None: ...

global___ApplicationReferenceDataSourceJSONMappingParameters = ApplicationReferenceDataSourceJSONMappingParameters

@typing_extensions.final
class ApplicationReferenceDataSourceCSVMappingParameters(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    RECORD_ROW_DELIMITER_FIELD_NUMBER: builtins.int
    RECORD_COLUMN_DELIMITER_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    record_row_delimiter: builtins.str
    record_column_delimiter: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        record_row_delimiter: builtins.str = ...,
        record_column_delimiter: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["record_column_delimiter", b"record_column_delimiter", "record_row_delimiter", b"record_row_delimiter", "resource_info", b"resource_info"]) -> None: ...

global___ApplicationReferenceDataSourceCSVMappingParameters = ApplicationReferenceDataSourceCSVMappingParameters

@typing_extensions.final
class ApplicationReferenceDataSourceMappingParameters(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    JSON_MAPPING_PARAMETERS_FIELD_NUMBER: builtins.int
    CS_V_MAPPING_PARAMETERS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def json_mapping_parameters(self) -> global___ApplicationReferenceDataSourceJSONMappingParameters: ...
    @property
    def cs_v_mapping_parameters(self) -> global___ApplicationReferenceDataSourceCSVMappingParameters: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        json_mapping_parameters: global___ApplicationReferenceDataSourceJSONMappingParameters | None = ...,
        cs_v_mapping_parameters: global___ApplicationReferenceDataSourceCSVMappingParameters | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cs_v_mapping_parameters", b"cs_v_mapping_parameters", "json_mapping_parameters", b"json_mapping_parameters", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cs_v_mapping_parameters", b"cs_v_mapping_parameters", "json_mapping_parameters", b"json_mapping_parameters", "resource_info", b"resource_info"]) -> None: ...

global___ApplicationReferenceDataSourceMappingParameters = ApplicationReferenceDataSourceMappingParameters

@typing_extensions.final
class ApplicationReferenceDataSourceRecordFormat(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    MAPPING_PARAMETERS_FIELD_NUMBER: builtins.int
    RECORD_FORMAT_TYPE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def mapping_parameters(self) -> global___ApplicationReferenceDataSourceMappingParameters: ...
    record_format_type: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        mapping_parameters: global___ApplicationReferenceDataSourceMappingParameters | None = ...,
        record_format_type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["mapping_parameters", b"mapping_parameters", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["mapping_parameters", b"mapping_parameters", "record_format_type", b"record_format_type", "resource_info", b"resource_info"]) -> None: ...

global___ApplicationReferenceDataSourceRecordFormat = ApplicationReferenceDataSourceRecordFormat

@typing_extensions.final
class ApplicationReferenceDataSourceReferenceSchema(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    RECORD_ENCODING_FIELD_NUMBER: builtins.int
    RECORD_COLUMNS_FIELD_NUMBER: builtins.int
    RECORD_FORMAT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    record_encoding: builtins.str
    @property
    def record_columns(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApplicationReferenceDataSourceRecordColumn]: ...
    @property
    def record_format(self) -> global___ApplicationReferenceDataSourceRecordFormat: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        record_encoding: builtins.str = ...,
        record_columns: collections.abc.Iterable[global___ApplicationReferenceDataSourceRecordColumn] | None = ...,
        record_format: global___ApplicationReferenceDataSourceRecordFormat | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["record_format", b"record_format", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["record_columns", b"record_columns", "record_encoding", b"record_encoding", "record_format", b"record_format", "resource_info", b"resource_info"]) -> None: ...

global___ApplicationReferenceDataSourceReferenceSchema = ApplicationReferenceDataSourceReferenceSchema

@typing_extensions.final
class ApplicationReferenceDataSourceS3ReferenceDataSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    BUCKET_ARN_FIELD_NUMBER: builtins.int
    FILE_KEY_FIELD_NUMBER: builtins.int
    REFERENCE_ROLE_ARN_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    bucket_arn: builtins.str
    file_key: builtins.str
    reference_role_arn: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        bucket_arn: builtins.str = ...,
        file_key: builtins.str = ...,
        reference_role_arn: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bucket_arn", b"bucket_arn", "file_key", b"file_key", "reference_role_arn", b"reference_role_arn", "resource_info", b"resource_info"]) -> None: ...

global___ApplicationReferenceDataSourceS3ReferenceDataSource = ApplicationReferenceDataSourceS3ReferenceDataSource

@typing_extensions.final
class ApplicationReferenceDataSourceReferenceDataSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    REFERENCE_SCHEMA_FIELD_NUMBER: builtins.int
    TABLE_NAME_FIELD_NUMBER: builtins.int
    S3_REFERENCE_DATA_SOURCE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def reference_schema(self) -> global___ApplicationReferenceDataSourceReferenceSchema: ...
    table_name: builtins.str
    @property
    def s3_reference_data_source(self) -> global___ApplicationReferenceDataSourceS3ReferenceDataSource: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        reference_schema: global___ApplicationReferenceDataSourceReferenceSchema | None = ...,
        table_name: builtins.str = ...,
        s3_reference_data_source: global___ApplicationReferenceDataSourceS3ReferenceDataSource | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["reference_schema", b"reference_schema", "resource_info", b"resource_info", "s3_reference_data_source", b"s3_reference_data_source"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["reference_schema", b"reference_schema", "resource_info", b"resource_info", "s3_reference_data_source", b"s3_reference_data_source", "table_name", b"table_name"]) -> None: ...

global___ApplicationReferenceDataSourceReferenceDataSource = ApplicationReferenceDataSourceReferenceDataSource

@typing_extensions.final
class ApplicationReferenceDataSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    APPLICATION_NAME_FIELD_NUMBER: builtins.int
    REFERENCE_DATA_SOURCE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    application_name: builtins.str
    @property
    def reference_data_source(self) -> global___ApplicationReferenceDataSourceReferenceDataSource: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        application_name: builtins.str = ...,
        reference_data_source: global___ApplicationReferenceDataSourceReferenceDataSource | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["reference_data_source", b"reference_data_source", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["application_name", b"application_name", "reference_data_source", b"reference_data_source", "resource_info", b"resource_info"]) -> None: ...

global___ApplicationReferenceDataSource = ApplicationReferenceDataSource
