# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_codeguruprofiler.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x61ws/aws_codeguruprofiler.proto\x12 oak9.tython.aws.codeguruprofiler\x1a\x13shared/shared.proto\"y\n\x15ProfilingGroupChannel\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\nchannel_id\x18\x02 \x01(\t\x12\x13\n\x0b\x63hannel_uri\x18\x03 \x01(\t\"\x83\x04\n\x0eProfilingGroup\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1c\n\x14profiling_group_name\x18\x02 \x01(\t\x12\x18\n\x10\x63ompute_platform\x18\x03 \x01(\t\x12\x61\n\x11\x61gent_permissions\x18\x04 \x03(\x0b\x32\x46.oak9.tython.aws.codeguruprofiler.ProfilingGroup.AgentPermissionsEntry\x12m\n,anomaly_detection_notification_configuration\x18\x05 \x03(\x0b\x32\x37.oak9.tython.aws.codeguruprofiler.ProfilingGroupChannel\x12H\n\x04tags\x18\x06 \x03(\x0b\x32:.oak9.tython.aws.codeguruprofiler.ProfilingGroup.TagsEntry\x1a\x37\n\x15\x41gentPermissionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"]\n\x10\x43odeGuruProfiler\x12I\n\x0fprofiling_group\x18\x01 \x03(\x0b\x32\x30.oak9.tython.aws.codeguruprofiler.ProfilingGroupb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_codeguruprofiler_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _PROFILINGGROUP_AGENTPERMISSIONSENTRY._options = None
  _PROFILINGGROUP_AGENTPERMISSIONSENTRY._serialized_options = b'8\001'
  _PROFILINGGROUP_TAGSENTRY._options = None
  _PROFILINGGROUP_TAGSENTRY._serialized_options = b'8\001'
  _PROFILINGGROUPCHANNEL._serialized_start=89
  _PROFILINGGROUPCHANNEL._serialized_end=210
  _PROFILINGGROUP._serialized_start=213
  _PROFILINGGROUP._serialized_end=728
  _PROFILINGGROUP_AGENTPERMISSIONSENTRY._serialized_start=628
  _PROFILINGGROUP_AGENTPERMISSIONSENTRY._serialized_end=683
  _PROFILINGGROUP_TAGSENTRY._serialized_start=685
  _PROFILINGGROUP_TAGSENTRY._serialized_end=728
  _CODEGURUPROFILER._serialized_start=730
  _CODEGURUPROFILER._serialized_end=823
# @@protoc_insertion_point(module_scope)
