"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Microsoft_Devices(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IOT_HUBS_FIELD_NUMBER: builtins.int
    IOT_HUBS_CERTIFICATES_FIELD_NUMBER: builtins.int
    IOT_HUBS_PRIVATE_ENDPOINT_CONNECTIONS_FIELD_NUMBER: builtins.int
    @property
    def iot_hubs(self) -> global___IotHubs: ...
    @property
    def iot_hubs_certificates(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___IotHubsCertificates]: ...
    @property
    def iot_hubs_private_endpoint_connections(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___IotHubsPrivateEndpointConnections]: ...
    def __init__(
        self,
        *,
        iot_hubs: global___IotHubs | None = ...,
        iot_hubs_certificates: collections.abc.Iterable[global___IotHubsCertificates] | None = ...,
        iot_hubs_private_endpoint_connections: collections.abc.Iterable[global___IotHubsPrivateEndpointConnections] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["iot_hubs", b"iot_hubs"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["iot_hubs", b"iot_hubs", "iot_hubs_certificates", b"iot_hubs_certificates", "iot_hubs_private_endpoint_connections", b"iot_hubs_private_endpoint_connections"]) -> None: ...

global___Microsoft_Devices = Microsoft_Devices

@typing_extensions.final
class Properties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLE_FILE_UPLOAD_NOTIFICATIONS_FIELD_NUMBER: builtins.int
    MIN_TLS_VERSION_FIELD_NUMBER: builtins.int
    PUBLIC_NETWORK_ACCESS_FIELD_NUMBER: builtins.int
    enable_file_upload_notifications: builtins.bool
    min_tls_version: builtins.str
    public_network_access: builtins.str
    def __init__(
        self,
        *,
        enable_file_upload_notifications: builtins.bool = ...,
        min_tls_version: builtins.str = ...,
        public_network_access: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["enable_file_upload_notifications", b"enable_file_upload_notifications", "min_tls_version", b"min_tls_version", "public_network_access", b"public_network_access"]) -> None: ...

global___Properties = Properties

@typing_extensions.final
class IotHubsPrivateEndpointConnections(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PRIVATE_ENDPOINT_FIELD_NUMBER: builtins.int
    PRIVATE_LINK_SERVICE_CONNECTION_STATE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def private_endpoint(self) -> global___PrivateEndpoint: ...
    @property
    def private_link_service_connection_state(self) -> global___PrivateLinkServiceConnectionState: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        private_endpoint: global___PrivateEndpoint | None = ...,
        private_link_service_connection_state: global___PrivateLinkServiceConnectionState | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["private_endpoint", b"private_endpoint", "private_link_service_connection_state", b"private_link_service_connection_state", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "private_endpoint", b"private_endpoint", "private_link_service_connection_state", b"private_link_service_connection_state", "resource_info", b"resource_info"]) -> None: ...

global___IotHubsPrivateEndpointConnections = IotHubsPrivateEndpointConnections

@typing_extensions.final
class IotHubsEventHubEndpointsConsumerGroups(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___IotHubsEventHubEndpointsConsumerGroups = IotHubsEventHubEndpointsConsumerGroups

@typing_extensions.final
class IotHubsCertificates(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    CERTIFICATE_FIELD_NUMBER: builtins.int
    IS_VERIFIED_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    certificate: builtins.str
    is_verified: builtins.bool
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        certificate: builtins.str = ...,
        is_verified: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["certificate", b"certificate", "is_verified", b"is_verified", "name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___IotHubsCertificates = IotHubsCertificates

@typing_extensions.final
class IotHubs(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class EventHubEndpointsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class MessagingEndpointsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class StorageEndpointsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    IDENTITY_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ALLOWED_FQDN_LIST_FIELD_NUMBER: builtins.int
    AUTHORIZATION_POLICIES_FIELD_NUMBER: builtins.int
    CLOUD_TO_DEVICE_FIELD_NUMBER: builtins.int
    COMMENTS_FIELD_NUMBER: builtins.int
    DISABLE_DEVICE_S_A_S_FIELD_NUMBER: builtins.int
    DISABLE_LOCAL_AUTH_FIELD_NUMBER: builtins.int
    DISABLE_MODULE_S_A_S_FIELD_NUMBER: builtins.int
    ENABLE_DATA_RESIDENCY_FIELD_NUMBER: builtins.int
    EVENT_HUB_ENDPOINTS_FIELD_NUMBER: builtins.int
    FEATURES_FIELD_NUMBER: builtins.int
    IP_FILTER_RULES_FIELD_NUMBER: builtins.int
    MESSAGING_ENDPOINTS_FIELD_NUMBER: builtins.int
    NETWORK_RULE_SETS_FIELD_NUMBER: builtins.int
    PRIVATE_ENDPOINT_CONNECTIONS_FIELD_NUMBER: builtins.int
    RESTRICT_OUTBOUND_NETWORK_ACCESS_FIELD_NUMBER: builtins.int
    ROUTING_FIELD_NUMBER: builtins.int
    STORAGE_ENDPOINTS_FIELD_NUMBER: builtins.int
    SKU_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    PROPERTIES_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    etag: builtins.str
    @property
    def identity(self) -> global___ArmIdentity: ...
    location: builtins.str
    name: builtins.str
    @property
    def allowed_fqdn_list(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def authorization_policies(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SharedAccessSignatureAuthorizationRule]: ...
    @property
    def cloud_to_device(self) -> global___CloudToDeviceProperties: ...
    comments: builtins.str
    disable_device_s_a_s: builtins.bool
    disable_local_auth: builtins.bool
    disable_module_s_a_s: builtins.bool
    enable_data_residency: builtins.bool
    @property
    def event_hub_endpoints(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    features: builtins.str
    @property
    def ip_filter_rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___IpFilterRule]: ...
    @property
    def messaging_endpoints(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def network_rule_sets(self) -> global___NetworkRuleSetProperties: ...
    @property
    def private_endpoint_connections(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PrivateEndpointConnection]: ...
    restrict_outbound_network_access: builtins.bool
    @property
    def routing(self) -> global___RoutingProperties: ...
    @property
    def storage_endpoints(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def sku(self) -> global___IotHubSkuInfo: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def properties(self) -> global___Properties: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        etag: builtins.str = ...,
        identity: global___ArmIdentity | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        allowed_fqdn_list: collections.abc.Iterable[builtins.str] | None = ...,
        authorization_policies: collections.abc.Iterable[global___SharedAccessSignatureAuthorizationRule] | None = ...,
        cloud_to_device: global___CloudToDeviceProperties | None = ...,
        comments: builtins.str = ...,
        disable_device_s_a_s: builtins.bool = ...,
        disable_local_auth: builtins.bool = ...,
        disable_module_s_a_s: builtins.bool = ...,
        enable_data_residency: builtins.bool = ...,
        event_hub_endpoints: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        features: builtins.str = ...,
        ip_filter_rules: collections.abc.Iterable[global___IpFilterRule] | None = ...,
        messaging_endpoints: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        network_rule_sets: global___NetworkRuleSetProperties | None = ...,
        private_endpoint_connections: collections.abc.Iterable[global___PrivateEndpointConnection] | None = ...,
        restrict_outbound_network_access: builtins.bool = ...,
        routing: global___RoutingProperties | None = ...,
        storage_endpoints: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        sku: global___IotHubSkuInfo | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        properties: global___Properties | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cloud_to_device", b"cloud_to_device", "identity", b"identity", "network_rule_sets", b"network_rule_sets", "properties", b"properties", "resource_info", b"resource_info", "routing", b"routing", "sku", b"sku"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["allowed_fqdn_list", b"allowed_fqdn_list", "authorization_policies", b"authorization_policies", "cloud_to_device", b"cloud_to_device", "comments", b"comments", "disable_device_s_a_s", b"disable_device_s_a_s", "disable_local_auth", b"disable_local_auth", "disable_module_s_a_s", b"disable_module_s_a_s", "enable_data_residency", b"enable_data_residency", "etag", b"etag", "event_hub_endpoints", b"event_hub_endpoints", "features", b"features", "identity", b"identity", "ip_filter_rules", b"ip_filter_rules", "location", b"location", "messaging_endpoints", b"messaging_endpoints", "name", b"name", "network_rule_sets", b"network_rule_sets", "private_endpoint_connections", b"private_endpoint_connections", "properties", b"properties", "resource_info", b"resource_info", "restrict_outbound_network_access", b"restrict_outbound_network_access", "routing", b"routing", "sku", b"sku", "storage_endpoints", b"storage_endpoints", "tags", b"tags"]) -> None: ...

global___IotHubs = IotHubs

@typing_extensions.final
class IotHubSkuInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CAPACITY_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    capacity: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        capacity: builtins.int = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["capacity", b"capacity", "name", b"name"]) -> None: ...

global___IotHubSkuInfo = IotHubSkuInfo

@typing_extensions.final
class RoutingProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENDPOINTS_FIELD_NUMBER: builtins.int
    ENRICHMENTS_FIELD_NUMBER: builtins.int
    FALLBACK_ROUTE_FIELD_NUMBER: builtins.int
    ROUTES_FIELD_NUMBER: builtins.int
    @property
    def endpoints(self) -> global___RoutingEndpoints: ...
    @property
    def enrichments(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___EnrichmentProperties]: ...
    @property
    def fallback_route(self) -> global___FallbackRouteProperties: ...
    @property
    def routes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RouteProperties]: ...
    def __init__(
        self,
        *,
        endpoints: global___RoutingEndpoints | None = ...,
        enrichments: collections.abc.Iterable[global___EnrichmentProperties] | None = ...,
        fallback_route: global___FallbackRouteProperties | None = ...,
        routes: collections.abc.Iterable[global___RouteProperties] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["endpoints", b"endpoints", "fallback_route", b"fallback_route"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["endpoints", b"endpoints", "enrichments", b"enrichments", "fallback_route", b"fallback_route", "routes", b"routes"]) -> None: ...

global___RoutingProperties = RoutingProperties

@typing_extensions.final
class RouteProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONDITION_FIELD_NUMBER: builtins.int
    ENDPOINT_NAMES_FIELD_NUMBER: builtins.int
    IS_ENABLED_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    condition: builtins.str
    @property
    def endpoint_names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    is_enabled: builtins.bool
    name: builtins.str
    source: builtins.str
    def __init__(
        self,
        *,
        condition: builtins.str = ...,
        endpoint_names: collections.abc.Iterable[builtins.str] | None = ...,
        is_enabled: builtins.bool = ...,
        name: builtins.str = ...,
        source: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "endpoint_names", b"endpoint_names", "is_enabled", b"is_enabled", "name", b"name", "source", b"source"]) -> None: ...

global___RouteProperties = RouteProperties

@typing_extensions.final
class FallbackRouteProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONDITION_FIELD_NUMBER: builtins.int
    ENDPOINT_NAMES_FIELD_NUMBER: builtins.int
    IS_ENABLED_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    condition: builtins.str
    @property
    def endpoint_names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    is_enabled: builtins.bool
    name: builtins.str
    source: builtins.str
    def __init__(
        self,
        *,
        condition: builtins.str = ...,
        endpoint_names: collections.abc.Iterable[builtins.str] | None = ...,
        is_enabled: builtins.bool = ...,
        name: builtins.str = ...,
        source: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "endpoint_names", b"endpoint_names", "is_enabled", b"is_enabled", "name", b"name", "source", b"source"]) -> None: ...

global___FallbackRouteProperties = FallbackRouteProperties

@typing_extensions.final
class EnrichmentProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENDPOINT_NAMES_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    @property
    def endpoint_names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    key: builtins.str
    value: builtins.str
    def __init__(
        self,
        *,
        endpoint_names: collections.abc.Iterable[builtins.str] | None = ...,
        key: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["endpoint_names", b"endpoint_names", "key", b"key", "value", b"value"]) -> None: ...

global___EnrichmentProperties = EnrichmentProperties

@typing_extensions.final
class RoutingEndpoints(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EVENT_HUBS_FIELD_NUMBER: builtins.int
    SERVICE_BUS_QUEUES_FIELD_NUMBER: builtins.int
    SERVICE_BUS_TOPICS_FIELD_NUMBER: builtins.int
    STORAGE_CONTAINERS_FIELD_NUMBER: builtins.int
    @property
    def event_hubs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RoutingEventHubProperties]: ...
    @property
    def service_bus_queues(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RoutingServiceBusQueueEndpointProperties]: ...
    @property
    def service_bus_topics(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RoutingServiceBusTopicEndpointProperties]: ...
    @property
    def storage_containers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RoutingStorageContainerProperties]: ...
    def __init__(
        self,
        *,
        event_hubs: collections.abc.Iterable[global___RoutingEventHubProperties] | None = ...,
        service_bus_queues: collections.abc.Iterable[global___RoutingServiceBusQueueEndpointProperties] | None = ...,
        service_bus_topics: collections.abc.Iterable[global___RoutingServiceBusTopicEndpointProperties] | None = ...,
        storage_containers: collections.abc.Iterable[global___RoutingStorageContainerProperties] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["event_hubs", b"event_hubs", "service_bus_queues", b"service_bus_queues", "service_bus_topics", b"service_bus_topics", "storage_containers", b"storage_containers"]) -> None: ...

global___RoutingEndpoints = RoutingEndpoints

@typing_extensions.final
class RoutingStorageContainerProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUTHENTICATION_TYPE_FIELD_NUMBER: builtins.int
    BATCH_FREQUENCY_IN_SECONDS_FIELD_NUMBER: builtins.int
    CONNECTION_STRING_FIELD_NUMBER: builtins.int
    CONTAINER_NAME_FIELD_NUMBER: builtins.int
    ENCODING_FIELD_NUMBER: builtins.int
    ENDPOINT_URI_FIELD_NUMBER: builtins.int
    FILE_NAME_FORMAT_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    IDENTITY_FIELD_NUMBER: builtins.int
    MAX_CHUNK_SIZE_IN_BYTES_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    RESOURCE_GROUP_FIELD_NUMBER: builtins.int
    SUBSCRIPTION_ID_FIELD_NUMBER: builtins.int
    authentication_type: builtins.str
    batch_frequency_in_seconds: builtins.int
    connection_string: builtins.str
    container_name: builtins.str
    encoding: builtins.str
    endpoint_uri: builtins.str
    file_name_format: builtins.str
    id: builtins.str
    @property
    def identity(self) -> global___ManagedIdentity: ...
    max_chunk_size_in_bytes: builtins.int
    name: builtins.str
    resource_group: builtins.str
    subscription_id: builtins.str
    def __init__(
        self,
        *,
        authentication_type: builtins.str = ...,
        batch_frequency_in_seconds: builtins.int = ...,
        connection_string: builtins.str = ...,
        container_name: builtins.str = ...,
        encoding: builtins.str = ...,
        endpoint_uri: builtins.str = ...,
        file_name_format: builtins.str = ...,
        id: builtins.str = ...,
        identity: global___ManagedIdentity | None = ...,
        max_chunk_size_in_bytes: builtins.int = ...,
        name: builtins.str = ...,
        resource_group: builtins.str = ...,
        subscription_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["identity", b"identity"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["authentication_type", b"authentication_type", "batch_frequency_in_seconds", b"batch_frequency_in_seconds", "connection_string", b"connection_string", "container_name", b"container_name", "encoding", b"encoding", "endpoint_uri", b"endpoint_uri", "file_name_format", b"file_name_format", "id", b"id", "identity", b"identity", "max_chunk_size_in_bytes", b"max_chunk_size_in_bytes", "name", b"name", "resource_group", b"resource_group", "subscription_id", b"subscription_id"]) -> None: ...

global___RoutingStorageContainerProperties = RoutingStorageContainerProperties

@typing_extensions.final
class RoutingServiceBusTopicEndpointProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUTHENTICATION_TYPE_FIELD_NUMBER: builtins.int
    CONNECTION_STRING_FIELD_NUMBER: builtins.int
    ENDPOINT_URI_FIELD_NUMBER: builtins.int
    ENTITY_PATH_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    IDENTITY_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    RESOURCE_GROUP_FIELD_NUMBER: builtins.int
    SUBSCRIPTION_ID_FIELD_NUMBER: builtins.int
    authentication_type: builtins.str
    connection_string: builtins.str
    endpoint_uri: builtins.str
    entity_path: builtins.str
    id: builtins.str
    @property
    def identity(self) -> global___ManagedIdentity: ...
    name: builtins.str
    resource_group: builtins.str
    subscription_id: builtins.str
    def __init__(
        self,
        *,
        authentication_type: builtins.str = ...,
        connection_string: builtins.str = ...,
        endpoint_uri: builtins.str = ...,
        entity_path: builtins.str = ...,
        id: builtins.str = ...,
        identity: global___ManagedIdentity | None = ...,
        name: builtins.str = ...,
        resource_group: builtins.str = ...,
        subscription_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["identity", b"identity"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["authentication_type", b"authentication_type", "connection_string", b"connection_string", "endpoint_uri", b"endpoint_uri", "entity_path", b"entity_path", "id", b"id", "identity", b"identity", "name", b"name", "resource_group", b"resource_group", "subscription_id", b"subscription_id"]) -> None: ...

global___RoutingServiceBusTopicEndpointProperties = RoutingServiceBusTopicEndpointProperties

@typing_extensions.final
class RoutingServiceBusQueueEndpointProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUTHENTICATION_TYPE_FIELD_NUMBER: builtins.int
    CONNECTION_STRING_FIELD_NUMBER: builtins.int
    ENDPOINT_URI_FIELD_NUMBER: builtins.int
    ENTITY_PATH_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    IDENTITY_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    RESOURCE_GROUP_FIELD_NUMBER: builtins.int
    SUBSCRIPTION_ID_FIELD_NUMBER: builtins.int
    authentication_type: builtins.str
    connection_string: builtins.str
    endpoint_uri: builtins.str
    entity_path: builtins.str
    id: builtins.str
    @property
    def identity(self) -> global___ManagedIdentity: ...
    name: builtins.str
    resource_group: builtins.str
    subscription_id: builtins.str
    def __init__(
        self,
        *,
        authentication_type: builtins.str = ...,
        connection_string: builtins.str = ...,
        endpoint_uri: builtins.str = ...,
        entity_path: builtins.str = ...,
        id: builtins.str = ...,
        identity: global___ManagedIdentity | None = ...,
        name: builtins.str = ...,
        resource_group: builtins.str = ...,
        subscription_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["identity", b"identity"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["authentication_type", b"authentication_type", "connection_string", b"connection_string", "endpoint_uri", b"endpoint_uri", "entity_path", b"entity_path", "id", b"id", "identity", b"identity", "name", b"name", "resource_group", b"resource_group", "subscription_id", b"subscription_id"]) -> None: ...

global___RoutingServiceBusQueueEndpointProperties = RoutingServiceBusQueueEndpointProperties

@typing_extensions.final
class RoutingEventHubProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUTHENTICATION_TYPE_FIELD_NUMBER: builtins.int
    CONNECTION_STRING_FIELD_NUMBER: builtins.int
    ENDPOINT_URI_FIELD_NUMBER: builtins.int
    ENTITY_PATH_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    IDENTITY_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    RESOURCE_GROUP_FIELD_NUMBER: builtins.int
    SUBSCRIPTION_ID_FIELD_NUMBER: builtins.int
    authentication_type: builtins.str
    connection_string: builtins.str
    endpoint_uri: builtins.str
    entity_path: builtins.str
    id: builtins.str
    @property
    def identity(self) -> global___ManagedIdentity: ...
    name: builtins.str
    resource_group: builtins.str
    subscription_id: builtins.str
    def __init__(
        self,
        *,
        authentication_type: builtins.str = ...,
        connection_string: builtins.str = ...,
        endpoint_uri: builtins.str = ...,
        entity_path: builtins.str = ...,
        id: builtins.str = ...,
        identity: global___ManagedIdentity | None = ...,
        name: builtins.str = ...,
        resource_group: builtins.str = ...,
        subscription_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["identity", b"identity"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["authentication_type", b"authentication_type", "connection_string", b"connection_string", "endpoint_uri", b"endpoint_uri", "entity_path", b"entity_path", "id", b"id", "identity", b"identity", "name", b"name", "resource_group", b"resource_group", "subscription_id", b"subscription_id"]) -> None: ...

global___RoutingEventHubProperties = RoutingEventHubProperties

@typing_extensions.final
class ManagedIdentity(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ASSIGNED_IDENTITY_FIELD_NUMBER: builtins.int
    user_assigned_identity: builtins.str
    def __init__(
        self,
        *,
        user_assigned_identity: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["user_assigned_identity", b"user_assigned_identity"]) -> None: ...

global___ManagedIdentity = ManagedIdentity

@typing_extensions.final
class PrivateEndpointConnection(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PRIVATE_ENDPOINT_FIELD_NUMBER: builtins.int
    PRIVATE_LINK_SERVICE_CONNECTION_STATE_FIELD_NUMBER: builtins.int
    @property
    def private_endpoint(self) -> global___PrivateEndpoint: ...
    @property
    def private_link_service_connection_state(self) -> global___PrivateLinkServiceConnectionState: ...
    def __init__(
        self,
        *,
        private_endpoint: global___PrivateEndpoint | None = ...,
        private_link_service_connection_state: global___PrivateLinkServiceConnectionState | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["private_endpoint", b"private_endpoint", "private_link_service_connection_state", b"private_link_service_connection_state"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["private_endpoint", b"private_endpoint", "private_link_service_connection_state", b"private_link_service_connection_state"]) -> None: ...

global___PrivateEndpointConnection = PrivateEndpointConnection

@typing_extensions.final
class PrivateLinkServiceConnectionState(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACTIONS_REQUIRED_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    actions_required: builtins.str
    description: builtins.str
    status: builtins.str
    def __init__(
        self,
        *,
        actions_required: builtins.str = ...,
        description: builtins.str = ...,
        status: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["actions_required", b"actions_required", "description", b"description", "status", b"status"]) -> None: ...

global___PrivateLinkServiceConnectionState = PrivateLinkServiceConnectionState

@typing_extensions.final
class PrivateEndpoint(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___PrivateEndpoint = PrivateEndpoint

@typing_extensions.final
class NetworkRuleSetProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLY_TO_BUILT_IN_EVENT_HUB_ENDPOINT_FIELD_NUMBER: builtins.int
    DEFAULT_ACTION_FIELD_NUMBER: builtins.int
    IP_RULES_FIELD_NUMBER: builtins.int
    apply_to_built_in_event_hub_endpoint: builtins.bool
    default_action: builtins.str
    @property
    def ip_rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NetworkRuleSetIpRule]: ...
    def __init__(
        self,
        *,
        apply_to_built_in_event_hub_endpoint: builtins.bool = ...,
        default_action: builtins.str = ...,
        ip_rules: collections.abc.Iterable[global___NetworkRuleSetIpRule] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["apply_to_built_in_event_hub_endpoint", b"apply_to_built_in_event_hub_endpoint", "default_action", b"default_action", "ip_rules", b"ip_rules"]) -> None: ...

global___NetworkRuleSetProperties = NetworkRuleSetProperties

@typing_extensions.final
class NetworkRuleSetIpRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACTION_FIELD_NUMBER: builtins.int
    FILTER_NAME_FIELD_NUMBER: builtins.int
    IP_MASK_FIELD_NUMBER: builtins.int
    action: builtins.str
    filter_name: builtins.str
    ip_mask: builtins.str
    def __init__(
        self,
        *,
        action: builtins.str = ...,
        filter_name: builtins.str = ...,
        ip_mask: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["action", b"action", "filter_name", b"filter_name", "ip_mask", b"ip_mask"]) -> None: ...

global___NetworkRuleSetIpRule = NetworkRuleSetIpRule

@typing_extensions.final
class IpFilterRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACTION_FIELD_NUMBER: builtins.int
    FILTER_NAME_FIELD_NUMBER: builtins.int
    IP_MASK_FIELD_NUMBER: builtins.int
    action: builtins.str
    filter_name: builtins.str
    ip_mask: builtins.str
    def __init__(
        self,
        *,
        action: builtins.str = ...,
        filter_name: builtins.str = ...,
        ip_mask: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["action", b"action", "filter_name", b"filter_name", "ip_mask", b"ip_mask"]) -> None: ...

global___IpFilterRule = IpFilterRule

@typing_extensions.final
class CloudToDeviceProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEFAULT_TTL_AS_ISO8601_FIELD_NUMBER: builtins.int
    FEEDBACK_FIELD_NUMBER: builtins.int
    MAX_DELIVERY_COUNT_FIELD_NUMBER: builtins.int
    default_ttl_as_iso8601: builtins.str
    @property
    def feedback(self) -> global___FeedbackProperties: ...
    max_delivery_count: builtins.int
    def __init__(
        self,
        *,
        default_ttl_as_iso8601: builtins.str = ...,
        feedback: global___FeedbackProperties | None = ...,
        max_delivery_count: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["feedback", b"feedback"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["default_ttl_as_iso8601", b"default_ttl_as_iso8601", "feedback", b"feedback", "max_delivery_count", b"max_delivery_count"]) -> None: ...

global___CloudToDeviceProperties = CloudToDeviceProperties

@typing_extensions.final
class FeedbackProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOCK_DURATION_AS_ISO8601_FIELD_NUMBER: builtins.int
    MAX_DELIVERY_COUNT_FIELD_NUMBER: builtins.int
    TTL_AS_ISO8601_FIELD_NUMBER: builtins.int
    lock_duration_as_iso8601: builtins.str
    max_delivery_count: builtins.int
    ttl_as_iso8601: builtins.str
    def __init__(
        self,
        *,
        lock_duration_as_iso8601: builtins.str = ...,
        max_delivery_count: builtins.int = ...,
        ttl_as_iso8601: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["lock_duration_as_iso8601", b"lock_duration_as_iso8601", "max_delivery_count", b"max_delivery_count", "ttl_as_iso8601", b"ttl_as_iso8601"]) -> None: ...

global___FeedbackProperties = FeedbackProperties

@typing_extensions.final
class SharedAccessSignatureAuthorizationRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_NAME_FIELD_NUMBER: builtins.int
    PRIMARY_KEY_FIELD_NUMBER: builtins.int
    RIGHTS_FIELD_NUMBER: builtins.int
    SECONDARY_KEY_FIELD_NUMBER: builtins.int
    key_name: builtins.str
    primary_key: builtins.str
    rights: builtins.str
    secondary_key: builtins.str
    def __init__(
        self,
        *,
        key_name: builtins.str = ...,
        primary_key: builtins.str = ...,
        rights: builtins.str = ...,
        secondary_key: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["key_name", b"key_name", "primary_key", b"primary_key", "rights", b"rights", "secondary_key", b"secondary_key"]) -> None: ...

global___SharedAccessSignatureAuthorizationRule = SharedAccessSignatureAuthorizationRule

@typing_extensions.final
class ArmIdentity(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class UserAssignedIdentitiesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    TYPE_FIELD_NUMBER: builtins.int
    USER_ASSIGNED_IDENTITIES_FIELD_NUMBER: builtins.int
    type: builtins.str
    @property
    def user_assigned_identities(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        type: builtins.str = ...,
        user_assigned_identities: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["type", b"type", "user_assigned_identities", b"user_assigned_identities"]) -> None: ...

global___ArmIdentity = ArmIdentity
