"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class RecaptchaEnterpriseKeyXAndroidSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALLOW_ALL_PACKAGE_NAMES_FIELD_NUMBER: builtins.int
    ALLOWED_PACKAGE_NAMES_FIELD_NUMBER: builtins.int
    allow_all_package_names: builtins.bool
    @property
    def allowed_package_names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        allow_all_package_names: builtins.bool = ...,
        allowed_package_names: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["allow_all_package_names", b"allow_all_package_names", "allowed_package_names", b"allowed_package_names"]) -> None: ...

global___RecaptchaEnterpriseKeyXAndroidSettings = RecaptchaEnterpriseKeyXAndroidSettings

@typing_extensions.final
class RecaptchaEnterpriseKeyXIosSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALLOW_ALL_BUNDLE_IDS_FIELD_NUMBER: builtins.int
    ALLOWED_BUNDLE_IDS_FIELD_NUMBER: builtins.int
    allow_all_bundle_ids: builtins.bool
    @property
    def allowed_bundle_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        allow_all_bundle_ids: builtins.bool = ...,
        allowed_bundle_ids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["allow_all_bundle_ids", b"allow_all_bundle_ids", "allowed_bundle_ids", b"allowed_bundle_ids"]) -> None: ...

global___RecaptchaEnterpriseKeyXIosSettings = RecaptchaEnterpriseKeyXIosSettings

@typing_extensions.final
class RecaptchaEnterpriseKeyXTestingOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TESTING_CHALLENGE_FIELD_NUMBER: builtins.int
    TESTING_SCORE_FIELD_NUMBER: builtins.int
    testing_challenge: builtins.str
    testing_score: builtins.float
    def __init__(
        self,
        *,
        testing_challenge: builtins.str = ...,
        testing_score: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["testing_challenge", b"testing_challenge", "testing_score", b"testing_score"]) -> None: ...

global___RecaptchaEnterpriseKeyXTestingOptions = RecaptchaEnterpriseKeyXTestingOptions

@typing_extensions.final
class RecaptchaEnterpriseKeyXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___RecaptchaEnterpriseKeyXTimeouts = RecaptchaEnterpriseKeyXTimeouts

@typing_extensions.final
class RecaptchaEnterpriseKeyXWebSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALLOW_ALL_DOMAINS_FIELD_NUMBER: builtins.int
    ALLOW_AMP_TRAFFIC_FIELD_NUMBER: builtins.int
    ALLOWED_DOMAINS_FIELD_NUMBER: builtins.int
    CHALLENGE_SECURITY_PREFERENCE_FIELD_NUMBER: builtins.int
    INTEGRATION_TYPE_FIELD_NUMBER: builtins.int
    allow_all_domains: builtins.bool
    allow_amp_traffic: builtins.bool
    @property
    def allowed_domains(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    challenge_security_preference: builtins.str
    integration_type: builtins.str
    def __init__(
        self,
        *,
        allow_all_domains: builtins.bool = ...,
        allow_amp_traffic: builtins.bool = ...,
        allowed_domains: collections.abc.Iterable[builtins.str] | None = ...,
        challenge_security_preference: builtins.str = ...,
        integration_type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["allow_all_domains", b"allow_all_domains", "allow_amp_traffic", b"allow_amp_traffic", "allowed_domains", b"allowed_domains", "challenge_security_preference", b"challenge_security_preference", "integration_type", b"integration_type"]) -> None: ...

global___RecaptchaEnterpriseKeyXWebSettings = RecaptchaEnterpriseKeyXWebSettings

@typing_extensions.final
class RecaptchaEnterpriseKey(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    CREATE_TIME_FIELD_NUMBER: builtins.int
    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    ANDROID_SETTINGS_FIELD_NUMBER: builtins.int
    IOS_SETTINGS_FIELD_NUMBER: builtins.int
    TESTING_OPTIONS_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    WEB_SETTINGS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    create_time: builtins.str
    display_name: builtins.str
    id: builtins.str
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    name: builtins.str
    project: builtins.str
    @property
    def android_settings(self) -> global___RecaptchaEnterpriseKeyXAndroidSettings: ...
    @property
    def ios_settings(self) -> global___RecaptchaEnterpriseKeyXIosSettings: ...
    @property
    def testing_options(self) -> global___RecaptchaEnterpriseKeyXTestingOptions: ...
    @property
    def timeouts(self) -> global___RecaptchaEnterpriseKeyXTimeouts: ...
    @property
    def web_settings(self) -> global___RecaptchaEnterpriseKeyXWebSettings: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        create_time: builtins.str = ...,
        display_name: builtins.str = ...,
        id: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        android_settings: global___RecaptchaEnterpriseKeyXAndroidSettings | None = ...,
        ios_settings: global___RecaptchaEnterpriseKeyXIosSettings | None = ...,
        testing_options: global___RecaptchaEnterpriseKeyXTestingOptions | None = ...,
        timeouts: global___RecaptchaEnterpriseKeyXTimeouts | None = ...,
        web_settings: global___RecaptchaEnterpriseKeyXWebSettings | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["android_settings", b"android_settings", "ios_settings", b"ios_settings", "resource_info", b"resource_info", "testing_options", b"testing_options", "timeouts", b"timeouts", "web_settings", b"web_settings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["android_settings", b"android_settings", "create_time", b"create_time", "display_name", b"display_name", "id", b"id", "ios_settings", b"ios_settings", "labels", b"labels", "name", b"name", "project", b"project", "resource_info", b"resource_info", "testing_options", b"testing_options", "timeouts", b"timeouts", "web_settings", b"web_settings"]) -> None: ...

global___RecaptchaEnterpriseKey = RecaptchaEnterpriseKey
