# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_emr.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11\x61ws/aws_emr.proto\x12\x13oak9.tython.aws.emr\x1a\x13shared/shared.proto\"\x87\x02\n\x12\x43lusterApplication\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12T\n\x0f\x61\x64\x64itional_info\x18\x02 \x03(\x0b\x32;.oak9.tython.aws.emr.ClusterApplication.AdditionalInfoEntry\x12\x0c\n\x04\x61rgs\x18\x03 \x03(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0f\n\x07version\x18\x05 \x01(\t\x1a\x35\n\x13\x41\x64\x64itionalInfoEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"y\n\"ClusterScriptBootstrapActionConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04\x61rgs\x18\x02 \x03(\t\x12\x0c\n\x04path\x18\x03 \x01(\t\"\xbf\x01\n\x1c\x43lusterBootstrapActionConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12X\n\x17script_bootstrap_action\x18\x03 \x01(\x0b\x32\x37.oak9.tython.aws.emr.ClusterScriptBootstrapActionConfig\"\xd4\x02\n\x14\x43lusterConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0e\x63lassification\x18\x02 \x01(\t\x12h\n\x18\x63onfiguration_properties\x18\x03 \x03(\x0b\x32\x46.oak9.tython.aws.emr.ClusterConfiguration.ConfigurationPropertiesEntry\x12\x41\n\x0e\x63onfigurations\x18\x04 \x03(\x0b\x32).oak9.tython.aws.emr.ClusterConfiguration\x1a>\n\x1c\x43onfigurationPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x8c\x01\n\x1a\x43lusterVolumeSpecification\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04iops\x18\x02 \x01(\x05\x12\x12\n\nsize_in_gb\x18\x03 \x01(\x05\x12\x13\n\x0bvolume_type\x18\x04 \x01(\t\"\xc3\x01\n\x1b\x43lusterEbsBlockDeviceConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12M\n\x14volume_specification\x18\x02 \x01(\x0b\x32/.oak9.tython.aws.emr.ClusterVolumeSpecification\x12\x1c\n\x14volumes_per_instance\x18\x03 \x01(\x05\"\xbd\x01\n\x17\x43lusterEbsConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12R\n\x18\x65\x62s_block_device_configs\x18\x02 \x03(\x0b\x32\x30.oak9.tython.aws.emr.ClusterEbsBlockDeviceConfig\x12\x15\n\rebs_optimized\x18\x03 \x01(\x08\"\xd9\x02\n\x19\x43lusterInstanceTypeConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\tbid_price\x18\x02 \x01(\t\x12\x32\n*bid_price_as_percentage_of_on_demand_price\x18\x03 \x01(\x01\x12\x41\n\x0e\x63onfigurations\x18\x04 \x03(\x0b\x32).oak9.tython.aws.emr.ClusterConfiguration\x12G\n\x11\x65\x62s_configuration\x18\x05 \x01(\x0b\x32,.oak9.tython.aws.emr.ClusterEbsConfiguration\x12\x15\n\rinstance_type\x18\x06 \x01(\t\x12\x19\n\x11weighted_capacity\x18\x07 \x01(\x05\"\xb9\x01\n$ClusterSpotProvisioningSpecification\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1e\n\x16\x62lock_duration_minutes\x18\x02 \x01(\x05\x12\x16\n\x0etimeout_action\x18\x03 \x01(\t\x12 \n\x18timeout_duration_minutes\x18\x04 \x01(\x05\"\xc0\x01\n.ClusterInstanceFleetProvisioningSpecifications\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12U\n\x12spot_specification\x18\x02 \x01(\x0b\x32\x39.oak9.tython.aws.emr.ClusterSpotProvisioningSpecification\"\xd7\x02\n\x1a\x43lusterInstanceFleetConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12M\n\x15instance_type_configs\x18\x02 \x03(\x0b\x32..oak9.tython.aws.emr.ClusterInstanceTypeConfig\x12\x62\n\x15launch_specifications\x18\x03 \x01(\x0b\x32\x43.oak9.tython.aws.emr.ClusterInstanceFleetProvisioningSpecifications\x12\x0c\n\x04name\x18\x04 \x01(\t\x12!\n\x19target_on_demand_capacity\x18\x05 \x01(\x05\x12\x1c\n\x14target_spot_capacity\x18\x06 \x01(\x05\"\x80\x01\n\x19\x43lusterScalingConstraints\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0cmax_capacity\x18\x02 \x01(\x05\x12\x14\n\x0cmin_capacity\x18\x03 \x01(\x05\"\xaa\x01\n\'ClusterSimpleScalingPolicyConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x17\n\x0f\x61\x64justment_type\x18\x02 \x01(\t\x12\x11\n\tcool_down\x18\x03 \x01(\x05\x12\x1a\n\x12scaling_adjustment\x18\x04 \x01(\x05\"\xca\x01\n\x14\x43lusterScalingAction\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06market\x18\x02 \x01(\t\x12i\n#simple_scaling_policy_configuration\x18\x03 \x01(\x0b\x32<.oak9.tython.aws.emr.ClusterSimpleScalingPolicyConfiguration\"m\n\x16\x43lusterMetricDimension\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\"\xc1\x02\n ClusterCloudWatchAlarmDefinition\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1b\n\x13\x63omparison_operator\x18\x02 \x01(\t\x12?\n\ndimensions\x18\x03 \x03(\x0b\x32+.oak9.tython.aws.emr.ClusterMetricDimension\x12\x1a\n\x12\x65valuation_periods\x18\x04 \x01(\x05\x12\x13\n\x0bmetric_name\x18\x05 \x01(\t\x12\x11\n\tnamespace\x18\x06 \x01(\t\x12\x0e\n\x06period\x18\x07 \x01(\x05\x12\x11\n\tstatistic\x18\x08 \x01(\t\x12\x11\n\tthreshold\x18\t \x01(\x01\x12\x0c\n\x04unit\x18\n \x01(\t\"\xad\x01\n\x15\x43lusterScalingTrigger\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12[\n\x1c\x63loud_watch_alarm_definition\x18\x02 \x01(\x0b\x32\x35.oak9.tython.aws.emr.ClusterCloudWatchAlarmDefinition\"\xe8\x01\n\x12\x43lusterScalingRule\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x39\n\x06\x61\x63tion\x18\x02 \x01(\x0b\x32).oak9.tython.aws.emr.ClusterScalingAction\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12;\n\x07trigger\x18\x05 \x01(\x0b\x32*.oak9.tython.aws.emr.ClusterScalingTrigger\"\xd0\x01\n\x18\x43lusterAutoScalingPolicy\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x43\n\x0b\x63onstraints\x18\x02 \x01(\x0b\x32..oak9.tython.aws.emr.ClusterScalingConstraints\x12\x36\n\x05rules\x18\x03 \x03(\x0b\x32\'.oak9.tython.aws.emr.ClusterScalingRule\"\x8d\x03\n\x1a\x43lusterInstanceGroupConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12J\n\x13\x61uto_scaling_policy\x18\x02 \x01(\x0b\x32-.oak9.tython.aws.emr.ClusterAutoScalingPolicy\x12\x11\n\tbid_price\x18\x03 \x01(\t\x12\x41\n\x0e\x63onfigurations\x18\x04 \x03(\x0b\x32).oak9.tython.aws.emr.ClusterConfiguration\x12G\n\x11\x65\x62s_configuration\x18\x05 \x01(\x0b\x32,.oak9.tython.aws.emr.ClusterEbsConfiguration\x12\x16\n\x0einstance_count\x18\x06 \x01(\x05\x12\x15\n\rinstance_type\x18\x07 \x01(\t\x12\x0e\n\x06market\x18\x08 \x01(\t\x12\x0c\n\x04name\x18\t \x01(\t\"j\n\x14\x43lusterPlacementType\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x19\n\x11\x61vailability_zone\x18\x02 \x01(\t\"\xca\x06\n\x1d\x43lusterJobFlowInstancesConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12)\n!additional_master_security_groups\x18\x02 \x03(\t\x12(\n additional_slave_security_groups\x18\x03 \x03(\t\x12L\n\x13\x63ore_instance_fleet\x18\x04 \x01(\x0b\x32/.oak9.tython.aws.emr.ClusterInstanceFleetConfig\x12L\n\x13\x63ore_instance_group\x18\x05 \x01(\x0b\x32/.oak9.tython.aws.emr.ClusterInstanceGroupConfig\x12\x14\n\x0c\x65\x63\x32_key_name\x18\x06 \x01(\t\x12\x15\n\rec2_subnet_id\x18\x07 \x01(\t\x12\x16\n\x0e\x65\x63\x32_subnet_ids\x18\x08 \x03(\t\x12)\n!emr_managed_master_security_group\x18\t \x01(\t\x12(\n emr_managed_slave_security_group\x18\n \x01(\t\x12\x16\n\x0ehadoop_version\x18\x0b \x01(\t\x12)\n!keep_job_flow_alive_when_no_steps\x18\x0c \x01(\x08\x12N\n\x15master_instance_fleet\x18\r \x01(\x0b\x32/.oak9.tython.aws.emr.ClusterInstanceFleetConfig\x12N\n\x15master_instance_group\x18\x0e \x01(\x0b\x32/.oak9.tython.aws.emr.ClusterInstanceGroupConfig\x12<\n\tplacement\x18\x0f \x01(\x0b\x32).oak9.tython.aws.emr.ClusterPlacementType\x12%\n\x1dservice_access_security_group\x18\x10 \x01(\t\x12\x1d\n\x15termination_protected\x18\x11 \x01(\x08\"\xeb\x01\n\x19\x43lusterKerberosAttributes\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1f\n\x17\x61\x64_domain_join_password\x18\x02 \x01(\t\x12\x1b\n\x13\x61\x64_domain_join_user\x18\x03 \x01(\t\x12,\n$cross_realm_trust_principal_password\x18\x04 \x01(\t\x12\x1a\n\x12kdc_admin_password\x18\x05 \x01(\t\x12\r\n\x05realm\x18\x06 \x01(\t\"f\n\x0f\x43lusterKeyValue\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\"\xc3\x01\n\x1a\x43lusterHadoopJarStepConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04\x61rgs\x18\x02 \x03(\t\x12\x0b\n\x03jar\x18\x03 \x01(\t\x12\x12\n\nmain_class\x18\x04 \x01(\t\x12=\n\x0fstep_properties\x18\x05 \x03(\x0b\x32$.oak9.tython.aws.emr.ClusterKeyValue\"\xbf\x01\n\x11\x43lusterStepConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x19\n\x11\x61\x63tion_on_failure\x18\x02 \x01(\t\x12H\n\x0fhadoop_jar_step\x18\x03 \x01(\x0b\x32/.oak9.tython.aws.emr.ClusterHadoopJarStepConfig\x12\x0c\n\x04name\x18\x04 \x01(\t\"\xd0\x07\n\x07\x43luster\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12I\n\x0f\x61\x64\x64itional_info\x18\x02 \x03(\x0b\x32\x30.oak9.tython.aws.emr.Cluster.AdditionalInfoEntry\x12=\n\x0c\x61pplications\x18\x03 \x03(\x0b\x32\'.oak9.tython.aws.emr.ClusterApplication\x12\x19\n\x11\x61uto_scaling_role\x18\x04 \x01(\t\x12L\n\x11\x62ootstrap_actions\x18\x05 \x03(\x0b\x32\x31.oak9.tython.aws.emr.ClusterBootstrapActionConfig\x12\x41\n\x0e\x63onfigurations\x18\x06 \x03(\x0b\x32).oak9.tython.aws.emr.ClusterConfiguration\x12\x15\n\rcustom_ami_id\x18\x07 \x01(\t\x12\x1c\n\x14\x65\x62s_root_volume_size\x18\x08 \x01(\x05\x12\x45\n\tinstances\x18\t \x01(\x0b\x32\x32.oak9.tython.aws.emr.ClusterJobFlowInstancesConfig\x12\x15\n\rjob_flow_role\x18\n \x01(\t\x12K\n\x13kerberos_attributes\x18\x0b \x01(\x0b\x32..oak9.tython.aws.emr.ClusterKerberosAttributes\x12\x0f\n\x07log_uri\x18\x0c \x01(\t\x12\x0c\n\x04name\x18\r \x01(\t\x12\x15\n\rrelease_label\x18\x0e \x01(\t\x12\x1b\n\x13scale_down_behavior\x18\x0f \x01(\t\x12\x1e\n\x16security_configuration\x18\x10 \x01(\t\x12\x14\n\x0cservice_role\x18\x11 \x01(\t\x12\x35\n\x05steps\x18\x12 \x03(\x0b\x32&.oak9.tython.aws.emr.ClusterStepConfig\x12\x34\n\x04tags\x18\x13 \x03(\x0b\x32&.oak9.tython.aws.emr.Cluster.TagsEntry\x12\x1c\n\x14visible_to_all_users\x18\x14 \x01(\x08\x1a\x35\n\x13\x41\x64\x64itionalInfoEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xbb\x02\n\x03\x45MR\x12-\n\x07\x63luster\x18\x01 \x03(\x0b\x32\x1c.oak9.tython.aws.emr.Cluster\x12G\n\x15instance_fleet_config\x18\x02 \x03(\x0b\x32(.oak9.tython.aws.emr.InstanceFleetConfig\x12G\n\x15instance_group_config\x18\x03 \x03(\x0b\x32(.oak9.tython.aws.emr.InstanceGroupConfig\x12J\n\x16security_configuration\x18\x04 \x03(\x0b\x32*.oak9.tython.aws.emr.SecurityConfiguration\x12\'\n\x04step\x18\x05 \x03(\x0b\x32\x19.oak9.tython.aws.emr.Step\"\xf8\x02\n InstanceFleetConfigConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0e\x63lassification\x18\x02 \x01(\t\x12t\n\x18\x63onfiguration_properties\x18\x03 \x03(\x0b\x32R.oak9.tython.aws.emr.InstanceFleetConfigConfiguration.ConfigurationPropertiesEntry\x12M\n\x0e\x63onfigurations\x18\x04 \x03(\x0b\x32\x35.oak9.tython.aws.emr.InstanceFleetConfigConfiguration\x1a>\n\x1c\x43onfigurationPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x98\x01\n&InstanceFleetConfigVolumeSpecification\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04iops\x18\x02 \x01(\x05\x12\x12\n\nsize_in_gb\x18\x03 \x01(\x05\x12\x13\n\x0bvolume_type\x18\x04 \x01(\t\"\xdb\x01\n\'InstanceFleetConfigEbsBlockDeviceConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12Y\n\x14volume_specification\x18\x02 \x01(\x0b\x32;.oak9.tython.aws.emr.InstanceFleetConfigVolumeSpecification\x12\x1c\n\x14volumes_per_instance\x18\x03 \x01(\x05\"\xd5\x01\n#InstanceFleetConfigEbsConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12^\n\x18\x65\x62s_block_device_configs\x18\x02 \x03(\x0b\x32<.oak9.tython.aws.emr.InstanceFleetConfigEbsBlockDeviceConfig\x12\x15\n\rebs_optimized\x18\x03 \x01(\x08\"\xfd\x02\n%InstanceFleetConfigInstanceTypeConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\tbid_price\x18\x02 \x01(\t\x12\x32\n*bid_price_as_percentage_of_on_demand_price\x18\x03 \x01(\x01\x12M\n\x0e\x63onfigurations\x18\x04 \x03(\x0b\x32\x35.oak9.tython.aws.emr.InstanceFleetConfigConfiguration\x12S\n\x11\x65\x62s_configuration\x18\x05 \x01(\x0b\x32\x38.oak9.tython.aws.emr.InstanceFleetConfigEbsConfiguration\x12\x15\n\rinstance_type\x18\x06 \x01(\t\x12\x19\n\x11weighted_capacity\x18\x07 \x01(\x05\"\xc5\x01\n0InstanceFleetConfigSpotProvisioningSpecification\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1e\n\x16\x62lock_duration_minutes\x18\x02 \x01(\x05\x12\x16\n\x0etimeout_action\x18\x03 \x01(\t\x12 \n\x18timeout_duration_minutes\x18\x04 \x01(\x05\"\xd8\x01\n:InstanceFleetConfigInstanceFleetProvisioningSpecifications\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x61\n\x12spot_specification\x18\x02 \x01(\x0b\x32\x45.oak9.tython.aws.emr.InstanceFleetConfigSpotProvisioningSpecification\"\x99\x03\n\x13InstanceFleetConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\ncluster_id\x18\x02 \x01(\t\x12\x1b\n\x13instance_fleet_type\x18\x03 \x01(\t\x12Y\n\x15instance_type_configs\x18\x04 \x03(\x0b\x32:.oak9.tython.aws.emr.InstanceFleetConfigInstanceTypeConfig\x12n\n\x15launch_specifications\x18\x05 \x01(\x0b\x32O.oak9.tython.aws.emr.InstanceFleetConfigInstanceFleetProvisioningSpecifications\x12\x0c\n\x04name\x18\x06 \x01(\t\x12!\n\x19target_on_demand_capacity\x18\x07 \x01(\x05\x12\x1c\n\x14target_spot_capacity\x18\x08 \x01(\x05\"\x8c\x01\n%InstanceGroupConfigScalingConstraints\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0cmax_capacity\x18\x02 \x01(\x05\x12\x14\n\x0cmin_capacity\x18\x03 \x01(\x05\"\xb6\x01\n3InstanceGroupConfigSimpleScalingPolicyConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x17\n\x0f\x61\x64justment_type\x18\x02 \x01(\t\x12\x11\n\tcool_down\x18\x03 \x01(\x05\x12\x1a\n\x12scaling_adjustment\x18\x04 \x01(\x05\"\xe2\x01\n InstanceGroupConfigScalingAction\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06market\x18\x02 \x01(\t\x12u\n#simple_scaling_policy_configuration\x18\x03 \x01(\x0b\x32H.oak9.tython.aws.emr.InstanceGroupConfigSimpleScalingPolicyConfiguration\"y\n\"InstanceGroupConfigMetricDimension\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\"\xd9\x02\n,InstanceGroupConfigCloudWatchAlarmDefinition\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1b\n\x13\x63omparison_operator\x18\x02 \x01(\t\x12K\n\ndimensions\x18\x03 \x03(\x0b\x32\x37.oak9.tython.aws.emr.InstanceGroupConfigMetricDimension\x12\x1a\n\x12\x65valuation_periods\x18\x04 \x01(\x05\x12\x13\n\x0bmetric_name\x18\x05 \x01(\t\x12\x11\n\tnamespace\x18\x06 \x01(\t\x12\x0e\n\x06period\x18\x07 \x01(\x05\x12\x11\n\tstatistic\x18\x08 \x01(\t\x12\x11\n\tthreshold\x18\t \x01(\x01\x12\x0c\n\x04unit\x18\n \x01(\t\"\xc5\x01\n!InstanceGroupConfigScalingTrigger\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12g\n\x1c\x63loud_watch_alarm_definition\x18\x02 \x01(\x0b\x32\x41.oak9.tython.aws.emr.InstanceGroupConfigCloudWatchAlarmDefinition\"\x8c\x02\n\x1eInstanceGroupConfigScalingRule\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x45\n\x06\x61\x63tion\x18\x02 \x01(\x0b\x32\x35.oak9.tython.aws.emr.InstanceGroupConfigScalingAction\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12G\n\x07trigger\x18\x05 \x01(\x0b\x32\x36.oak9.tython.aws.emr.InstanceGroupConfigScalingTrigger\"\xf4\x01\n$InstanceGroupConfigAutoScalingPolicy\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12O\n\x0b\x63onstraints\x18\x02 \x01(\x0b\x32:.oak9.tython.aws.emr.InstanceGroupConfigScalingConstraints\x12\x42\n\x05rules\x18\x03 \x03(\x0b\x32\x33.oak9.tython.aws.emr.InstanceGroupConfigScalingRule\"\xf8\x02\n InstanceGroupConfigConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0e\x63lassification\x18\x02 \x01(\t\x12t\n\x18\x63onfiguration_properties\x18\x03 \x03(\x0b\x32R.oak9.tython.aws.emr.InstanceGroupConfigConfiguration.ConfigurationPropertiesEntry\x12M\n\x0e\x63onfigurations\x18\x04 \x03(\x0b\x32\x35.oak9.tython.aws.emr.InstanceGroupConfigConfiguration\x1a>\n\x1c\x43onfigurationPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x98\x01\n&InstanceGroupConfigVolumeSpecification\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04iops\x18\x02 \x01(\x05\x12\x12\n\nsize_in_gb\x18\x03 \x01(\x05\x12\x13\n\x0bvolume_type\x18\x04 \x01(\t\"\xdb\x01\n\'InstanceGroupConfigEbsBlockDeviceConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12Y\n\x14volume_specification\x18\x02 \x01(\x0b\x32;.oak9.tython.aws.emr.InstanceGroupConfigVolumeSpecification\x12\x1c\n\x14volumes_per_instance\x18\x03 \x01(\x05\"\xd5\x01\n#InstanceGroupConfigEbsConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12^\n\x18\x65\x62s_block_device_configs\x18\x02 \x03(\x0b\x32<.oak9.tython.aws.emr.InstanceGroupConfigEbsBlockDeviceConfig\x12\x15\n\rebs_optimized\x18\x03 \x01(\x08\"\xd6\x03\n\x13InstanceGroupConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12V\n\x13\x61uto_scaling_policy\x18\x02 \x01(\x0b\x32\x39.oak9.tython.aws.emr.InstanceGroupConfigAutoScalingPolicy\x12\x11\n\tbid_price\x18\x03 \x01(\t\x12M\n\x0e\x63onfigurations\x18\x04 \x03(\x0b\x32\x35.oak9.tython.aws.emr.InstanceGroupConfigConfiguration\x12S\n\x11\x65\x62s_configuration\x18\x05 \x01(\x0b\x32\x38.oak9.tython.aws.emr.InstanceGroupConfigEbsConfiguration\x12\x16\n\x0einstance_count\x18\x06 \x01(\x05\x12\x15\n\rinstance_role\x18\x07 \x01(\t\x12\x15\n\rinstance_type\x18\x08 \x01(\t\x12\x13\n\x0bjob_flow_id\x18\t \x01(\t\x12\x0e\n\x06market\x18\n \x01(\t\x12\x0c\n\x04name\x18\x0b \x01(\t\"\x83\x02\n\x15SecurityConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x65\n\x16security_configuration\x18\x03 \x03(\x0b\x32\x45.oak9.tython.aws.emr.SecurityConfiguration.SecurityConfigurationEntry\x1a<\n\x1aSecurityConfigurationEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"c\n\x0cStepKeyValue\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\"\xbd\x01\n\x17StepHadoopJarStepConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04\x61rgs\x18\x02 \x03(\t\x12\x0b\n\x03jar\x18\x03 \x01(\t\x12\x12\n\nmain_class\x18\x04 \x01(\t\x12:\n\x0fstep_properties\x18\x05 \x03(\x0b\x32!.oak9.tython.aws.emr.StepKeyValue\"\xc4\x01\n\x04Step\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x19\n\x11\x61\x63tion_on_failure\x18\x02 \x01(\t\x12\x45\n\x0fhadoop_jar_step\x18\x03 \x01(\x0b\x32,.oak9.tython.aws.emr.StepHadoopJarStepConfig\x12\x13\n\x0bjob_flow_id\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_emr_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CLUSTERAPPLICATION_ADDITIONALINFOENTRY._options = None
  _CLUSTERAPPLICATION_ADDITIONALINFOENTRY._serialized_options = b'8\001'
  _CLUSTERCONFIGURATION_CONFIGURATIONPROPERTIESENTRY._options = None
  _CLUSTERCONFIGURATION_CONFIGURATIONPROPERTIESENTRY._serialized_options = b'8\001'
  _CLUSTER_ADDITIONALINFOENTRY._options = None
  _CLUSTER_ADDITIONALINFOENTRY._serialized_options = b'8\001'
  _CLUSTER_TAGSENTRY._options = None
  _CLUSTER_TAGSENTRY._serialized_options = b'8\001'
  _INSTANCEFLEETCONFIGCONFIGURATION_CONFIGURATIONPROPERTIESENTRY._options = None
  _INSTANCEFLEETCONFIGCONFIGURATION_CONFIGURATIONPROPERTIESENTRY._serialized_options = b'8\001'
  _INSTANCEGROUPCONFIGCONFIGURATION_CONFIGURATIONPROPERTIESENTRY._options = None
  _INSTANCEGROUPCONFIGCONFIGURATION_CONFIGURATIONPROPERTIESENTRY._serialized_options = b'8\001'
  _SECURITYCONFIGURATION_SECURITYCONFIGURATIONENTRY._options = None
  _SECURITYCONFIGURATION_SECURITYCONFIGURATIONENTRY._serialized_options = b'8\001'
  _CLUSTERAPPLICATION._serialized_start=64
  _CLUSTERAPPLICATION._serialized_end=327
  _CLUSTERAPPLICATION_ADDITIONALINFOENTRY._serialized_start=274
  _CLUSTERAPPLICATION_ADDITIONALINFOENTRY._serialized_end=327
  _CLUSTERSCRIPTBOOTSTRAPACTIONCONFIG._serialized_start=329
  _CLUSTERSCRIPTBOOTSTRAPACTIONCONFIG._serialized_end=450
  _CLUSTERBOOTSTRAPACTIONCONFIG._serialized_start=453
  _CLUSTERBOOTSTRAPACTIONCONFIG._serialized_end=644
  _CLUSTERCONFIGURATION._serialized_start=647
  _CLUSTERCONFIGURATION._serialized_end=987
  _CLUSTERCONFIGURATION_CONFIGURATIONPROPERTIESENTRY._serialized_start=925
  _CLUSTERCONFIGURATION_CONFIGURATIONPROPERTIESENTRY._serialized_end=987
  _CLUSTERVOLUMESPECIFICATION._serialized_start=990
  _CLUSTERVOLUMESPECIFICATION._serialized_end=1130
  _CLUSTEREBSBLOCKDEVICECONFIG._serialized_start=1133
  _CLUSTEREBSBLOCKDEVICECONFIG._serialized_end=1328
  _CLUSTEREBSCONFIGURATION._serialized_start=1331
  _CLUSTEREBSCONFIGURATION._serialized_end=1520
  _CLUSTERINSTANCETYPECONFIG._serialized_start=1523
  _CLUSTERINSTANCETYPECONFIG._serialized_end=1868
  _CLUSTERSPOTPROVISIONINGSPECIFICATION._serialized_start=1871
  _CLUSTERSPOTPROVISIONINGSPECIFICATION._serialized_end=2056
  _CLUSTERINSTANCEFLEETPROVISIONINGSPECIFICATIONS._serialized_start=2059
  _CLUSTERINSTANCEFLEETPROVISIONINGSPECIFICATIONS._serialized_end=2251
  _CLUSTERINSTANCEFLEETCONFIG._serialized_start=2254
  _CLUSTERINSTANCEFLEETCONFIG._serialized_end=2597
  _CLUSTERSCALINGCONSTRAINTS._serialized_start=2600
  _CLUSTERSCALINGCONSTRAINTS._serialized_end=2728
  _CLUSTERSIMPLESCALINGPOLICYCONFIGURATION._serialized_start=2731
  _CLUSTERSIMPLESCALINGPOLICYCONFIGURATION._serialized_end=2901
  _CLUSTERSCALINGACTION._serialized_start=2904
  _CLUSTERSCALINGACTION._serialized_end=3106
  _CLUSTERMETRICDIMENSION._serialized_start=3108
  _CLUSTERMETRICDIMENSION._serialized_end=3217
  _CLUSTERCLOUDWATCHALARMDEFINITION._serialized_start=3220
  _CLUSTERCLOUDWATCHALARMDEFINITION._serialized_end=3541
  _CLUSTERSCALINGTRIGGER._serialized_start=3544
  _CLUSTERSCALINGTRIGGER._serialized_end=3717
  _CLUSTERSCALINGRULE._serialized_start=3720
  _CLUSTERSCALINGRULE._serialized_end=3952
  _CLUSTERAUTOSCALINGPOLICY._serialized_start=3955
  _CLUSTERAUTOSCALINGPOLICY._serialized_end=4163
  _CLUSTERINSTANCEGROUPCONFIG._serialized_start=4166
  _CLUSTERINSTANCEGROUPCONFIG._serialized_end=4563
  _CLUSTERPLACEMENTTYPE._serialized_start=4565
  _CLUSTERPLACEMENTTYPE._serialized_end=4671
  _CLUSTERJOBFLOWINSTANCESCONFIG._serialized_start=4674
  _CLUSTERJOBFLOWINSTANCESCONFIG._serialized_end=5516
  _CLUSTERKERBEROSATTRIBUTES._serialized_start=5519
  _CLUSTERKERBEROSATTRIBUTES._serialized_end=5754
  _CLUSTERKEYVALUE._serialized_start=5756
  _CLUSTERKEYVALUE._serialized_end=5858
  _CLUSTERHADOOPJARSTEPCONFIG._serialized_start=5861
  _CLUSTERHADOOPJARSTEPCONFIG._serialized_end=6056
  _CLUSTERSTEPCONFIG._serialized_start=6059
  _CLUSTERSTEPCONFIG._serialized_end=6250
  _CLUSTER._serialized_start=6253
  _CLUSTER._serialized_end=7229
  _CLUSTER_ADDITIONALINFOENTRY._serialized_start=274
  _CLUSTER_ADDITIONALINFOENTRY._serialized_end=327
  _CLUSTER_TAGSENTRY._serialized_start=7186
  _CLUSTER_TAGSENTRY._serialized_end=7229
  _EMR._serialized_start=7232
  _EMR._serialized_end=7547
  _INSTANCEFLEETCONFIGCONFIGURATION._serialized_start=7550
  _INSTANCEFLEETCONFIGCONFIGURATION._serialized_end=7926
  _INSTANCEFLEETCONFIGCONFIGURATION_CONFIGURATIONPROPERTIESENTRY._serialized_start=925
  _INSTANCEFLEETCONFIGCONFIGURATION_CONFIGURATIONPROPERTIESENTRY._serialized_end=987
  _INSTANCEFLEETCONFIGVOLUMESPECIFICATION._serialized_start=7929
  _INSTANCEFLEETCONFIGVOLUMESPECIFICATION._serialized_end=8081
  _INSTANCEFLEETCONFIGEBSBLOCKDEVICECONFIG._serialized_start=8084
  _INSTANCEFLEETCONFIGEBSBLOCKDEVICECONFIG._serialized_end=8303
  _INSTANCEFLEETCONFIGEBSCONFIGURATION._serialized_start=8306
  _INSTANCEFLEETCONFIGEBSCONFIGURATION._serialized_end=8519
  _INSTANCEFLEETCONFIGINSTANCETYPECONFIG._serialized_start=8522
  _INSTANCEFLEETCONFIGINSTANCETYPECONFIG._serialized_end=8903
  _INSTANCEFLEETCONFIGSPOTPROVISIONINGSPECIFICATION._serialized_start=8906
  _INSTANCEFLEETCONFIGSPOTPROVISIONINGSPECIFICATION._serialized_end=9103
  _INSTANCEFLEETCONFIGINSTANCEFLEETPROVISIONINGSPECIFICATIONS._serialized_start=9106
  _INSTANCEFLEETCONFIGINSTANCEFLEETPROVISIONINGSPECIFICATIONS._serialized_end=9322
  _INSTANCEFLEETCONFIG._serialized_start=9325
  _INSTANCEFLEETCONFIG._serialized_end=9734
  _INSTANCEGROUPCONFIGSCALINGCONSTRAINTS._serialized_start=9737
  _INSTANCEGROUPCONFIGSCALINGCONSTRAINTS._serialized_end=9877
  _INSTANCEGROUPCONFIGSIMPLESCALINGPOLICYCONFIGURATION._serialized_start=9880
  _INSTANCEGROUPCONFIGSIMPLESCALINGPOLICYCONFIGURATION._serialized_end=10062
  _INSTANCEGROUPCONFIGSCALINGACTION._serialized_start=10065
  _INSTANCEGROUPCONFIGSCALINGACTION._serialized_end=10291
  _INSTANCEGROUPCONFIGMETRICDIMENSION._serialized_start=10293
  _INSTANCEGROUPCONFIGMETRICDIMENSION._serialized_end=10414
  _INSTANCEGROUPCONFIGCLOUDWATCHALARMDEFINITION._serialized_start=10417
  _INSTANCEGROUPCONFIGCLOUDWATCHALARMDEFINITION._serialized_end=10762
  _INSTANCEGROUPCONFIGSCALINGTRIGGER._serialized_start=10765
  _INSTANCEGROUPCONFIGSCALINGTRIGGER._serialized_end=10962
  _INSTANCEGROUPCONFIGSCALINGRULE._serialized_start=10965
  _INSTANCEGROUPCONFIGSCALINGRULE._serialized_end=11233
  _INSTANCEGROUPCONFIGAUTOSCALINGPOLICY._serialized_start=11236
  _INSTANCEGROUPCONFIGAUTOSCALINGPOLICY._serialized_end=11480
  _INSTANCEGROUPCONFIGCONFIGURATION._serialized_start=11483
  _INSTANCEGROUPCONFIGCONFIGURATION._serialized_end=11859
  _INSTANCEGROUPCONFIGCONFIGURATION_CONFIGURATIONPROPERTIESENTRY._serialized_start=925
  _INSTANCEGROUPCONFIGCONFIGURATION_CONFIGURATIONPROPERTIESENTRY._serialized_end=987
  _INSTANCEGROUPCONFIGVOLUMESPECIFICATION._serialized_start=11862
  _INSTANCEGROUPCONFIGVOLUMESPECIFICATION._serialized_end=12014
  _INSTANCEGROUPCONFIGEBSBLOCKDEVICECONFIG._serialized_start=12017
  _INSTANCEGROUPCONFIGEBSBLOCKDEVICECONFIG._serialized_end=12236
  _INSTANCEGROUPCONFIGEBSCONFIGURATION._serialized_start=12239
  _INSTANCEGROUPCONFIGEBSCONFIGURATION._serialized_end=12452
  _INSTANCEGROUPCONFIG._serialized_start=12455
  _INSTANCEGROUPCONFIG._serialized_end=12925
  _SECURITYCONFIGURATION._serialized_start=12928
  _SECURITYCONFIGURATION._serialized_end=13187
  _SECURITYCONFIGURATION_SECURITYCONFIGURATIONENTRY._serialized_start=13127
  _SECURITYCONFIGURATION_SECURITYCONFIGURATIONENTRY._serialized_end=13187
  _STEPKEYVALUE._serialized_start=13189
  _STEPKEYVALUE._serialized_end=13288
  _STEPHADOOPJARSTEPCONFIG._serialized_start=13291
  _STEPHADOOPJARSTEPCONFIG._serialized_end=13480
  _STEP._serialized_start=13483
  _STEP._serialized_end=13679
# @@protoc_insertion_point(module_scope)
