# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_tags.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12gcp/gcp_tags.proto\x12\x14oak9.tython.gcp.tags\x1a\x13shared/shared.proto\"9\n\x17TagsTagBindingXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\"\xc7\x01\n\x0eTagsTagBinding\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0e\n\x06parent\x18\x03 \x01(\t\x12\x11\n\ttag_value\x18\x04 \x01(\t\x12?\n\x08timeouts\x18\x05 \x01(\x0b\x32-.oak9.tython.gcp.tags.TagsTagBindingXTimeouts\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"E\n\x13TagsTagKeyXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\x98\x02\n\nTagsTagKey\x12\x13\n\x0b\x63reate_time\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x17\n\x0fnamespaced_name\x18\x05 \x01(\t\x12\x0e\n\x06parent\x18\x06 \x01(\t\x12\x12\n\nshort_name\x18\x07 \x01(\t\x12\x13\n\x0bupdate_time\x18\x08 \x01(\t\x12;\n\x08timeouts\x18\t \x01(\x0b\x32).oak9.tython.gcp.tags.TagsTagKeyXTimeouts\x12\x37\n\rresource_info\x18\n \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"X\n\x1eTagsTagKeyIamBindingXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\xe2\x01\n\x14TagsTagKeyIamBinding\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0f\n\x07members\x18\x03 \x03(\t\x12\x0c\n\x04role\x18\x04 \x01(\t\x12\x0f\n\x07tag_key\x18\x05 \x01(\t\x12G\n\tcondition\x18\x06 \x01(\x0b\x32\x34.oak9.tython.gcp.tags.TagsTagKeyIamBindingXCondition\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"W\n\x1dTagsTagKeyIamMemberXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\xdf\x01\n\x13TagsTagKeyIamMember\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0e\n\x06member\x18\x03 \x01(\t\x12\x0c\n\x04role\x18\x04 \x01(\t\x12\x0f\n\x07tag_key\x18\x05 \x01(\t\x12\x46\n\tcondition\x18\x06 \x01(\x0b\x32\x33.oak9.tython.gcp.tags.TagsTagKeyIamMemberXCondition\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x8e\x01\n\x13TagsTagKeyIamPolicy\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x13\n\x0bpolicy_data\x18\x03 \x01(\t\x12\x0f\n\x07tag_key\x18\x04 \x01(\t\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"G\n\x15TagsTagValueXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\x9c\x02\n\x0cTagsTagValue\x12\x13\n\x0b\x63reate_time\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x17\n\x0fnamespaced_name\x18\x05 \x01(\t\x12\x0e\n\x06parent\x18\x06 \x01(\t\x12\x12\n\nshort_name\x18\x07 \x01(\t\x12\x13\n\x0bupdate_time\x18\x08 \x01(\t\x12=\n\x08timeouts\x18\t \x01(\x0b\x32+.oak9.tython.gcp.tags.TagsTagValueXTimeouts\x12\x37\n\rresource_info\x18\n \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"Z\n TagsTagValueIamBindingXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\xe8\x01\n\x16TagsTagValueIamBinding\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0f\n\x07members\x18\x03 \x03(\t\x12\x0c\n\x04role\x18\x04 \x01(\t\x12\x11\n\ttag_value\x18\x05 \x01(\t\x12I\n\tcondition\x18\x06 \x01(\x0b\x32\x36.oak9.tython.gcp.tags.TagsTagValueIamBindingXCondition\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"Y\n\x1fTagsTagValueIamMemberXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\xe5\x01\n\x15TagsTagValueIamMember\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0e\n\x06member\x18\x03 \x01(\t\x12\x0c\n\x04role\x18\x04 \x01(\t\x12\x11\n\ttag_value\x18\x05 \x01(\t\x12H\n\tcondition\x18\x06 \x01(\x0b\x32\x35.oak9.tython.gcp.tags.TagsTagValueIamMemberXCondition\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x92\x01\n\x15TagsTagValueIamPolicy\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x13\n\x0bpolicy_data\x18\x03 \x01(\t\x12\x11\n\ttag_value\x18\x04 \x01(\t\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_tags_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _TAGSTAGBINDINGXTIMEOUTS._serialized_start=65
  _TAGSTAGBINDINGXTIMEOUTS._serialized_end=122
  _TAGSTAGBINDING._serialized_start=125
  _TAGSTAGBINDING._serialized_end=324
  _TAGSTAGKEYXTIMEOUTS._serialized_start=326
  _TAGSTAGKEYXTIMEOUTS._serialized_end=395
  _TAGSTAGKEY._serialized_start=398
  _TAGSTAGKEY._serialized_end=678
  _TAGSTAGKEYIAMBINDINGXCONDITION._serialized_start=680
  _TAGSTAGKEYIAMBINDINGXCONDITION._serialized_end=768
  _TAGSTAGKEYIAMBINDING._serialized_start=771
  _TAGSTAGKEYIAMBINDING._serialized_end=997
  _TAGSTAGKEYIAMMEMBERXCONDITION._serialized_start=999
  _TAGSTAGKEYIAMMEMBERXCONDITION._serialized_end=1086
  _TAGSTAGKEYIAMMEMBER._serialized_start=1089
  _TAGSTAGKEYIAMMEMBER._serialized_end=1312
  _TAGSTAGKEYIAMPOLICY._serialized_start=1315
  _TAGSTAGKEYIAMPOLICY._serialized_end=1457
  _TAGSTAGVALUEXTIMEOUTS._serialized_start=1459
  _TAGSTAGVALUEXTIMEOUTS._serialized_end=1530
  _TAGSTAGVALUE._serialized_start=1533
  _TAGSTAGVALUE._serialized_end=1817
  _TAGSTAGVALUEIAMBINDINGXCONDITION._serialized_start=1819
  _TAGSTAGVALUEIAMBINDINGXCONDITION._serialized_end=1909
  _TAGSTAGVALUEIAMBINDING._serialized_start=1912
  _TAGSTAGVALUEIAMBINDING._serialized_end=2144
  _TAGSTAGVALUEIAMMEMBERXCONDITION._serialized_start=2146
  _TAGSTAGVALUEIAMMEMBERXCONDITION._serialized_end=2235
  _TAGSTAGVALUEIAMMEMBER._serialized_start=2238
  _TAGSTAGVALUEIAMMEMBER._serialized_end=2467
  _TAGSTAGVALUEIAMPOLICY._serialized_start=2470
  _TAGSTAGVALUEIAMPOLICY._serialized_end=2616
# @@protoc_insertion_point(module_scope)
