"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ComputeSecurityPolicyXAdaptiveProtectionConfigXLayer7DdosDefenseConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLE_FIELD_NUMBER: builtins.int
    RULE_VISIBILITY_FIELD_NUMBER: builtins.int
    enable: builtins.bool
    rule_visibility: builtins.str
    def __init__(
        self,
        *,
        enable: builtins.bool = ...,
        rule_visibility: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["enable", b"enable", "rule_visibility", b"rule_visibility"]) -> None: ...

global___ComputeSecurityPolicyXAdaptiveProtectionConfigXLayer7DdosDefenseConfig = ComputeSecurityPolicyXAdaptiveProtectionConfigXLayer7DdosDefenseConfig

@typing_extensions.final
class ComputeSecurityPolicyXAdaptiveProtectionConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LAYER_7_DDOS_DEFENSE_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def layer_7_ddos_defense_config(self) -> global___ComputeSecurityPolicyXAdaptiveProtectionConfigXLayer7DdosDefenseConfig: ...
    def __init__(
        self,
        *,
        layer_7_ddos_defense_config: global___ComputeSecurityPolicyXAdaptiveProtectionConfigXLayer7DdosDefenseConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["layer_7_ddos_defense_config", b"layer_7_ddos_defense_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["layer_7_ddos_defense_config", b"layer_7_ddos_defense_config"]) -> None: ...

global___ComputeSecurityPolicyXAdaptiveProtectionConfig = ComputeSecurityPolicyXAdaptiveProtectionConfig

@typing_extensions.final
class ComputeSecurityPolicyXAdvancedOptionsConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JSON_PARSING_FIELD_NUMBER: builtins.int
    LOG_LEVEL_FIELD_NUMBER: builtins.int
    json_parsing: builtins.str
    log_level: builtins.str
    def __init__(
        self,
        *,
        json_parsing: builtins.str = ...,
        log_level: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["json_parsing", b"json_parsing", "log_level", b"log_level"]) -> None: ...

global___ComputeSecurityPolicyXAdvancedOptionsConfig = ComputeSecurityPolicyXAdvancedOptionsConfig

@typing_extensions.final
class ComputeSecurityPolicyXRuleXMatchXConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SRC_IP_RANGES_FIELD_NUMBER: builtins.int
    @property
    def src_ip_ranges(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        src_ip_ranges: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["src_ip_ranges", b"src_ip_ranges"]) -> None: ...

global___ComputeSecurityPolicyXRuleXMatchXConfig = ComputeSecurityPolicyXRuleXMatchXConfig

@typing_extensions.final
class ComputeSecurityPolicyXRuleXMatchXExpr(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXPRESSION_FIELD_NUMBER: builtins.int
    expression: builtins.str
    def __init__(
        self,
        *,
        expression: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["expression", b"expression"]) -> None: ...

global___ComputeSecurityPolicyXRuleXMatchXExpr = ComputeSecurityPolicyXRuleXMatchXExpr

@typing_extensions.final
class ComputeSecurityPolicyXRuleXMatch(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VERSIONED_EXPR_FIELD_NUMBER: builtins.int
    CONFIG_FIELD_NUMBER: builtins.int
    EXPR_FIELD_NUMBER: builtins.int
    versioned_expr: builtins.str
    @property
    def config(self) -> global___ComputeSecurityPolicyXRuleXMatchXConfig: ...
    @property
    def expr(self) -> global___ComputeSecurityPolicyXRuleXMatchXExpr: ...
    def __init__(
        self,
        *,
        versioned_expr: builtins.str = ...,
        config: global___ComputeSecurityPolicyXRuleXMatchXConfig | None = ...,
        expr: global___ComputeSecurityPolicyXRuleXMatchXExpr | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["config", b"config", "expr", b"expr"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["config", b"config", "expr", b"expr", "versioned_expr", b"versioned_expr"]) -> None: ...

global___ComputeSecurityPolicyXRuleXMatch = ComputeSecurityPolicyXRuleXMatch

@typing_extensions.final
class ComputeSecurityPolicyXRuleXRateLimitOptionsXBanThreshold(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COUNT_FIELD_NUMBER: builtins.int
    INTERVAL_SEC_FIELD_NUMBER: builtins.int
    count: builtins.float
    interval_sec: builtins.float
    def __init__(
        self,
        *,
        count: builtins.float = ...,
        interval_sec: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["count", b"count", "interval_sec", b"interval_sec"]) -> None: ...

global___ComputeSecurityPolicyXRuleXRateLimitOptionsXBanThreshold = ComputeSecurityPolicyXRuleXRateLimitOptionsXBanThreshold

@typing_extensions.final
class ComputeSecurityPolicyXRuleXRateLimitOptionsXExceedRedirectOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TARGET_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    target: builtins.str
    type: builtins.str
    def __init__(
        self,
        *,
        target: builtins.str = ...,
        type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["target", b"target", "type", b"type"]) -> None: ...

global___ComputeSecurityPolicyXRuleXRateLimitOptionsXExceedRedirectOptions = ComputeSecurityPolicyXRuleXRateLimitOptionsXExceedRedirectOptions

@typing_extensions.final
class ComputeSecurityPolicyXRuleXRateLimitOptionsXRateLimitThreshold(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COUNT_FIELD_NUMBER: builtins.int
    INTERVAL_SEC_FIELD_NUMBER: builtins.int
    count: builtins.float
    interval_sec: builtins.float
    def __init__(
        self,
        *,
        count: builtins.float = ...,
        interval_sec: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["count", b"count", "interval_sec", b"interval_sec"]) -> None: ...

global___ComputeSecurityPolicyXRuleXRateLimitOptionsXRateLimitThreshold = ComputeSecurityPolicyXRuleXRateLimitOptionsXRateLimitThreshold

@typing_extensions.final
class ComputeSecurityPolicyXRuleXRateLimitOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BAN_DURATION_SEC_FIELD_NUMBER: builtins.int
    CONFORM_ACTION_FIELD_NUMBER: builtins.int
    ENFORCE_ON_KEY_FIELD_NUMBER: builtins.int
    ENFORCE_ON_KEY_NAME_FIELD_NUMBER: builtins.int
    EXCEED_ACTION_FIELD_NUMBER: builtins.int
    BAN_THRESHOLD_FIELD_NUMBER: builtins.int
    EXCEED_REDIRECT_OPTIONS_FIELD_NUMBER: builtins.int
    RATE_LIMIT_THRESHOLD_FIELD_NUMBER: builtins.int
    ban_duration_sec: builtins.float
    conform_action: builtins.str
    enforce_on_key: builtins.str
    enforce_on_key_name: builtins.str
    exceed_action: builtins.str
    @property
    def ban_threshold(self) -> global___ComputeSecurityPolicyXRuleXRateLimitOptionsXBanThreshold: ...
    @property
    def exceed_redirect_options(self) -> global___ComputeSecurityPolicyXRuleXRateLimitOptionsXExceedRedirectOptions: ...
    @property
    def rate_limit_threshold(self) -> global___ComputeSecurityPolicyXRuleXRateLimitOptionsXRateLimitThreshold: ...
    def __init__(
        self,
        *,
        ban_duration_sec: builtins.float = ...,
        conform_action: builtins.str = ...,
        enforce_on_key: builtins.str = ...,
        enforce_on_key_name: builtins.str = ...,
        exceed_action: builtins.str = ...,
        ban_threshold: global___ComputeSecurityPolicyXRuleXRateLimitOptionsXBanThreshold | None = ...,
        exceed_redirect_options: global___ComputeSecurityPolicyXRuleXRateLimitOptionsXExceedRedirectOptions | None = ...,
        rate_limit_threshold: global___ComputeSecurityPolicyXRuleXRateLimitOptionsXRateLimitThreshold | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["ban_threshold", b"ban_threshold", "exceed_redirect_options", b"exceed_redirect_options", "rate_limit_threshold", b"rate_limit_threshold"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ban_duration_sec", b"ban_duration_sec", "ban_threshold", b"ban_threshold", "conform_action", b"conform_action", "enforce_on_key", b"enforce_on_key", "enforce_on_key_name", b"enforce_on_key_name", "exceed_action", b"exceed_action", "exceed_redirect_options", b"exceed_redirect_options", "rate_limit_threshold", b"rate_limit_threshold"]) -> None: ...

global___ComputeSecurityPolicyXRuleXRateLimitOptions = ComputeSecurityPolicyXRuleXRateLimitOptions

@typing_extensions.final
class ComputeSecurityPolicyXRuleXRedirectOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TARGET_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    target: builtins.str
    type: builtins.str
    def __init__(
        self,
        *,
        target: builtins.str = ...,
        type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["target", b"target", "type", b"type"]) -> None: ...

global___ComputeSecurityPolicyXRuleXRedirectOptions = ComputeSecurityPolicyXRuleXRedirectOptions

@typing_extensions.final
class ComputeSecurityPolicyXRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACTION_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    PREVIEW_FIELD_NUMBER: builtins.int
    PRIORITY_FIELD_NUMBER: builtins.int
    MATCH_FIELD_NUMBER: builtins.int
    RATE_LIMIT_OPTIONS_FIELD_NUMBER: builtins.int
    REDIRECT_OPTIONS_FIELD_NUMBER: builtins.int
    action: builtins.str
    description: builtins.str
    preview: builtins.bool
    priority: builtins.float
    @property
    def match(self) -> global___ComputeSecurityPolicyXRuleXMatch: ...
    @property
    def rate_limit_options(self) -> global___ComputeSecurityPolicyXRuleXRateLimitOptions: ...
    @property
    def redirect_options(self) -> global___ComputeSecurityPolicyXRuleXRedirectOptions: ...
    def __init__(
        self,
        *,
        action: builtins.str = ...,
        description: builtins.str = ...,
        preview: builtins.bool = ...,
        priority: builtins.float = ...,
        match: global___ComputeSecurityPolicyXRuleXMatch | None = ...,
        rate_limit_options: global___ComputeSecurityPolicyXRuleXRateLimitOptions | None = ...,
        redirect_options: global___ComputeSecurityPolicyXRuleXRedirectOptions | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["match", b"match", "rate_limit_options", b"rate_limit_options", "redirect_options", b"redirect_options"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["action", b"action", "description", b"description", "match", b"match", "preview", b"preview", "priority", b"priority", "rate_limit_options", b"rate_limit_options", "redirect_options", b"redirect_options"]) -> None: ...

global___ComputeSecurityPolicyXRule = ComputeSecurityPolicyXRule

@typing_extensions.final
class ComputeSecurityPolicyXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___ComputeSecurityPolicyXTimeouts = ComputeSecurityPolicyXTimeouts

@typing_extensions.final
class ComputeSecurityPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    FINGERPRINT_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    SELF_LINK_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    ADAPTIVE_PROTECTION_CONFIG_FIELD_NUMBER: builtins.int
    ADVANCED_OPTIONS_CONFIG_FIELD_NUMBER: builtins.int
    RULE_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    description: builtins.str
    fingerprint: builtins.str
    id: builtins.str
    name: builtins.str
    project: builtins.str
    self_link: builtins.str
    type: builtins.str
    @property
    def adaptive_protection_config(self) -> global___ComputeSecurityPolicyXAdaptiveProtectionConfig: ...
    @property
    def advanced_options_config(self) -> global___ComputeSecurityPolicyXAdvancedOptionsConfig: ...
    @property
    def rule(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeSecurityPolicyXRule]: ...
    @property
    def timeouts(self) -> global___ComputeSecurityPolicyXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        fingerprint: builtins.str = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        self_link: builtins.str = ...,
        type: builtins.str = ...,
        adaptive_protection_config: global___ComputeSecurityPolicyXAdaptiveProtectionConfig | None = ...,
        advanced_options_config: global___ComputeSecurityPolicyXAdvancedOptionsConfig | None = ...,
        rule: collections.abc.Iterable[global___ComputeSecurityPolicyXRule] | None = ...,
        timeouts: global___ComputeSecurityPolicyXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["adaptive_protection_config", b"adaptive_protection_config", "advanced_options_config", b"advanced_options_config", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["adaptive_protection_config", b"adaptive_protection_config", "advanced_options_config", b"advanced_options_config", "description", b"description", "fingerprint", b"fingerprint", "id", b"id", "name", b"name", "project", b"project", "resource_info", b"resource_info", "rule", b"rule", "self_link", b"self_link", "timeouts", b"timeouts", "type", b"type"]) -> None: ...

global___ComputeSecurityPolicy = ComputeSecurityPolicy
