"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Microsoft_Network_networkSecurityGroups(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NETWORK_SECURITY_GROUPS_FIELD_NUMBER: builtins.int
    NETWORK_SECURITY_GROUPS_SECURITY_RULES_FIELD_NUMBER: builtins.int
    @property
    def network_security_groups(self) -> global___NetworkSecurityGroups: ...
    @property
    def network_security_groups_security_rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NetworkSecurityGroupsSecurityRules]: ...
    def __init__(
        self,
        *,
        network_security_groups: global___NetworkSecurityGroups | None = ...,
        network_security_groups_security_rules: collections.abc.Iterable[global___NetworkSecurityGroupsSecurityRules] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["network_security_groups", b"network_security_groups"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["network_security_groups", b"network_security_groups", "network_security_groups_security_rules", b"network_security_groups_security_rules"]) -> None: ...

global___Microsoft_Network_networkSecurityGroups = Microsoft_Network_networkSecurityGroups

@typing_extensions.final
class NetworkSecurityGroupsSecurityRules(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    PROTOCOL_FIELD_NUMBER: builtins.int
    SOURCE_PORT_RANGE_FIELD_NUMBER: builtins.int
    DESTINATION_PORT_RANGE_FIELD_NUMBER: builtins.int
    SOURCE_ADDRESS_PREFIX_FIELD_NUMBER: builtins.int
    SOURCE_ADDRESS_PREFIXES_FIELD_NUMBER: builtins.int
    SOURCE_APPLICATION_SECURITY_GROUPS_FIELD_NUMBER: builtins.int
    DESTINATION_ADDRESS_PREFIX_FIELD_NUMBER: builtins.int
    DESTINATION_ADDRESS_PREFIXES_FIELD_NUMBER: builtins.int
    DESTINATION_APPLICATION_SECURITY_GROUPS_FIELD_NUMBER: builtins.int
    SOURCE_PORT_RANGES_FIELD_NUMBER: builtins.int
    DESTINATION_PORT_RANGES_FIELD_NUMBER: builtins.int
    ACCESS_FIELD_NUMBER: builtins.int
    PRIORITY_FIELD_NUMBER: builtins.int
    DIRECTION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    description: builtins.str
    protocol: builtins.str
    source_port_range: builtins.str
    destination_port_range: builtins.str
    source_address_prefix: builtins.str
    @property
    def source_address_prefixes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def source_application_security_groups(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    destination_address_prefix: builtins.str
    @property
    def destination_address_prefixes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def destination_application_security_groups(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def source_port_ranges(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def destination_port_ranges(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    access: builtins.str
    priority: builtins.int
    direction: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        protocol: builtins.str = ...,
        source_port_range: builtins.str = ...,
        destination_port_range: builtins.str = ...,
        source_address_prefix: builtins.str = ...,
        source_address_prefixes: collections.abc.Iterable[builtins.str] | None = ...,
        source_application_security_groups: collections.abc.Iterable[builtins.str] | None = ...,
        destination_address_prefix: builtins.str = ...,
        destination_address_prefixes: collections.abc.Iterable[builtins.str] | None = ...,
        destination_application_security_groups: collections.abc.Iterable[builtins.str] | None = ...,
        source_port_ranges: collections.abc.Iterable[builtins.str] | None = ...,
        destination_port_ranges: collections.abc.Iterable[builtins.str] | None = ...,
        access: builtins.str = ...,
        priority: builtins.int = ...,
        direction: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["access", b"access", "description", b"description", "destination_address_prefix", b"destination_address_prefix", "destination_address_prefixes", b"destination_address_prefixes", "destination_application_security_groups", b"destination_application_security_groups", "destination_port_range", b"destination_port_range", "destination_port_ranges", b"destination_port_ranges", "direction", b"direction", "name", b"name", "priority", b"priority", "protocol", b"protocol", "resource_info", b"resource_info", "source_address_prefix", b"source_address_prefix", "source_address_prefixes", b"source_address_prefixes", "source_application_security_groups", b"source_application_security_groups", "source_port_range", b"source_port_range", "source_port_ranges", b"source_port_ranges"]) -> None: ...

global___NetworkSecurityGroupsSecurityRules = NetworkSecurityGroupsSecurityRules

@typing_extensions.final
class NetworkSecurityGroups(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    SECURITY_RULES_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    location: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def security_rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SecurityRule]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        location: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        security_rules: collections.abc.Iterable[global___SecurityRule] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["location", b"location", "name", b"name", "resource_info", b"resource_info", "security_rules", b"security_rules", "tags", b"tags"]) -> None: ...

global___NetworkSecurityGroups = NetworkSecurityGroups

@typing_extensions.final
class SecurityRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    PROTOCOL_FIELD_NUMBER: builtins.int
    SOURCE_PORT_RANGE_FIELD_NUMBER: builtins.int
    DESTINATION_PORT_RANGE_FIELD_NUMBER: builtins.int
    SOURCE_ADDRESS_PREFIX_FIELD_NUMBER: builtins.int
    SOURCE_ADDRESS_PREFIXES_FIELD_NUMBER: builtins.int
    SOURCE_APPLICATION_SECURITY_GROUPS_FIELD_NUMBER: builtins.int
    DESTINATION_ADDRESS_PREFIX_FIELD_NUMBER: builtins.int
    DESTINATION_ADDRESS_PREFIXES_FIELD_NUMBER: builtins.int
    DESTINATION_APPLICATION_SECURITY_GROUPS_FIELD_NUMBER: builtins.int
    SOURCE_PORT_RANGES_FIELD_NUMBER: builtins.int
    DESTINATION_PORT_RANGES_FIELD_NUMBER: builtins.int
    ACCESS_FIELD_NUMBER: builtins.int
    PRIORITY_FIELD_NUMBER: builtins.int
    DIRECTION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    description: builtins.str
    protocol: builtins.str
    source_port_range: builtins.str
    destination_port_range: builtins.str
    source_address_prefix: builtins.str
    @property
    def source_address_prefixes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def source_application_security_groups(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    destination_address_prefix: builtins.str
    @property
    def destination_address_prefixes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def destination_application_security_groups(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def source_port_ranges(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def destination_port_ranges(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    access: builtins.str
    priority: builtins.int
    direction: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        protocol: builtins.str = ...,
        source_port_range: builtins.str = ...,
        destination_port_range: builtins.str = ...,
        source_address_prefix: builtins.str = ...,
        source_address_prefixes: collections.abc.Iterable[builtins.str] | None = ...,
        source_application_security_groups: collections.abc.Iterable[builtins.str] | None = ...,
        destination_address_prefix: builtins.str = ...,
        destination_address_prefixes: collections.abc.Iterable[builtins.str] | None = ...,
        destination_application_security_groups: collections.abc.Iterable[builtins.str] | None = ...,
        source_port_ranges: collections.abc.Iterable[builtins.str] | None = ...,
        destination_port_ranges: collections.abc.Iterable[builtins.str] | None = ...,
        access: builtins.str = ...,
        priority: builtins.int = ...,
        direction: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["access", b"access", "description", b"description", "destination_address_prefix", b"destination_address_prefix", "destination_address_prefixes", b"destination_address_prefixes", "destination_application_security_groups", b"destination_application_security_groups", "destination_port_range", b"destination_port_range", "destination_port_ranges", b"destination_port_ranges", "direction", b"direction", "name", b"name", "priority", b"priority", "protocol", b"protocol", "source_address_prefix", b"source_address_prefix", "source_address_prefixes", b"source_address_prefixes", "source_application_security_groups", b"source_application_security_groups", "source_port_range", b"source_port_range", "source_port_ranges", b"source_port_ranges"]) -> None: ...

global___SecurityRule = SecurityRule
