# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: azure/azure_microsoft_network_networksecuritygroups.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n9azure/azure_microsoft_network_networksecuritygroups.proto\x12\x39oak9.tython.azure.microsoft_network_networksecuritygroups\x1a\x13shared/shared.proto\"\xac\x02\n\'Microsoft_Network_networkSecurityGroups\x12q\n\x17network_security_groups\x18\x01 \x01(\x0b\x32P.oak9.tython.azure.microsoft_network_networksecuritygroups.NetworkSecurityGroups\x12\x8d\x01\n&network_security_groups_security_rules\x18\x02 \x03(\x0b\x32].oak9.tython.azure.microsoft_network_networksecuritygroups.NetworkSecurityGroupsSecurityRules\"\xa6\x04\n\"NetworkSecurityGroupsSecurityRules\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x10\n\x08protocol\x18\x04 \x01(\t\x12\x19\n\x11source_port_range\x18\x05 \x01(\t\x12\x1e\n\x16\x64\x65stination_port_range\x18\x06 \x01(\t\x12\x1d\n\x15source_address_prefix\x18\x07 \x01(\t\x12\x1f\n\x17source_address_prefixes\x18\x08 \x03(\t\x12*\n\"source_application_security_groups\x18\t \x03(\t\x12\"\n\x1a\x64\x65stination_address_prefix\x18\n \x01(\t\x12$\n\x1c\x64\x65stination_address_prefixes\x18\x0b \x03(\t\x12/\n\'destination_application_security_groups\x18\x0c \x03(\t\x12\x1a\n\x12source_port_ranges\x18\r \x03(\t\x12\x1f\n\x17\x64\x65stination_port_ranges\x18\x0e \x03(\t\x12\x0e\n\x06\x61\x63\x63\x65ss\x18\x0f \x01(\t\x12\x10\n\x08priority\x18\x10 \x01(\x05\x12\x11\n\tdirection\x18\x11 \x01(\t\"\xe8\x02\n\x15NetworkSecurityGroups\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12h\n\x04tags\x18\x04 \x03(\x0b\x32Z.oak9.tython.azure.microsoft_network_networksecuritygroups.NetworkSecurityGroups.TagsEntry\x12_\n\x0esecurity_rules\x18\x05 \x03(\x0b\x32G.oak9.tython.azure.microsoft_network_networksecuritygroups.SecurityRule\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xd7\x03\n\x0cSecurityRule\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x10\n\x08protocol\x18\x02 \x01(\t\x12\x19\n\x11source_port_range\x18\x03 \x01(\t\x12\x1e\n\x16\x64\x65stination_port_range\x18\x04 \x01(\t\x12\x1d\n\x15source_address_prefix\x18\x05 \x01(\t\x12\x1f\n\x17source_address_prefixes\x18\x06 \x03(\t\x12*\n\"source_application_security_groups\x18\x07 \x03(\t\x12\"\n\x1a\x64\x65stination_address_prefix\x18\x08 \x01(\t\x12$\n\x1c\x64\x65stination_address_prefixes\x18\t \x03(\t\x12/\n\'destination_application_security_groups\x18\n \x03(\t\x12\x1a\n\x12source_port_ranges\x18\x0b \x03(\t\x12\x1f\n\x17\x64\x65stination_port_ranges\x18\x0c \x03(\t\x12\x0e\n\x06\x61\x63\x63\x65ss\x18\r \x01(\t\x12\x10\n\x08priority\x18\x0e \x01(\x05\x12\x11\n\tdirection\x18\x0f \x01(\t\x12\x0c\n\x04name\x18\x10 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'azure.azure_microsoft_network_networksecuritygroups_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _NETWORKSECURITYGROUPS_TAGSENTRY._options = None
  _NETWORKSECURITYGROUPS_TAGSENTRY._serialized_options = b'8\001'
  _MICROSOFT_NETWORK_NETWORKSECURITYGROUPS._serialized_start=142
  _MICROSOFT_NETWORK_NETWORKSECURITYGROUPS._serialized_end=442
  _NETWORKSECURITYGROUPSSECURITYRULES._serialized_start=445
  _NETWORKSECURITYGROUPSSECURITYRULES._serialized_end=995
  _NETWORKSECURITYGROUPS._serialized_start=998
  _NETWORKSECURITYGROUPS._serialized_end=1358
  _NETWORKSECURITYGROUPS_TAGSENTRY._serialized_start=1315
  _NETWORKSECURITYGROUPS_TAGSENTRY._serialized_end=1358
  _SECURITYRULE._serialized_start=1361
  _SECURITYRULE._serialized_end=1832
# @@protoc_insertion_point(module_scope)
