"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class SqlDatabaseXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___SqlDatabaseXTimeouts = SqlDatabaseXTimeouts

@typing_extensions.final
class SqlDatabase(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHARSET_FIELD_NUMBER: builtins.int
    COLLATION_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    INSTANCE_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    SELF_LINK_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    charset: builtins.str
    collation: builtins.str
    id: builtins.str
    instance: builtins.str
    name: builtins.str
    project: builtins.str
    self_link: builtins.str
    @property
    def timeouts(self) -> global___SqlDatabaseXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        charset: builtins.str = ...,
        collation: builtins.str = ...,
        id: builtins.str = ...,
        instance: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        self_link: builtins.str = ...,
        timeouts: global___SqlDatabaseXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["charset", b"charset", "collation", b"collation", "id", b"id", "instance", b"instance", "name", b"name", "project", b"project", "resource_info", b"resource_info", "self_link", b"self_link", "timeouts", b"timeouts"]) -> None: ...

global___SqlDatabase = SqlDatabase

@typing_extensions.final
class SqlDatabaseInstanceXReplicaConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CA_CERTIFICATE_FIELD_NUMBER: builtins.int
    CLIENT_CERTIFICATE_FIELD_NUMBER: builtins.int
    CLIENT_KEY_FIELD_NUMBER: builtins.int
    CONNECT_RETRY_INTERVAL_FIELD_NUMBER: builtins.int
    DUMP_FILE_PATH_FIELD_NUMBER: builtins.int
    FAILOVER_TARGET_FIELD_NUMBER: builtins.int
    MASTER_HEARTBEAT_PERIOD_FIELD_NUMBER: builtins.int
    PASSWORD_FIELD_NUMBER: builtins.int
    SSL_CIPHER_FIELD_NUMBER: builtins.int
    USERNAME_FIELD_NUMBER: builtins.int
    VERIFY_SERVER_CERTIFICATE_FIELD_NUMBER: builtins.int
    ca_certificate: builtins.str
    client_certificate: builtins.str
    client_key: builtins.str
    connect_retry_interval: builtins.float
    dump_file_path: builtins.str
    failover_target: builtins.bool
    master_heartbeat_period: builtins.float
    password: builtins.str
    ssl_cipher: builtins.str
    username: builtins.str
    verify_server_certificate: builtins.bool
    def __init__(
        self,
        *,
        ca_certificate: builtins.str = ...,
        client_certificate: builtins.str = ...,
        client_key: builtins.str = ...,
        connect_retry_interval: builtins.float = ...,
        dump_file_path: builtins.str = ...,
        failover_target: builtins.bool = ...,
        master_heartbeat_period: builtins.float = ...,
        password: builtins.str = ...,
        ssl_cipher: builtins.str = ...,
        username: builtins.str = ...,
        verify_server_certificate: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["ca_certificate", b"ca_certificate", "client_certificate", b"client_certificate", "client_key", b"client_key", "connect_retry_interval", b"connect_retry_interval", "dump_file_path", b"dump_file_path", "failover_target", b"failover_target", "master_heartbeat_period", b"master_heartbeat_period", "password", b"password", "ssl_cipher", b"ssl_cipher", "username", b"username", "verify_server_certificate", b"verify_server_certificate"]) -> None: ...

global___SqlDatabaseInstanceXReplicaConfiguration = SqlDatabaseInstanceXReplicaConfiguration

@typing_extensions.final
class SqlDatabaseInstanceXRestoreBackupContext(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BACKUP_RUN_ID_FIELD_NUMBER: builtins.int
    INSTANCE_ID_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    backup_run_id: builtins.float
    instance_id: builtins.str
    project: builtins.str
    def __init__(
        self,
        *,
        backup_run_id: builtins.float = ...,
        instance_id: builtins.str = ...,
        project: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["backup_run_id", b"backup_run_id", "instance_id", b"instance_id", "project", b"project"]) -> None: ...

global___SqlDatabaseInstanceXRestoreBackupContext = SqlDatabaseInstanceXRestoreBackupContext

@typing_extensions.final
class SqlDatabaseInstanceXSettingsXActiveDirectoryConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DOMAIN_FIELD_NUMBER: builtins.int
    domain: builtins.str
    def __init__(
        self,
        *,
        domain: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["domain", b"domain"]) -> None: ...

global___SqlDatabaseInstanceXSettingsXActiveDirectoryConfig = SqlDatabaseInstanceXSettingsXActiveDirectoryConfig

@typing_extensions.final
class SqlDatabaseInstanceXSettingsXBackupConfigurationXBackupRetentionSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RETAINED_BACKUPS_FIELD_NUMBER: builtins.int
    RETENTION_UNIT_FIELD_NUMBER: builtins.int
    retained_backups: builtins.float
    retention_unit: builtins.str
    def __init__(
        self,
        *,
        retained_backups: builtins.float = ...,
        retention_unit: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["retained_backups", b"retained_backups", "retention_unit", b"retention_unit"]) -> None: ...

global___SqlDatabaseInstanceXSettingsXBackupConfigurationXBackupRetentionSettings = SqlDatabaseInstanceXSettingsXBackupConfigurationXBackupRetentionSettings

@typing_extensions.final
class SqlDatabaseInstanceXSettingsXBackupConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BINARY_LOG_ENABLED_FIELD_NUMBER: builtins.int
    ENABLED_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    POINT_IN_TIME_RECOVERY_ENABLED_FIELD_NUMBER: builtins.int
    START_TIME_FIELD_NUMBER: builtins.int
    TRANSACTION_LOG_RETENTION_DAYS_FIELD_NUMBER: builtins.int
    BACKUP_RETENTION_SETTINGS_FIELD_NUMBER: builtins.int
    binary_log_enabled: builtins.bool
    enabled: builtins.bool
    location: builtins.str
    point_in_time_recovery_enabled: builtins.bool
    start_time: builtins.str
    transaction_log_retention_days: builtins.float
    @property
    def backup_retention_settings(self) -> global___SqlDatabaseInstanceXSettingsXBackupConfigurationXBackupRetentionSettings: ...
    def __init__(
        self,
        *,
        binary_log_enabled: builtins.bool = ...,
        enabled: builtins.bool = ...,
        location: builtins.str = ...,
        point_in_time_recovery_enabled: builtins.bool = ...,
        start_time: builtins.str = ...,
        transaction_log_retention_days: builtins.float = ...,
        backup_retention_settings: global___SqlDatabaseInstanceXSettingsXBackupConfigurationXBackupRetentionSettings | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["backup_retention_settings", b"backup_retention_settings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["backup_retention_settings", b"backup_retention_settings", "binary_log_enabled", b"binary_log_enabled", "enabled", b"enabled", "location", b"location", "point_in_time_recovery_enabled", b"point_in_time_recovery_enabled", "start_time", b"start_time", "transaction_log_retention_days", b"transaction_log_retention_days"]) -> None: ...

global___SqlDatabaseInstanceXSettingsXBackupConfiguration = SqlDatabaseInstanceXSettingsXBackupConfiguration

@typing_extensions.final
class SqlDatabaseInstanceXSettingsXDatabaseFlags(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    name: builtins.str
    value: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "value", b"value"]) -> None: ...

global___SqlDatabaseInstanceXSettingsXDatabaseFlags = SqlDatabaseInstanceXSettingsXDatabaseFlags

@typing_extensions.final
class SqlDatabaseInstanceXSettingsXInsightsConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    QUERY_INSIGHTS_ENABLED_FIELD_NUMBER: builtins.int
    QUERY_STRING_LENGTH_FIELD_NUMBER: builtins.int
    RECORD_APPLICATION_TAGS_FIELD_NUMBER: builtins.int
    RECORD_CLIENT_ADDRESS_FIELD_NUMBER: builtins.int
    query_insights_enabled: builtins.bool
    query_string_length: builtins.float
    record_application_tags: builtins.bool
    record_client_address: builtins.bool
    def __init__(
        self,
        *,
        query_insights_enabled: builtins.bool = ...,
        query_string_length: builtins.float = ...,
        record_application_tags: builtins.bool = ...,
        record_client_address: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["query_insights_enabled", b"query_insights_enabled", "query_string_length", b"query_string_length", "record_application_tags", b"record_application_tags", "record_client_address", b"record_client_address"]) -> None: ...

global___SqlDatabaseInstanceXSettingsXInsightsConfig = SqlDatabaseInstanceXSettingsXInsightsConfig

@typing_extensions.final
class SqlDatabaseInstanceXSettingsXIpConfigurationXAuthorizedNetworks(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXPIRATION_TIME_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    expiration_time: builtins.str
    name: builtins.str
    value: builtins.str
    def __init__(
        self,
        *,
        expiration_time: builtins.str = ...,
        name: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["expiration_time", b"expiration_time", "name", b"name", "value", b"value"]) -> None: ...

global___SqlDatabaseInstanceXSettingsXIpConfigurationXAuthorizedNetworks = SqlDatabaseInstanceXSettingsXIpConfigurationXAuthorizedNetworks

@typing_extensions.final
class SqlDatabaseInstanceXSettingsXIpConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALLOCATED_IP_RANGE_FIELD_NUMBER: builtins.int
    IPV4_ENABLED_FIELD_NUMBER: builtins.int
    PRIVATE_NETWORK_FIELD_NUMBER: builtins.int
    REQUIRE_SSL_FIELD_NUMBER: builtins.int
    AUTHORIZED_NETWORKS_FIELD_NUMBER: builtins.int
    allocated_ip_range: builtins.str
    ipv4_enabled: builtins.bool
    private_network: builtins.str
    require_ssl: builtins.bool
    @property
    def authorized_networks(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SqlDatabaseInstanceXSettingsXIpConfigurationXAuthorizedNetworks]: ...
    def __init__(
        self,
        *,
        allocated_ip_range: builtins.str = ...,
        ipv4_enabled: builtins.bool = ...,
        private_network: builtins.str = ...,
        require_ssl: builtins.bool = ...,
        authorized_networks: collections.abc.Iterable[global___SqlDatabaseInstanceXSettingsXIpConfigurationXAuthorizedNetworks] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["allocated_ip_range", b"allocated_ip_range", "authorized_networks", b"authorized_networks", "ipv4_enabled", b"ipv4_enabled", "private_network", b"private_network", "require_ssl", b"require_ssl"]) -> None: ...

global___SqlDatabaseInstanceXSettingsXIpConfiguration = SqlDatabaseInstanceXSettingsXIpConfiguration

@typing_extensions.final
class SqlDatabaseInstanceXSettingsXLocationPreference(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLLOW_GAE_APPLICATION_FIELD_NUMBER: builtins.int
    SECONDARY_ZONE_FIELD_NUMBER: builtins.int
    ZONE_FIELD_NUMBER: builtins.int
    follow_gae_application: builtins.str
    secondary_zone: builtins.str
    zone: builtins.str
    def __init__(
        self,
        *,
        follow_gae_application: builtins.str = ...,
        secondary_zone: builtins.str = ...,
        zone: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["follow_gae_application", b"follow_gae_application", "secondary_zone", b"secondary_zone", "zone", b"zone"]) -> None: ...

global___SqlDatabaseInstanceXSettingsXLocationPreference = SqlDatabaseInstanceXSettingsXLocationPreference

@typing_extensions.final
class SqlDatabaseInstanceXSettingsXMaintenanceWindow(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DAY_FIELD_NUMBER: builtins.int
    HOUR_FIELD_NUMBER: builtins.int
    UPDATE_TRACK_FIELD_NUMBER: builtins.int
    day: builtins.float
    hour: builtins.float
    update_track: builtins.str
    def __init__(
        self,
        *,
        day: builtins.float = ...,
        hour: builtins.float = ...,
        update_track: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["day", b"day", "hour", b"hour", "update_track", b"update_track"]) -> None: ...

global___SqlDatabaseInstanceXSettingsXMaintenanceWindow = SqlDatabaseInstanceXSettingsXMaintenanceWindow

@typing_extensions.final
class SqlDatabaseInstanceXSettingsXSqlServerAuditConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUCKET_FIELD_NUMBER: builtins.int
    RETENTION_INTERVAL_FIELD_NUMBER: builtins.int
    UPLOAD_INTERVAL_FIELD_NUMBER: builtins.int
    bucket: builtins.str
    retention_interval: builtins.str
    upload_interval: builtins.str
    def __init__(
        self,
        *,
        bucket: builtins.str = ...,
        retention_interval: builtins.str = ...,
        upload_interval: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bucket", b"bucket", "retention_interval", b"retention_interval", "upload_interval", b"upload_interval"]) -> None: ...

global___SqlDatabaseInstanceXSettingsXSqlServerAuditConfig = SqlDatabaseInstanceXSettingsXSqlServerAuditConfig

@typing_extensions.final
class SqlDatabaseInstanceXSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class UserLabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    ACTIVATION_POLICY_FIELD_NUMBER: builtins.int
    AVAILABILITY_TYPE_FIELD_NUMBER: builtins.int
    COLLATION_FIELD_NUMBER: builtins.int
    DISK_AUTORESIZE_FIELD_NUMBER: builtins.int
    DISK_AUTORESIZE_LIMIT_FIELD_NUMBER: builtins.int
    DISK_SIZE_FIELD_NUMBER: builtins.int
    DISK_TYPE_FIELD_NUMBER: builtins.int
    PRICING_PLAN_FIELD_NUMBER: builtins.int
    TIER_FIELD_NUMBER: builtins.int
    USER_LABELS_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    ACTIVE_DIRECTORY_CONFIG_FIELD_NUMBER: builtins.int
    BACKUP_CONFIGURATION_FIELD_NUMBER: builtins.int
    DATABASE_FLAGS_FIELD_NUMBER: builtins.int
    INSIGHTS_CONFIG_FIELD_NUMBER: builtins.int
    IP_CONFIGURATION_FIELD_NUMBER: builtins.int
    LOCATION_PREFERENCE_FIELD_NUMBER: builtins.int
    MAINTENANCE_WINDOW_FIELD_NUMBER: builtins.int
    SQL_SERVER_AUDIT_CONFIG_FIELD_NUMBER: builtins.int
    activation_policy: builtins.str
    availability_type: builtins.str
    collation: builtins.str
    disk_autoresize: builtins.bool
    disk_autoresize_limit: builtins.float
    disk_size: builtins.float
    disk_type: builtins.str
    pricing_plan: builtins.str
    tier: builtins.str
    @property
    def user_labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    version: builtins.float
    @property
    def active_directory_config(self) -> global___SqlDatabaseInstanceXSettingsXActiveDirectoryConfig: ...
    @property
    def backup_configuration(self) -> global___SqlDatabaseInstanceXSettingsXBackupConfiguration: ...
    @property
    def database_flags(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SqlDatabaseInstanceXSettingsXDatabaseFlags]: ...
    @property
    def insights_config(self) -> global___SqlDatabaseInstanceXSettingsXInsightsConfig: ...
    @property
    def ip_configuration(self) -> global___SqlDatabaseInstanceXSettingsXIpConfiguration: ...
    @property
    def location_preference(self) -> global___SqlDatabaseInstanceXSettingsXLocationPreference: ...
    @property
    def maintenance_window(self) -> global___SqlDatabaseInstanceXSettingsXMaintenanceWindow: ...
    @property
    def sql_server_audit_config(self) -> global___SqlDatabaseInstanceXSettingsXSqlServerAuditConfig: ...
    def __init__(
        self,
        *,
        activation_policy: builtins.str = ...,
        availability_type: builtins.str = ...,
        collation: builtins.str = ...,
        disk_autoresize: builtins.bool = ...,
        disk_autoresize_limit: builtins.float = ...,
        disk_size: builtins.float = ...,
        disk_type: builtins.str = ...,
        pricing_plan: builtins.str = ...,
        tier: builtins.str = ...,
        user_labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        version: builtins.float = ...,
        active_directory_config: global___SqlDatabaseInstanceXSettingsXActiveDirectoryConfig | None = ...,
        backup_configuration: global___SqlDatabaseInstanceXSettingsXBackupConfiguration | None = ...,
        database_flags: collections.abc.Iterable[global___SqlDatabaseInstanceXSettingsXDatabaseFlags] | None = ...,
        insights_config: global___SqlDatabaseInstanceXSettingsXInsightsConfig | None = ...,
        ip_configuration: global___SqlDatabaseInstanceXSettingsXIpConfiguration | None = ...,
        location_preference: global___SqlDatabaseInstanceXSettingsXLocationPreference | None = ...,
        maintenance_window: global___SqlDatabaseInstanceXSettingsXMaintenanceWindow | None = ...,
        sql_server_audit_config: global___SqlDatabaseInstanceXSettingsXSqlServerAuditConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["active_directory_config", b"active_directory_config", "backup_configuration", b"backup_configuration", "insights_config", b"insights_config", "ip_configuration", b"ip_configuration", "location_preference", b"location_preference", "maintenance_window", b"maintenance_window", "sql_server_audit_config", b"sql_server_audit_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["activation_policy", b"activation_policy", "active_directory_config", b"active_directory_config", "availability_type", b"availability_type", "backup_configuration", b"backup_configuration", "collation", b"collation", "database_flags", b"database_flags", "disk_autoresize", b"disk_autoresize", "disk_autoresize_limit", b"disk_autoresize_limit", "disk_size", b"disk_size", "disk_type", b"disk_type", "insights_config", b"insights_config", "ip_configuration", b"ip_configuration", "location_preference", b"location_preference", "maintenance_window", b"maintenance_window", "pricing_plan", b"pricing_plan", "sql_server_audit_config", b"sql_server_audit_config", "tier", b"tier", "user_labels", b"user_labels", "version", b"version"]) -> None: ...

global___SqlDatabaseInstanceXSettings = SqlDatabaseInstanceXSettings

@typing_extensions.final
class SqlDatabaseInstanceXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___SqlDatabaseInstanceXTimeouts = SqlDatabaseInstanceXTimeouts

@typing_extensions.final
class SqlDatabaseInstance(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class IpAddressEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class ServerCaCertEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    CONNECTION_NAME_FIELD_NUMBER: builtins.int
    DATABASE_VERSION_FIELD_NUMBER: builtins.int
    DELETION_PROTECTION_FIELD_NUMBER: builtins.int
    ENCRYPTION_KEY_NAME_FIELD_NUMBER: builtins.int
    FIRST_IP_ADDRESS_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    IP_ADDRESS_FIELD_NUMBER: builtins.int
    MASTER_INSTANCE_NAME_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PRIVATE_IP_ADDRESS_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    PUBLIC_IP_ADDRESS_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    ROOT_PASSWORD_FIELD_NUMBER: builtins.int
    SELF_LINK_FIELD_NUMBER: builtins.int
    SERVER_CA_CERT_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_EMAIL_ADDRESS_FIELD_NUMBER: builtins.int
    REPLICA_CONFIGURATION_FIELD_NUMBER: builtins.int
    RESTORE_BACKUP_CONTEXT_FIELD_NUMBER: builtins.int
    SETTINGS_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    connection_name: builtins.str
    database_version: builtins.str
    deletion_protection: builtins.bool
    encryption_key_name: builtins.str
    first_ip_address: builtins.str
    id: builtins.str
    @property
    def ip_address(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    master_instance_name: builtins.str
    name: builtins.str
    private_ip_address: builtins.str
    project: builtins.str
    public_ip_address: builtins.str
    region: builtins.str
    root_password: builtins.str
    self_link: builtins.str
    @property
    def server_ca_cert(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    service_account_email_address: builtins.str
    @property
    def replica_configuration(self) -> global___SqlDatabaseInstanceXReplicaConfiguration: ...
    @property
    def restore_backup_context(self) -> global___SqlDatabaseInstanceXRestoreBackupContext: ...
    @property
    def settings(self) -> global___SqlDatabaseInstanceXSettings: ...
    @property
    def timeouts(self) -> global___SqlDatabaseInstanceXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        connection_name: builtins.str = ...,
        database_version: builtins.str = ...,
        deletion_protection: builtins.bool = ...,
        encryption_key_name: builtins.str = ...,
        first_ip_address: builtins.str = ...,
        id: builtins.str = ...,
        ip_address: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        master_instance_name: builtins.str = ...,
        name: builtins.str = ...,
        private_ip_address: builtins.str = ...,
        project: builtins.str = ...,
        public_ip_address: builtins.str = ...,
        region: builtins.str = ...,
        root_password: builtins.str = ...,
        self_link: builtins.str = ...,
        server_ca_cert: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        service_account_email_address: builtins.str = ...,
        replica_configuration: global___SqlDatabaseInstanceXReplicaConfiguration | None = ...,
        restore_backup_context: global___SqlDatabaseInstanceXRestoreBackupContext | None = ...,
        settings: global___SqlDatabaseInstanceXSettings | None = ...,
        timeouts: global___SqlDatabaseInstanceXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["replica_configuration", b"replica_configuration", "resource_info", b"resource_info", "restore_backup_context", b"restore_backup_context", "settings", b"settings", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["connection_name", b"connection_name", "database_version", b"database_version", "deletion_protection", b"deletion_protection", "encryption_key_name", b"encryption_key_name", "first_ip_address", b"first_ip_address", "id", b"id", "ip_address", b"ip_address", "master_instance_name", b"master_instance_name", "name", b"name", "private_ip_address", b"private_ip_address", "project", b"project", "public_ip_address", b"public_ip_address", "region", b"region", "replica_configuration", b"replica_configuration", "resource_info", b"resource_info", "restore_backup_context", b"restore_backup_context", "root_password", b"root_password", "self_link", b"self_link", "server_ca_cert", b"server_ca_cert", "service_account_email_address", b"service_account_email_address", "settings", b"settings", "timeouts", b"timeouts"]) -> None: ...

global___SqlDatabaseInstance = SqlDatabaseInstance

@typing_extensions.final
class SqlSourceRepresentationInstanceXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete"]) -> None: ...

global___SqlSourceRepresentationInstanceXTimeouts = SqlSourceRepresentationInstanceXTimeouts

@typing_extensions.final
class SqlSourceRepresentationInstance(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATABASE_VERSION_FIELD_NUMBER: builtins.int
    HOST_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PORT_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    database_version: builtins.str
    host: builtins.str
    id: builtins.str
    name: builtins.str
    port: builtins.float
    project: builtins.str
    region: builtins.str
    @property
    def timeouts(self) -> global___SqlSourceRepresentationInstanceXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        database_version: builtins.str = ...,
        host: builtins.str = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        port: builtins.float = ...,
        project: builtins.str = ...,
        region: builtins.str = ...,
        timeouts: global___SqlSourceRepresentationInstanceXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["database_version", b"database_version", "host", b"host", "id", b"id", "name", b"name", "port", b"port", "project", b"project", "region", b"region", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> None: ...

global___SqlSourceRepresentationInstance = SqlSourceRepresentationInstance

@typing_extensions.final
class SqlSslCertXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete"]) -> None: ...

global___SqlSslCertXTimeouts = SqlSslCertXTimeouts

@typing_extensions.final
class SqlSslCert(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CERT_FIELD_NUMBER: builtins.int
    CERT_SERIAL_NUMBER_FIELD_NUMBER: builtins.int
    COMMON_NAME_FIELD_NUMBER: builtins.int
    CREATE_TIME_FIELD_NUMBER: builtins.int
    EXPIRATION_TIME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    INSTANCE_FIELD_NUMBER: builtins.int
    PRIVATE_KEY_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    SERVER_CA_CERT_FIELD_NUMBER: builtins.int
    SHA1_FINGERPRINT_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    cert: builtins.str
    cert_serial_number: builtins.str
    common_name: builtins.str
    create_time: builtins.str
    expiration_time: builtins.str
    id: builtins.str
    instance: builtins.str
    private_key: builtins.str
    project: builtins.str
    server_ca_cert: builtins.str
    sha1_fingerprint: builtins.str
    @property
    def timeouts(self) -> global___SqlSslCertXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        cert: builtins.str = ...,
        cert_serial_number: builtins.str = ...,
        common_name: builtins.str = ...,
        create_time: builtins.str = ...,
        expiration_time: builtins.str = ...,
        id: builtins.str = ...,
        instance: builtins.str = ...,
        private_key: builtins.str = ...,
        project: builtins.str = ...,
        server_ca_cert: builtins.str = ...,
        sha1_fingerprint: builtins.str = ...,
        timeouts: global___SqlSslCertXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cert", b"cert", "cert_serial_number", b"cert_serial_number", "common_name", b"common_name", "create_time", b"create_time", "expiration_time", b"expiration_time", "id", b"id", "instance", b"instance", "private_key", b"private_key", "project", b"project", "resource_info", b"resource_info", "server_ca_cert", b"server_ca_cert", "sha1_fingerprint", b"sha1_fingerprint", "timeouts", b"timeouts"]) -> None: ...

global___SqlSslCert = SqlSslCert

@typing_extensions.final
class SqlUserXSqlServerUserDetails(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISABLED_FIELD_NUMBER: builtins.int
    SERVER_ROLES_FIELD_NUMBER: builtins.int
    disabled: builtins.bool
    @property
    def server_roles(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        disabled: builtins.bool = ...,
        server_roles: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["disabled", b"disabled", "server_roles", b"server_roles"]) -> None: ...

global___SqlUserXSqlServerUserDetails = SqlUserXSqlServerUserDetails

@typing_extensions.final
class SqlUserXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___SqlUserXTimeouts = SqlUserXTimeouts

@typing_extensions.final
class SqlUser(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DELETION_POLICY_FIELD_NUMBER: builtins.int
    HOST_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    INSTANCE_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PASSWORD_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    SQL_SERVER_USER_DETAILS_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    deletion_policy: builtins.str
    host: builtins.str
    id: builtins.str
    instance: builtins.str
    name: builtins.str
    password: builtins.str
    project: builtins.str
    type: builtins.str
    @property
    def sql_server_user_details(self) -> global___SqlUserXSqlServerUserDetails: ...
    @property
    def timeouts(self) -> global___SqlUserXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        deletion_policy: builtins.str = ...,
        host: builtins.str = ...,
        id: builtins.str = ...,
        instance: builtins.str = ...,
        name: builtins.str = ...,
        password: builtins.str = ...,
        project: builtins.str = ...,
        type: builtins.str = ...,
        sql_server_user_details: global___SqlUserXSqlServerUserDetails | None = ...,
        timeouts: global___SqlUserXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "sql_server_user_details", b"sql_server_user_details", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["deletion_policy", b"deletion_policy", "host", b"host", "id", b"id", "instance", b"instance", "name", b"name", "password", b"password", "project", b"project", "resource_info", b"resource_info", "sql_server_user_details", b"sql_server_user_details", "timeouts", b"timeouts", "type", b"type"]) -> None: ...

global___SqlUser = SqlUser
