# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_sns.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11\x61ws/aws_sns.proto\x12\x13oak9.tython.aws.sns\x1a\x13shared/shared.proto\"\xb8\x04\n\x0cSubscription\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12N\n\x0f\x64\x65livery_policy\x18\x02 \x03(\x0b\x32\x35.oak9.tython.aws.sns.Subscription.DeliveryPolicyEntry\x12\x10\n\x08\x65ndpoint\x18\x03 \x01(\t\x12J\n\rfilter_policy\x18\x04 \x03(\x0b\x32\x33.oak9.tython.aws.sns.Subscription.FilterPolicyEntry\x12\x10\n\x08protocol\x18\x05 \x01(\t\x12\x1c\n\x14raw_message_delivery\x18\x06 \x01(\x08\x12L\n\x0eredrive_policy\x18\x07 \x03(\x0b\x32\x34.oak9.tython.aws.sns.Subscription.RedrivePolicyEntry\x12\x0e\n\x06region\x18\x08 \x01(\t\x12\x11\n\ttopic_arn\x18\t \x01(\t\x1a\x35\n\x13\x44\x65liveryPolicyEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x33\n\x11\x46ilterPolicyEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x34\n\x12RedrivePolicyEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa1\x01\n\x03SNS\x12\x37\n\x0csubscription\x18\x01 \x03(\x0b\x32!.oak9.tython.aws.sns.Subscription\x12)\n\x05topic\x18\x02 \x01(\x0b\x32\x1a.oak9.tython.aws.sns.Topic\x12\x36\n\x0ctopic_policy\x18\x03 \x01(\x0b\x32 .oak9.tython.aws.sns.TopicPolicy\"p\n\x11TopicSubscription\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08\x65ndpoint\x18\x02 \x01(\t\x12\x10\n\x08protocol\x18\x03 \x01(\t\"\xc9\x02\n\x05Topic\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12#\n\x1b\x63ontent_based_deduplication\x18\x02 \x01(\x08\x12\x14\n\x0c\x64isplay_name\x18\x03 \x01(\t\x12\x19\n\x11kms_master_key_id\x18\x04 \x01(\t\x12<\n\x0csubscription\x18\x05 \x03(\x0b\x32&.oak9.tython.aws.sns.TopicSubscription\x12\x32\n\x04tags\x18\x06 \x03(\x0b\x32$.oak9.tython.aws.sns.Topic.TagsEntry\x12\x12\n\ntopic_name\x18\x07 \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"o\n\x0bTopicPolicy\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x17\n\x0fpolicy_document\x18\x02 \x01(\t\x12\x0e\n\x06topics\x18\x03 \x03(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_sns_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SUBSCRIPTION_DELIVERYPOLICYENTRY._options = None
  _SUBSCRIPTION_DELIVERYPOLICYENTRY._serialized_options = b'8\001'
  _SUBSCRIPTION_FILTERPOLICYENTRY._options = None
  _SUBSCRIPTION_FILTERPOLICYENTRY._serialized_options = b'8\001'
  _SUBSCRIPTION_REDRIVEPOLICYENTRY._options = None
  _SUBSCRIPTION_REDRIVEPOLICYENTRY._serialized_options = b'8\001'
  _TOPIC_TAGSENTRY._options = None
  _TOPIC_TAGSENTRY._serialized_options = b'8\001'
  _SUBSCRIPTION._serialized_start=64
  _SUBSCRIPTION._serialized_end=632
  _SUBSCRIPTION_DELIVERYPOLICYENTRY._serialized_start=472
  _SUBSCRIPTION_DELIVERYPOLICYENTRY._serialized_end=525
  _SUBSCRIPTION_FILTERPOLICYENTRY._serialized_start=527
  _SUBSCRIPTION_FILTERPOLICYENTRY._serialized_end=578
  _SUBSCRIPTION_REDRIVEPOLICYENTRY._serialized_start=580
  _SUBSCRIPTION_REDRIVEPOLICYENTRY._serialized_end=632
  _SNS._serialized_start=635
  _SNS._serialized_end=796
  _TOPICSUBSCRIPTION._serialized_start=798
  _TOPICSUBSCRIPTION._serialized_end=910
  _TOPIC._serialized_start=913
  _TOPIC._serialized_end=1242
  _TOPIC_TAGSENTRY._serialized_start=1199
  _TOPIC_TAGSENTRY._serialized_end=1242
  _TOPICPOLICY._serialized_start=1244
  _TOPICPOLICY._serialized_end=1355
# @@protoc_insertion_point(module_scope)
