# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_container.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17gcp/gcp_container.proto\x12\x19oak9.tython.gcp.container\x1a\x13shared/shared.proto\"N\n/ContainerAnalysisNoteXAttestationAuthorityXHint\x12\x1b\n\x13human_readable_name\x18\x01 \x01(\t\"\x86\x01\n*ContainerAnalysisNoteXAttestationAuthority\x12X\n\x04hint\x18\x01 \x01(\x0b\x32J.oak9.tython.gcp.container.ContainerAnalysisNoteXAttestationAuthorityXHint\">\n ContainerAnalysisNoteXRelatedUrl\x12\r\n\x05label\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x02 \x01(\t\"P\n\x1e\x43ontainerAnalysisNoteXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xa2\x04\n\x15\x43ontainerAnalysisNote\x12\x13\n\x0b\x63reate_time\x18\x01 \x01(\t\x12\x17\n\x0f\x65xpiration_time\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0c\n\x04kind\x18\x04 \x01(\t\x12\x18\n\x10long_description\x18\x05 \x01(\t\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x0f\n\x07project\x18\x07 \x01(\t\x12\x1a\n\x12related_note_names\x18\x08 \x03(\t\x12\x19\n\x11short_description\x18\t \x01(\t\x12\x13\n\x0bupdate_time\x18\n \x01(\t\x12\x64\n\x15\x61ttestation_authority\x18\x0b \x01(\x0b\x32\x45.oak9.tython.gcp.container.ContainerAnalysisNoteXAttestationAuthority\x12P\n\x0brelated_url\x18\x0c \x03(\x0b\x32;.oak9.tython.gcp.container.ContainerAnalysisNoteXRelatedUrl\x12K\n\x08timeouts\x18\r \x01(\x0b\x32\x39.oak9.tython.gcp.container.ContainerAnalysisNoteXTimeouts\x12\x37\n\rresource_info\x18\x0e \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"^\n2ContainerAnalysisOccurrenceXAttestationXSignatures\x12\x15\n\rpublic_key_id\x18\x01 \x01(\t\x12\x11\n\tsignature\x18\x02 \x01(\t\"\xa8\x01\n\'ContainerAnalysisOccurrenceXAttestation\x12\x1a\n\x12serialized_payload\x18\x01 \x01(\t\x12\x61\n\nsignatures\x18\x02 \x03(\x0b\x32M.oak9.tython.gcp.container.ContainerAnalysisOccurrenceXAttestationXSignatures\"V\n$ContainerAnalysisOccurrenceXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xa3\x03\n\x1b\x43ontainerAnalysisOccurrence\x12\x13\n\x0b\x63reate_time\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x11\n\tnote_name\x18\x05 \x01(\t\x12\x0f\n\x07project\x18\x06 \x01(\t\x12\x13\n\x0bremediation\x18\x07 \x01(\t\x12\x14\n\x0cresource_uri\x18\x08 \x01(\t\x12\x13\n\x0bupdate_time\x18\t \x01(\t\x12W\n\x0b\x61ttestation\x18\n \x01(\x0b\x32\x42.oak9.tython.gcp.container.ContainerAnalysisOccurrenceXAttestation\x12Q\n\x08timeouts\x18\x0b \x01(\x0b\x32?.oak9.tython.gcp.container.ContainerAnalysisOccurrenceXTimeouts\x12\x37\n\rresource_info\x18\x0c \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"@\n,ContainerAwsClusterXAuthorizationXAdminUsers\x12\x10\n\x08username\x18\x01 \x01(\t\"\x81\x01\n!ContainerAwsClusterXAuthorization\x12\\\n\x0b\x61\x64min_users\x18\x01 \x03(\x0b\x32G.oak9.tython.gcp.container.ContainerAwsClusterXAuthorizationXAdminUsers\"i\n:ContainerAwsClusterXControlPlaneXAwsServicesAuthentication\x12\x10\n\x08role_arn\x18\x01 \x01(\t\x12\x19\n\x11role_session_name\x18\x02 \x01(\t\"H\n1ContainerAwsClusterXControlPlaneXConfigEncryption\x12\x13\n\x0bkms_key_arn\x18\x01 \x01(\t\"J\n3ContainerAwsClusterXControlPlaneXDatabaseEncryption\x12\x13\n\x0bkms_key_arn\x18\x01 \x01(\t\"w\n+ContainerAwsClusterXControlPlaneXMainVolume\x12\x0c\n\x04iops\x18\x01 \x01(\x01\x12\x13\n\x0bkms_key_arn\x18\x02 \x01(\t\x12\x10\n\x08size_gib\x18\x03 \x01(\x01\x12\x13\n\x0bvolume_type\x18\x04 \x01(\t\"Z\n,ContainerAwsClusterXControlPlaneXProxyConfig\x12\x12\n\nsecret_arn\x18\x01 \x01(\t\x12\x16\n\x0esecret_version\x18\x02 \x01(\t\"w\n+ContainerAwsClusterXControlPlaneXRootVolume\x12\x0c\n\x04iops\x18\x01 \x01(\x01\x12\x13\n\x0bkms_key_arn\x18\x02 \x01(\t\x12\x10\n\x08size_gib\x18\x03 \x01(\x01\x12\x13\n\x0bvolume_type\x18\x04 \x01(\t\"B\n*ContainerAwsClusterXControlPlaneXSshConfig\x12\x14\n\x0c\x65\x63\x32_key_pair\x18\x01 \x01(\t\"\xe0\x07\n ContainerAwsClusterXControlPlane\x12\x1c\n\x14iam_instance_profile\x18\x01 \x01(\t\x12\x15\n\rinstance_type\x18\x02 \x01(\t\x12\x1a\n\x12security_group_ids\x18\x03 \x03(\t\x12\x12\n\nsubnet_ids\x18\x04 \x03(\t\x12S\n\x04tags\x18\x05 \x03(\x0b\x32\x45.oak9.tython.gcp.container.ContainerAwsClusterXControlPlane.TagsEntry\x12\x0f\n\x07version\x18\x06 \x01(\t\x12z\n\x1b\x61ws_services_authentication\x18\x07 \x01(\x0b\x32U.oak9.tython.gcp.container.ContainerAwsClusterXControlPlaneXAwsServicesAuthentication\x12g\n\x11\x63onfig_encryption\x18\x08 \x01(\x0b\x32L.oak9.tython.gcp.container.ContainerAwsClusterXControlPlaneXConfigEncryption\x12k\n\x13\x64\x61tabase_encryption\x18\t \x01(\x0b\x32N.oak9.tython.gcp.container.ContainerAwsClusterXControlPlaneXDatabaseEncryption\x12[\n\x0bmain_volume\x18\n \x01(\x0b\x32\x46.oak9.tython.gcp.container.ContainerAwsClusterXControlPlaneXMainVolume\x12]\n\x0cproxy_config\x18\x0b \x01(\x0b\x32G.oak9.tython.gcp.container.ContainerAwsClusterXControlPlaneXProxyConfig\x12[\n\x0broot_volume\x18\x0c \x01(\x0b\x32\x46.oak9.tython.gcp.container.ContainerAwsClusterXControlPlaneXRootVolume\x12Y\n\nssh_config\x18\r \x01(\x0b\x32\x45.oak9.tython.gcp.container.ContainerAwsClusterXControlPlaneXSshConfig\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"@\n\x19\x43ontainerAwsClusterXFleet\x12\x12\n\nmembership\x18\x01 \x01(\t\x12\x0f\n\x07project\x18\x02 \x01(\t\"v\n\x1e\x43ontainerAwsClusterXNetworking\x12\x1f\n\x17pod_address_cidr_blocks\x18\x01 \x03(\t\x12#\n\x1bservice_address_cidr_blocks\x18\x02 \x03(\t\x12\x0e\n\x06vpc_id\x18\x03 \x01(\t\"N\n\x1c\x43ontainerAwsClusterXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xee\x07\n\x13\x43ontainerAwsCluster\x12T\n\x0b\x61nnotations\x18\x01 \x03(\x0b\x32?.oak9.tython.gcp.container.ContainerAwsCluster.AnnotationsEntry\x12\x12\n\naws_region\x18\x02 \x01(\t\x12\x13\n\x0b\x63reate_time\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x10\n\x08\x65ndpoint\x18\x05 \x01(\t\x12\x0c\n\x04\x65tag\x18\x06 \x01(\t\x12\n\n\x02id\x18\x07 \x01(\t\x12\x10\n\x08location\x18\x08 \x01(\t\x12\x0c\n\x04name\x18\t \x01(\t\x12\x0f\n\x07project\x18\n \x01(\t\x12\x13\n\x0breconciling\x18\x0b \x01(\x08\x12\r\n\x05state\x18\x0c \x01(\t\x12\x0b\n\x03uid\x18\r \x01(\t\x12\x13\n\x0bupdate_time\x18\x0e \x01(\t\x12l\n\x18workload_identity_config\x18\x0f \x03(\x0b\x32J.oak9.tython.gcp.container.ContainerAwsCluster.WorkloadIdentityConfigEntry\x12S\n\rauthorization\x18\x10 \x01(\x0b\x32<.oak9.tython.gcp.container.ContainerAwsClusterXAuthorization\x12R\n\rcontrol_plane\x18\x11 \x01(\x0b\x32;.oak9.tython.gcp.container.ContainerAwsClusterXControlPlane\x12\x43\n\x05\x66leet\x18\x12 \x01(\x0b\x32\x34.oak9.tython.gcp.container.ContainerAwsClusterXFleet\x12M\n\nnetworking\x18\x13 \x01(\x0b\x32\x39.oak9.tython.gcp.container.ContainerAwsClusterXNetworking\x12I\n\x08timeouts\x18\x14 \x01(\x0b\x32\x37.oak9.tython.gcp.container.ContainerAwsClusterXTimeouts\x12\x37\n\rresource_info\x18\x15 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a\x32\n\x10\x41nnotationsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a=\n\x1bWorkloadIdentityConfigEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"R\n ContainerAwsNodePoolXAutoscaling\x12\x16\n\x0emax_node_count\x18\x01 \x01(\x01\x12\x16\n\x0emin_node_count\x18\x02 \x01(\x01\"C\n,ContainerAwsNodePoolXConfigXConfigEncryption\x12\x13\n\x0bkms_key_arn\x18\x01 \x01(\t\"U\n\'ContainerAwsNodePoolXConfigXProxyConfig\x12\x12\n\nsecret_arn\x18\x01 \x01(\t\x12\x16\n\x0esecret_version\x18\x02 \x01(\t\"r\n&ContainerAwsNodePoolXConfigXRootVolume\x12\x0c\n\x04iops\x18\x01 \x01(\x01\x12\x13\n\x0bkms_key_arn\x18\x02 \x01(\t\x12\x10\n\x08size_gib\x18\x03 \x01(\x01\x12\x13\n\x0bvolume_type\x18\x04 \x01(\t\"=\n%ContainerAwsNodePoolXConfigXSshConfig\x12\x14\n\x0c\x65\x63\x32_key_pair\x18\x01 \x01(\t\"P\n\"ContainerAwsNodePoolXConfigXTaints\x12\x0e\n\x06\x65\x66\x66\x65\x63t\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\"\xa9\x06\n\x1b\x43ontainerAwsNodePoolXConfig\x12\x1c\n\x14iam_instance_profile\x18\x01 \x01(\t\x12\x15\n\rinstance_type\x18\x02 \x01(\t\x12R\n\x06labels\x18\x03 \x03(\x0b\x32\x42.oak9.tython.gcp.container.ContainerAwsNodePoolXConfig.LabelsEntry\x12\x1a\n\x12security_group_ids\x18\x04 \x03(\t\x12N\n\x04tags\x18\x05 \x03(\x0b\x32@.oak9.tython.gcp.container.ContainerAwsNodePoolXConfig.TagsEntry\x12\x62\n\x11\x63onfig_encryption\x18\x06 \x01(\x0b\x32G.oak9.tython.gcp.container.ContainerAwsNodePoolXConfigXConfigEncryption\x12X\n\x0cproxy_config\x18\x07 \x01(\x0b\x32\x42.oak9.tython.gcp.container.ContainerAwsNodePoolXConfigXProxyConfig\x12V\n\x0broot_volume\x18\x08 \x01(\x0b\x32\x41.oak9.tython.gcp.container.ContainerAwsNodePoolXConfigXRootVolume\x12T\n\nssh_config\x18\t \x01(\x0b\x32@.oak9.tython.gcp.container.ContainerAwsNodePoolXConfigXSshConfig\x12M\n\x06taints\x18\n \x03(\x0b\x32=.oak9.tython.gcp.container.ContainerAwsNodePoolXConfigXTaints\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"C\n&ContainerAwsNodePoolXMaxPodsConstraint\x12\x19\n\x11max_pods_per_node\x18\x01 \x01(\x01\"O\n\x1d\x43ontainerAwsNodePoolXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xfb\x05\n\x14\x43ontainerAwsNodePool\x12U\n\x0b\x61nnotations\x18\x01 \x03(\x0b\x32@.oak9.tython.gcp.container.ContainerAwsNodePool.AnnotationsEntry\x12\x0f\n\x07\x63luster\x18\x02 \x01(\t\x12\x13\n\x0b\x63reate_time\x18\x03 \x01(\t\x12\x0c\n\x04\x65tag\x18\x04 \x01(\t\x12\n\n\x02id\x18\x05 \x01(\t\x12\x10\n\x08location\x18\x06 \x01(\t\x12\x0c\n\x04name\x18\x07 \x01(\t\x12\x0f\n\x07project\x18\x08 \x01(\t\x12\x13\n\x0breconciling\x18\t \x01(\x08\x12\r\n\x05state\x18\n \x01(\t\x12\x11\n\tsubnet_id\x18\x0b \x01(\t\x12\x0b\n\x03uid\x18\x0c \x01(\t\x12\x13\n\x0bupdate_time\x18\r \x01(\t\x12\x0f\n\x07version\x18\x0e \x01(\t\x12P\n\x0b\x61utoscaling\x18\x0f \x01(\x0b\x32;.oak9.tython.gcp.container.ContainerAwsNodePoolXAutoscaling\x12\x46\n\x06\x63onfig\x18\x10 \x01(\x0b\x32\x36.oak9.tython.gcp.container.ContainerAwsNodePoolXConfig\x12^\n\x13max_pods_constraint\x18\x11 \x01(\x0b\x32\x41.oak9.tython.gcp.container.ContainerAwsNodePoolXMaxPodsConstraint\x12J\n\x08timeouts\x18\x12 \x01(\x0b\x32\x38.oak9.tython.gcp.container.ContainerAwsNodePoolXTimeouts\x12\x37\n\rresource_info\x18\x13 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a\x32\n\x10\x41nnotationsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"?\n\x1d\x43ontainerAzureClientXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\"\xba\x02\n\x14\x43ontainerAzureClient\x12\x16\n\x0e\x61pplication_id\x18\x01 \x01(\t\x12\x13\n\x0b\x63\x65rtificate\x18\x02 \x01(\t\x12\x13\n\x0b\x63reate_time\x18\x03 \x01(\t\x12\n\n\x02id\x18\x04 \x01(\t\x12\x10\n\x08location\x18\x05 \x01(\t\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x0f\n\x07project\x18\x07 \x01(\t\x12\x11\n\ttenant_id\x18\x08 \x01(\t\x12\x0b\n\x03uid\x18\t \x01(\t\x12J\n\x08timeouts\x18\n \x01(\x0b\x32\x38.oak9.tython.gcp.container.ContainerAzureClientXTimeouts\x12\x37\n\rresource_info\x18\x0b \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"B\n.ContainerAzureClusterXAuthorizationXAdminUsers\x12\x10\n\x08username\x18\x01 \x01(\t\"\x85\x01\n#ContainerAzureClusterXAuthorization\x12^\n\x0b\x61\x64min_users\x18\x01 \x03(\x0b\x32I.oak9.tython.gcp.container.ContainerAzureClusterXAuthorizationXAdminUsers\"G\n5ContainerAzureClusterXControlPlaneXDatabaseEncryption\x12\x0e\n\x06key_id\x18\x01 \x01(\t\"A\n-ContainerAzureClusterXControlPlaneXMainVolume\x12\x10\n\x08size_gib\x18\x01 \x01(\x01\"^\n.ContainerAzureClusterXControlPlaneXProxyConfig\x12\x19\n\x11resource_group_id\x18\x01 \x01(\t\x12\x11\n\tsecret_id\x18\x02 \x01(\t\"j\n4ContainerAzureClusterXControlPlaneXReplicaPlacements\x12\x1f\n\x17\x61zure_availability_zone\x18\x01 \x01(\t\x12\x11\n\tsubnet_id\x18\x02 \x01(\t\"A\n-ContainerAzureClusterXControlPlaneXRootVolume\x12\x10\n\x08size_gib\x18\x01 \x01(\x01\"F\n,ContainerAzureClusterXControlPlaneXSshConfig\x12\x16\n\x0e\x61uthorized_key\x18\x01 \x01(\t\"\xb5\x06\n\"ContainerAzureClusterXControlPlane\x12\x11\n\tsubnet_id\x18\x01 \x01(\t\x12U\n\x04tags\x18\x02 \x03(\x0b\x32G.oak9.tython.gcp.container.ContainerAzureClusterXControlPlane.TagsEntry\x12\x0f\n\x07version\x18\x03 \x01(\t\x12\x0f\n\x07vm_size\x18\x04 \x01(\t\x12m\n\x13\x64\x61tabase_encryption\x18\x05 \x01(\x0b\x32P.oak9.tython.gcp.container.ContainerAzureClusterXControlPlaneXDatabaseEncryption\x12]\n\x0bmain_volume\x18\x06 \x01(\x0b\x32H.oak9.tython.gcp.container.ContainerAzureClusterXControlPlaneXMainVolume\x12_\n\x0cproxy_config\x18\x07 \x01(\x0b\x32I.oak9.tython.gcp.container.ContainerAzureClusterXControlPlaneXProxyConfig\x12k\n\x12replica_placements\x18\x08 \x03(\x0b\x32O.oak9.tython.gcp.container.ContainerAzureClusterXControlPlaneXReplicaPlacements\x12]\n\x0broot_volume\x18\t \x01(\x0b\x32H.oak9.tython.gcp.container.ContainerAzureClusterXControlPlaneXRootVolume\x12[\n\nssh_config\x18\n \x01(\x0b\x32G.oak9.tython.gcp.container.ContainerAzureClusterXControlPlaneXSshConfig\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"B\n\x1b\x43ontainerAzureClusterXFleet\x12\x12\n\nmembership\x18\x01 \x01(\t\x12\x0f\n\x07project\x18\x02 \x01(\t\"\x84\x01\n ContainerAzureClusterXNetworking\x12\x1f\n\x17pod_address_cidr_blocks\x18\x01 \x03(\t\x12#\n\x1bservice_address_cidr_blocks\x18\x02 \x03(\t\x12\x1a\n\x12virtual_network_id\x18\x03 \x01(\t\"P\n\x1e\x43ontainerAzureClusterXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xab\x08\n\x15\x43ontainerAzureCluster\x12V\n\x0b\x61nnotations\x18\x01 \x03(\x0b\x32\x41.oak9.tython.gcp.container.ContainerAzureCluster.AnnotationsEntry\x12\x14\n\x0c\x61zure_region\x18\x02 \x01(\t\x12\x0e\n\x06\x63lient\x18\x03 \x01(\t\x12\x13\n\x0b\x63reate_time\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12\x10\n\x08\x65ndpoint\x18\x06 \x01(\t\x12\x0c\n\x04\x65tag\x18\x07 \x01(\t\x12\n\n\x02id\x18\x08 \x01(\t\x12\x10\n\x08location\x18\t \x01(\t\x12\x0c\n\x04name\x18\n \x01(\t\x12\x0f\n\x07project\x18\x0b \x01(\t\x12\x13\n\x0breconciling\x18\x0c \x01(\x08\x12\x19\n\x11resource_group_id\x18\r \x01(\t\x12\r\n\x05state\x18\x0e \x01(\t\x12\x0b\n\x03uid\x18\x0f \x01(\t\x12\x13\n\x0bupdate_time\x18\x10 \x01(\t\x12n\n\x18workload_identity_config\x18\x11 \x03(\x0b\x32L.oak9.tython.gcp.container.ContainerAzureCluster.WorkloadIdentityConfigEntry\x12U\n\rauthorization\x18\x12 \x01(\x0b\x32>.oak9.tython.gcp.container.ContainerAzureClusterXAuthorization\x12T\n\rcontrol_plane\x18\x13 \x01(\x0b\x32=.oak9.tython.gcp.container.ContainerAzureClusterXControlPlane\x12\x45\n\x05\x66leet\x18\x14 \x01(\x0b\x32\x36.oak9.tython.gcp.container.ContainerAzureClusterXFleet\x12O\n\nnetworking\x18\x15 \x01(\x0b\x32;.oak9.tython.gcp.container.ContainerAzureClusterXNetworking\x12K\n\x08timeouts\x18\x16 \x01(\x0b\x32\x39.oak9.tython.gcp.container.ContainerAzureClusterXTimeouts\x12\x37\n\rresource_info\x18\x17 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a\x32\n\x10\x41nnotationsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a=\n\x1bWorkloadIdentityConfigEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"T\n\"ContainerAzureNodePoolXAutoscaling\x12\x16\n\x0emax_node_count\x18\x01 \x01(\x01\x12\x16\n\x0emin_node_count\x18\x02 \x01(\x01\"Y\n)ContainerAzureNodePoolXConfigXProxyConfig\x12\x19\n\x11resource_group_id\x18\x01 \x01(\t\x12\x11\n\tsecret_id\x18\x02 \x01(\t\"<\n(ContainerAzureNodePoolXConfigXRootVolume\x12\x10\n\x08size_gib\x18\x01 \x01(\x01\"A\n\'ContainerAzureNodePoolXConfigXSshConfig\x12\x16\n\x0e\x61uthorized_key\x18\x01 \x01(\t\"\xbd\x03\n\x1d\x43ontainerAzureNodePoolXConfig\x12P\n\x04tags\x18\x01 \x03(\x0b\x32\x42.oak9.tython.gcp.container.ContainerAzureNodePoolXConfig.TagsEntry\x12\x0f\n\x07vm_size\x18\x02 \x01(\t\x12Z\n\x0cproxy_config\x18\x03 \x01(\x0b\x32\x44.oak9.tython.gcp.container.ContainerAzureNodePoolXConfigXProxyConfig\x12X\n\x0broot_volume\x18\x04 \x01(\x0b\x32\x43.oak9.tython.gcp.container.ContainerAzureNodePoolXConfigXRootVolume\x12V\n\nssh_config\x18\x05 \x01(\x0b\x32\x42.oak9.tython.gcp.container.ContainerAzureNodePoolXConfigXSshConfig\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"E\n(ContainerAzureNodePoolXMaxPodsConstraint\x12\x19\n\x11max_pods_per_node\x18\x01 \x01(\x01\"Q\n\x1f\x43ontainerAzureNodePoolXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xa8\x06\n\x16\x43ontainerAzureNodePool\x12W\n\x0b\x61nnotations\x18\x01 \x03(\x0b\x32\x42.oak9.tython.gcp.container.ContainerAzureNodePool.AnnotationsEntry\x12\x1f\n\x17\x61zure_availability_zone\x18\x02 \x01(\t\x12\x0f\n\x07\x63luster\x18\x03 \x01(\t\x12\x13\n\x0b\x63reate_time\x18\x04 \x01(\t\x12\x0c\n\x04\x65tag\x18\x05 \x01(\t\x12\n\n\x02id\x18\x06 \x01(\t\x12\x10\n\x08location\x18\x07 \x01(\t\x12\x0c\n\x04name\x18\x08 \x01(\t\x12\x0f\n\x07project\x18\t \x01(\t\x12\x13\n\x0breconciling\x18\n \x01(\x08\x12\r\n\x05state\x18\x0b \x01(\t\x12\x11\n\tsubnet_id\x18\x0c \x01(\t\x12\x0b\n\x03uid\x18\r \x01(\t\x12\x13\n\x0bupdate_time\x18\x0e \x01(\t\x12\x0f\n\x07version\x18\x0f \x01(\t\x12R\n\x0b\x61utoscaling\x18\x10 \x01(\x0b\x32=.oak9.tython.gcp.container.ContainerAzureNodePoolXAutoscaling\x12H\n\x06\x63onfig\x18\x11 \x01(\x0b\x32\x38.oak9.tython.gcp.container.ContainerAzureNodePoolXConfig\x12`\n\x13max_pods_constraint\x18\x12 \x01(\x0b\x32\x43.oak9.tython.gcp.container.ContainerAzureNodePoolXMaxPodsConstraint\x12L\n\x08timeouts\x18\x13 \x01(\x0b\x32:.oak9.tython.gcp.container.ContainerAzureNodePoolXTimeouts\x12\x37\n\rresource_info\x18\x14 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a\x32\n\x10\x41nnotationsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\\\n,ContainerClusterXAddonsConfigXCloudrunConfig\x12\x10\n\x08\x64isabled\x18\x01 \x01(\x08\x12\x1a\n\x12load_balancer_type\x18\x02 \x01(\t\"?\n,ContainerClusterXAddonsConfigXDnsCacheConfig\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\"Q\n>ContainerClusterXAddonsConfigXGcePersistentDiskCsiDriverConfig\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\"L\n9ContainerClusterXAddonsConfigXGcpFilestoreCsiDriverConfig\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\"J\n6ContainerClusterXAddonsConfigXHorizontalPodAutoscaling\x12\x10\n\x08\x64isabled\x18\x01 \x01(\x08\"C\n/ContainerClusterXAddonsConfigXHttpLoadBalancing\x12\x10\n\x08\x64isabled\x18\x01 \x01(\x08\"E\n1ContainerClusterXAddonsConfigXNetworkPolicyConfig\x12\x10\n\x08\x64isabled\x18\x01 \x01(\x08\"\xbb\x06\n\x1d\x43ontainerClusterXAddonsConfig\x12`\n\x0f\x63loudrun_config\x18\x01 \x01(\x0b\x32G.oak9.tython.gcp.container.ContainerClusterXAddonsConfigXCloudrunConfig\x12\x61\n\x10\x64ns_cache_config\x18\x02 \x01(\x0b\x32G.oak9.tython.gcp.container.ContainerClusterXAddonsConfigXDnsCacheConfig\x12\x88\x01\n%gce_persistent_disk_csi_driver_config\x18\x03 \x01(\x0b\x32Y.oak9.tython.gcp.container.ContainerClusterXAddonsConfigXGcePersistentDiskCsiDriverConfig\x12}\n\x1fgcp_filestore_csi_driver_config\x18\x04 \x01(\x0b\x32T.oak9.tython.gcp.container.ContainerClusterXAddonsConfigXGcpFilestoreCsiDriverConfig\x12u\n\x1ahorizontal_pod_autoscaling\x18\x05 \x01(\x0b\x32Q.oak9.tython.gcp.container.ContainerClusterXAddonsConfigXHorizontalPodAutoscaling\x12g\n\x13http_load_balancing\x18\x06 \x01(\x0b\x32J.oak9.tython.gcp.container.ContainerClusterXAddonsConfigXHttpLoadBalancing\x12k\n\x15network_policy_config\x18\x07 \x01(\x0b\x32L.oak9.tython.gcp.container.ContainerClusterXAddonsConfigXNetworkPolicyConfig\"D\n*ContainerClusterXAuthenticatorGroupsConfig\x12\x16\n\x0esecurity_group\x18\x01 \x01(\t\"P\n$ContainerClusterXBinaryAuthorization\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x17\n\x0f\x65valuation_mode\x18\x02 \x01(\t\"\x9c\x01\n<ContainerClusterXClusterAutoscalingXAutoProvisioningDefaults\x12\x19\n\x11\x62oot_disk_kms_key\x18\x01 \x01(\t\x12\x12\n\nimage_type\x18\x02 \x01(\t\x12\x14\n\x0coauth_scopes\x18\x03 \x03(\t\x12\x17\n\x0fservice_account\x18\x04 \x01(\t\"m\n2ContainerClusterXClusterAutoscalingXResourceLimits\x12\x0f\n\x07maximum\x18\x01 \x01(\x01\x12\x0f\n\x07minimum\x18\x02 \x01(\x01\x12\x15\n\rresource_type\x18\x03 \x01(\t\"\x9b\x02\n#ContainerClusterXClusterAutoscaling\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12{\n\x1a\x61uto_provisioning_defaults\x18\x02 \x01(\x0b\x32W.oak9.tython.gcp.container.ContainerClusterXClusterAutoscalingXAutoProvisioningDefaults\x12\x66\n\x0fresource_limits\x18\x03 \x03(\x0b\x32M.oak9.tython.gcp.container.ContainerClusterXClusterAutoscalingXResourceLimits\"5\n\"ContainerClusterXConfidentialNodes\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\"F\n#ContainerClusterXDatabaseEncryption\x12\x10\n\x08key_name\x18\x01 \x01(\t\x12\r\n\x05state\x18\x02 \x01(\t\"6\n\"ContainerClusterXDefaultSnatStatus\x12\x10\n\x08\x64isabled\x18\x01 \x01(\x08\"h\n\x1a\x43ontainerClusterXDnsConfig\x12\x13\n\x0b\x63luster_dns\x18\x01 \x01(\t\x12\x1a\n\x12\x63luster_dns_domain\x18\x02 \x01(\t\x12\x19\n\x11\x63luster_dns_scope\x18\x03 \x01(\t\"\xb5\x01\n#ContainerClusterXIpAllocationPolicy\x12\x1f\n\x17\x63luster_ipv4_cidr_block\x18\x01 \x01(\t\x12$\n\x1c\x63luster_secondary_range_name\x18\x02 \x01(\t\x12 \n\x18services_ipv4_cidr_block\x18\x03 \x01(\t\x12%\n\x1dservices_secondary_range_name\x18\x04 \x01(\t\";\n\x1e\x43ontainerClusterXLoggingConfig\x12\x19\n\x11\x65nable_components\x18\x01 \x03(\t\"a\n9ContainerClusterXMaintenancePolicyXDailyMaintenanceWindow\x12\x10\n\x08\x64uration\x18\x01 \x01(\t\x12\x12\n\nstart_time\x18\x02 \x01(\t\"Y\nHContainerClusterXMaintenancePolicyXMaintenanceExclusionXExclusionOptions\x12\r\n\x05scope\x18\x01 \x01(\t\"\xf7\x01\n7ContainerClusterXMaintenancePolicyXMaintenanceExclusion\x12\x10\n\x08\x65nd_time\x18\x01 \x01(\t\x12\x16\n\x0e\x65xclusion_name\x18\x02 \x01(\t\x12\x12\n\nstart_time\x18\x03 \x01(\t\x12~\n\x11\x65xclusion_options\x18\x04 \x01(\x0b\x32\x63.oak9.tython.gcp.container.ContainerClusterXMaintenancePolicyXMaintenanceExclusionXExclusionOptions\"n\n2ContainerClusterXMaintenancePolicyXRecurringWindow\x12\x10\n\x08\x65nd_time\x18\x01 \x01(\t\x12\x12\n\nrecurrence\x18\x02 \x01(\t\x12\x12\n\nstart_time\x18\x03 \x01(\t\"\xf8\x02\n\"ContainerClusterXMaintenancePolicy\x12v\n\x18\x64\x61ily_maintenance_window\x18\x01 \x01(\x0b\x32T.oak9.tython.gcp.container.ContainerClusterXMaintenancePolicyXDailyMaintenanceWindow\x12q\n\x15maintenance_exclusion\x18\x02 \x03(\x0b\x32R.oak9.tython.gcp.container.ContainerClusterXMaintenancePolicyXMaintenanceExclusion\x12g\n\x10recurring_window\x18\x03 \x01(\x0b\x32M.oak9.tython.gcp.container.ContainerClusterXMaintenancePolicyXRecurringWindow\"W\n3ContainerClusterXMasterAuthXClientCertificateConfig\x12 \n\x18issue_client_certificate\x18\x01 \x01(\x08\"\xe0\x01\n\x1b\x43ontainerClusterXMasterAuth\x12\x1a\n\x12\x63lient_certificate\x18\x01 \x01(\t\x12\x12\n\nclient_key\x18\x02 \x01(\t\x12\x1e\n\x16\x63luster_ca_certificate\x18\x03 \x01(\t\x12q\n\x19\x63lient_certificate_config\x18\x04 \x01(\x0b\x32N.oak9.tython.gcp.container.ContainerClusterXMasterAuthXClientCertificateConfig\"f\n:ContainerClusterXMasterAuthorizedNetworksConfigXCidrBlocks\x12\x12\n\ncidr_block\x18\x01 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x02 \x01(\t\"\x9d\x01\n/ContainerClusterXMasterAuthorizedNetworksConfig\x12j\n\x0b\x63idr_blocks\x18\x01 \x03(\x0b\x32U.oak9.tython.gcp.container.ContainerClusterXMasterAuthorizedNetworksConfigXCidrBlocks\">\n!ContainerClusterXMonitoringConfig\x12\x19\n\x11\x65nable_components\x18\x01 \x03(\t\"C\n\x1e\x43ontainerClusterXNetworkPolicy\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x10\n\x08provider\x18\x02 \x01(\t\"9\n&ContainerClusterXNodeConfigXGcfsConfig\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\"4\n!ContainerClusterXNodeConfigXGvnic\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\"u\n2ContainerClusterXNodeConfigXShieldedInstanceConfig\x12#\n\x1b\x65nable_integrity_monitoring\x18\x01 \x01(\x08\x12\x1a\n\x12\x65nable_secure_boot\x18\x02 \x01(\x08\"B\n2ContainerClusterXNodeConfigXWorkloadMetadataConfig\x12\x0c\n\x04mode\x18\x01 \x01(\t\"\xe7\t\n\x1b\x43ontainerClusterXNodeConfig\x12\x19\n\x11\x62oot_disk_kms_key\x18\x01 \x01(\t\x12\x14\n\x0c\x64isk_size_gb\x18\x02 \x01(\x01\x12\x11\n\tdisk_type\x18\x03 \x01(\t\x12g\n\x11guest_accelerator\x18\x04 \x03(\x0b\x32L.oak9.tython.gcp.container.ContainerClusterXNodeConfig.GuestAcceleratorEntry\x12\x12\n\nimage_type\x18\x05 \x01(\t\x12R\n\x06labels\x18\x06 \x03(\x0b\x32\x42.oak9.tython.gcp.container.ContainerClusterXNodeConfig.LabelsEntry\x12\x17\n\x0flocal_ssd_count\x18\x07 \x01(\x01\x12\x14\n\x0cmachine_type\x18\x08 \x01(\t\x12V\n\x08metadata\x18\t \x03(\x0b\x32\x44.oak9.tython.gcp.container.ContainerClusterXNodeConfig.MetadataEntry\x12\x18\n\x10min_cpu_platform\x18\n \x01(\t\x12\x12\n\nnode_group\x18\x0b \x01(\t\x12\x14\n\x0coauth_scopes\x18\x0c \x03(\t\x12\x13\n\x0bpreemptible\x18\r \x01(\x08\x12\x17\n\x0fservice_account\x18\x0e \x01(\t\x12\x0c\n\x04spot\x18\x0f \x01(\x08\x12\x0c\n\x04tags\x18\x10 \x03(\t\x12P\n\x05taint\x18\x11 \x03(\x0b\x32\x41.oak9.tython.gcp.container.ContainerClusterXNodeConfig.TaintEntry\x12V\n\x0bgcfs_config\x18\x12 \x01(\x0b\x32\x41.oak9.tython.gcp.container.ContainerClusterXNodeConfigXGcfsConfig\x12K\n\x05gvnic\x18\x13 \x01(\x0b\x32<.oak9.tython.gcp.container.ContainerClusterXNodeConfigXGvnic\x12o\n\x18shielded_instance_config\x18\x14 \x01(\x0b\x32M.oak9.tython.gcp.container.ContainerClusterXNodeConfigXShieldedInstanceConfig\x12o\n\x18workload_metadata_config\x18\x15 \x01(\x0b\x32M.oak9.tython.gcp.container.ContainerClusterXNodeConfigXWorkloadMetadataConfig\x1a\x37\n\x15GuestAcceleratorEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a,\n\nTaintEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"W\n%ContainerClusterXNodePoolXAutoscaling\x12\x16\n\x0emax_node_count\x18\x01 \x01(\x01\x12\x16\n\x0emin_node_count\x18\x02 \x01(\x01\"Q\n$ContainerClusterXNodePoolXManagement\x12\x13\n\x0b\x61uto_repair\x18\x01 \x01(\x08\x12\x14\n\x0c\x61uto_upgrade\x18\x02 \x01(\x08\"B\n/ContainerClusterXNodePoolXNodeConfigXGcfsConfig\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\"=\n*ContainerClusterXNodePoolXNodeConfigXGvnic\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\"~\n;ContainerClusterXNodePoolXNodeConfigXShieldedInstanceConfig\x12#\n\x1b\x65nable_integrity_monitoring\x18\x01 \x01(\x08\x12\x1a\n\x12\x65nable_secure_boot\x18\x02 \x01(\x08\"K\n;ContainerClusterXNodePoolXNodeConfigXWorkloadMetadataConfig\x12\x0c\n\x04mode\x18\x01 \x01(\t\"\xb8\n\n$ContainerClusterXNodePoolXNodeConfig\x12\x19\n\x11\x62oot_disk_kms_key\x18\x01 \x01(\t\x12\x14\n\x0c\x64isk_size_gb\x18\x02 \x01(\x01\x12\x11\n\tdisk_type\x18\x03 \x01(\t\x12p\n\x11guest_accelerator\x18\x04 \x03(\x0b\x32U.oak9.tython.gcp.container.ContainerClusterXNodePoolXNodeConfig.GuestAcceleratorEntry\x12\x12\n\nimage_type\x18\x05 \x01(\t\x12[\n\x06labels\x18\x06 \x03(\x0b\x32K.oak9.tython.gcp.container.ContainerClusterXNodePoolXNodeConfig.LabelsEntry\x12\x17\n\x0flocal_ssd_count\x18\x07 \x01(\x01\x12\x14\n\x0cmachine_type\x18\x08 \x01(\t\x12_\n\x08metadata\x18\t \x03(\x0b\x32M.oak9.tython.gcp.container.ContainerClusterXNodePoolXNodeConfig.MetadataEntry\x12\x18\n\x10min_cpu_platform\x18\n \x01(\t\x12\x12\n\nnode_group\x18\x0b \x01(\t\x12\x14\n\x0coauth_scopes\x18\x0c \x03(\t\x12\x13\n\x0bpreemptible\x18\r \x01(\x08\x12\x17\n\x0fservice_account\x18\x0e \x01(\t\x12\x0c\n\x04spot\x18\x0f \x01(\x08\x12\x0c\n\x04tags\x18\x10 \x03(\t\x12Y\n\x05taint\x18\x11 \x03(\x0b\x32J.oak9.tython.gcp.container.ContainerClusterXNodePoolXNodeConfig.TaintEntry\x12_\n\x0bgcfs_config\x18\x12 \x01(\x0b\x32J.oak9.tython.gcp.container.ContainerClusterXNodePoolXNodeConfigXGcfsConfig\x12T\n\x05gvnic\x18\x13 \x01(\x0b\x32\x45.oak9.tython.gcp.container.ContainerClusterXNodePoolXNodeConfigXGvnic\x12x\n\x18shielded_instance_config\x18\x14 \x01(\x0b\x32V.oak9.tython.gcp.container.ContainerClusterXNodePoolXNodeConfigXShieldedInstanceConfig\x12x\n\x18workload_metadata_config\x18\x15 \x01(\x0b\x32V.oak9.tython.gcp.container.ContainerClusterXNodePoolXNodeConfigXWorkloadMetadataConfig\x1a\x37\n\x15GuestAcceleratorEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a,\n\nTaintEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"W\n)ContainerClusterXNodePoolXUpgradeSettings\x12\x11\n\tmax_surge\x18\x01 \x01(\x01\x12\x17\n\x0fmax_unavailable\x18\x02 \x01(\x01\"\xd6\x04\n\x19\x43ontainerClusterXNodePool\x12\x1a\n\x12initial_node_count\x18\x01 \x01(\x01\x12\x1b\n\x13instance_group_urls\x18\x02 \x03(\t\x12#\n\x1bmanaged_instance_group_urls\x18\x03 \x03(\t\x12\x19\n\x11max_pods_per_node\x18\x04 \x01(\x01\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x13\n\x0bname_prefix\x18\x06 \x01(\t\x12\x12\n\nnode_count\x18\x07 \x01(\x01\x12\x16\n\x0enode_locations\x18\x08 \x03(\t\x12\x0f\n\x07version\x18\t \x01(\t\x12U\n\x0b\x61utoscaling\x18\n \x01(\x0b\x32@.oak9.tython.gcp.container.ContainerClusterXNodePoolXAutoscaling\x12S\n\nmanagement\x18\x0b \x01(\x0b\x32?.oak9.tython.gcp.container.ContainerClusterXNodePoolXManagement\x12T\n\x0bnode_config\x18\x0c \x01(\x0b\x32?.oak9.tython.gcp.container.ContainerClusterXNodePoolXNodeConfig\x12^\n\x10upgrade_settings\x18\r \x01(\x0b\x32\x44.oak9.tython.gcp.container.ContainerClusterXNodePoolXUpgradeSettings\"L\n*ContainerClusterXNotificationConfigXPubsub\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\r\n\x05topic\x18\x02 \x01(\t\"|\n#ContainerClusterXNotificationConfig\x12U\n\x06pubsub\x18\x01 \x01(\x0b\x32\x45.oak9.tython.gcp.container.ContainerClusterXNotificationConfigXPubsub\"Q\n>ContainerClusterXPrivateClusterConfigXMasterGlobalAccessConfig\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\"\xcf\x02\n%ContainerClusterXPrivateClusterConfig\x12\x1f\n\x17\x65nable_private_endpoint\x18\x01 \x01(\x08\x12\x1c\n\x14\x65nable_private_nodes\x18\x02 \x01(\x08\x12\x1e\n\x16master_ipv4_cidr_block\x18\x03 \x01(\t\x12\x14\n\x0cpeering_name\x18\x04 \x01(\t\x12\x18\n\x10private_endpoint\x18\x05 \x01(\t\x12\x17\n\x0fpublic_endpoint\x18\x06 \x01(\t\x12~\n\x1bmaster_global_access_config\x18\x07 \x01(\x0b\x32Y.oak9.tython.gcp.container.ContainerClusterXPrivateClusterConfigXMasterGlobalAccessConfig\"2\n\x1f\x43ontainerClusterXReleaseChannel\x12\x0f\n\x07\x63hannel\x18\x01 \x01(\t\"T\n>ContainerClusterXResourceUsageExportConfigXBigqueryDestination\x12\x12\n\ndataset_id\x18\x01 \x01(\t\"\xfb\x01\n*ContainerClusterXResourceUsageExportConfig\x12&\n\x1e\x65nable_network_egress_metering\x18\x01 \x01(\x08\x12,\n$enable_resource_consumption_metering\x18\x02 \x01(\x08\x12w\n\x14\x62igquery_destination\x18\x03 \x01(\x0b\x32Y.oak9.tython.gcp.container.ContainerClusterXResourceUsageExportConfigXBigqueryDestination\"Y\n\x19\x43ontainerClusterXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0c\n\x04read\x18\x03 \x01(\t\x12\x0e\n\x06update\x18\x04 \x01(\t\":\n\'ContainerClusterXVerticalPodAutoscaling\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\"@\n\'ContainerClusterXWorkloadIdentityConfig\x12\x15\n\rworkload_pool\x18\x01 \x01(\t\"\x9d\x19\n\x10\x43ontainerCluster\x12\x19\n\x11\x63luster_ipv4_cidr\x18\x01 \x01(\t\x12\x19\n\x11\x64\x61tapath_provider\x18\x02 \x01(\t\x12!\n\x19\x64\x65\x66\x61ult_max_pods_per_node\x18\x03 \x01(\x01\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x18\n\x10\x65nable_autopilot\x18\x05 \x01(\x08\x12#\n\x1b\x65nable_binary_authorization\x18\x06 \x01(\x08\x12#\n\x1b\x65nable_intranode_visibility\x18\x07 \x01(\x08\x12\x1f\n\x17\x65nable_kubernetes_alpha\x18\x08 \x01(\x08\x12\x1a\n\x12\x65nable_legacy_abac\x18\t \x01(\x08\x12\x1d\n\x15\x65nable_shielded_nodes\x18\n \x01(\x08\x12\x12\n\nenable_tpu\x18\x0b \x01(\x08\x12\x10\n\x08\x65ndpoint\x18\x0c \x01(\t\x12\n\n\x02id\x18\r \x01(\t\x12\x1a\n\x12initial_node_count\x18\x0e \x01(\x01\x12\x19\n\x11label_fingerprint\x18\x0f \x01(\t\x12\x10\n\x08location\x18\x10 \x01(\t\x12\x17\n\x0flogging_service\x18\x11 \x01(\t\x12\x16\n\x0emaster_version\x18\x12 \x01(\t\x12\x1a\n\x12min_master_version\x18\x13 \x01(\t\x12\x1a\n\x12monitoring_service\x18\x14 \x01(\t\x12\x0c\n\x04name\x18\x15 \x01(\t\x12\x0f\n\x07network\x18\x16 \x01(\t\x12\x17\n\x0fnetworking_mode\x18\x17 \x01(\t\x12\x16\n\x0enode_locations\x18\x18 \x03(\t\x12\x14\n\x0cnode_version\x18\x19 \x01(\t\x12\x11\n\toperation\x18\x1a \x01(\t\x12\"\n\x1aprivate_ipv6_google_access\x18\x1b \x01(\t\x12\x0f\n\x07project\x18\x1c \x01(\t\x12 \n\x18remove_default_node_pool\x18\x1d \x01(\x08\x12X\n\x0fresource_labels\x18\x1e \x03(\x0b\x32?.oak9.tython.gcp.container.ContainerCluster.ResourceLabelsEntry\x12\x11\n\tself_link\x18\x1f \x01(\t\x12\x1a\n\x12services_ipv4_cidr\x18  \x01(\t\x12\x12\n\nsubnetwork\x18! \x01(\t\x12\x1b\n\x13tpu_ipv4_cidr_block\x18\" \x01(\t\x12O\n\raddons_config\x18# \x01(\x0b\x32\x38.oak9.tython.gcp.container.ContainerClusterXAddonsConfig\x12j\n\x1b\x61uthenticator_groups_config\x18$ \x01(\x0b\x32\x45.oak9.tython.gcp.container.ContainerClusterXAuthenticatorGroupsConfig\x12]\n\x14\x62inary_authorization\x18% \x01(\x0b\x32?.oak9.tython.gcp.container.ContainerClusterXBinaryAuthorization\x12[\n\x13\x63luster_autoscaling\x18& \x01(\x0b\x32>.oak9.tython.gcp.container.ContainerClusterXClusterAutoscaling\x12Y\n\x12\x63onfidential_nodes\x18\' \x01(\x0b\x32=.oak9.tython.gcp.container.ContainerClusterXConfidentialNodes\x12[\n\x13\x64\x61tabase_encryption\x18( \x01(\x0b\x32>.oak9.tython.gcp.container.ContainerClusterXDatabaseEncryption\x12Z\n\x13\x64\x65\x66\x61ult_snat_status\x18) \x01(\x0b\x32=.oak9.tython.gcp.container.ContainerClusterXDefaultSnatStatus\x12I\n\ndns_config\x18* \x01(\x0b\x32\x35.oak9.tython.gcp.container.ContainerClusterXDnsConfig\x12\\\n\x14ip_allocation_policy\x18+ \x01(\x0b\x32>.oak9.tython.gcp.container.ContainerClusterXIpAllocationPolicy\x12Q\n\x0elogging_config\x18, \x01(\x0b\x32\x39.oak9.tython.gcp.container.ContainerClusterXLoggingConfig\x12Y\n\x12maintenance_policy\x18- \x01(\x0b\x32=.oak9.tython.gcp.container.ContainerClusterXMaintenancePolicy\x12K\n\x0bmaster_auth\x18. \x01(\x0b\x32\x36.oak9.tython.gcp.container.ContainerClusterXMasterAuth\x12u\n!master_authorized_networks_config\x18/ \x01(\x0b\x32J.oak9.tython.gcp.container.ContainerClusterXMasterAuthorizedNetworksConfig\x12W\n\x11monitoring_config\x18\x30 \x01(\x0b\x32<.oak9.tython.gcp.container.ContainerClusterXMonitoringConfig\x12Q\n\x0enetwork_policy\x18\x31 \x01(\x0b\x32\x39.oak9.tython.gcp.container.ContainerClusterXNetworkPolicy\x12K\n\x0bnode_config\x18\x32 \x01(\x0b\x32\x36.oak9.tython.gcp.container.ContainerClusterXNodeConfig\x12G\n\tnode_pool\x18\x33 \x03(\x0b\x32\x34.oak9.tython.gcp.container.ContainerClusterXNodePool\x12[\n\x13notification_config\x18\x34 \x01(\x0b\x32>.oak9.tython.gcp.container.ContainerClusterXNotificationConfig\x12`\n\x16private_cluster_config\x18\x35 \x01(\x0b\x32@.oak9.tython.gcp.container.ContainerClusterXPrivateClusterConfig\x12S\n\x0frelease_channel\x18\x36 \x01(\x0b\x32:.oak9.tython.gcp.container.ContainerClusterXReleaseChannel\x12k\n\x1cresource_usage_export_config\x18\x37 \x01(\x0b\x32\x45.oak9.tython.gcp.container.ContainerClusterXResourceUsageExportConfig\x12\x46\n\x08timeouts\x18\x38 \x01(\x0b\x32\x34.oak9.tython.gcp.container.ContainerClusterXTimeouts\x12\x64\n\x18vertical_pod_autoscaling\x18\x39 \x01(\x0b\x32\x42.oak9.tython.gcp.container.ContainerClusterXVerticalPodAutoscaling\x12\x64\n\x18workload_identity_config\x18: \x01(\x0b\x32\x42.oak9.tython.gcp.container.ContainerClusterXWorkloadIdentityConfig\x12\x37\n\rresource_info\x18; \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a\x35\n\x13ResourceLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"O\n\x1d\x43ontainerNodePoolXAutoscaling\x12\x16\n\x0emax_node_count\x18\x01 \x01(\x01\x12\x16\n\x0emin_node_count\x18\x02 \x01(\x01\"I\n\x1c\x43ontainerNodePoolXManagement\x12\x13\n\x0b\x61uto_repair\x18\x01 \x01(\x08\x12\x14\n\x0c\x61uto_upgrade\x18\x02 \x01(\x08\":\n\'ContainerNodePoolXNodeConfigXGcfsConfig\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\"5\n\"ContainerNodePoolXNodeConfigXGvnic\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\"v\n3ContainerNodePoolXNodeConfigXShieldedInstanceConfig\x12#\n\x1b\x65nable_integrity_monitoring\x18\x01 \x01(\x08\x12\x1a\n\x12\x65nable_secure_boot\x18\x02 \x01(\x08\"C\n3ContainerNodePoolXNodeConfigXWorkloadMetadataConfig\x12\x0c\n\x04mode\x18\x01 \x01(\t\"\xf0\t\n\x1c\x43ontainerNodePoolXNodeConfig\x12\x19\n\x11\x62oot_disk_kms_key\x18\x01 \x01(\t\x12\x14\n\x0c\x64isk_size_gb\x18\x02 \x01(\x01\x12\x11\n\tdisk_type\x18\x03 \x01(\t\x12h\n\x11guest_accelerator\x18\x04 \x03(\x0b\x32M.oak9.tython.gcp.container.ContainerNodePoolXNodeConfig.GuestAcceleratorEntry\x12\x12\n\nimage_type\x18\x05 \x01(\t\x12S\n\x06labels\x18\x06 \x03(\x0b\x32\x43.oak9.tython.gcp.container.ContainerNodePoolXNodeConfig.LabelsEntry\x12\x17\n\x0flocal_ssd_count\x18\x07 \x01(\x01\x12\x14\n\x0cmachine_type\x18\x08 \x01(\t\x12W\n\x08metadata\x18\t \x03(\x0b\x32\x45.oak9.tython.gcp.container.ContainerNodePoolXNodeConfig.MetadataEntry\x12\x18\n\x10min_cpu_platform\x18\n \x01(\t\x12\x12\n\nnode_group\x18\x0b \x01(\t\x12\x14\n\x0coauth_scopes\x18\x0c \x03(\t\x12\x13\n\x0bpreemptible\x18\r \x01(\x08\x12\x17\n\x0fservice_account\x18\x0e \x01(\t\x12\x0c\n\x04spot\x18\x0f \x01(\x08\x12\x0c\n\x04tags\x18\x10 \x03(\t\x12Q\n\x05taint\x18\x11 \x03(\x0b\x32\x42.oak9.tython.gcp.container.ContainerNodePoolXNodeConfig.TaintEntry\x12W\n\x0bgcfs_config\x18\x12 \x01(\x0b\x32\x42.oak9.tython.gcp.container.ContainerNodePoolXNodeConfigXGcfsConfig\x12L\n\x05gvnic\x18\x13 \x01(\x0b\x32=.oak9.tython.gcp.container.ContainerNodePoolXNodeConfigXGvnic\x12p\n\x18shielded_instance_config\x18\x14 \x01(\x0b\x32N.oak9.tython.gcp.container.ContainerNodePoolXNodeConfigXShieldedInstanceConfig\x12p\n\x18workload_metadata_config\x18\x15 \x01(\x0b\x32N.oak9.tython.gcp.container.ContainerNodePoolXNodeConfigXWorkloadMetadataConfig\x1a\x37\n\x15GuestAcceleratorEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a,\n\nTaintEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"L\n\x1a\x43ontainerNodePoolXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"O\n!ContainerNodePoolXUpgradeSettings\x12\x11\n\tmax_surge\x18\x01 \x01(\x01\x12\x17\n\x0fmax_unavailable\x18\x02 \x01(\x01\"\x83\x06\n\x11\x43ontainerNodePool\x12\x0f\n\x07\x63luster\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x1a\n\x12initial_node_count\x18\x03 \x01(\x01\x12\x1b\n\x13instance_group_urls\x18\x04 \x03(\t\x12\x10\n\x08location\x18\x05 \x01(\t\x12#\n\x1bmanaged_instance_group_urls\x18\x06 \x03(\t\x12\x19\n\x11max_pods_per_node\x18\x07 \x01(\x01\x12\x0c\n\x04name\x18\x08 \x01(\t\x12\x13\n\x0bname_prefix\x18\t \x01(\t\x12\x12\n\nnode_count\x18\n \x01(\x01\x12\x16\n\x0enode_locations\x18\x0b \x03(\t\x12\x11\n\toperation\x18\x0c \x01(\t\x12\x0f\n\x07project\x18\r \x01(\t\x12\x0f\n\x07version\x18\x0e \x01(\t\x12M\n\x0b\x61utoscaling\x18\x0f \x01(\x0b\x32\x38.oak9.tython.gcp.container.ContainerNodePoolXAutoscaling\x12K\n\nmanagement\x18\x10 \x01(\x0b\x32\x37.oak9.tython.gcp.container.ContainerNodePoolXManagement\x12L\n\x0bnode_config\x18\x11 \x01(\x0b\x32\x37.oak9.tython.gcp.container.ContainerNodePoolXNodeConfig\x12G\n\x08timeouts\x18\x12 \x01(\x0b\x32\x35.oak9.tython.gcp.container.ContainerNodePoolXTimeouts\x12V\n\x10upgrade_settings\x18\x13 \x01(\x0b\x32<.oak9.tython.gcp.container.ContainerNodePoolXUpgradeSettings\x12\x37\n\rresource_info\x18\x14 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x95\x01\n\x11\x43ontainerRegistry\x12\x18\n\x10\x62ucket_self_link\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x0f\n\x07project\x18\x04 \x01(\t\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_container_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CONTAINERAWSCLUSTERXCONTROLPLANE_TAGSENTRY._options = None
  _CONTAINERAWSCLUSTERXCONTROLPLANE_TAGSENTRY._serialized_options = b'8\001'
  _CONTAINERAWSCLUSTER_ANNOTATIONSENTRY._options = None
  _CONTAINERAWSCLUSTER_ANNOTATIONSENTRY._serialized_options = b'8\001'
  _CONTAINERAWSCLUSTER_WORKLOADIDENTITYCONFIGENTRY._options = None
  _CONTAINERAWSCLUSTER_WORKLOADIDENTITYCONFIGENTRY._serialized_options = b'8\001'
  _CONTAINERAWSNODEPOOLXCONFIG_LABELSENTRY._options = None
  _CONTAINERAWSNODEPOOLXCONFIG_LABELSENTRY._serialized_options = b'8\001'
  _CONTAINERAWSNODEPOOLXCONFIG_TAGSENTRY._options = None
  _CONTAINERAWSNODEPOOLXCONFIG_TAGSENTRY._serialized_options = b'8\001'
  _CONTAINERAWSNODEPOOL_ANNOTATIONSENTRY._options = None
  _CONTAINERAWSNODEPOOL_ANNOTATIONSENTRY._serialized_options = b'8\001'
  _CONTAINERAZURECLUSTERXCONTROLPLANE_TAGSENTRY._options = None
  _CONTAINERAZURECLUSTERXCONTROLPLANE_TAGSENTRY._serialized_options = b'8\001'
  _CONTAINERAZURECLUSTER_ANNOTATIONSENTRY._options = None
  _CONTAINERAZURECLUSTER_ANNOTATIONSENTRY._serialized_options = b'8\001'
  _CONTAINERAZURECLUSTER_WORKLOADIDENTITYCONFIGENTRY._options = None
  _CONTAINERAZURECLUSTER_WORKLOADIDENTITYCONFIGENTRY._serialized_options = b'8\001'
  _CONTAINERAZURENODEPOOLXCONFIG_TAGSENTRY._options = None
  _CONTAINERAZURENODEPOOLXCONFIG_TAGSENTRY._serialized_options = b'8\001'
  _CONTAINERAZURENODEPOOL_ANNOTATIONSENTRY._options = None
  _CONTAINERAZURENODEPOOL_ANNOTATIONSENTRY._serialized_options = b'8\001'
  _CONTAINERCLUSTERXNODECONFIG_GUESTACCELERATORENTRY._options = None
  _CONTAINERCLUSTERXNODECONFIG_GUESTACCELERATORENTRY._serialized_options = b'8\001'
  _CONTAINERCLUSTERXNODECONFIG_LABELSENTRY._options = None
  _CONTAINERCLUSTERXNODECONFIG_LABELSENTRY._serialized_options = b'8\001'
  _CONTAINERCLUSTERXNODECONFIG_METADATAENTRY._options = None
  _CONTAINERCLUSTERXNODECONFIG_METADATAENTRY._serialized_options = b'8\001'
  _CONTAINERCLUSTERXNODECONFIG_TAINTENTRY._options = None
  _CONTAINERCLUSTERXNODECONFIG_TAINTENTRY._serialized_options = b'8\001'
  _CONTAINERCLUSTERXNODEPOOLXNODECONFIG_GUESTACCELERATORENTRY._options = None
  _CONTAINERCLUSTERXNODEPOOLXNODECONFIG_GUESTACCELERATORENTRY._serialized_options = b'8\001'
  _CONTAINERCLUSTERXNODEPOOLXNODECONFIG_LABELSENTRY._options = None
  _CONTAINERCLUSTERXNODEPOOLXNODECONFIG_LABELSENTRY._serialized_options = b'8\001'
  _CONTAINERCLUSTERXNODEPOOLXNODECONFIG_METADATAENTRY._options = None
  _CONTAINERCLUSTERXNODEPOOLXNODECONFIG_METADATAENTRY._serialized_options = b'8\001'
  _CONTAINERCLUSTERXNODEPOOLXNODECONFIG_TAINTENTRY._options = None
  _CONTAINERCLUSTERXNODEPOOLXNODECONFIG_TAINTENTRY._serialized_options = b'8\001'
  _CONTAINERCLUSTER_RESOURCELABELSENTRY._options = None
  _CONTAINERCLUSTER_RESOURCELABELSENTRY._serialized_options = b'8\001'
  _CONTAINERNODEPOOLXNODECONFIG_GUESTACCELERATORENTRY._options = None
  _CONTAINERNODEPOOLXNODECONFIG_GUESTACCELERATORENTRY._serialized_options = b'8\001'
  _CONTAINERNODEPOOLXNODECONFIG_LABELSENTRY._options = None
  _CONTAINERNODEPOOLXNODECONFIG_LABELSENTRY._serialized_options = b'8\001'
  _CONTAINERNODEPOOLXNODECONFIG_METADATAENTRY._options = None
  _CONTAINERNODEPOOLXNODECONFIG_METADATAENTRY._serialized_options = b'8\001'
  _CONTAINERNODEPOOLXNODECONFIG_TAINTENTRY._options = None
  _CONTAINERNODEPOOLXNODECONFIG_TAINTENTRY._serialized_options = b'8\001'
  _CONTAINERANALYSISNOTEXATTESTATIONAUTHORITYXHINT._serialized_start=75
  _CONTAINERANALYSISNOTEXATTESTATIONAUTHORITYXHINT._serialized_end=153
  _CONTAINERANALYSISNOTEXATTESTATIONAUTHORITY._serialized_start=156
  _CONTAINERANALYSISNOTEXATTESTATIONAUTHORITY._serialized_end=290
  _CONTAINERANALYSISNOTEXRELATEDURL._serialized_start=292
  _CONTAINERANALYSISNOTEXRELATEDURL._serialized_end=354
  _CONTAINERANALYSISNOTEXTIMEOUTS._serialized_start=356
  _CONTAINERANALYSISNOTEXTIMEOUTS._serialized_end=436
  _CONTAINERANALYSISNOTE._serialized_start=439
  _CONTAINERANALYSISNOTE._serialized_end=985
  _CONTAINERANALYSISOCCURRENCEXATTESTATIONXSIGNATURES._serialized_start=987
  _CONTAINERANALYSISOCCURRENCEXATTESTATIONXSIGNATURES._serialized_end=1081
  _CONTAINERANALYSISOCCURRENCEXATTESTATION._serialized_start=1084
  _CONTAINERANALYSISOCCURRENCEXATTESTATION._serialized_end=1252
  _CONTAINERANALYSISOCCURRENCEXTIMEOUTS._serialized_start=1254
  _CONTAINERANALYSISOCCURRENCEXTIMEOUTS._serialized_end=1340
  _CONTAINERANALYSISOCCURRENCE._serialized_start=1343
  _CONTAINERANALYSISOCCURRENCE._serialized_end=1762
  _CONTAINERAWSCLUSTERXAUTHORIZATIONXADMINUSERS._serialized_start=1764
  _CONTAINERAWSCLUSTERXAUTHORIZATIONXADMINUSERS._serialized_end=1828
  _CONTAINERAWSCLUSTERXAUTHORIZATION._serialized_start=1831
  _CONTAINERAWSCLUSTERXAUTHORIZATION._serialized_end=1960
  _CONTAINERAWSCLUSTERXCONTROLPLANEXAWSSERVICESAUTHENTICATION._serialized_start=1962
  _CONTAINERAWSCLUSTERXCONTROLPLANEXAWSSERVICESAUTHENTICATION._serialized_end=2067
  _CONTAINERAWSCLUSTERXCONTROLPLANEXCONFIGENCRYPTION._serialized_start=2069
  _CONTAINERAWSCLUSTERXCONTROLPLANEXCONFIGENCRYPTION._serialized_end=2141
  _CONTAINERAWSCLUSTERXCONTROLPLANEXDATABASEENCRYPTION._serialized_start=2143
  _CONTAINERAWSCLUSTERXCONTROLPLANEXDATABASEENCRYPTION._serialized_end=2217
  _CONTAINERAWSCLUSTERXCONTROLPLANEXMAINVOLUME._serialized_start=2219
  _CONTAINERAWSCLUSTERXCONTROLPLANEXMAINVOLUME._serialized_end=2338
  _CONTAINERAWSCLUSTERXCONTROLPLANEXPROXYCONFIG._serialized_start=2340
  _CONTAINERAWSCLUSTERXCONTROLPLANEXPROXYCONFIG._serialized_end=2430
  _CONTAINERAWSCLUSTERXCONTROLPLANEXROOTVOLUME._serialized_start=2432
  _CONTAINERAWSCLUSTERXCONTROLPLANEXROOTVOLUME._serialized_end=2551
  _CONTAINERAWSCLUSTERXCONTROLPLANEXSSHCONFIG._serialized_start=2553
  _CONTAINERAWSCLUSTERXCONTROLPLANEXSSHCONFIG._serialized_end=2619
  _CONTAINERAWSCLUSTERXCONTROLPLANE._serialized_start=2622
  _CONTAINERAWSCLUSTERXCONTROLPLANE._serialized_end=3614
  _CONTAINERAWSCLUSTERXCONTROLPLANE_TAGSENTRY._serialized_start=3571
  _CONTAINERAWSCLUSTERXCONTROLPLANE_TAGSENTRY._serialized_end=3614
  _CONTAINERAWSCLUSTERXFLEET._serialized_start=3616
  _CONTAINERAWSCLUSTERXFLEET._serialized_end=3680
  _CONTAINERAWSCLUSTERXNETWORKING._serialized_start=3682
  _CONTAINERAWSCLUSTERXNETWORKING._serialized_end=3800
  _CONTAINERAWSCLUSTERXTIMEOUTS._serialized_start=3802
  _CONTAINERAWSCLUSTERXTIMEOUTS._serialized_end=3880
  _CONTAINERAWSCLUSTER._serialized_start=3883
  _CONTAINERAWSCLUSTER._serialized_end=4889
  _CONTAINERAWSCLUSTER_ANNOTATIONSENTRY._serialized_start=4776
  _CONTAINERAWSCLUSTER_ANNOTATIONSENTRY._serialized_end=4826
  _CONTAINERAWSCLUSTER_WORKLOADIDENTITYCONFIGENTRY._serialized_start=4828
  _CONTAINERAWSCLUSTER_WORKLOADIDENTITYCONFIGENTRY._serialized_end=4889
  _CONTAINERAWSNODEPOOLXAUTOSCALING._serialized_start=4891
  _CONTAINERAWSNODEPOOLXAUTOSCALING._serialized_end=4973
  _CONTAINERAWSNODEPOOLXCONFIGXCONFIGENCRYPTION._serialized_start=4975
  _CONTAINERAWSNODEPOOLXCONFIGXCONFIGENCRYPTION._serialized_end=5042
  _CONTAINERAWSNODEPOOLXCONFIGXPROXYCONFIG._serialized_start=5044
  _CONTAINERAWSNODEPOOLXCONFIGXPROXYCONFIG._serialized_end=5129
  _CONTAINERAWSNODEPOOLXCONFIGXROOTVOLUME._serialized_start=5131
  _CONTAINERAWSNODEPOOLXCONFIGXROOTVOLUME._serialized_end=5245
  _CONTAINERAWSNODEPOOLXCONFIGXSSHCONFIG._serialized_start=5247
  _CONTAINERAWSNODEPOOLXCONFIGXSSHCONFIG._serialized_end=5308
  _CONTAINERAWSNODEPOOLXCONFIGXTAINTS._serialized_start=5310
  _CONTAINERAWSNODEPOOLXCONFIGXTAINTS._serialized_end=5390
  _CONTAINERAWSNODEPOOLXCONFIG._serialized_start=5393
  _CONTAINERAWSNODEPOOLXCONFIG._serialized_end=6202
  _CONTAINERAWSNODEPOOLXCONFIG_LABELSENTRY._serialized_start=6112
  _CONTAINERAWSNODEPOOLXCONFIG_LABELSENTRY._serialized_end=6157
  _CONTAINERAWSNODEPOOLXCONFIG_TAGSENTRY._serialized_start=3571
  _CONTAINERAWSNODEPOOLXCONFIG_TAGSENTRY._serialized_end=3614
  _CONTAINERAWSNODEPOOLXMAXPODSCONSTRAINT._serialized_start=6204
  _CONTAINERAWSNODEPOOLXMAXPODSCONSTRAINT._serialized_end=6271
  _CONTAINERAWSNODEPOOLXTIMEOUTS._serialized_start=6273
  _CONTAINERAWSNODEPOOLXTIMEOUTS._serialized_end=6352
  _CONTAINERAWSNODEPOOL._serialized_start=6355
  _CONTAINERAWSNODEPOOL._serialized_end=7118
  _CONTAINERAWSNODEPOOL_ANNOTATIONSENTRY._serialized_start=4776
  _CONTAINERAWSNODEPOOL_ANNOTATIONSENTRY._serialized_end=4826
  _CONTAINERAZURECLIENTXTIMEOUTS._serialized_start=7120
  _CONTAINERAZURECLIENTXTIMEOUTS._serialized_end=7183
  _CONTAINERAZURECLIENT._serialized_start=7186
  _CONTAINERAZURECLIENT._serialized_end=7500
  _CONTAINERAZURECLUSTERXAUTHORIZATIONXADMINUSERS._serialized_start=7502
  _CONTAINERAZURECLUSTERXAUTHORIZATIONXADMINUSERS._serialized_end=7568
  _CONTAINERAZURECLUSTERXAUTHORIZATION._serialized_start=7571
  _CONTAINERAZURECLUSTERXAUTHORIZATION._serialized_end=7704
  _CONTAINERAZURECLUSTERXCONTROLPLANEXDATABASEENCRYPTION._serialized_start=7706
  _CONTAINERAZURECLUSTERXCONTROLPLANEXDATABASEENCRYPTION._serialized_end=7777
  _CONTAINERAZURECLUSTERXCONTROLPLANEXMAINVOLUME._serialized_start=7779
  _CONTAINERAZURECLUSTERXCONTROLPLANEXMAINVOLUME._serialized_end=7844
  _CONTAINERAZURECLUSTERXCONTROLPLANEXPROXYCONFIG._serialized_start=7846
  _CONTAINERAZURECLUSTERXCONTROLPLANEXPROXYCONFIG._serialized_end=7940
  _CONTAINERAZURECLUSTERXCONTROLPLANEXREPLICAPLACEMENTS._serialized_start=7942
  _CONTAINERAZURECLUSTERXCONTROLPLANEXREPLICAPLACEMENTS._serialized_end=8048
  _CONTAINERAZURECLUSTERXCONTROLPLANEXROOTVOLUME._serialized_start=8050
  _CONTAINERAZURECLUSTERXCONTROLPLANEXROOTVOLUME._serialized_end=8115
  _CONTAINERAZURECLUSTERXCONTROLPLANEXSSHCONFIG._serialized_start=8117
  _CONTAINERAZURECLUSTERXCONTROLPLANEXSSHCONFIG._serialized_end=8187
  _CONTAINERAZURECLUSTERXCONTROLPLANE._serialized_start=8190
  _CONTAINERAZURECLUSTERXCONTROLPLANE._serialized_end=9011
  _CONTAINERAZURECLUSTERXCONTROLPLANE_TAGSENTRY._serialized_start=3571
  _CONTAINERAZURECLUSTERXCONTROLPLANE_TAGSENTRY._serialized_end=3614
  _CONTAINERAZURECLUSTERXFLEET._serialized_start=9013
  _CONTAINERAZURECLUSTERXFLEET._serialized_end=9079
  _CONTAINERAZURECLUSTERXNETWORKING._serialized_start=9082
  _CONTAINERAZURECLUSTERXNETWORKING._serialized_end=9214
  _CONTAINERAZURECLUSTERXTIMEOUTS._serialized_start=9216
  _CONTAINERAZURECLUSTERXTIMEOUTS._serialized_end=9296
  _CONTAINERAZURECLUSTER._serialized_start=9299
  _CONTAINERAZURECLUSTER._serialized_end=10366
  _CONTAINERAZURECLUSTER_ANNOTATIONSENTRY._serialized_start=4776
  _CONTAINERAZURECLUSTER_ANNOTATIONSENTRY._serialized_end=4826
  _CONTAINERAZURECLUSTER_WORKLOADIDENTITYCONFIGENTRY._serialized_start=4828
  _CONTAINERAZURECLUSTER_WORKLOADIDENTITYCONFIGENTRY._serialized_end=4889
  _CONTAINERAZURENODEPOOLXAUTOSCALING._serialized_start=10368
  _CONTAINERAZURENODEPOOLXAUTOSCALING._serialized_end=10452
  _CONTAINERAZURENODEPOOLXCONFIGXPROXYCONFIG._serialized_start=10454
  _CONTAINERAZURENODEPOOLXCONFIGXPROXYCONFIG._serialized_end=10543
  _CONTAINERAZURENODEPOOLXCONFIGXROOTVOLUME._serialized_start=10545
  _CONTAINERAZURENODEPOOLXCONFIGXROOTVOLUME._serialized_end=10605
  _CONTAINERAZURENODEPOOLXCONFIGXSSHCONFIG._serialized_start=10607
  _CONTAINERAZURENODEPOOLXCONFIGXSSHCONFIG._serialized_end=10672
  _CONTAINERAZURENODEPOOLXCONFIG._serialized_start=10675
  _CONTAINERAZURENODEPOOLXCONFIG._serialized_end=11120
  _CONTAINERAZURENODEPOOLXCONFIG_TAGSENTRY._serialized_start=3571
  _CONTAINERAZURENODEPOOLXCONFIG_TAGSENTRY._serialized_end=3614
  _CONTAINERAZURENODEPOOLXMAXPODSCONSTRAINT._serialized_start=11122
  _CONTAINERAZURENODEPOOLXMAXPODSCONSTRAINT._serialized_end=11191
  _CONTAINERAZURENODEPOOLXTIMEOUTS._serialized_start=11193
  _CONTAINERAZURENODEPOOLXTIMEOUTS._serialized_end=11274
  _CONTAINERAZURENODEPOOL._serialized_start=11277
  _CONTAINERAZURENODEPOOL._serialized_end=12085
  _CONTAINERAZURENODEPOOL_ANNOTATIONSENTRY._serialized_start=4776
  _CONTAINERAZURENODEPOOL_ANNOTATIONSENTRY._serialized_end=4826
  _CONTAINERCLUSTERXADDONSCONFIGXCLOUDRUNCONFIG._serialized_start=12087
  _CONTAINERCLUSTERXADDONSCONFIGXCLOUDRUNCONFIG._serialized_end=12179
  _CONTAINERCLUSTERXADDONSCONFIGXDNSCACHECONFIG._serialized_start=12181
  _CONTAINERCLUSTERXADDONSCONFIGXDNSCACHECONFIG._serialized_end=12244
  _CONTAINERCLUSTERXADDONSCONFIGXGCEPERSISTENTDISKCSIDRIVERCONFIG._serialized_start=12246
  _CONTAINERCLUSTERXADDONSCONFIGXGCEPERSISTENTDISKCSIDRIVERCONFIG._serialized_end=12327
  _CONTAINERCLUSTERXADDONSCONFIGXGCPFILESTORECSIDRIVERCONFIG._serialized_start=12329
  _CONTAINERCLUSTERXADDONSCONFIGXGCPFILESTORECSIDRIVERCONFIG._serialized_end=12405
  _CONTAINERCLUSTERXADDONSCONFIGXHORIZONTALPODAUTOSCALING._serialized_start=12407
  _CONTAINERCLUSTERXADDONSCONFIGXHORIZONTALPODAUTOSCALING._serialized_end=12481
  _CONTAINERCLUSTERXADDONSCONFIGXHTTPLOADBALANCING._serialized_start=12483
  _CONTAINERCLUSTERXADDONSCONFIGXHTTPLOADBALANCING._serialized_end=12550
  _CONTAINERCLUSTERXADDONSCONFIGXNETWORKPOLICYCONFIG._serialized_start=12552
  _CONTAINERCLUSTERXADDONSCONFIGXNETWORKPOLICYCONFIG._serialized_end=12621
  _CONTAINERCLUSTERXADDONSCONFIG._serialized_start=12624
  _CONTAINERCLUSTERXADDONSCONFIG._serialized_end=13451
  _CONTAINERCLUSTERXAUTHENTICATORGROUPSCONFIG._serialized_start=13453
  _CONTAINERCLUSTERXAUTHENTICATORGROUPSCONFIG._serialized_end=13521
  _CONTAINERCLUSTERXBINARYAUTHORIZATION._serialized_start=13523
  _CONTAINERCLUSTERXBINARYAUTHORIZATION._serialized_end=13603
  _CONTAINERCLUSTERXCLUSTERAUTOSCALINGXAUTOPROVISIONINGDEFAULTS._serialized_start=13606
  _CONTAINERCLUSTERXCLUSTERAUTOSCALINGXAUTOPROVISIONINGDEFAULTS._serialized_end=13762
  _CONTAINERCLUSTERXCLUSTERAUTOSCALINGXRESOURCELIMITS._serialized_start=13764
  _CONTAINERCLUSTERXCLUSTERAUTOSCALINGXRESOURCELIMITS._serialized_end=13873
  _CONTAINERCLUSTERXCLUSTERAUTOSCALING._serialized_start=13876
  _CONTAINERCLUSTERXCLUSTERAUTOSCALING._serialized_end=14159
  _CONTAINERCLUSTERXCONFIDENTIALNODES._serialized_start=14161
  _CONTAINERCLUSTERXCONFIDENTIALNODES._serialized_end=14214
  _CONTAINERCLUSTERXDATABASEENCRYPTION._serialized_start=14216
  _CONTAINERCLUSTERXDATABASEENCRYPTION._serialized_end=14286
  _CONTAINERCLUSTERXDEFAULTSNATSTATUS._serialized_start=14288
  _CONTAINERCLUSTERXDEFAULTSNATSTATUS._serialized_end=14342
  _CONTAINERCLUSTERXDNSCONFIG._serialized_start=14344
  _CONTAINERCLUSTERXDNSCONFIG._serialized_end=14448
  _CONTAINERCLUSTERXIPALLOCATIONPOLICY._serialized_start=14451
  _CONTAINERCLUSTERXIPALLOCATIONPOLICY._serialized_end=14632
  _CONTAINERCLUSTERXLOGGINGCONFIG._serialized_start=14634
  _CONTAINERCLUSTERXLOGGINGCONFIG._serialized_end=14693
  _CONTAINERCLUSTERXMAINTENANCEPOLICYXDAILYMAINTENANCEWINDOW._serialized_start=14695
  _CONTAINERCLUSTERXMAINTENANCEPOLICYXDAILYMAINTENANCEWINDOW._serialized_end=14792
  _CONTAINERCLUSTERXMAINTENANCEPOLICYXMAINTENANCEEXCLUSIONXEXCLUSIONOPTIONS._serialized_start=14794
  _CONTAINERCLUSTERXMAINTENANCEPOLICYXMAINTENANCEEXCLUSIONXEXCLUSIONOPTIONS._serialized_end=14883
  _CONTAINERCLUSTERXMAINTENANCEPOLICYXMAINTENANCEEXCLUSION._serialized_start=14886
  _CONTAINERCLUSTERXMAINTENANCEPOLICYXMAINTENANCEEXCLUSION._serialized_end=15133
  _CONTAINERCLUSTERXMAINTENANCEPOLICYXRECURRINGWINDOW._serialized_start=15135
  _CONTAINERCLUSTERXMAINTENANCEPOLICYXRECURRINGWINDOW._serialized_end=15245
  _CONTAINERCLUSTERXMAINTENANCEPOLICY._serialized_start=15248
  _CONTAINERCLUSTERXMAINTENANCEPOLICY._serialized_end=15624
  _CONTAINERCLUSTERXMASTERAUTHXCLIENTCERTIFICATECONFIG._serialized_start=15626
  _CONTAINERCLUSTERXMASTERAUTHXCLIENTCERTIFICATECONFIG._serialized_end=15713
  _CONTAINERCLUSTERXMASTERAUTH._serialized_start=15716
  _CONTAINERCLUSTERXMASTERAUTH._serialized_end=15940
  _CONTAINERCLUSTERXMASTERAUTHORIZEDNETWORKSCONFIGXCIDRBLOCKS._serialized_start=15942
  _CONTAINERCLUSTERXMASTERAUTHORIZEDNETWORKSCONFIGXCIDRBLOCKS._serialized_end=16044
  _CONTAINERCLUSTERXMASTERAUTHORIZEDNETWORKSCONFIG._serialized_start=16047
  _CONTAINERCLUSTERXMASTERAUTHORIZEDNETWORKSCONFIG._serialized_end=16204
  _CONTAINERCLUSTERXMONITORINGCONFIG._serialized_start=16206
  _CONTAINERCLUSTERXMONITORINGCONFIG._serialized_end=16268
  _CONTAINERCLUSTERXNETWORKPOLICY._serialized_start=16270
  _CONTAINERCLUSTERXNETWORKPOLICY._serialized_end=16337
  _CONTAINERCLUSTERXNODECONFIGXGCFSCONFIG._serialized_start=16339
  _CONTAINERCLUSTERXNODECONFIGXGCFSCONFIG._serialized_end=16396
  _CONTAINERCLUSTERXNODECONFIGXGVNIC._serialized_start=16398
  _CONTAINERCLUSTERXNODECONFIGXGVNIC._serialized_end=16450
  _CONTAINERCLUSTERXNODECONFIGXSHIELDEDINSTANCECONFIG._serialized_start=16452
  _CONTAINERCLUSTERXNODECONFIGXSHIELDEDINSTANCECONFIG._serialized_end=16569
  _CONTAINERCLUSTERXNODECONFIGXWORKLOADMETADATACONFIG._serialized_start=16571
  _CONTAINERCLUSTERXNODECONFIGXWORKLOADMETADATACONFIG._serialized_end=16637
  _CONTAINERCLUSTERXNODECONFIG._serialized_start=16640
  _CONTAINERCLUSTERXNODECONFIG._serialized_end=17895
  _CONTAINERCLUSTERXNODECONFIG_GUESTACCELERATORENTRY._serialized_start=17698
  _CONTAINERCLUSTERXNODECONFIG_GUESTACCELERATORENTRY._serialized_end=17753
  _CONTAINERCLUSTERXNODECONFIG_LABELSENTRY._serialized_start=6112
  _CONTAINERCLUSTERXNODECONFIG_LABELSENTRY._serialized_end=6157
  _CONTAINERCLUSTERXNODECONFIG_METADATAENTRY._serialized_start=17802
  _CONTAINERCLUSTERXNODECONFIG_METADATAENTRY._serialized_end=17849
  _CONTAINERCLUSTERXNODECONFIG_TAINTENTRY._serialized_start=17851
  _CONTAINERCLUSTERXNODECONFIG_TAINTENTRY._serialized_end=17895
  _CONTAINERCLUSTERXNODEPOOLXAUTOSCALING._serialized_start=17897
  _CONTAINERCLUSTERXNODEPOOLXAUTOSCALING._serialized_end=17984
  _CONTAINERCLUSTERXNODEPOOLXMANAGEMENT._serialized_start=17986
  _CONTAINERCLUSTERXNODEPOOLXMANAGEMENT._serialized_end=18067
  _CONTAINERCLUSTERXNODEPOOLXNODECONFIGXGCFSCONFIG._serialized_start=18069
  _CONTAINERCLUSTERXNODEPOOLXNODECONFIGXGCFSCONFIG._serialized_end=18135
  _CONTAINERCLUSTERXNODEPOOLXNODECONFIGXGVNIC._serialized_start=18137
  _CONTAINERCLUSTERXNODEPOOLXNODECONFIGXGVNIC._serialized_end=18198
  _CONTAINERCLUSTERXNODEPOOLXNODECONFIGXSHIELDEDINSTANCECONFIG._serialized_start=18200
  _CONTAINERCLUSTERXNODEPOOLXNODECONFIGXSHIELDEDINSTANCECONFIG._serialized_end=18326
  _CONTAINERCLUSTERXNODEPOOLXNODECONFIGXWORKLOADMETADATACONFIG._serialized_start=18328
  _CONTAINERCLUSTERXNODEPOOLXNODECONFIGXWORKLOADMETADATACONFIG._serialized_end=18403
  _CONTAINERCLUSTERXNODEPOOLXNODECONFIG._serialized_start=18406
  _CONTAINERCLUSTERXNODEPOOLXNODECONFIG._serialized_end=19742
  _CONTAINERCLUSTERXNODEPOOLXNODECONFIG_GUESTACCELERATORENTRY._serialized_start=17698
  _CONTAINERCLUSTERXNODEPOOLXNODECONFIG_GUESTACCELERATORENTRY._serialized_end=17753
  _CONTAINERCLUSTERXNODEPOOLXNODECONFIG_LABELSENTRY._serialized_start=6112
  _CONTAINERCLUSTERXNODEPOOLXNODECONFIG_LABELSENTRY._serialized_end=6157
  _CONTAINERCLUSTERXNODEPOOLXNODECONFIG_METADATAENTRY._serialized_start=17802
  _CONTAINERCLUSTERXNODEPOOLXNODECONFIG_METADATAENTRY._serialized_end=17849
  _CONTAINERCLUSTERXNODEPOOLXNODECONFIG_TAINTENTRY._serialized_start=17851
  _CONTAINERCLUSTERXNODEPOOLXNODECONFIG_TAINTENTRY._serialized_end=17895
  _CONTAINERCLUSTERXNODEPOOLXUPGRADESETTINGS._serialized_start=19744
  _CONTAINERCLUSTERXNODEPOOLXUPGRADESETTINGS._serialized_end=19831
  _CONTAINERCLUSTERXNODEPOOL._serialized_start=19834
  _CONTAINERCLUSTERXNODEPOOL._serialized_end=20432
  _CONTAINERCLUSTERXNOTIFICATIONCONFIGXPUBSUB._serialized_start=20434
  _CONTAINERCLUSTERXNOTIFICATIONCONFIGXPUBSUB._serialized_end=20510
  _CONTAINERCLUSTERXNOTIFICATIONCONFIG._serialized_start=20512
  _CONTAINERCLUSTERXNOTIFICATIONCONFIG._serialized_end=20636
  _CONTAINERCLUSTERXPRIVATECLUSTERCONFIGXMASTERGLOBALACCESSCONFIG._serialized_start=20638
  _CONTAINERCLUSTERXPRIVATECLUSTERCONFIGXMASTERGLOBALACCESSCONFIG._serialized_end=20719
  _CONTAINERCLUSTERXPRIVATECLUSTERCONFIG._serialized_start=20722
  _CONTAINERCLUSTERXPRIVATECLUSTERCONFIG._serialized_end=21057
  _CONTAINERCLUSTERXRELEASECHANNEL._serialized_start=21059
  _CONTAINERCLUSTERXRELEASECHANNEL._serialized_end=21109
  _CONTAINERCLUSTERXRESOURCEUSAGEEXPORTCONFIGXBIGQUERYDESTINATION._serialized_start=21111
  _CONTAINERCLUSTERXRESOURCEUSAGEEXPORTCONFIGXBIGQUERYDESTINATION._serialized_end=21195
  _CONTAINERCLUSTERXRESOURCEUSAGEEXPORTCONFIG._serialized_start=21198
  _CONTAINERCLUSTERXRESOURCEUSAGEEXPORTCONFIG._serialized_end=21449
  _CONTAINERCLUSTERXTIMEOUTS._serialized_start=21451
  _CONTAINERCLUSTERXTIMEOUTS._serialized_end=21540
  _CONTAINERCLUSTERXVERTICALPODAUTOSCALING._serialized_start=21542
  _CONTAINERCLUSTERXVERTICALPODAUTOSCALING._serialized_end=21600
  _CONTAINERCLUSTERXWORKLOADIDENTITYCONFIG._serialized_start=21602
  _CONTAINERCLUSTERXWORKLOADIDENTITYCONFIG._serialized_end=21666
  _CONTAINERCLUSTER._serialized_start=21669
  _CONTAINERCLUSTER._serialized_end=24898
  _CONTAINERCLUSTER_RESOURCELABELSENTRY._serialized_start=24845
  _CONTAINERCLUSTER_RESOURCELABELSENTRY._serialized_end=24898
  _CONTAINERNODEPOOLXAUTOSCALING._serialized_start=24900
  _CONTAINERNODEPOOLXAUTOSCALING._serialized_end=24979
  _CONTAINERNODEPOOLXMANAGEMENT._serialized_start=24981
  _CONTAINERNODEPOOLXMANAGEMENT._serialized_end=25054
  _CONTAINERNODEPOOLXNODECONFIGXGCFSCONFIG._serialized_start=25056
  _CONTAINERNODEPOOLXNODECONFIGXGCFSCONFIG._serialized_end=25114
  _CONTAINERNODEPOOLXNODECONFIGXGVNIC._serialized_start=25116
  _CONTAINERNODEPOOLXNODECONFIGXGVNIC._serialized_end=25169
  _CONTAINERNODEPOOLXNODECONFIGXSHIELDEDINSTANCECONFIG._serialized_start=25171
  _CONTAINERNODEPOOLXNODECONFIGXSHIELDEDINSTANCECONFIG._serialized_end=25289
  _CONTAINERNODEPOOLXNODECONFIGXWORKLOADMETADATACONFIG._serialized_start=25291
  _CONTAINERNODEPOOLXNODECONFIGXWORKLOADMETADATACONFIG._serialized_end=25358
  _CONTAINERNODEPOOLXNODECONFIG._serialized_start=25361
  _CONTAINERNODEPOOLXNODECONFIG._serialized_end=26625
  _CONTAINERNODEPOOLXNODECONFIG_GUESTACCELERATORENTRY._serialized_start=17698
  _CONTAINERNODEPOOLXNODECONFIG_GUESTACCELERATORENTRY._serialized_end=17753
  _CONTAINERNODEPOOLXNODECONFIG_LABELSENTRY._serialized_start=6112
  _CONTAINERNODEPOOLXNODECONFIG_LABELSENTRY._serialized_end=6157
  _CONTAINERNODEPOOLXNODECONFIG_METADATAENTRY._serialized_start=17802
  _CONTAINERNODEPOOLXNODECONFIG_METADATAENTRY._serialized_end=17849
  _CONTAINERNODEPOOLXNODECONFIG_TAINTENTRY._serialized_start=17851
  _CONTAINERNODEPOOLXNODECONFIG_TAINTENTRY._serialized_end=17895
  _CONTAINERNODEPOOLXTIMEOUTS._serialized_start=26627
  _CONTAINERNODEPOOLXTIMEOUTS._serialized_end=26703
  _CONTAINERNODEPOOLXUPGRADESETTINGS._serialized_start=26705
  _CONTAINERNODEPOOLXUPGRADESETTINGS._serialized_end=26784
  _CONTAINERNODEPOOL._serialized_start=26787
  _CONTAINERNODEPOOL._serialized_end=27558
  _CONTAINERREGISTRY._serialized_start=27561
  _CONTAINERREGISTRY._serialized_end=27710
# @@protoc_insertion_point(module_scope)
