"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class AppEnvironmentVariable(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    value: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        value: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info", "value", b"value"]) -> None: ...

global___AppEnvironmentVariable = AppEnvironmentVariable

@typing_extensions.final
class AppBasicAuthConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    USERNAME_FIELD_NUMBER: builtins.int
    ENABLE_BASIC_AUTH_FIELD_NUMBER: builtins.int
    PASSWORD_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    username: builtins.str
    enable_basic_auth: builtins.bool
    password: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        username: builtins.str = ...,
        enable_basic_auth: builtins.bool = ...,
        password: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["enable_basic_auth", b"enable_basic_auth", "password", b"password", "resource_info", b"resource_info", "username", b"username"]) -> None: ...

global___AppBasicAuthConfig = AppBasicAuthConfig

@typing_extensions.final
class AppAutoBranchCreationConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ENVIRONMENT_VARIABLES_FIELD_NUMBER: builtins.int
    ENABLE_AUTO_BRANCH_CREATION_FIELD_NUMBER: builtins.int
    PULL_REQUEST_ENVIRONMENT_NAME_FIELD_NUMBER: builtins.int
    AUTO_BRANCH_CREATION_PATTERNS_FIELD_NUMBER: builtins.int
    ENABLE_PULL_REQUEST_PREVIEW_FIELD_NUMBER: builtins.int
    ENABLE_AUTO_BUILD_FIELD_NUMBER: builtins.int
    ENABLE_PERFORMANCE_MODE_FIELD_NUMBER: builtins.int
    BUILD_SPEC_FIELD_NUMBER: builtins.int
    STAGE_FIELD_NUMBER: builtins.int
    BASIC_AUTH_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def environment_variables(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AppEnvironmentVariable]: ...
    enable_auto_branch_creation: builtins.bool
    pull_request_environment_name: builtins.str
    @property
    def auto_branch_creation_patterns(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    enable_pull_request_preview: builtins.bool
    enable_auto_build: builtins.bool
    enable_performance_mode: builtins.bool
    build_spec: builtins.str
    stage: builtins.str
    @property
    def basic_auth_config(self) -> global___AppBasicAuthConfig: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        environment_variables: collections.abc.Iterable[global___AppEnvironmentVariable] | None = ...,
        enable_auto_branch_creation: builtins.bool = ...,
        pull_request_environment_name: builtins.str = ...,
        auto_branch_creation_patterns: collections.abc.Iterable[builtins.str] | None = ...,
        enable_pull_request_preview: builtins.bool = ...,
        enable_auto_build: builtins.bool = ...,
        enable_performance_mode: builtins.bool = ...,
        build_spec: builtins.str = ...,
        stage: builtins.str = ...,
        basic_auth_config: global___AppBasicAuthConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["basic_auth_config", b"basic_auth_config", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auto_branch_creation_patterns", b"auto_branch_creation_patterns", "basic_auth_config", b"basic_auth_config", "build_spec", b"build_spec", "enable_auto_branch_creation", b"enable_auto_branch_creation", "enable_auto_build", b"enable_auto_build", "enable_performance_mode", b"enable_performance_mode", "enable_pull_request_preview", b"enable_pull_request_preview", "environment_variables", b"environment_variables", "pull_request_environment_name", b"pull_request_environment_name", "resource_info", b"resource_info", "stage", b"stage"]) -> None: ...

global___AppAutoBranchCreationConfig = AppAutoBranchCreationConfig

@typing_extensions.final
class AppCustomRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    TARGET_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    condition: builtins.str
    status: builtins.str
    target: builtins.str
    source: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        condition: builtins.str = ...,
        status: builtins.str = ...,
        target: builtins.str = ...,
        source: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info", "source", b"source", "status", b"status", "target", b"target"]) -> None: ...

global___AppCustomRule = AppCustomRule

@typing_extensions.final
class App(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    AUTO_BRANCH_CREATION_CONFIG_FIELD_NUMBER: builtins.int
    OAUTH_TOKEN_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ENABLE_BRANCH_AUTO_DELETION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    REPOSITORY_FIELD_NUMBER: builtins.int
    ENVIRONMENT_VARIABLES_FIELD_NUMBER: builtins.int
    ACCESS_TOKEN_FIELD_NUMBER: builtins.int
    BUILD_SPEC_FIELD_NUMBER: builtins.int
    CUSTOM_RULES_FIELD_NUMBER: builtins.int
    BASIC_AUTH_CONFIG_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    IAM_SERVICE_ROLE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def auto_branch_creation_config(self) -> global___AppAutoBranchCreationConfig: ...
    oauth_token: builtins.str
    description: builtins.str
    enable_branch_auto_deletion: builtins.bool
    name: builtins.str
    repository: builtins.str
    @property
    def environment_variables(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AppEnvironmentVariable]: ...
    access_token: builtins.str
    build_spec: builtins.str
    @property
    def custom_rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AppCustomRule]: ...
    @property
    def basic_auth_config(self) -> global___AppBasicAuthConfig: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    iam_service_role: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        auto_branch_creation_config: global___AppAutoBranchCreationConfig | None = ...,
        oauth_token: builtins.str = ...,
        description: builtins.str = ...,
        enable_branch_auto_deletion: builtins.bool = ...,
        name: builtins.str = ...,
        repository: builtins.str = ...,
        environment_variables: collections.abc.Iterable[global___AppEnvironmentVariable] | None = ...,
        access_token: builtins.str = ...,
        build_spec: builtins.str = ...,
        custom_rules: collections.abc.Iterable[global___AppCustomRule] | None = ...,
        basic_auth_config: global___AppBasicAuthConfig | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        iam_service_role: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["auto_branch_creation_config", b"auto_branch_creation_config", "basic_auth_config", b"basic_auth_config", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["access_token", b"access_token", "auto_branch_creation_config", b"auto_branch_creation_config", "basic_auth_config", b"basic_auth_config", "build_spec", b"build_spec", "custom_rules", b"custom_rules", "description", b"description", "enable_branch_auto_deletion", b"enable_branch_auto_deletion", "environment_variables", b"environment_variables", "iam_service_role", b"iam_service_role", "name", b"name", "oauth_token", b"oauth_token", "repository", b"repository", "resource_info", b"resource_info", "tags", b"tags"]) -> None: ...

global___App = App

@typing_extensions.final
class Amplify(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APP_FIELD_NUMBER: builtins.int
    BRANCH_FIELD_NUMBER: builtins.int
    DOMAIN_FIELD_NUMBER: builtins.int
    @property
    def app(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___App]: ...
    @property
    def branch(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Branch]: ...
    @property
    def domain(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Domain]: ...
    def __init__(
        self,
        *,
        app: collections.abc.Iterable[global___App] | None = ...,
        branch: collections.abc.Iterable[global___Branch] | None = ...,
        domain: collections.abc.Iterable[global___Domain] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["app", b"app", "branch", b"branch", "domain", b"domain"]) -> None: ...

global___Amplify = Amplify

@typing_extensions.final
class BranchEnvironmentVariable(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    value: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        value: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info", "value", b"value"]) -> None: ...

global___BranchEnvironmentVariable = BranchEnvironmentVariable

@typing_extensions.final
class BranchBasicAuthConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    USERNAME_FIELD_NUMBER: builtins.int
    ENABLE_BASIC_AUTH_FIELD_NUMBER: builtins.int
    PASSWORD_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    username: builtins.str
    enable_basic_auth: builtins.bool
    password: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        username: builtins.str = ...,
        enable_basic_auth: builtins.bool = ...,
        password: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["enable_basic_auth", b"enable_basic_auth", "password", b"password", "resource_info", b"resource_info", "username", b"username"]) -> None: ...

global___BranchBasicAuthConfig = BranchBasicAuthConfig

@typing_extensions.final
class Branch(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ENVIRONMENT_VARIABLES_FIELD_NUMBER: builtins.int
    APP_ID_FIELD_NUMBER: builtins.int
    PULL_REQUEST_ENVIRONMENT_NAME_FIELD_NUMBER: builtins.int
    ENABLE_PULL_REQUEST_PREVIEW_FIELD_NUMBER: builtins.int
    ENABLE_AUTO_BUILD_FIELD_NUMBER: builtins.int
    ENABLE_PERFORMANCE_MODE_FIELD_NUMBER: builtins.int
    BUILD_SPEC_FIELD_NUMBER: builtins.int
    STAGE_FIELD_NUMBER: builtins.int
    BRANCH_NAME_FIELD_NUMBER: builtins.int
    BASIC_AUTH_CONFIG_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    description: builtins.str
    @property
    def environment_variables(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___BranchEnvironmentVariable]: ...
    app_id: builtins.str
    pull_request_environment_name: builtins.str
    enable_pull_request_preview: builtins.bool
    enable_auto_build: builtins.bool
    enable_performance_mode: builtins.bool
    build_spec: builtins.str
    stage: builtins.str
    branch_name: builtins.str
    @property
    def basic_auth_config(self) -> global___BranchBasicAuthConfig: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        description: builtins.str = ...,
        environment_variables: collections.abc.Iterable[global___BranchEnvironmentVariable] | None = ...,
        app_id: builtins.str = ...,
        pull_request_environment_name: builtins.str = ...,
        enable_pull_request_preview: builtins.bool = ...,
        enable_auto_build: builtins.bool = ...,
        enable_performance_mode: builtins.bool = ...,
        build_spec: builtins.str = ...,
        stage: builtins.str = ...,
        branch_name: builtins.str = ...,
        basic_auth_config: global___BranchBasicAuthConfig | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["basic_auth_config", b"basic_auth_config", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["app_id", b"app_id", "basic_auth_config", b"basic_auth_config", "branch_name", b"branch_name", "build_spec", b"build_spec", "description", b"description", "enable_auto_build", b"enable_auto_build", "enable_performance_mode", b"enable_performance_mode", "enable_pull_request_preview", b"enable_pull_request_preview", "environment_variables", b"environment_variables", "pull_request_environment_name", b"pull_request_environment_name", "resource_info", b"resource_info", "stage", b"stage", "tags", b"tags"]) -> None: ...

global___Branch = Branch

@typing_extensions.final
class DomainSubDomainSetting(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    PREFIX_FIELD_NUMBER: builtins.int
    BRANCH_NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    prefix: builtins.str
    branch_name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        prefix: builtins.str = ...,
        branch_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["branch_name", b"branch_name", "prefix", b"prefix", "resource_info", b"resource_info"]) -> None: ...

global___DomainSubDomainSetting = DomainSubDomainSetting

@typing_extensions.final
class Domain(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    SUB_DOMAIN_SETTINGS_FIELD_NUMBER: builtins.int
    APP_ID_FIELD_NUMBER: builtins.int
    AUTO_SUB_DOMAIN_IAM_ROLE_FIELD_NUMBER: builtins.int
    DOMAIN_NAME_FIELD_NUMBER: builtins.int
    ENABLE_AUTO_SUB_DOMAIN_FIELD_NUMBER: builtins.int
    AUTO_SUB_DOMAIN_CREATION_PATTERNS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def sub_domain_settings(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DomainSubDomainSetting]: ...
    app_id: builtins.str
    auto_sub_domain_iam_role: builtins.str
    domain_name: builtins.str
    enable_auto_sub_domain: builtins.bool
    @property
    def auto_sub_domain_creation_patterns(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        sub_domain_settings: collections.abc.Iterable[global___DomainSubDomainSetting] | None = ...,
        app_id: builtins.str = ...,
        auto_sub_domain_iam_role: builtins.str = ...,
        domain_name: builtins.str = ...,
        enable_auto_sub_domain: builtins.bool = ...,
        auto_sub_domain_creation_patterns: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["app_id", b"app_id", "auto_sub_domain_creation_patterns", b"auto_sub_domain_creation_patterns", "auto_sub_domain_iam_role", b"auto_sub_domain_iam_role", "domain_name", b"domain_name", "enable_auto_sub_domain", b"enable_auto_sub_domain", "resource_info", b"resource_info", "sub_domain_settings", b"sub_domain_settings"]) -> None: ...

global___Domain = Domain
