# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_compute_vpn.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19gcp/gcp_compute_vpn.proto\x12\x1boak9.tython.gcp.compute_vpn\x1a\x13shared/shared.proto\"<\n\x1a\x43omputeVpnGatewayXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\"\xbb\x02\n\x11\x43omputeVpnGateway\x12\x1a\n\x12\x63reation_timestamp\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x12\n\ngateway_id\x18\x03 \x01(\x01\x12\n\n\x02id\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x0f\n\x07network\x18\x06 \x01(\t\x12\x0f\n\x07project\x18\x07 \x01(\t\x12\x0e\n\x06region\x18\x08 \x01(\t\x12\x11\n\tself_link\x18\t \x01(\t\x12I\n\x08timeouts\x18\n \x01(\x0b\x32\x37.oak9.tython.gcp.compute_vpn.ComputeVpnGatewayXTimeouts\x12\x37\n\rresource_info\x18\x0b \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\";\n\x19\x43omputeVpnTunnelXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\"\x9c\x05\n\x10\x43omputeVpnTunnel\x12\x1a\n\x12\x63reation_timestamp\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x17\n\x0f\x64\x65tailed_status\x18\x03 \x01(\t\x12\n\n\x02id\x18\x04 \x01(\t\x12\x13\n\x0bike_version\x18\x05 \x01(\x01\x12\x1e\n\x16local_traffic_selector\x18\x06 \x03(\t\x12\x0c\n\x04name\x18\x07 \x01(\t\x12\x1d\n\x15peer_external_gateway\x18\x08 \x01(\t\x12\'\n\x1fpeer_external_gateway_interface\x18\t \x01(\x01\x12\x18\n\x10peer_gcp_gateway\x18\n \x01(\t\x12\x0f\n\x07peer_ip\x18\x0b \x01(\t\x12\x0f\n\x07project\x18\x0c \x01(\t\x12\x0e\n\x06region\x18\r \x01(\t\x12\x1f\n\x17remote_traffic_selector\x18\x0e \x03(\t\x12\x0e\n\x06router\x18\x0f \x01(\t\x12\x11\n\tself_link\x18\x10 \x01(\t\x12\x15\n\rshared_secret\x18\x11 \x01(\t\x12\x1a\n\x12shared_secret_hash\x18\x12 \x01(\t\x12\x1a\n\x12target_vpn_gateway\x18\x13 \x01(\t\x12\x11\n\ttunnel_id\x18\x14 \x01(\t\x12\x13\n\x0bvpn_gateway\x18\x15 \x01(\t\x12\x1d\n\x15vpn_gateway_interface\x18\x16 \x01(\x01\x12H\n\x08timeouts\x18\x17 \x01(\x0b\x32\x36.oak9.tython.gcp.compute_vpn.ComputeVpnTunnelXTimeouts\x12\x37\n\rresource_info\x18\x18 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_compute_vpn_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMPUTEVPNGATEWAYXTIMEOUTS._serialized_start=79
  _COMPUTEVPNGATEWAYXTIMEOUTS._serialized_end=139
  _COMPUTEVPNGATEWAY._serialized_start=142
  _COMPUTEVPNGATEWAY._serialized_end=457
  _COMPUTEVPNTUNNELXTIMEOUTS._serialized_start=459
  _COMPUTEVPNTUNNELXTIMEOUTS._serialized_end=518
  _COMPUTEVPNTUNNEL._serialized_start=521
  _COMPUTEVPNTUNNEL._serialized_end=1189
# @@protoc_insertion_point(module_scope)
