# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_dms.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11\x61ws/aws_dms.proto\x12\x13oak9.tython.aws.dms\x1a\x13shared/shared.proto\"\x9b\x01\n\x0b\x43\x65rtificate\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1e\n\x16\x63\x65rtificate_identifier\x18\x02 \x01(\t\x12\x17\n\x0f\x63\x65rtificate_pem\x18\x03 \x01(\t\x12\x1a\n\x12\x63\x65rtificate_wallet\x18\x04 \x01(\t\"\x88\x03\n\x03\x44MS\x12\x35\n\x0b\x63\x65rtificate\x18\x01 \x03(\x0b\x32 .oak9.tython.aws.dms.Certificate\x12/\n\x08\x65ndpoint\x18\x02 \x03(\x0b\x32\x1d.oak9.tython.aws.dms.Endpoint\x12\x42\n\x12\x65vent_subscription\x18\x03 \x03(\x0b\x32&.oak9.tython.aws.dms.EventSubscription\x12\x46\n\x14replication_instance\x18\x04 \x03(\x0b\x32(.oak9.tython.aws.dms.ReplicationInstance\x12M\n\x18replication_subnet_group\x18\x05 \x03(\x0b\x32+.oak9.tython.aws.dms.ReplicationSubnetGroup\x12>\n\x10replication_task\x18\x06 \x03(\x0b\x32$.oak9.tython.aws.dms.ReplicationTask\"o\n\x15\x45ndpointKafkaSettings\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06\x62roker\x18\x02 \x01(\t\x12\r\n\x05topic\x18\x03 \x01(\t\"\x8d\x02\n\x17\x45ndpointNeptuneSettings\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x17\n\x0fmax_retry_count\x18\x02 \x01(\x05\x12\x15\n\rmax_file_size\x18\x03 \x01(\x05\x12\x18\n\x10s3_bucket_folder\x18\x04 \x01(\t\x12\x1c\n\x14\x65rror_retry_duration\x18\x05 \x01(\x05\x12\x18\n\x10iam_auth_enabled\x18\x06 \x01(\x08\x12\x16\n\x0es3_bucket_name\x18\x07 \x01(\t\x12\x1f\n\x17service_access_role_arn\x18\x08 \x01(\t\"\xd1\x01\n\x1d\x45ndpointElasticsearchSettings\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0c\x65ndpoint_uri\x18\x02 \x01(\t\x12\"\n\x1a\x66ull_load_error_percentage\x18\x03 \x01(\x05\x12\x1c\n\x14\x65rror_retry_duration\x18\x04 \x01(\x05\x12\x1f\n\x17service_access_role_arn\x18\x05 \x01(\t\"\x89\x02\n\x12\x45ndpointS3Settings\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12!\n\x19\x65xternal_table_definition\x18\x02 \x01(\t\x12\x13\n\x0b\x62ucket_name\x18\x03 \x01(\t\x12\x15\n\rbucket_folder\x18\x04 \x01(\t\x12\x19\n\x11\x63sv_row_delimiter\x18\x05 \x01(\t\x12\x15\n\rcsv_delimiter\x18\x06 \x01(\t\x12\x1f\n\x17service_access_role_arn\x18\x07 \x01(\t\x12\x18\n\x10\x63ompression_type\x18\x08 \x01(\t\"t\n\x18\x45ndpointDynamoDbSettings\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1f\n\x17service_access_role_arn\x18\x02 \x01(\t\"\x9f\x01\n\x17\x45ndpointKinesisSettings\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0emessage_format\x18\x02 \x01(\t\x12\x12\n\nstream_arn\x18\x03 \x01(\t\x12\x1f\n\x17service_access_role_arn\x18\x04 \x01(\t\"\xbc\x02\n\x17\x45ndpointMongoDbSettings\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x61uth_source\x18\x02 \x01(\t\x12\x16\n\x0e\x61uth_mechanism\x18\x03 \x01(\t\x12\x10\n\x08username\x18\x04 \x01(\t\x12\x1b\n\x13\x64ocs_to_investigate\x18\x05 \x01(\t\x12\x13\n\x0bserver_name\x18\x06 \x01(\t\x12\x0c\n\x04port\x18\x07 \x01(\x05\x12\x16\n\x0e\x65xtract_doc_id\x18\x08 \x01(\t\x12\x15\n\rdatabase_name\x18\t \x01(\t\x12\x11\n\tauth_type\x18\n \x01(\t\x12\x10\n\x08password\x18\x0b \x01(\t\x12\x15\n\rnesting_level\x18\x0c \x01(\t\"\xac\x07\n\x08\x45ndpoint\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\nkms_key_id\x18\x02 \x01(\t\x12\x42\n\x0ekafka_settings\x18\x03 \x01(\x0b\x32*.oak9.tython.aws.dms.EndpointKafkaSettings\x12\x0c\n\x04port\x18\x04 \x01(\x05\x12\x15\n\rdatabase_name\x18\x05 \x01(\t\x12\x46\n\x10neptune_settings\x18\x06 \x01(\x0b\x32,.oak9.tython.aws.dms.EndpointNeptuneSettings\x12R\n\x16\x65lasticsearch_settings\x18\x07 \x01(\x0b\x32\x32.oak9.tython.aws.dms.EndpointElasticsearchSettings\x12<\n\x0bs3_settings\x18\x08 \x01(\x0b\x32\'.oak9.tython.aws.dms.EndpointS3Settings\x12\x13\n\x0b\x65ngine_name\x18\t \x01(\t\x12I\n\x12\x64ynamo_db_settings\x18\n \x01(\x0b\x32-.oak9.tython.aws.dms.EndpointDynamoDbSettings\x12\x46\n\x10kinesis_settings\x18\x0b \x01(\x0b\x32,.oak9.tython.aws.dms.EndpointKinesisSettings\x12\x10\n\x08username\x18\x0c \x01(\t\x12\x10\n\x08ssl_mode\x18\r \x01(\t\x12\x13\n\x0bserver_name\x18\x0e \x01(\t\x12#\n\x1b\x65xtra_connection_attributes\x18\x0f \x01(\t\x12\x15\n\rendpoint_type\x18\x10 \x01(\t\x12\x35\n\x04tags\x18\x11 \x03(\x0b\x32\'.oak9.tython.aws.dms.Endpoint.TagsEntry\x12\x1b\n\x13\x65ndpoint_identifier\x18\x12 \x01(\t\x12\x10\n\x08password\x18\x13 \x01(\t\x12\x17\n\x0f\x63\x65rtificate_arn\x18\x14 \x01(\t\x12G\n\x11mongo_db_settings\x18\x15 \x01(\x0b\x32,.oak9.tython.aws.dms.EndpointMongoDbSettings\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xbf\x02\n\x11\x45ventSubscription\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0bsource_type\x18\x02 \x01(\t\x12\x18\n\x10\x65vent_categories\x18\x03 \x03(\t\x12\x0f\n\x07\x65nabled\x18\x04 \x01(\x08\x12\x19\n\x11subscription_name\x18\x05 \x01(\t\x12\x15\n\rsns_topic_arn\x18\x06 \x01(\t\x12\x12\n\nsource_ids\x18\x07 \x03(\t\x12>\n\x04tags\x18\x08 \x03(\x0b\x32\x30.oak9.tython.aws.dms.EventSubscription.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xd7\x04\n\x13ReplicationInstance\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\'\n\x1freplication_instance_identifier\x18\x02 \x01(\t\x12\x16\n\x0e\x65ngine_version\x18\x03 \x01(\t\x12\x12\n\nkms_key_id\x18\x04 \x01(\t\x12\x19\n\x11\x61vailability_zone\x18\x05 \x01(\t\x12$\n\x1cpreferred_maintenance_window\x18\x06 \x01(\t\x12\"\n\x1a\x61uto_minor_version_upgrade\x18\x07 \x01(\x08\x12+\n#replication_subnet_group_identifier\x18\x08 \x01(\t\x12\x19\n\x11\x61llocated_storage\x18\t \x01(\x05\x12\x1e\n\x16vpc_security_group_ids\x18\n \x03(\t\x12#\n\x1b\x61llow_major_version_upgrade\x18\x0b \x01(\x08\x12\"\n\x1areplication_instance_class\x18\x0c \x01(\t\x12\x1b\n\x13publicly_accessible\x18\r \x01(\x08\x12\x10\n\x08multi_az\x18\x0e \x01(\x08\x12@\n\x04tags\x18\x0f \x03(\x0b\x32\x32.oak9.tython.aws.dms.ReplicationInstance.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb2\x02\n\x16ReplicationSubnetGroup\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12,\n$replication_subnet_group_description\x18\x02 \x01(\t\x12+\n#replication_subnet_group_identifier\x18\x03 \x01(\t\x12\x12\n\nsubnet_ids\x18\x04 \x03(\t\x12\x43\n\x04tags\x18\x05 \x03(\x0b\x32\x35.oak9.tython.aws.dms.ReplicationSubnetGroup.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xeb\x03\n\x0fReplicationTask\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12!\n\x19replication_task_settings\x18\x02 \x01(\t\x12\x16\n\x0etable_mappings\x18\x03 \x01(\t\x12\x1a\n\x12\x63\x64\x63_start_position\x18\x04 \x01(\t\x12#\n\x1breplication_task_identifier\x18\x05 \x01(\t\x12\x19\n\x11\x63\x64\x63_stop_position\x18\x06 \x01(\t\x12\x1b\n\x13source_endpoint_arn\x18\x07 \x01(\t\x12\x16\n\x0emigration_type\x18\x08 \x01(\t\x12\x1b\n\x13target_endpoint_arn\x18\t \x01(\t\x12 \n\x18replication_instance_arn\x18\n \x01(\t\x12<\n\x04tags\x18\x0b \x03(\x0b\x32..oak9.tython.aws.dms.ReplicationTask.TagsEntry\x12\x11\n\ttask_data\x18\x0c \x01(\t\x12\x16\n\x0e\x63\x64\x63_start_time\x18\r \x01(\x01\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_dms_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ENDPOINT_TAGSENTRY._options = None
  _ENDPOINT_TAGSENTRY._serialized_options = b'8\001'
  _EVENTSUBSCRIPTION_TAGSENTRY._options = None
  _EVENTSUBSCRIPTION_TAGSENTRY._serialized_options = b'8\001'
  _REPLICATIONINSTANCE_TAGSENTRY._options = None
  _REPLICATIONINSTANCE_TAGSENTRY._serialized_options = b'8\001'
  _REPLICATIONSUBNETGROUP_TAGSENTRY._options = None
  _REPLICATIONSUBNETGROUP_TAGSENTRY._serialized_options = b'8\001'
  _REPLICATIONTASK_TAGSENTRY._options = None
  _REPLICATIONTASK_TAGSENTRY._serialized_options = b'8\001'
  _CERTIFICATE._serialized_start=64
  _CERTIFICATE._serialized_end=219
  _DMS._serialized_start=222
  _DMS._serialized_end=614
  _ENDPOINTKAFKASETTINGS._serialized_start=616
  _ENDPOINTKAFKASETTINGS._serialized_end=727
  _ENDPOINTNEPTUNESETTINGS._serialized_start=730
  _ENDPOINTNEPTUNESETTINGS._serialized_end=999
  _ENDPOINTELASTICSEARCHSETTINGS._serialized_start=1002
  _ENDPOINTELASTICSEARCHSETTINGS._serialized_end=1211
  _ENDPOINTS3SETTINGS._serialized_start=1214
  _ENDPOINTS3SETTINGS._serialized_end=1479
  _ENDPOINTDYNAMODBSETTINGS._serialized_start=1481
  _ENDPOINTDYNAMODBSETTINGS._serialized_end=1597
  _ENDPOINTKINESISSETTINGS._serialized_start=1600
  _ENDPOINTKINESISSETTINGS._serialized_end=1759
  _ENDPOINTMONGODBSETTINGS._serialized_start=1762
  _ENDPOINTMONGODBSETTINGS._serialized_end=2078
  _ENDPOINT._serialized_start=2081
  _ENDPOINT._serialized_end=3021
  _ENDPOINT_TAGSENTRY._serialized_start=2978
  _ENDPOINT_TAGSENTRY._serialized_end=3021
  _EVENTSUBSCRIPTION._serialized_start=3024
  _EVENTSUBSCRIPTION._serialized_end=3343
  _EVENTSUBSCRIPTION_TAGSENTRY._serialized_start=2978
  _EVENTSUBSCRIPTION_TAGSENTRY._serialized_end=3021
  _REPLICATIONINSTANCE._serialized_start=3346
  _REPLICATIONINSTANCE._serialized_end=3945
  _REPLICATIONINSTANCE_TAGSENTRY._serialized_start=2978
  _REPLICATIONINSTANCE_TAGSENTRY._serialized_end=3021
  _REPLICATIONSUBNETGROUP._serialized_start=3948
  _REPLICATIONSUBNETGROUP._serialized_end=4254
  _REPLICATIONSUBNETGROUP_TAGSENTRY._serialized_start=2978
  _REPLICATIONSUBNETGROUP_TAGSENTRY._serialized_end=3021
  _REPLICATIONTASK._serialized_start=4257
  _REPLICATIONTASK._serialized_end=4748
  _REPLICATIONTASK_TAGSENTRY._serialized_start=2978
  _REPLICATIONTASK_TAGSENTRY._serialized_end=3021
# @@protoc_insertion_point(module_scope)
