# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_ec2_subnet.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18\x61ws/aws_ec2_subnet.proto\x12\x1aoak9.tython.aws.ec2_subnet\x1a\x13shared/shared.proto\"\xcc\x02\n\x06Subnet\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\'\n\x1f\x61ssign_ipv6_address_on_creation\x18\x02 \x01(\x08\x12\x19\n\x11\x61vailability_zone\x18\x03 \x01(\t\x12\x12\n\ncidr_block\x18\x04 \x01(\t\x12\x17\n\x0fipv6_cidr_block\x18\x05 \x01(\t\x12\x1f\n\x17map_public_ip_on_launch\x18\x06 \x01(\x08\x12:\n\x04tags\x18\x07 \x03(\x0b\x32,.oak9.tython.aws.ec2_subnet.Subnet.TagsEntry\x12\x0e\n\x06vpc_id\x18\x08 \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xca\x02\n\nEC2_Subnet\x12\x32\n\x06subnet\x18\x01 \x01(\x0b\x32\".oak9.tython.aws.ec2_subnet.Subnet\x12\x46\n\x11subnet_cidr_block\x18\x02 \x01(\x0b\x32+.oak9.tython.aws.ec2_subnet.SubnetCidrBlock\x12_\n\x1esubnet_network_acl_association\x18\x03 \x01(\x0b\x32\x37.oak9.tython.aws.ec2_subnet.SubnetNetworkAclAssociation\x12_\n\x1esubnet_route_table_association\x18\x04 \x01(\x0b\x32\x37.oak9.tython.aws.ec2_subnet.SubnetRouteTableAssociation\"v\n\x0fSubnetCidrBlock\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x17\n\x0fipv6_cidr_block\x18\x02 \x01(\t\x12\x11\n\tsubnet_id\x18\x03 \x01(\t\"\x81\x01\n\x1bSubnetNetworkAclAssociation\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0enetwork_acl_id\x18\x02 \x01(\t\x12\x11\n\tsubnet_id\x18\x03 \x01(\t\"\x81\x01\n\x1bSubnetRouteTableAssociation\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0eroute_table_id\x18\x02 \x01(\t\x12\x11\n\tsubnet_id\x18\x03 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_ec2_subnet_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SUBNET_TAGSENTRY._options = None
  _SUBNET_TAGSENTRY._serialized_options = b'8\001'
  _SUBNET._serialized_start=78
  _SUBNET._serialized_end=410
  _SUBNET_TAGSENTRY._serialized_start=367
  _SUBNET_TAGSENTRY._serialized_end=410
  _EC2_SUBNET._serialized_start=413
  _EC2_SUBNET._serialized_end=743
  _SUBNETCIDRBLOCK._serialized_start=745
  _SUBNETCIDRBLOCK._serialized_end=863
  _SUBNETNETWORKACLASSOCIATION._serialized_start=866
  _SUBNETNETWORKACLASSOCIATION._serialized_end=995
  _SUBNETROUTETABLEASSOCIATION._serialized_start=998
  _SUBNETROUTETABLEASSOCIATION._serialized_end=1127
# @@protoc_insertion_point(module_scope)
