"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ComputeAutoscalerXAutoscalingPolicyXCpuUtilization(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PREDICTIVE_METHOD_FIELD_NUMBER: builtins.int
    TARGET_FIELD_NUMBER: builtins.int
    predictive_method: builtins.str
    target: builtins.float
    def __init__(
        self,
        *,
        predictive_method: builtins.str = ...,
        target: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["predictive_method", b"predictive_method", "target", b"target"]) -> None: ...

global___ComputeAutoscalerXAutoscalingPolicyXCpuUtilization = ComputeAutoscalerXAutoscalingPolicyXCpuUtilization

@typing_extensions.final
class ComputeAutoscalerXAutoscalingPolicyXLoadBalancingUtilization(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TARGET_FIELD_NUMBER: builtins.int
    target: builtins.float
    def __init__(
        self,
        *,
        target: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["target", b"target"]) -> None: ...

global___ComputeAutoscalerXAutoscalingPolicyXLoadBalancingUtilization = ComputeAutoscalerXAutoscalingPolicyXLoadBalancingUtilization

@typing_extensions.final
class ComputeAutoscalerXAutoscalingPolicyXMetric(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    TARGET_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    name: builtins.str
    target: builtins.float
    type: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        target: builtins.float = ...,
        type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "target", b"target", "type", b"type"]) -> None: ...

global___ComputeAutoscalerXAutoscalingPolicyXMetric = ComputeAutoscalerXAutoscalingPolicyXMetric

@typing_extensions.final
class ComputeAutoscalerXAutoscalingPolicyXScaleInControlXMaxScaledInReplicas(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FIXED_FIELD_NUMBER: builtins.int
    PERCENT_FIELD_NUMBER: builtins.int
    fixed: builtins.float
    percent: builtins.float
    def __init__(
        self,
        *,
        fixed: builtins.float = ...,
        percent: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["fixed", b"fixed", "percent", b"percent"]) -> None: ...

global___ComputeAutoscalerXAutoscalingPolicyXScaleInControlXMaxScaledInReplicas = ComputeAutoscalerXAutoscalingPolicyXScaleInControlXMaxScaledInReplicas

@typing_extensions.final
class ComputeAutoscalerXAutoscalingPolicyXScaleInControl(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TIME_WINDOW_SEC_FIELD_NUMBER: builtins.int
    MAX_SCALED_IN_REPLICAS_FIELD_NUMBER: builtins.int
    time_window_sec: builtins.float
    @property
    def max_scaled_in_replicas(self) -> global___ComputeAutoscalerXAutoscalingPolicyXScaleInControlXMaxScaledInReplicas: ...
    def __init__(
        self,
        *,
        time_window_sec: builtins.float = ...,
        max_scaled_in_replicas: global___ComputeAutoscalerXAutoscalingPolicyXScaleInControlXMaxScaledInReplicas | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["max_scaled_in_replicas", b"max_scaled_in_replicas"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["max_scaled_in_replicas", b"max_scaled_in_replicas", "time_window_sec", b"time_window_sec"]) -> None: ...

global___ComputeAutoscalerXAutoscalingPolicyXScaleInControl = ComputeAutoscalerXAutoscalingPolicyXScaleInControl

@typing_extensions.final
class ComputeAutoscalerXAutoscalingPolicyXScalingSchedules(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    DISABLED_FIELD_NUMBER: builtins.int
    DURATION_SEC_FIELD_NUMBER: builtins.int
    MIN_REQUIRED_REPLICAS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    SCHEDULE_FIELD_NUMBER: builtins.int
    TIME_ZONE_FIELD_NUMBER: builtins.int
    description: builtins.str
    disabled: builtins.bool
    duration_sec: builtins.float
    min_required_replicas: builtins.float
    name: builtins.str
    schedule: builtins.str
    time_zone: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        disabled: builtins.bool = ...,
        duration_sec: builtins.float = ...,
        min_required_replicas: builtins.float = ...,
        name: builtins.str = ...,
        schedule: builtins.str = ...,
        time_zone: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "disabled", b"disabled", "duration_sec", b"duration_sec", "min_required_replicas", b"min_required_replicas", "name", b"name", "schedule", b"schedule", "time_zone", b"time_zone"]) -> None: ...

global___ComputeAutoscalerXAutoscalingPolicyXScalingSchedules = ComputeAutoscalerXAutoscalingPolicyXScalingSchedules

@typing_extensions.final
class ComputeAutoscalerXAutoscalingPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COOLDOWN_PERIOD_FIELD_NUMBER: builtins.int
    MAX_REPLICAS_FIELD_NUMBER: builtins.int
    MIN_REPLICAS_FIELD_NUMBER: builtins.int
    MODE_FIELD_NUMBER: builtins.int
    CPU_UTILIZATION_FIELD_NUMBER: builtins.int
    LOAD_BALANCING_UTILIZATION_FIELD_NUMBER: builtins.int
    METRIC_FIELD_NUMBER: builtins.int
    SCALE_IN_CONTROL_FIELD_NUMBER: builtins.int
    SCALING_SCHEDULES_FIELD_NUMBER: builtins.int
    cooldown_period: builtins.float
    max_replicas: builtins.float
    min_replicas: builtins.float
    mode: builtins.str
    @property
    def cpu_utilization(self) -> global___ComputeAutoscalerXAutoscalingPolicyXCpuUtilization: ...
    @property
    def load_balancing_utilization(self) -> global___ComputeAutoscalerXAutoscalingPolicyXLoadBalancingUtilization: ...
    @property
    def metric(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeAutoscalerXAutoscalingPolicyXMetric]: ...
    @property
    def scale_in_control(self) -> global___ComputeAutoscalerXAutoscalingPolicyXScaleInControl: ...
    @property
    def scaling_schedules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeAutoscalerXAutoscalingPolicyXScalingSchedules]: ...
    def __init__(
        self,
        *,
        cooldown_period: builtins.float = ...,
        max_replicas: builtins.float = ...,
        min_replicas: builtins.float = ...,
        mode: builtins.str = ...,
        cpu_utilization: global___ComputeAutoscalerXAutoscalingPolicyXCpuUtilization | None = ...,
        load_balancing_utilization: global___ComputeAutoscalerXAutoscalingPolicyXLoadBalancingUtilization | None = ...,
        metric: collections.abc.Iterable[global___ComputeAutoscalerXAutoscalingPolicyXMetric] | None = ...,
        scale_in_control: global___ComputeAutoscalerXAutoscalingPolicyXScaleInControl | None = ...,
        scaling_schedules: collections.abc.Iterable[global___ComputeAutoscalerXAutoscalingPolicyXScalingSchedules] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cpu_utilization", b"cpu_utilization", "load_balancing_utilization", b"load_balancing_utilization", "scale_in_control", b"scale_in_control"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cooldown_period", b"cooldown_period", "cpu_utilization", b"cpu_utilization", "load_balancing_utilization", b"load_balancing_utilization", "max_replicas", b"max_replicas", "metric", b"metric", "min_replicas", b"min_replicas", "mode", b"mode", "scale_in_control", b"scale_in_control", "scaling_schedules", b"scaling_schedules"]) -> None: ...

global___ComputeAutoscalerXAutoscalingPolicy = ComputeAutoscalerXAutoscalingPolicy

@typing_extensions.final
class ComputeAutoscalerXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___ComputeAutoscalerXTimeouts = ComputeAutoscalerXTimeouts

@typing_extensions.final
class ComputeAutoscaler(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATION_TIMESTAMP_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    SELF_LINK_FIELD_NUMBER: builtins.int
    TARGET_FIELD_NUMBER: builtins.int
    ZONE_FIELD_NUMBER: builtins.int
    AUTOSCALING_POLICY_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    creation_timestamp: builtins.str
    description: builtins.str
    id: builtins.str
    name: builtins.str
    project: builtins.str
    self_link: builtins.str
    target: builtins.str
    zone: builtins.str
    @property
    def autoscaling_policy(self) -> global___ComputeAutoscalerXAutoscalingPolicy: ...
    @property
    def timeouts(self) -> global___ComputeAutoscalerXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        creation_timestamp: builtins.str = ...,
        description: builtins.str = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        self_link: builtins.str = ...,
        target: builtins.str = ...,
        zone: builtins.str = ...,
        autoscaling_policy: global___ComputeAutoscalerXAutoscalingPolicy | None = ...,
        timeouts: global___ComputeAutoscalerXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["autoscaling_policy", b"autoscaling_policy", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["autoscaling_policy", b"autoscaling_policy", "creation_timestamp", b"creation_timestamp", "description", b"description", "id", b"id", "name", b"name", "project", b"project", "resource_info", b"resource_info", "self_link", b"self_link", "target", b"target", "timeouts", b"timeouts", "zone", b"zone"]) -> None: ...

global___ComputeAutoscaler = ComputeAutoscaler
