# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: azure/azure_microsoft_devices.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#azure/azure_microsoft_devices.proto\x12#oak9.tython.azure.microsoft_devices\x1a\x13shared/shared.proto\"\xa3\x02\n\x11Microsoft_Devices\x12>\n\x08iot_hubs\x18\x01 \x01(\x0b\x32,.oak9.tython.azure.microsoft_devices.IotHubs\x12W\n\x15iot_hubs_certificates\x18\x02 \x03(\x0b\x32\x38.oak9.tython.azure.microsoft_devices.IotHubsCertificates\x12u\n%iot_hubs_private_endpoint_connections\x18\x03 \x03(\x0b\x32\x46.oak9.tython.azure.microsoft_devices.IotHubsPrivateEndpointConnections\"n\n\nProperties\x12(\n enable_file_upload_notifications\x18\x01 \x01(\x08\x12\x17\n\x0fmin_tls_version\x18\x02 \x01(\t\x12\x1d\n\x15public_network_access\x18\x03 \x01(\t\"\xb1\x02\n!IotHubsPrivateEndpointConnections\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12N\n\x10private_endpoint\x18\x03 \x01(\x0b\x32\x34.oak9.tython.azure.microsoft_devices.PrivateEndpoint\x12u\n%private_link_service_connection_state\x18\x04 \x01(\x0b\x32\x46.oak9.tython.azure.microsoft_devices.PrivateLinkServiceConnectionState\"o\n&IotHubsEventHubEndpointsConsumerGroups\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x86\x01\n\x13IotHubsCertificates\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x63\x65rtificate\x18\x03 \x01(\t\x12\x13\n\x0bis_verified\x18\x04 \x01(\x08\"\xf8\x0c\n\x07IotHubs\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\x12\x42\n\x08identity\x18\x03 \x01(\x0b\x32\x30.oak9.tython.azure.microsoft_devices.ArmIdentity\x12\x10\n\x08location\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x19\n\x11\x61llowed_fqdn_list\x18\x06 \x03(\t\x12k\n\x16\x61uthorization_policies\x18\x07 \x03(\x0b\x32K.oak9.tython.azure.microsoft_devices.SharedAccessSignatureAuthorizationRule\x12U\n\x0f\x63loud_to_device\x18\x08 \x01(\x0b\x32<.oak9.tython.azure.microsoft_devices.CloudToDeviceProperties\x12\x10\n\x08\x63omments\x18\t \x01(\t\x12\x1c\n\x14\x64isable_device_s_a_s\x18\n \x01(\x08\x12\x1a\n\x12\x64isable_local_auth\x18\x0b \x01(\x08\x12\x1c\n\x14\x64isable_module_s_a_s\x18\x0c \x01(\x08\x12\x1d\n\x15\x65nable_data_residency\x18\r \x01(\x08\x12`\n\x13\x65vent_hub_endpoints\x18\x0e \x03(\x0b\x32\x43.oak9.tython.azure.microsoft_devices.IotHubs.EventHubEndpointsEntry\x12\x10\n\x08\x66\x65\x61tures\x18\x0f \x01(\t\x12J\n\x0fip_filter_rules\x18\x10 \x03(\x0b\x32\x31.oak9.tython.azure.microsoft_devices.IpFilterRule\x12\x61\n\x13messaging_endpoints\x18\x11 \x03(\x0b\x32\x44.oak9.tython.azure.microsoft_devices.IotHubs.MessagingEndpointsEntry\x12X\n\x11network_rule_sets\x18\x12 \x01(\x0b\x32=.oak9.tython.azure.microsoft_devices.NetworkRuleSetProperties\x12\x64\n\x1cprivate_endpoint_connections\x18\x13 \x03(\x0b\x32>.oak9.tython.azure.microsoft_devices.PrivateEndpointConnection\x12(\n restrict_outbound_network_access\x18\x14 \x01(\x08\x12G\n\x07routing\x18\x15 \x01(\x0b\x32\x36.oak9.tython.azure.microsoft_devices.RoutingProperties\x12]\n\x11storage_endpoints\x18\x16 \x03(\x0b\x32\x42.oak9.tython.azure.microsoft_devices.IotHubs.StorageEndpointsEntry\x12?\n\x03sku\x18\x17 \x01(\x0b\x32\x32.oak9.tython.azure.microsoft_devices.IotHubSkuInfo\x12\x44\n\x04tags\x18\x18 \x03(\x0b\x32\x36.oak9.tython.azure.microsoft_devices.IotHubs.TagsEntry\x12\x43\n\nproperties\x18\x19 \x01(\x0b\x32/.oak9.tython.azure.microsoft_devices.Properties\x1a\x38\n\x16\x45ventHubEndpointsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x39\n\x17MessagingEndpointsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x37\n\x15StorageEndpointsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"/\n\rIotHubSkuInfo\x12\x10\n\x08\x63\x61pacity\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\"\xc9\x02\n\x11RoutingProperties\x12H\n\tendpoints\x18\x01 \x01(\x0b\x32\x35.oak9.tython.azure.microsoft_devices.RoutingEndpoints\x12N\n\x0b\x65nrichments\x18\x02 \x03(\x0b\x32\x39.oak9.tython.azure.microsoft_devices.EnrichmentProperties\x12T\n\x0e\x66\x61llback_route\x18\x03 \x01(\x0b\x32<.oak9.tython.azure.microsoft_devices.FallbackRouteProperties\x12\x44\n\x06routes\x18\x04 \x03(\x0b\x32\x34.oak9.tython.azure.microsoft_devices.RouteProperties\"n\n\x0fRouteProperties\x12\x11\n\tcondition\x18\x01 \x01(\t\x12\x16\n\x0e\x65ndpoint_names\x18\x02 \x03(\t\x12\x12\n\nis_enabled\x18\x03 \x01(\x08\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0e\n\x06source\x18\x05 \x01(\t\"v\n\x17\x46\x61llbackRouteProperties\x12\x11\n\tcondition\x18\x01 \x01(\t\x12\x16\n\x0e\x65ndpoint_names\x18\x02 \x03(\t\x12\x12\n\nis_enabled\x18\x03 \x01(\x08\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0e\n\x06source\x18\x05 \x01(\t\"J\n\x14\x45nrichmentProperties\x12\x16\n\x0e\x65ndpoint_names\x18\x01 \x03(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\"\xa0\x03\n\x10RoutingEndpoints\x12R\n\nevent_hubs\x18\x01 \x03(\x0b\x32>.oak9.tython.azure.microsoft_devices.RoutingEventHubProperties\x12i\n\x12service_bus_queues\x18\x02 \x03(\x0b\x32M.oak9.tython.azure.microsoft_devices.RoutingServiceBusQueueEndpointProperties\x12i\n\x12service_bus_topics\x18\x03 \x03(\x0b\x32M.oak9.tython.azure.microsoft_devices.RoutingServiceBusTopicEndpointProperties\x12\x62\n\x12storage_containers\x18\x04 \x03(\x0b\x32\x46.oak9.tython.azure.microsoft_devices.RoutingStorageContainerProperties\"\x8d\x03\n!RoutingStorageContainerProperties\x12\x1b\n\x13\x61uthentication_type\x18\x01 \x01(\t\x12\"\n\x1a\x62\x61tch_frequency_in_seconds\x18\x02 \x01(\x05\x12\x19\n\x11\x63onnection_string\x18\x03 \x01(\t\x12\x16\n\x0e\x63ontainer_name\x18\x04 \x01(\t\x12\x10\n\x08\x65ncoding\x18\x05 \x01(\t\x12\x14\n\x0c\x65ndpoint_uri\x18\x06 \x01(\t\x12\x18\n\x10\x66ile_name_format\x18\x07 \x01(\t\x12\n\n\x02id\x18\x08 \x01(\t\x12\x46\n\x08identity\x18\t \x01(\x0b\x32\x34.oak9.tython.azure.microsoft_devices.ManagedIdentity\x12\x1f\n\x17max_chunk_size_in_bytes\x18\n \x01(\x05\x12\x0c\n\x04name\x18\x0b \x01(\t\x12\x16\n\x0eresource_group\x18\x0c \x01(\t\x12\x17\n\x0fsubscription_id\x18\r \x01(\t\"\xa0\x02\n(RoutingServiceBusTopicEndpointProperties\x12\x1b\n\x13\x61uthentication_type\x18\x01 \x01(\t\x12\x19\n\x11\x63onnection_string\x18\x02 \x01(\t\x12\x14\n\x0c\x65ndpoint_uri\x18\x03 \x01(\t\x12\x13\n\x0b\x65ntity_path\x18\x04 \x01(\t\x12\n\n\x02id\x18\x05 \x01(\t\x12\x46\n\x08identity\x18\x06 \x01(\x0b\x32\x34.oak9.tython.azure.microsoft_devices.ManagedIdentity\x12\x0c\n\x04name\x18\x07 \x01(\t\x12\x16\n\x0eresource_group\x18\x08 \x01(\t\x12\x17\n\x0fsubscription_id\x18\t \x01(\t\"\xa0\x02\n(RoutingServiceBusQueueEndpointProperties\x12\x1b\n\x13\x61uthentication_type\x18\x01 \x01(\t\x12\x19\n\x11\x63onnection_string\x18\x02 \x01(\t\x12\x14\n\x0c\x65ndpoint_uri\x18\x03 \x01(\t\x12\x13\n\x0b\x65ntity_path\x18\x04 \x01(\t\x12\n\n\x02id\x18\x05 \x01(\t\x12\x46\n\x08identity\x18\x06 \x01(\x0b\x32\x34.oak9.tython.azure.microsoft_devices.ManagedIdentity\x12\x0c\n\x04name\x18\x07 \x01(\t\x12\x16\n\x0eresource_group\x18\x08 \x01(\t\x12\x17\n\x0fsubscription_id\x18\t \x01(\t\"\x91\x02\n\x19RoutingEventHubProperties\x12\x1b\n\x13\x61uthentication_type\x18\x01 \x01(\t\x12\x19\n\x11\x63onnection_string\x18\x02 \x01(\t\x12\x14\n\x0c\x65ndpoint_uri\x18\x03 \x01(\t\x12\x13\n\x0b\x65ntity_path\x18\x04 \x01(\t\x12\n\n\x02id\x18\x05 \x01(\t\x12\x46\n\x08identity\x18\x06 \x01(\x0b\x32\x34.oak9.tython.azure.microsoft_devices.ManagedIdentity\x12\x0c\n\x04name\x18\x07 \x01(\t\x12\x16\n\x0eresource_group\x18\x08 \x01(\t\x12\x17\n\x0fsubscription_id\x18\t \x01(\t\"1\n\x0fManagedIdentity\x12\x1e\n\x16user_assigned_identity\x18\x01 \x01(\t\"\xe2\x01\n\x19PrivateEndpointConnection\x12N\n\x10private_endpoint\x18\x01 \x01(\x0b\x32\x34.oak9.tython.azure.microsoft_devices.PrivateEndpoint\x12u\n%private_link_service_connection_state\x18\x02 \x01(\x0b\x32\x46.oak9.tython.azure.microsoft_devices.PrivateLinkServiceConnectionState\"b\n!PrivateLinkServiceConnectionState\x12\x18\n\x10\x61\x63tions_required\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0e\n\x06status\x18\x03 \x01(\t\"\x1f\n\x0fPrivateEndpoint\x12\x0c\n\x04name\x18\x01 \x01(\t\"\xad\x01\n\x18NetworkRuleSetProperties\x12,\n$apply_to_built_in_event_hub_endpoint\x18\x01 \x01(\x08\x12\x16\n\x0e\x64\x65\x66\x61ult_action\x18\x02 \x01(\t\x12K\n\x08ip_rules\x18\x03 \x03(\x0b\x32\x39.oak9.tython.azure.microsoft_devices.NetworkRuleSetIpRule\"L\n\x14NetworkRuleSetIpRule\x12\x0e\n\x06\x61\x63tion\x18\x01 \x01(\t\x12\x13\n\x0b\x66ilter_name\x18\x02 \x01(\t\x12\x0f\n\x07ip_mask\x18\x03 \x01(\t\"D\n\x0cIpFilterRule\x12\x0e\n\x06\x61\x63tion\x18\x01 \x01(\t\x12\x13\n\x0b\x66ilter_name\x18\x02 \x01(\t\x12\x0f\n\x07ip_mask\x18\x03 \x01(\t\"\xa0\x01\n\x17\x43loudToDeviceProperties\x12\x1e\n\x16\x64\x65\x66\x61ult_ttl_as_iso8601\x18\x01 \x01(\t\x12I\n\x08\x66\x65\x65\x64\x62\x61\x63k\x18\x02 \x01(\x0b\x32\x37.oak9.tython.azure.microsoft_devices.FeedbackProperties\x12\x1a\n\x12max_delivery_count\x18\x03 \x01(\x05\"j\n\x12\x46\x65\x65\x64\x62\x61\x63kProperties\x12 \n\x18lock_duration_as_iso8601\x18\x01 \x01(\t\x12\x1a\n\x12max_delivery_count\x18\x02 \x01(\x05\x12\x16\n\x0ettl_as_iso8601\x18\x03 \x01(\t\"v\n&SharedAccessSignatureAuthorizationRule\x12\x10\n\x08key_name\x18\x01 \x01(\t\x12\x13\n\x0bprimary_key\x18\x02 \x01(\t\x12\x0e\n\x06rights\x18\x03 \x01(\t\x12\x15\n\rsecondary_key\x18\x04 \x01(\t\"\xca\x01\n\x0b\x41rmIdentity\x12\x0c\n\x04type\x18\x01 \x01(\t\x12n\n\x18user_assigned_identities\x18\x02 \x03(\x0b\x32L.oak9.tython.azure.microsoft_devices.ArmIdentity.UserAssignedIdentitiesEntry\x1a=\n\x1bUserAssignedIdentitiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'azure.azure_microsoft_devices_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _IOTHUBS_EVENTHUBENDPOINTSENTRY._options = None
  _IOTHUBS_EVENTHUBENDPOINTSENTRY._serialized_options = b'8\001'
  _IOTHUBS_MESSAGINGENDPOINTSENTRY._options = None
  _IOTHUBS_MESSAGINGENDPOINTSENTRY._serialized_options = b'8\001'
  _IOTHUBS_STORAGEENDPOINTSENTRY._options = None
  _IOTHUBS_STORAGEENDPOINTSENTRY._serialized_options = b'8\001'
  _IOTHUBS_TAGSENTRY._options = None
  _IOTHUBS_TAGSENTRY._serialized_options = b'8\001'
  _ARMIDENTITY_USERASSIGNEDIDENTITIESENTRY._options = None
  _ARMIDENTITY_USERASSIGNEDIDENTITIESENTRY._serialized_options = b'8\001'
  _MICROSOFT_DEVICES._serialized_start=98
  _MICROSOFT_DEVICES._serialized_end=389
  _PROPERTIES._serialized_start=391
  _PROPERTIES._serialized_end=501
  _IOTHUBSPRIVATEENDPOINTCONNECTIONS._serialized_start=504
  _IOTHUBSPRIVATEENDPOINTCONNECTIONS._serialized_end=809
  _IOTHUBSEVENTHUBENDPOINTSCONSUMERGROUPS._serialized_start=811
  _IOTHUBSEVENTHUBENDPOINTSCONSUMERGROUPS._serialized_end=922
  _IOTHUBSCERTIFICATES._serialized_start=925
  _IOTHUBSCERTIFICATES._serialized_end=1059
  _IOTHUBS._serialized_start=1062
  _IOTHUBS._serialized_end=2718
  _IOTHUBS_EVENTHUBENDPOINTSENTRY._serialized_start=2501
  _IOTHUBS_EVENTHUBENDPOINTSENTRY._serialized_end=2557
  _IOTHUBS_MESSAGINGENDPOINTSENTRY._serialized_start=2559
  _IOTHUBS_MESSAGINGENDPOINTSENTRY._serialized_end=2616
  _IOTHUBS_STORAGEENDPOINTSENTRY._serialized_start=2618
  _IOTHUBS_STORAGEENDPOINTSENTRY._serialized_end=2673
  _IOTHUBS_TAGSENTRY._serialized_start=2675
  _IOTHUBS_TAGSENTRY._serialized_end=2718
  _IOTHUBSKUINFO._serialized_start=2720
  _IOTHUBSKUINFO._serialized_end=2767
  _ROUTINGPROPERTIES._serialized_start=2770
  _ROUTINGPROPERTIES._serialized_end=3099
  _ROUTEPROPERTIES._serialized_start=3101
  _ROUTEPROPERTIES._serialized_end=3211
  _FALLBACKROUTEPROPERTIES._serialized_start=3213
  _FALLBACKROUTEPROPERTIES._serialized_end=3331
  _ENRICHMENTPROPERTIES._serialized_start=3333
  _ENRICHMENTPROPERTIES._serialized_end=3407
  _ROUTINGENDPOINTS._serialized_start=3410
  _ROUTINGENDPOINTS._serialized_end=3826
  _ROUTINGSTORAGECONTAINERPROPERTIES._serialized_start=3829
  _ROUTINGSTORAGECONTAINERPROPERTIES._serialized_end=4226
  _ROUTINGSERVICEBUSTOPICENDPOINTPROPERTIES._serialized_start=4229
  _ROUTINGSERVICEBUSTOPICENDPOINTPROPERTIES._serialized_end=4517
  _ROUTINGSERVICEBUSQUEUEENDPOINTPROPERTIES._serialized_start=4520
  _ROUTINGSERVICEBUSQUEUEENDPOINTPROPERTIES._serialized_end=4808
  _ROUTINGEVENTHUBPROPERTIES._serialized_start=4811
  _ROUTINGEVENTHUBPROPERTIES._serialized_end=5084
  _MANAGEDIDENTITY._serialized_start=5086
  _MANAGEDIDENTITY._serialized_end=5135
  _PRIVATEENDPOINTCONNECTION._serialized_start=5138
  _PRIVATEENDPOINTCONNECTION._serialized_end=5364
  _PRIVATELINKSERVICECONNECTIONSTATE._serialized_start=5366
  _PRIVATELINKSERVICECONNECTIONSTATE._serialized_end=5464
  _PRIVATEENDPOINT._serialized_start=5466
  _PRIVATEENDPOINT._serialized_end=5497
  _NETWORKRULESETPROPERTIES._serialized_start=5500
  _NETWORKRULESETPROPERTIES._serialized_end=5673
  _NETWORKRULESETIPRULE._serialized_start=5675
  _NETWORKRULESETIPRULE._serialized_end=5751
  _IPFILTERRULE._serialized_start=5753
  _IPFILTERRULE._serialized_end=5821
  _CLOUDTODEVICEPROPERTIES._serialized_start=5824
  _CLOUDTODEVICEPROPERTIES._serialized_end=5984
  _FEEDBACKPROPERTIES._serialized_start=5986
  _FEEDBACKPROPERTIES._serialized_end=6092
  _SHAREDACCESSSIGNATUREAUTHORIZATIONRULE._serialized_start=6094
  _SHAREDACCESSSIGNATUREAUTHORIZATIONRULE._serialized_end=6212
  _ARMIDENTITY._serialized_start=6215
  _ARMIDENTITY._serialized_end=6417
  _ARMIDENTITY_USERASSIGNEDIDENTITIESENTRY._serialized_start=6356
  _ARMIDENTITY_USERASSIGNEDIDENTITIESENTRY._serialized_end=6417
# @@protoc_insertion_point(module_scope)
