# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_sqs.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11\x61ws/aws_sqs.proto\x12\x13oak9.tython.aws.sqs\x1a\x13shared/shared.proto\"\xcf\x04\n\x05Queue\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12#\n\x1b\x63ontent_based_deduplication\x18\x02 \x01(\x08\x12\x15\n\rdelay_seconds\x18\x03 \x01(\x05\x12\x12\n\nfifo_queue\x18\x04 \x01(\x08\x12)\n!kms_data_key_reuse_period_seconds\x18\x05 \x01(\x05\x12\x19\n\x11kms_master_key_id\x18\x06 \x01(\t\x12\x1c\n\x14maximum_message_size\x18\x07 \x01(\x05\x12 \n\x18message_retention_period\x18\x08 \x01(\x05\x12\x12\n\nqueue_name\x18\t \x01(\t\x12)\n!receive_message_wait_time_seconds\x18\n \x01(\x05\x12\x45\n\x0eredrive_policy\x18\x0b \x03(\x0b\x32-.oak9.tython.aws.sqs.Queue.RedrivePolicyEntry\x12\x32\n\x04tags\x18\x0c \x03(\x0b\x32$.oak9.tython.aws.sqs.Queue.TagsEntry\x12\x1a\n\x12visibility_timeout\x18\r \x01(\x05\x1a\x34\n\x12RedrivePolicyEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"h\n\x03SQS\x12)\n\x05queue\x18\x01 \x01(\x0b\x32\x1a.oak9.tython.aws.sqs.Queue\x12\x36\n\x0cqueue_policy\x18\x02 \x01(\x0b\x32 .oak9.tython.aws.sqs.QueuePolicy\"o\n\x0bQueuePolicy\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06queues\x18\x02 \x03(\t\x12\x17\n\x0fpolicy_document\x18\x03 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_sqs_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _QUEUE_REDRIVEPOLICYENTRY._options = None
  _QUEUE_REDRIVEPOLICYENTRY._serialized_options = b'8\001'
  _QUEUE_TAGSENTRY._options = None
  _QUEUE_TAGSENTRY._serialized_options = b'8\001'
  _QUEUE._serialized_start=64
  _QUEUE._serialized_end=655
  _QUEUE_REDRIVEPOLICYENTRY._serialized_start=558
  _QUEUE_REDRIVEPOLICYENTRY._serialized_end=610
  _QUEUE_TAGSENTRY._serialized_start=612
  _QUEUE_TAGSENTRY._serialized_end=655
  _SQS._serialized_start=657
  _SQS._serialized_end=761
  _QUEUEPOLICY._serialized_start=763
  _QUEUEPOLICY._serialized_end=874
# @@protoc_insertion_point(module_scope)
