# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: azure/azure_microsoft_servicebus.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&azure/azure_microsoft_servicebus.proto\x12&oak9.tython.azure.microsoft_servicebus\x1a\x13shared/shared.proto\"\x88\x02\n\x14Microsoft_ServiceBus\x12\x46\n\nnamespaces\x18\x01 \x01(\x0b\x32\x32.oak9.tython.azure.microsoft_servicebus.Namespaces\x12S\n\x11namespaces_queues\x18\x02 \x03(\x0b\x32\x38.oak9.tython.azure.microsoft_servicebus.NamespacesQueues\x12S\n\x11namespaces_topics\x18\x03 \x03(\x0b\x32\x38.oak9.tython.azure.microsoft_servicebus.NamespacesTopics\"\xde\x02\n\"NamespacesTopicsSubscriptionsRules\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12>\n\x06\x61\x63tion\x18\x03 \x01(\x0b\x32..oak9.tython.azure.microsoft_servicebus.Action\x12U\n\x12\x63orrelation_filter\x18\x04 \x01(\x0b\x32\x39.oak9.tython.azure.microsoft_servicebus.CorrelationFilter\x12\x13\n\x0b\x66ilter_type\x18\x05 \x01(\t\x12\x45\n\nsql_filter\x18\x06 \x01(\x0b\x32\x31.oak9.tython.azure.microsoft_servicebus.SqlFilter\"`\n\tSqlFilter\x12\x1b\n\x13\x63ompatibility_level\x18\x01 \x01(\x05\x12\x1e\n\x16requires_preprocessing\x18\x02 \x01(\x08\x12\x16\n\x0esql_expression\x18\x03 \x01(\t\"\xe5\x02\n\x11\x43orrelationFilter\x12\x14\n\x0c\x63ontent_type\x18\x01 \x01(\t\x12\x16\n\x0e\x63orrelation_id\x18\x02 \x01(\t\x12\r\n\x05label\x18\x03 \x01(\t\x12\x12\n\nmessage_id\x18\x04 \x01(\t\x12]\n\nproperties\x18\x05 \x03(\x0b\x32I.oak9.tython.azure.microsoft_servicebus.CorrelationFilter.PropertiesEntry\x12\x10\n\x08reply_to\x18\x06 \x01(\t\x12\x1b\n\x13reply_to_session_id\x18\x07 \x01(\t\x12\x1e\n\x16requires_preprocessing\x18\x08 \x01(\x08\x12\x12\n\nsession_id\x18\t \x01(\t\x12\n\n\x02to\x18\n \x01(\t\x1a\x31\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"]\n\x06\x41\x63tion\x12\x1b\n\x13\x63ompatibility_level\x18\x01 \x01(\x05\x12\x1e\n\x16requires_preprocessing\x18\x02 \x01(\x08\x12\x16\n\x0esql_expression\x18\x03 \x01(\t\"\xf8\x05\n\x1dNamespacesTopicsSubscriptions\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x1b\n\x13\x61uto_delete_on_idle\x18\x03 \x01(\t\x12\x62\n\x18\x63lient_affine_properties\x18\x04 \x01(\x0b\x32@.oak9.tython.azure.microsoft_servicebus.SBClientAffineProperties\x12\x36\n.dead_lettering_on_filter_evaluation_exceptions\x18\x05 \x01(\x08\x12,\n$dead_lettering_on_message_expiration\x18\x06 \x01(\x08\x12$\n\x1c\x64\x65\x66\x61ult_message_time_to_live\x18\x07 \x01(\t\x12/\n\'duplicate_detection_history_time_window\x18\x08 \x01(\t\x12!\n\x19\x65nable_batched_operations\x18\t \x01(\x08\x12)\n!forward_dead_lettered_messages_to\x18\n \x01(\t\x12\x12\n\nforward_to\x18\x0b \x01(\t\x12\x18\n\x10is_client_affine\x18\x0c \x01(\x08\x12\x15\n\rlock_duration\x18\r \x01(\t\x12\x1a\n\x12max_delivery_count\x18\x0e \x01(\x05\x12\x18\n\x10requires_session\x18\x0f \x01(\x08\x12\x0e\n\x06status\x18\x10 \x01(\t\x12y\n%namespaces_topics_subscriptions_rules\x18\x11 \x03(\x0b\x32J.oak9.tython.azure.microsoft_servicebus.NamespacesTopicsSubscriptionsRules\"T\n\x18SBClientAffineProperties\x12\x11\n\tclient_id\x18\x01 \x01(\t\x12\x12\n\nis_durable\x18\x02 \x01(\x08\x12\x11\n\tis_shared\x18\x03 \x01(\x08\"{\n\"NamespacesTopicsAuthorizationRules\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0e\n\x06rights\x18\x03 \x03(\t\"\xa6\x05\n\x10NamespacesTopics\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x1b\n\x13\x61uto_delete_on_idle\x18\x03 \x01(\t\x12$\n\x1c\x64\x65\x66\x61ult_message_time_to_live\x18\x04 \x01(\t\x12/\n\'duplicate_detection_history_time_window\x18\x05 \x01(\t\x12!\n\x19\x65nable_batched_operations\x18\x06 \x01(\x08\x12\x16\n\x0e\x65nable_express\x18\x07 \x01(\x08\x12\x1b\n\x13\x65nable_partitioning\x18\x08 \x01(\x08\x12%\n\x1dmax_message_size_in_kilobytes\x18\t \x01(\x05\x12\x1d\n\x15max_size_in_megabytes\x18\n \x01(\x05\x12$\n\x1crequires_duplicate_detection\x18\x0b \x01(\x08\x12\x0e\n\x06status\x18\x0c \x01(\t\x12\x18\n\x10support_ordering\x18\r \x01(\x08\x12y\n%namespaces_topics_authorization_rules\x18\x0e \x03(\x0b\x32J.oak9.tython.azure.microsoft_servicebus.NamespacesTopicsAuthorizationRules\x12n\n\x1fnamespaces_topics_subscriptions\x18\x0f \x03(\x0b\x32\x45.oak9.tython.azure.microsoft_servicebus.NamespacesTopicsSubscriptions\"{\n\"NamespacesQueuesAuthorizationRules\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0e\n\x06rights\x18\x03 \x03(\t\"\xd6\x05\n\x10NamespacesQueues\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x1b\n\x13\x61uto_delete_on_idle\x18\x03 \x01(\t\x12,\n$dead_lettering_on_message_expiration\x18\x04 \x01(\x08\x12$\n\x1c\x64\x65\x66\x61ult_message_time_to_live\x18\x05 \x01(\t\x12/\n\'duplicate_detection_history_time_window\x18\x06 \x01(\t\x12!\n\x19\x65nable_batched_operations\x18\x07 \x01(\x08\x12\x16\n\x0e\x65nable_express\x18\x08 \x01(\x08\x12\x1b\n\x13\x65nable_partitioning\x18\t \x01(\x08\x12)\n!forward_dead_lettered_messages_to\x18\n \x01(\t\x12\x12\n\nforward_to\x18\x0b \x01(\t\x12\x15\n\rlock_duration\x18\x0c \x01(\t\x12\x1a\n\x12max_delivery_count\x18\r \x01(\x05\x12%\n\x1dmax_message_size_in_kilobytes\x18\x0e \x01(\x05\x12\x1d\n\x15max_size_in_megabytes\x18\x0f \x01(\x05\x12$\n\x1crequires_duplicate_detection\x18\x10 \x01(\x08\x12\x18\n\x10requires_session\x18\x11 \x01(\x08\x12\x0e\n\x06status\x18\x12 \x01(\t\x12y\n%namespaces_queues_authorization_rules\x18\x13 \x03(\x0b\x32J.oak9.tython.azure.microsoft_servicebus.NamespacesQueuesAuthorizationRules\"\xc4\x02\n$NamespacesPrivateEndpointConnections\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12Q\n\x10private_endpoint\x18\x03 \x01(\x0b\x32\x37.oak9.tython.azure.microsoft_servicebus.PrivateEndpoint\x12\x66\n%private_link_service_connection_state\x18\x04 \x01(\x0b\x32\x37.oak9.tython.azure.microsoft_servicebus.ConnectionState\x12\x1a\n\x12provisioning_state\x18\x05 \x01(\t\"\xf2\x02\n\x19NamespacesNetworkRuleSets\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x16\n\x0e\x64\x65\x66\x61ult_action\x18\x03 \x01(\t\x12J\n\x08ip_rules\x18\x04 \x03(\x0b\x32\x38.oak9.tython.azure.microsoft_servicebus.NWRuleSetIpRules\x12\x1d\n\x15public_network_access\x18\x05 \x01(\t\x12&\n\x1etrusted_service_access_enabled\x18\x06 \x01(\x08\x12\x63\n\x15virtual_network_rules\x18\x07 \x03(\x0b\x32\x44.oak9.tython.azure.microsoft_servicebus.NWRuleSetVirtualNetworkRules\"\x8c\x01\n\x1cNWRuleSetVirtualNetworkRules\x12,\n$ignore_missing_vnet_service_endpoint\x18\x01 \x01(\x08\x12>\n\x06subnet\x18\x02 \x01(\x0b\x32..oak9.tython.azure.microsoft_servicebus.Subnet\"\x14\n\x06Subnet\x12\n\n\x02id\x18\x01 \x01(\t\"3\n\x10NWRuleSetIpRules\x12\x0e\n\x06\x61\x63tion\x18\x01 \x01(\t\x12\x0f\n\x07ip_mask\x18\x02 \x01(\t\"\xa1\x01\n!NamespacesMigrationConfigurations\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x1b\n\x13post_migration_name\x18\x03 \x01(\t\x12\x18\n\x10target_namespace\x18\x04 \x01(\t\"\x9d\x01\n!NamespacesDisasterRecoveryConfigs\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x16\n\x0e\x61lternate_name\x18\x03 \x01(\t\x12\x19\n\x11partner_namespace\x18\x04 \x01(\t\"u\n\x1cNamespacesAuthorizationRules\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0e\n\x06rights\x18\x03 \x03(\t\"\xe0\x08\n\nNamespaces\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x42\n\x08identity\x18\x02 \x01(\x0b\x32\x30.oak9.tython.azure.microsoft_servicebus.Identity\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x16\n\x0e\x61lternate_name\x18\x05 \x01(\t\x12\x1a\n\x12\x64isable_local_auth\x18\x06 \x01(\x08\x12\x46\n\nencryption\x18\x07 \x01(\x0b\x32\x32.oak9.tython.azure.microsoft_servicebus.Encryption\x12g\n\x1cprivate_endpoint_connections\x18\x08 \x03(\x0b\x32\x41.oak9.tython.azure.microsoft_servicebus.PrivateEndpointConnection\x12\x16\n\x0ezone_redundant\x18\t \x01(\x08\x12:\n\x03sku\x18\n \x01(\x0b\x32-.oak9.tython.azure.microsoft_servicebus.SBSku\x12J\n\x04tags\x18\x0b \x03(\x0b\x32<.oak9.tython.azure.microsoft_servicebus.Namespaces.TagsEntry\x12g\n\x1cnamespaces_network_rule_sets\x18\x0c \x03(\x0b\x32\x41.oak9.tython.azure.microsoft_servicebus.NamespacesNetworkRuleSets\x12m\n\x1fnamespaces__authorization_rules\x18\r \x03(\x0b\x32\x44.oak9.tython.azure.microsoft_servicebus.NamespacesAuthorizationRules\x12w\n$namespaces_disaster_recovery_configs\x18\x0e \x03(\x0b\x32I.oak9.tython.azure.microsoft_servicebus.NamespacesDisasterRecoveryConfigs\x12v\n#namespaces_migration_configurations\x18\x0f \x03(\x0b\x32I.oak9.tython.azure.microsoft_servicebus.NamespacesMigrationConfigurations\x12\x1b\n\x13minimum_tls_version\x18\x10 \x01(\t\x12\x1d\n\x15public_network_access\x18\x11 \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"5\n\x05SBSku\x12\x10\n\x08\x63\x61pacity\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04tier\x18\x03 \x01(\t\"\xf2\x01\n\x19PrivateEndpointConnection\x12Q\n\x10private_endpoint\x18\x01 \x01(\x0b\x32\x37.oak9.tython.azure.microsoft_servicebus.PrivateEndpoint\x12\x66\n%private_link_service_connection_state\x18\x02 \x01(\x0b\x32\x37.oak9.tython.azure.microsoft_servicebus.ConnectionState\x12\x1a\n\x12provisioning_state\x18\x03 \x01(\t\"6\n\x0f\x43onnectionState\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x0e\n\x06status\x18\x02 \x01(\t\"\x1d\n\x0fPrivateEndpoint\x12\n\n\x02id\x18\x01 \x01(\t\"\xa5\x01\n\nEncryption\x12\x12\n\nkey_source\x18\x01 \x01(\t\x12X\n\x14key_vault_properties\x18\x02 \x03(\x0b\x32:.oak9.tython.azure.microsoft_servicebus.KeyVaultProperties\x12)\n!require_infrastructure_encryption\x18\x03 \x01(\x08\"\xac\x01\n\x12KeyVaultProperties\x12X\n\x08identity\x18\x01 \x01(\x0b\x32\x46.oak9.tython.azure.microsoft_servicebus.UserAssignedIdentityProperties\x12\x10\n\x08key_name\x18\x02 \x01(\t\x12\x15\n\rkey_vault_uri\x18\x03 \x01(\t\x12\x13\n\x0bkey_version\x18\x04 \x01(\t\"@\n\x1eUserAssignedIdentityProperties\x12\x1e\n\x16user_assigned_identity\x18\x01 \x01(\t\"\xc7\x01\n\x08Identity\x12\x0c\n\x04type\x18\x01 \x01(\t\x12n\n\x18user_assigned_identities\x18\x02 \x03(\x0b\x32L.oak9.tython.azure.microsoft_servicebus.Identity.UserAssignedIdentitiesEntry\x1a=\n\x1bUserAssignedIdentitiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'azure.azure_microsoft_servicebus_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CORRELATIONFILTER_PROPERTIESENTRY._options = None
  _CORRELATIONFILTER_PROPERTIESENTRY._serialized_options = b'8\001'
  _NAMESPACES_TAGSENTRY._options = None
  _NAMESPACES_TAGSENTRY._serialized_options = b'8\001'
  _IDENTITY_USERASSIGNEDIDENTITIESENTRY._options = None
  _IDENTITY_USERASSIGNEDIDENTITIESENTRY._serialized_options = b'8\001'
  _MICROSOFT_SERVICEBUS._serialized_start=104
  _MICROSOFT_SERVICEBUS._serialized_end=368
  _NAMESPACESTOPICSSUBSCRIPTIONSRULES._serialized_start=371
  _NAMESPACESTOPICSSUBSCRIPTIONSRULES._serialized_end=721
  _SQLFILTER._serialized_start=723
  _SQLFILTER._serialized_end=819
  _CORRELATIONFILTER._serialized_start=822
  _CORRELATIONFILTER._serialized_end=1179
  _CORRELATIONFILTER_PROPERTIESENTRY._serialized_start=1130
  _CORRELATIONFILTER_PROPERTIESENTRY._serialized_end=1179
  _ACTION._serialized_start=1181
  _ACTION._serialized_end=1274
  _NAMESPACESTOPICSSUBSCRIPTIONS._serialized_start=1277
  _NAMESPACESTOPICSSUBSCRIPTIONS._serialized_end=2037
  _SBCLIENTAFFINEPROPERTIES._serialized_start=2039
  _SBCLIENTAFFINEPROPERTIES._serialized_end=2123
  _NAMESPACESTOPICSAUTHORIZATIONRULES._serialized_start=2125
  _NAMESPACESTOPICSAUTHORIZATIONRULES._serialized_end=2248
  _NAMESPACESTOPICS._serialized_start=2251
  _NAMESPACESTOPICS._serialized_end=2929
  _NAMESPACESQUEUESAUTHORIZATIONRULES._serialized_start=2931
  _NAMESPACESQUEUESAUTHORIZATIONRULES._serialized_end=3054
  _NAMESPACESQUEUES._serialized_start=3057
  _NAMESPACESQUEUES._serialized_end=3783
  _NAMESPACESPRIVATEENDPOINTCONNECTIONS._serialized_start=3786
  _NAMESPACESPRIVATEENDPOINTCONNECTIONS._serialized_end=4110
  _NAMESPACESNETWORKRULESETS._serialized_start=4113
  _NAMESPACESNETWORKRULESETS._serialized_end=4483
  _NWRULESETVIRTUALNETWORKRULES._serialized_start=4486
  _NWRULESETVIRTUALNETWORKRULES._serialized_end=4626
  _SUBNET._serialized_start=4628
  _SUBNET._serialized_end=4648
  _NWRULESETIPRULES._serialized_start=4650
  _NWRULESETIPRULES._serialized_end=4701
  _NAMESPACESMIGRATIONCONFIGURATIONS._serialized_start=4704
  _NAMESPACESMIGRATIONCONFIGURATIONS._serialized_end=4865
  _NAMESPACESDISASTERRECOVERYCONFIGS._serialized_start=4868
  _NAMESPACESDISASTERRECOVERYCONFIGS._serialized_end=5025
  _NAMESPACESAUTHORIZATIONRULES._serialized_start=5027
  _NAMESPACESAUTHORIZATIONRULES._serialized_end=5144
  _NAMESPACES._serialized_start=5147
  _NAMESPACES._serialized_end=6267
  _NAMESPACES_TAGSENTRY._serialized_start=6224
  _NAMESPACES_TAGSENTRY._serialized_end=6267
  _SBSKU._serialized_start=6269
  _SBSKU._serialized_end=6322
  _PRIVATEENDPOINTCONNECTION._serialized_start=6325
  _PRIVATEENDPOINTCONNECTION._serialized_end=6567
  _CONNECTIONSTATE._serialized_start=6569
  _CONNECTIONSTATE._serialized_end=6623
  _PRIVATEENDPOINT._serialized_start=6625
  _PRIVATEENDPOINT._serialized_end=6654
  _ENCRYPTION._serialized_start=6657
  _ENCRYPTION._serialized_end=6822
  _KEYVAULTPROPERTIES._serialized_start=6825
  _KEYVAULTPROPERTIES._serialized_end=6997
  _USERASSIGNEDIDENTITYPROPERTIES._serialized_start=6999
  _USERASSIGNEDIDENTITYPROPERTIES._serialized_end=7063
  _IDENTITY._serialized_start=7066
  _IDENTITY._serialized_end=7265
  _IDENTITY_USERASSIGNEDIDENTITIESENTRY._serialized_start=7204
  _IDENTITY_USERASSIGNEDIDENTITIESENTRY._serialized_end=7265
# @@protoc_insertion_point(module_scope)
