# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: azure/azure_microsoft_network_privatednszones.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3azure/azure_microsoft_network_privatednszones.proto\x12\x33oak9.tython.azure.microsoft_network_privatednszones\x1a\x13shared/shared.proto\"\x8f\x02\n!Microsoft_Network_privateDnsZones\x12_\n\x11private_dns_zones\x18\x01 \x01(\x0b\x32\x44.oak9.tython.azure.microsoft_network_privatednszones.PrivateDnsZones\x12\x88\x01\n\'private_dns_zones_virtual_network_links\x18\x02 \x03(\x0b\x32W.oak9.tython.azure.microsoft_network_privatednszones.PrivateDnsZonesVirtualNetworkLinks\"\xb6\x07\n\x12PrivateDnsZonesTXT\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x65tag\x18\x03 \x01(\t\x12g\n\x08metadata\x18\x04 \x03(\x0b\x32U.oak9.tython.azure.microsoft_network_privatednszones.PrivateDnsZonesTXT.MetadataEntry\x12\x0b\n\x03ttl\x18\x05 \x01(\x05\x12O\n\ta_records\x18\x06 \x03(\x0b\x32<.oak9.tython.azure.microsoft_network_privatednszones.ARecord\x12U\n\x0c\x61\x61\x61\x61_records\x18\x07 \x03(\x0b\x32?.oak9.tython.azure.microsoft_network_privatednszones.AaaaRecord\x12V\n\x0c\x63name_record\x18\x08 \x01(\x0b\x32@.oak9.tython.azure.microsoft_network_privatednszones.CnameRecord\x12Q\n\nmx_records\x18\t \x03(\x0b\x32=.oak9.tython.azure.microsoft_network_privatednszones.MxRecord\x12S\n\x0bptr_records\x18\n \x03(\x0b\x32>.oak9.tython.azure.microsoft_network_privatednszones.PtrRecord\x12R\n\nsoa_record\x18\x0b \x01(\x0b\x32>.oak9.tython.azure.microsoft_network_privatednszones.SoaRecord\x12S\n\x0bsrv_records\x18\x0c \x03(\x0b\x32>.oak9.tython.azure.microsoft_network_privatednszones.SrvRecord\x12S\n\x0btxt_records\x18\r \x03(\x0b\x32>.oak9.tython.azure.microsoft_network_privatednszones.TxtRecord\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb6\x07\n\x12PrivateDnsZonesSRV\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x65tag\x18\x03 \x01(\t\x12g\n\x08metadata\x18\x04 \x03(\x0b\x32U.oak9.tython.azure.microsoft_network_privatednszones.PrivateDnsZonesSRV.MetadataEntry\x12\x0b\n\x03ttl\x18\x05 \x01(\x05\x12O\n\ta_records\x18\x06 \x03(\x0b\x32<.oak9.tython.azure.microsoft_network_privatednszones.ARecord\x12U\n\x0c\x61\x61\x61\x61_records\x18\x07 \x03(\x0b\x32?.oak9.tython.azure.microsoft_network_privatednszones.AaaaRecord\x12V\n\x0c\x63name_record\x18\x08 \x01(\x0b\x32@.oak9.tython.azure.microsoft_network_privatednszones.CnameRecord\x12Q\n\nmx_records\x18\t \x03(\x0b\x32=.oak9.tython.azure.microsoft_network_privatednszones.MxRecord\x12S\n\x0bptr_records\x18\n \x03(\x0b\x32>.oak9.tython.azure.microsoft_network_privatednszones.PtrRecord\x12R\n\nsoa_record\x18\x0b \x01(\x0b\x32>.oak9.tython.azure.microsoft_network_privatednszones.SoaRecord\x12S\n\x0bsrv_records\x18\x0c \x03(\x0b\x32>.oak9.tython.azure.microsoft_network_privatednszones.SrvRecord\x12S\n\x0btxt_records\x18\r \x03(\x0b\x32>.oak9.tython.azure.microsoft_network_privatednszones.TxtRecord\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb6\x07\n\x12PrivateDnsZonesSOA\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x65tag\x18\x03 \x01(\t\x12g\n\x08metadata\x18\x04 \x03(\x0b\x32U.oak9.tython.azure.microsoft_network_privatednszones.PrivateDnsZonesSOA.MetadataEntry\x12\x0b\n\x03ttl\x18\x05 \x01(\x05\x12O\n\ta_records\x18\x06 \x03(\x0b\x32<.oak9.tython.azure.microsoft_network_privatednszones.ARecord\x12U\n\x0c\x61\x61\x61\x61_records\x18\x07 \x03(\x0b\x32?.oak9.tython.azure.microsoft_network_privatednszones.AaaaRecord\x12V\n\x0c\x63name_record\x18\x08 \x01(\x0b\x32@.oak9.tython.azure.microsoft_network_privatednszones.CnameRecord\x12Q\n\nmx_records\x18\t \x03(\x0b\x32=.oak9.tython.azure.microsoft_network_privatednszones.MxRecord\x12S\n\x0bptr_records\x18\n \x03(\x0b\x32>.oak9.tython.azure.microsoft_network_privatednszones.PtrRecord\x12R\n\nsoa_record\x18\x0b \x01(\x0b\x32>.oak9.tython.azure.microsoft_network_privatednszones.SoaRecord\x12S\n\x0bsrv_records\x18\x0c \x03(\x0b\x32>.oak9.tython.azure.microsoft_network_privatednszones.SrvRecord\x12S\n\x0btxt_records\x18\r \x03(\x0b\x32>.oak9.tython.azure.microsoft_network_privatednszones.TxtRecord\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb6\x07\n\x12PrivateDnsZonesPTR\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x65tag\x18\x03 \x01(\t\x12g\n\x08metadata\x18\x04 \x03(\x0b\x32U.oak9.tython.azure.microsoft_network_privatednszones.PrivateDnsZonesPTR.MetadataEntry\x12\x0b\n\x03ttl\x18\x05 \x01(\x05\x12O\n\ta_records\x18\x06 \x03(\x0b\x32<.oak9.tython.azure.microsoft_network_privatednszones.ARecord\x12U\n\x0c\x61\x61\x61\x61_records\x18\x07 \x03(\x0b\x32?.oak9.tython.azure.microsoft_network_privatednszones.AaaaRecord\x12V\n\x0c\x63name_record\x18\x08 \x01(\x0b\x32@.oak9.tython.azure.microsoft_network_privatednszones.CnameRecord\x12Q\n\nmx_records\x18\t \x03(\x0b\x32=.oak9.tython.azure.microsoft_network_privatednszones.MxRecord\x12S\n\x0bptr_records\x18\n \x03(\x0b\x32>.oak9.tython.azure.microsoft_network_privatednszones.PtrRecord\x12R\n\nsoa_record\x18\x0b \x01(\x0b\x32>.oak9.tython.azure.microsoft_network_privatednszones.SoaRecord\x12S\n\x0bsrv_records\x18\x0c \x03(\x0b\x32>.oak9.tython.azure.microsoft_network_privatednszones.SrvRecord\x12S\n\x0btxt_records\x18\r \x03(\x0b\x32>.oak9.tython.azure.microsoft_network_privatednszones.TxtRecord\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb4\x07\n\x11PrivateDnsZonesMX\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x65tag\x18\x03 \x01(\t\x12\x66\n\x08metadata\x18\x04 \x03(\x0b\x32T.oak9.tython.azure.microsoft_network_privatednszones.PrivateDnsZonesMX.MetadataEntry\x12\x0b\n\x03ttl\x18\x05 \x01(\x05\x12O\n\ta_records\x18\x06 \x03(\x0b\x32<.oak9.tython.azure.microsoft_network_privatednszones.ARecord\x12U\n\x0c\x61\x61\x61\x61_records\x18\x07 \x03(\x0b\x32?.oak9.tython.azure.microsoft_network_privatednszones.AaaaRecord\x12V\n\x0c\x63name_record\x18\x08 \x01(\x0b\x32@.oak9.tython.azure.microsoft_network_privatednszones.CnameRecord\x12Q\n\nmx_records\x18\t \x03(\x0b\x32=.oak9.tython.azure.microsoft_network_privatednszones.MxRecord\x12S\n\x0bptr_records\x18\n \x03(\x0b\x32>.oak9.tython.azure.microsoft_network_privatednszones.PtrRecord\x12R\n\nsoa_record\x18\x0b \x01(\x0b\x32>.oak9.tython.azure.microsoft_network_privatednszones.SoaRecord\x12S\n\x0bsrv_records\x18\x0c \x03(\x0b\x32>.oak9.tython.azure.microsoft_network_privatednszones.SrvRecord\x12S\n\x0btxt_records\x18\r \x03(\x0b\x32>.oak9.tython.azure.microsoft_network_privatednszones.TxtRecord\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xba\x07\n\x14PrivateDnsZonesCNAME\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x65tag\x18\x03 \x01(\t\x12i\n\x08metadata\x18\x04 \x03(\x0b\x32W.oak9.tython.azure.microsoft_network_privatednszones.PrivateDnsZonesCNAME.MetadataEntry\x12\x0b\n\x03ttl\x18\x05 \x01(\x05\x12O\n\ta_records\x18\x06 \x03(\x0b\x32<.oak9.tython.azure.microsoft_network_privatednszones.ARecord\x12U\n\x0c\x61\x61\x61\x61_records\x18\x07 \x03(\x0b\x32?.oak9.tython.azure.microsoft_network_privatednszones.AaaaRecord\x12V\n\x0c\x63name_record\x18\x08 \x01(\x0b\x32@.oak9.tython.azure.microsoft_network_privatednszones.CnameRecord\x12Q\n\nmx_records\x18\t \x03(\x0b\x32=.oak9.tython.azure.microsoft_network_privatednszones.MxRecord\x12S\n\x0bptr_records\x18\n \x03(\x0b\x32>.oak9.tython.azure.microsoft_network_privatednszones.PtrRecord\x12R\n\nsoa_record\x18\x0b \x01(\x0b\x32>.oak9.tython.azure.microsoft_network_privatednszones.SoaRecord\x12S\n\x0bsrv_records\x18\x0c \x03(\x0b\x32>.oak9.tython.azure.microsoft_network_privatednszones.SrvRecord\x12S\n\x0btxt_records\x18\r \x03(\x0b\x32>.oak9.tython.azure.microsoft_network_privatednszones.TxtRecord\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb8\x07\n\x13PrivateDnsZonesAAAA\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x65tag\x18\x03 \x01(\t\x12h\n\x08metadata\x18\x04 \x03(\x0b\x32V.oak9.tython.azure.microsoft_network_privatednszones.PrivateDnsZonesAAAA.MetadataEntry\x12\x0b\n\x03ttl\x18\x05 \x01(\x05\x12O\n\ta_records\x18\x06 \x03(\x0b\x32<.oak9.tython.azure.microsoft_network_privatednszones.ARecord\x12U\n\x0c\x61\x61\x61\x61_records\x18\x07 \x03(\x0b\x32?.oak9.tython.azure.microsoft_network_privatednszones.AaaaRecord\x12V\n\x0c\x63name_record\x18\x08 \x01(\x0b\x32@.oak9.tython.azure.microsoft_network_privatednszones.CnameRecord\x12Q\n\nmx_records\x18\t \x03(\x0b\x32=.oak9.tython.azure.microsoft_network_privatednszones.MxRecord\x12S\n\x0bptr_records\x18\n \x03(\x0b\x32>.oak9.tython.azure.microsoft_network_privatednszones.PtrRecord\x12R\n\nsoa_record\x18\x0b \x01(\x0b\x32>.oak9.tython.azure.microsoft_network_privatednszones.SoaRecord\x12S\n\x0bsrv_records\x18\x0c \x03(\x0b\x32>.oak9.tython.azure.microsoft_network_privatednszones.SrvRecord\x12S\n\x0btxt_records\x18\r \x03(\x0b\x32>.oak9.tython.azure.microsoft_network_privatednszones.TxtRecord\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb2\x07\n\x10PrivateDnsZonesA\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x65tag\x18\x03 \x01(\t\x12\x65\n\x08metadata\x18\x04 \x03(\x0b\x32S.oak9.tython.azure.microsoft_network_privatednszones.PrivateDnsZonesA.MetadataEntry\x12\x0b\n\x03ttl\x18\x05 \x01(\x05\x12O\n\ta_records\x18\x06 \x03(\x0b\x32<.oak9.tython.azure.microsoft_network_privatednszones.ARecord\x12U\n\x0c\x61\x61\x61\x61_records\x18\x07 \x03(\x0b\x32?.oak9.tython.azure.microsoft_network_privatednszones.AaaaRecord\x12V\n\x0c\x63name_record\x18\x08 \x01(\x0b\x32@.oak9.tython.azure.microsoft_network_privatednszones.CnameRecord\x12Q\n\nmx_records\x18\t \x03(\x0b\x32=.oak9.tython.azure.microsoft_network_privatednszones.MxRecord\x12S\n\x0bptr_records\x18\n \x03(\x0b\x32>.oak9.tython.azure.microsoft_network_privatednszones.PtrRecord\x12R\n\nsoa_record\x18\x0b \x01(\x0b\x32>.oak9.tython.azure.microsoft_network_privatednszones.SoaRecord\x12S\n\x0bsrv_records\x18\x0c \x03(\x0b\x32>.oak9.tython.azure.microsoft_network_privatednszones.SrvRecord\x12S\n\x0btxt_records\x18\r \x03(\x0b\x32>.oak9.tython.azure.microsoft_network_privatednszones.TxtRecord\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x1a\n\tTxtRecord\x12\r\n\x05value\x18\x01 \x03(\t\"K\n\tSrvRecord\x12\x10\n\x08priority\x18\x01 \x01(\x05\x12\x0e\n\x06weight\x18\x02 \x01(\x05\x12\x0c\n\x04port\x18\x03 \x01(\x05\x12\x0e\n\x06target\x18\x04 \x01(\t\"\x93\x01\n\tSoaRecord\x12\x0c\n\x04host\x18\x01 \x01(\t\x12\r\n\x05\x65mail\x18\x02 \x01(\t\x12\x15\n\rserial_number\x18\x03 \x01(\x05\x12\x14\n\x0crefresh_time\x18\x04 \x01(\x05\x12\x12\n\nretry_time\x18\x05 \x01(\x05\x12\x13\n\x0b\x65xpire_time\x18\x06 \x01(\x05\x12\x13\n\x0bminimum_ttl\x18\x07 \x01(\x05\"\x1d\n\tPtrRecord\x12\x10\n\x08ptrdname\x18\x01 \x01(\t\"0\n\x08MxRecord\x12\x12\n\npreference\x18\x01 \x01(\x05\x12\x10\n\x08\x65xchange\x18\x02 \x01(\t\"\x1c\n\x0b\x43nameRecord\x12\r\n\x05\x63name\x18\x01 \x01(\t\"\"\n\nAaaaRecord\x12\x14\n\x0cipv6_address\x18\x01 \x01(\t\"\x1f\n\x07\x41Record\x12\x14\n\x0cipv4_address\x18\x01 \x01(\t\"\xce\x02\n\"PrivateDnsZonesVirtualNetworkLinks\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12o\n\x04tags\x18\x03 \x03(\x0b\x32\x61.oak9.tython.azure.microsoft_network_privatednszones.PrivateDnsZonesVirtualNetworkLinks.TagsEntry\x12\x0c\n\x04\x65tag\x18\x04 \x01(\t\x12\x17\n\x0fvirtual_network\x18\x05 \x01(\t\x12\x1c\n\x14registration_enabled\x18\x06 \x01(\x08\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xcb\x08\n\x0fPrivateDnsZones\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12\\\n\x04tags\x18\x04 \x03(\x0b\x32N.oak9.tython.azure.microsoft_network_privatednszones.PrivateDnsZones.TagsEntry\x12\x0c\n\x04\x65tag\x18\x05 \x01(\t\x12\x63\n\x14private_dns_zones__a\x18\x06 \x03(\x0b\x32\x45.oak9.tython.azure.microsoft_network_privatednszones.PrivateDnsZonesA\x12i\n\x17private_dns_zones__aaaa\x18\x07 \x03(\x0b\x32H.oak9.tython.azure.microsoft_network_privatednszones.PrivateDnsZonesAAAA\x12k\n\x18private_dns_zones__cname\x18\x08 \x03(\x0b\x32I.oak9.tython.azure.microsoft_network_privatednszones.PrivateDnsZonesCNAME\x12\x65\n\x15private_dns_zones__mx\x18\t \x03(\x0b\x32\x46.oak9.tython.azure.microsoft_network_privatednszones.PrivateDnsZonesMX\x12g\n\x16private_dns_zones__ptr\x18\n \x03(\x0b\x32G.oak9.tython.azure.microsoft_network_privatednszones.PrivateDnsZonesPTR\x12g\n\x16private_dns_zones__soa\x18\x0b \x03(\x0b\x32G.oak9.tython.azure.microsoft_network_privatednszones.PrivateDnsZonesSOA\x12g\n\x16private_dns_zones__srv\x18\x0c \x03(\x0b\x32G.oak9.tython.azure.microsoft_network_privatednszones.PrivateDnsZonesSRV\x12g\n\x16private_dns_zones__txt\x18\r \x03(\x0b\x32G.oak9.tython.azure.microsoft_network_privatednszones.PrivateDnsZonesTXT\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'azure.azure_microsoft_network_privatednszones_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _PRIVATEDNSZONESTXT_METADATAENTRY._options = None
  _PRIVATEDNSZONESTXT_METADATAENTRY._serialized_options = b'8\001'
  _PRIVATEDNSZONESSRV_METADATAENTRY._options = None
  _PRIVATEDNSZONESSRV_METADATAENTRY._serialized_options = b'8\001'
  _PRIVATEDNSZONESSOA_METADATAENTRY._options = None
  _PRIVATEDNSZONESSOA_METADATAENTRY._serialized_options = b'8\001'
  _PRIVATEDNSZONESPTR_METADATAENTRY._options = None
  _PRIVATEDNSZONESPTR_METADATAENTRY._serialized_options = b'8\001'
  _PRIVATEDNSZONESMX_METADATAENTRY._options = None
  _PRIVATEDNSZONESMX_METADATAENTRY._serialized_options = b'8\001'
  _PRIVATEDNSZONESCNAME_METADATAENTRY._options = None
  _PRIVATEDNSZONESCNAME_METADATAENTRY._serialized_options = b'8\001'
  _PRIVATEDNSZONESAAAA_METADATAENTRY._options = None
  _PRIVATEDNSZONESAAAA_METADATAENTRY._serialized_options = b'8\001'
  _PRIVATEDNSZONESA_METADATAENTRY._options = None
  _PRIVATEDNSZONESA_METADATAENTRY._serialized_options = b'8\001'
  _PRIVATEDNSZONESVIRTUALNETWORKLINKS_TAGSENTRY._options = None
  _PRIVATEDNSZONESVIRTUALNETWORKLINKS_TAGSENTRY._serialized_options = b'8\001'
  _PRIVATEDNSZONES_TAGSENTRY._options = None
  _PRIVATEDNSZONES_TAGSENTRY._serialized_options = b'8\001'
  _MICROSOFT_NETWORK_PRIVATEDNSZONES._serialized_start=130
  _MICROSOFT_NETWORK_PRIVATEDNSZONES._serialized_end=401
  _PRIVATEDNSZONESTXT._serialized_start=404
  _PRIVATEDNSZONESTXT._serialized_end=1354
  _PRIVATEDNSZONESTXT_METADATAENTRY._serialized_start=1307
  _PRIVATEDNSZONESTXT_METADATAENTRY._serialized_end=1354
  _PRIVATEDNSZONESSRV._serialized_start=1357
  _PRIVATEDNSZONESSRV._serialized_end=2307
  _PRIVATEDNSZONESSRV_METADATAENTRY._serialized_start=1307
  _PRIVATEDNSZONESSRV_METADATAENTRY._serialized_end=1354
  _PRIVATEDNSZONESSOA._serialized_start=2310
  _PRIVATEDNSZONESSOA._serialized_end=3260
  _PRIVATEDNSZONESSOA_METADATAENTRY._serialized_start=1307
  _PRIVATEDNSZONESSOA_METADATAENTRY._serialized_end=1354
  _PRIVATEDNSZONESPTR._serialized_start=3263
  _PRIVATEDNSZONESPTR._serialized_end=4213
  _PRIVATEDNSZONESPTR_METADATAENTRY._serialized_start=1307
  _PRIVATEDNSZONESPTR_METADATAENTRY._serialized_end=1354
  _PRIVATEDNSZONESMX._serialized_start=4216
  _PRIVATEDNSZONESMX._serialized_end=5164
  _PRIVATEDNSZONESMX_METADATAENTRY._serialized_start=1307
  _PRIVATEDNSZONESMX_METADATAENTRY._serialized_end=1354
  _PRIVATEDNSZONESCNAME._serialized_start=5167
  _PRIVATEDNSZONESCNAME._serialized_end=6121
  _PRIVATEDNSZONESCNAME_METADATAENTRY._serialized_start=1307
  _PRIVATEDNSZONESCNAME_METADATAENTRY._serialized_end=1354
  _PRIVATEDNSZONESAAAA._serialized_start=6124
  _PRIVATEDNSZONESAAAA._serialized_end=7076
  _PRIVATEDNSZONESAAAA_METADATAENTRY._serialized_start=1307
  _PRIVATEDNSZONESAAAA_METADATAENTRY._serialized_end=1354
  _PRIVATEDNSZONESA._serialized_start=7079
  _PRIVATEDNSZONESA._serialized_end=8025
  _PRIVATEDNSZONESA_METADATAENTRY._serialized_start=1307
  _PRIVATEDNSZONESA_METADATAENTRY._serialized_end=1354
  _TXTRECORD._serialized_start=8027
  _TXTRECORD._serialized_end=8053
  _SRVRECORD._serialized_start=8055
  _SRVRECORD._serialized_end=8130
  _SOARECORD._serialized_start=8133
  _SOARECORD._serialized_end=8280
  _PTRRECORD._serialized_start=8282
  _PTRRECORD._serialized_end=8311
  _MXRECORD._serialized_start=8313
  _MXRECORD._serialized_end=8361
  _CNAMERECORD._serialized_start=8363
  _CNAMERECORD._serialized_end=8391
  _AAAARECORD._serialized_start=8393
  _AAAARECORD._serialized_end=8427
  _ARECORD._serialized_start=8429
  _ARECORD._serialized_end=8460
  _PRIVATEDNSZONESVIRTUALNETWORKLINKS._serialized_start=8463
  _PRIVATEDNSZONESVIRTUALNETWORKLINKS._serialized_end=8797
  _PRIVATEDNSZONESVIRTUALNETWORKLINKS_TAGSENTRY._serialized_start=8754
  _PRIVATEDNSZONESVIRTUALNETWORKLINKS_TAGSENTRY._serialized_end=8797
  _PRIVATEDNSZONES._serialized_start=8800
  _PRIVATEDNSZONES._serialized_end=9899
  _PRIVATEDNSZONES_TAGSENTRY._serialized_start=8754
  _PRIVATEDNSZONES_TAGSENTRY._serialized_end=8797
# @@protoc_insertion_point(module_scope)
