# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_codebuild.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17\x61ws/aws_codebuild.proto\x12\x19oak9.tython.aws.codebuild\x1a\x13shared/shared.proto\"\x88\x01\n\x10ProjectVpcConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07subnets\x18\x02 \x03(\t\x12\x0e\n\x06vpc_id\x18\x03 \x01(\t\x12\x1a\n\x12security_group_ids\x18\x04 \x03(\t\"^\n\x11ProjectSourceAuth\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08resource\x18\x02 \x01(\t\"x\n\x18ProjectBuildStatusConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07\x63ontext\x18\x02 \x01(\t\x12\x12\n\ntarget_url\x18\x03 \x01(\t\"o\n\x1aProjectGitSubmodulesConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x18\n\x10\x66\x65tch_submodules\x18\x02 \x01(\x08\"\xb9\x03\n\rProjectSource\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1b\n\x13report_build_status\x18\x02 \x01(\x08\x12:\n\x04\x61uth\x18\x03 \x01(\x0b\x32,.oak9.tython.aws.codebuild.ProjectSourceAuth\x12\x19\n\x11source_identifier\x18\x04 \x01(\t\x12\x12\n\nbuild_spec\x18\x05 \x01(\t\x12\x17\n\x0fgit_clone_depth\x18\x06 \x01(\x05\x12P\n\x13\x62uild_status_config\x18\x07 \x01(\x0b\x32\x33.oak9.tython.aws.codebuild.ProjectBuildStatusConfig\x12T\n\x15git_submodules_config\x18\x08 \x01(\x0b\x32\x35.oak9.tython.aws.codebuild.ProjectGitSubmodulesConfig\x12\x14\n\x0cinsecure_ssl\x18\t \x01(\x08\x12\x10\n\x08location\x18\n \x01(\t\"M\n\x12ProjectFilterGroup\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xa8\x01\n\x16ProjectProjectTriggers\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x44\n\rfilter_groups\x18\x02 \x03(\x0b\x32-.oak9.tython.aws.codebuild.ProjectFilterGroup\x12\x0f\n\x07webhook\x18\x03 \x01(\x08\"\xfe\x01\n\x10ProjectArtifacts\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x1b\n\x13\x61rtifact_identifier\x18\x03 \x01(\t\x12\x1e\n\x16override_artifact_name\x18\x04 \x01(\x08\x12\x11\n\tpackaging\x18\x05 \x01(\t\x12\x1b\n\x13\x65ncryption_disabled\x18\x06 \x01(\x08\x12\x10\n\x08location\x18\x07 \x01(\t\x12\x0c\n\x04name\x18\x08 \x01(\t\x12\x16\n\x0enamespace_type\x18\t \x01(\t\"\x8f\x01\n\x1bProjectCloudWatchLogsConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06status\x18\x02 \x01(\t\x12\x12\n\ngroup_name\x18\x03 \x01(\t\x12\x13\n\x0bstream_name\x18\x04 \x01(\t\"\x8d\x01\n\x13ProjectS3LogsConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06status\x18\x02 \x01(\t\x12\x1b\n\x13\x65ncryption_disabled\x18\x03 \x01(\x08\x12\x10\n\x08location\x18\x04 \x01(\t\"\xdf\x01\n\x11ProjectLogsConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12P\n\x10\x63loud_watch_logs\x18\x02 \x01(\x0b\x32\x36.oak9.tython.aws.codebuild.ProjectCloudWatchLogsConfig\x12?\n\x07s3_logs\x18\x03 \x01(\x0b\x32..oak9.tython.aws.codebuild.ProjectS3LogsConfig\"\xad\x01\n ProjectProjectFileSystemLocation\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0bmount_point\x18\x02 \x01(\t\x12\x12\n\nidentifier\x18\x03 \x01(\t\x12\x15\n\rmount_options\x18\x04 \x01(\t\x12\x10\n\x08location\x18\x05 \x01(\t\"r\n\x1aProjectEnvironmentVariable\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\r\n\x05value\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\"\x85\x01\n\x19ProjectRegistryCredential\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\ncredential\x18\x02 \x01(\t\x12\x1b\n\x13\x63redential_provider\x18\x03 \x01(\t\"\xee\x02\n\x12ProjectEnvironment\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12T\n\x15\x65nvironment_variables\x18\x02 \x03(\x0b\x32\x35.oak9.tython.aws.codebuild.ProjectEnvironmentVariable\x12\x17\n\x0fprivileged_mode\x18\x03 \x01(\x08\x12#\n\x1bimage_pull_credentials_type\x18\x04 \x01(\t\x12\r\n\x05image\x18\x05 \x01(\t\x12Q\n\x13registry_credential\x18\x06 \x01(\x0b\x32\x34.oak9.tython.aws.codebuild.ProjectRegistryCredential\x12\x14\n\x0c\x63ompute_type\x18\x07 \x01(\t\x12\x13\n\x0b\x63\x65rtificate\x18\x08 \x01(\t\"\x89\x01\n\x1bProjectProjectSourceVersion\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x19\n\x11source_identifier\x18\x02 \x01(\t\x12\x16\n\x0esource_version\x18\x03 \x01(\t\"\x92\x01\n\x18ProjectBatchRestrictions\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1d\n\x15\x63ompute_types_allowed\x18\x02 \x03(\t\x12\x1e\n\x16maximum_builds_allowed\x18\x03 \x01(\x05\"\xee\x01\n\x1eProjectProjectBuildBatchConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x19\n\x11\x63ombine_artifacts\x18\x02 \x01(\x08\x12\x14\n\x0cservice_role\x18\x03 \x01(\t\x12\x17\n\x0ftimeout_in_mins\x18\x04 \x01(\x05\x12I\n\x0crestrictions\x18\x05 \x01(\x0b\x32\x33.oak9.tython.aws.codebuild.ProjectBatchRestrictions\"o\n\x13ProjectProjectCache\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\r\n\x05modes\x18\x02 \x03(\t\x12\x10\n\x08location\x18\x03 \x01(\t\"\xcd\t\n\x07Project\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12?\n\nvpc_config\x18\x03 \x01(\x0b\x32+.oak9.tython.aws.codebuild.ProjectVpcConfig\x12\x43\n\x11secondary_sources\x18\x04 \x03(\x0b\x32(.oak9.tython.aws.codebuild.ProjectSource\x12\x16\n\x0e\x65ncryption_key\x18\x05 \x01(\t\x12\x16\n\x0esource_version\x18\x06 \x01(\t\x12\x43\n\x08triggers\x18\x07 \x01(\x0b\x32\x31.oak9.tython.aws.codebuild.ProjectProjectTriggers\x12H\n\x13secondary_artifacts\x18\x08 \x03(\x0b\x32+.oak9.tython.aws.codebuild.ProjectArtifacts\x12\x38\n\x06source\x18\t \x01(\x0b\x32(.oak9.tython.aws.codebuild.ProjectSource\x12\x0c\n\x04name\x18\n \x01(\t\x12>\n\tartifacts\x18\x0b \x01(\x0b\x32+.oak9.tython.aws.codebuild.ProjectArtifacts\x12\x15\n\rbadge_enabled\x18\x0c \x01(\x08\x12\x41\n\x0blogs_config\x18\r \x01(\x0b\x32,.oak9.tython.aws.codebuild.ProjectLogsConfig\x12\x14\n\x0cservice_role\x18\x0e \x01(\t\x12!\n\x19queued_timeout_in_minutes\x18\x0f \x01(\x05\x12Z\n\x15\x66ile_system_locations\x18\x10 \x03(\x0b\x32;.oak9.tython.aws.codebuild.ProjectProjectFileSystemLocation\x12\x42\n\x0b\x65nvironment\x18\x11 \x01(\x0b\x32-.oak9.tython.aws.codebuild.ProjectEnvironment\x12Y\n\x19secondary_source_versions\x18\x12 \x03(\x0b\x32\x36.oak9.tython.aws.codebuild.ProjectProjectSourceVersion\x12U\n\x12\x62uild_batch_config\x18\x13 \x01(\x0b\x32\x39.oak9.tython.aws.codebuild.ProjectProjectBuildBatchConfig\x12:\n\x04tags\x18\x14 \x03(\x0b\x32,.oak9.tython.aws.codebuild.Project.TagsEntry\x12\x1a\n\x12timeout_in_minutes\x18\x15 \x01(\x05\x12=\n\x05\x63\x61\x63he\x18\x16 \x01(\x0b\x32..oak9.tython.aws.codebuild.ProjectProjectCache\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x97\x02\n\tCodeBuild\x12\x33\n\x07project\x18\x01 \x03(\x0b\x32\".oak9.tython.aws.codebuild.Project\x12<\n\x0creport_group\x18\x02 \x03(\x0b\x32&.oak9.tython.aws.codebuild.ReportGroup\x12\x46\n\x11source_credential\x18\x03 \x03(\x0b\x32+.oak9.tython.aws.codebuild.SourceCredential\x12O\n\x16project_webhook_filter\x18\x04 \x03(\x0b\x32/.oak9.tython.aws.codebuild.ProjectWebhookFilter\"\xc0\x01\n\x1fReportGroupS3ReportExportConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x0e\n\x06\x62ucket\x18\x03 \x01(\t\x12\x11\n\tpackaging\x18\x04 \x01(\t\x12\x16\n\x0e\x65ncryption_key\x18\x05 \x01(\t\x12\x1b\n\x13\x65ncryption_disabled\x18\x06 \x01(\x08\"\xc8\x01\n\x1dReportGroupReportExportConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12R\n\x0es3_destination\x18\x02 \x01(\x0b\x32:.oak9.tython.aws.codebuild.ReportGroupS3ReportExportConfig\x12\x1a\n\x12\x65xport_config_type\x18\x03 \x01(\t\"\xb8\x02\n\x0bReportGroup\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04type\x18\x02 \x01(\t\x12O\n\rexport_config\x18\x03 \x01(\x0b\x32\x38.oak9.tython.aws.codebuild.ReportGroupReportExportConfig\x12\x16\n\x0e\x64\x65lete_reports\x18\x04 \x01(\x08\x12>\n\x04tags\x18\x05 \x03(\x0b\x32\x30.oak9.tython.aws.codebuild.ReportGroup.TagsEntry\x12\x0c\n\x04name\x18\x06 \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x94\x01\n\x10SourceCredential\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0bserver_type\x18\x02 \x01(\t\x12\x10\n\x08username\x18\x03 \x01(\t\x12\r\n\x05token\x18\x04 \x01(\t\x12\x11\n\tauth_type\x18\x05 \x01(\t\"\x81\x01\n\x14ProjectWebhookFilter\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07pattern\x18\x02 \x01(\t\x12\x1f\n\x17\x65xclude_matched_pattern\x18\x03 \x01(\x08\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_codebuild_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _PROJECT_TAGSENTRY._options = None
  _PROJECT_TAGSENTRY._serialized_options = b'8\001'
  _REPORTGROUP_TAGSENTRY._options = None
  _REPORTGROUP_TAGSENTRY._serialized_options = b'8\001'
  _PROJECTVPCCONFIG._serialized_start=76
  _PROJECTVPCCONFIG._serialized_end=212
  _PROJECTSOURCEAUTH._serialized_start=214
  _PROJECTSOURCEAUTH._serialized_end=308
  _PROJECTBUILDSTATUSCONFIG._serialized_start=310
  _PROJECTBUILDSTATUSCONFIG._serialized_end=430
  _PROJECTGITSUBMODULESCONFIG._serialized_start=432
  _PROJECTGITSUBMODULESCONFIG._serialized_end=543
  _PROJECTSOURCE._serialized_start=546
  _PROJECTSOURCE._serialized_end=987
  _PROJECTFILTERGROUP._serialized_start=989
  _PROJECTFILTERGROUP._serialized_end=1066
  _PROJECTPROJECTTRIGGERS._serialized_start=1069
  _PROJECTPROJECTTRIGGERS._serialized_end=1237
  _PROJECTARTIFACTS._serialized_start=1240
  _PROJECTARTIFACTS._serialized_end=1494
  _PROJECTCLOUDWATCHLOGSCONFIG._serialized_start=1497
  _PROJECTCLOUDWATCHLOGSCONFIG._serialized_end=1640
  _PROJECTS3LOGSCONFIG._serialized_start=1643
  _PROJECTS3LOGSCONFIG._serialized_end=1784
  _PROJECTLOGSCONFIG._serialized_start=1787
  _PROJECTLOGSCONFIG._serialized_end=2010
  _PROJECTPROJECTFILESYSTEMLOCATION._serialized_start=2013
  _PROJECTPROJECTFILESYSTEMLOCATION._serialized_end=2186
  _PROJECTENVIRONMENTVARIABLE._serialized_start=2188
  _PROJECTENVIRONMENTVARIABLE._serialized_end=2302
  _PROJECTREGISTRYCREDENTIAL._serialized_start=2305
  _PROJECTREGISTRYCREDENTIAL._serialized_end=2438
  _PROJECTENVIRONMENT._serialized_start=2441
  _PROJECTENVIRONMENT._serialized_end=2807
  _PROJECTPROJECTSOURCEVERSION._serialized_start=2810
  _PROJECTPROJECTSOURCEVERSION._serialized_end=2947
  _PROJECTBATCHRESTRICTIONS._serialized_start=2950
  _PROJECTBATCHRESTRICTIONS._serialized_end=3096
  _PROJECTPROJECTBUILDBATCHCONFIG._serialized_start=3099
  _PROJECTPROJECTBUILDBATCHCONFIG._serialized_end=3337
  _PROJECTPROJECTCACHE._serialized_start=3339
  _PROJECTPROJECTCACHE._serialized_end=3450
  _PROJECT._serialized_start=3453
  _PROJECT._serialized_end=4682
  _PROJECT_TAGSENTRY._serialized_start=4639
  _PROJECT_TAGSENTRY._serialized_end=4682
  _CODEBUILD._serialized_start=4685
  _CODEBUILD._serialized_end=4964
  _REPORTGROUPS3REPORTEXPORTCONFIG._serialized_start=4967
  _REPORTGROUPS3REPORTEXPORTCONFIG._serialized_end=5159
  _REPORTGROUPREPORTEXPORTCONFIG._serialized_start=5162
  _REPORTGROUPREPORTEXPORTCONFIG._serialized_end=5362
  _REPORTGROUP._serialized_start=5365
  _REPORTGROUP._serialized_end=5677
  _REPORTGROUP_TAGSENTRY._serialized_start=4639
  _REPORTGROUP_TAGSENTRY._serialized_end=4682
  _SOURCECREDENTIAL._serialized_start=5680
  _SOURCECREDENTIAL._serialized_end=5828
  _PROJECTWEBHOOKFILTER._serialized_start=5831
  _PROJECTWEBHOOKFILTER._serialized_end=5960
# @@protoc_insertion_point(module_scope)
