# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_game.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12gcp/gcp_game.proto\x12\x14oak9.tython.gcp.game\x1a\x13shared/shared.proto\"S\n@GameServicesGameServerClusterXConnectionInfoXGkeClusterReference\x12\x0f\n\x07\x63luster\x18\x01 \x01(\t\"\xb8\x01\n,GameServicesGameServerClusterXConnectionInfo\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12u\n\x15gke_cluster_reference\x18\x02 \x01(\x0b\x32V.oak9.tython.gcp.game.GameServicesGameServerClusterXConnectionInfoXGkeClusterReference\"X\n&GameServicesGameServerClusterXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xfd\x03\n\x1dGameServicesGameServerCluster\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12O\n\x06labels\x18\x04 \x03(\x0b\x32?.oak9.tython.gcp.game.GameServicesGameServerCluster.LabelsEntry\x12\x10\n\x08location\x18\x05 \x01(\t\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x0f\n\x07project\x18\x07 \x01(\t\x12\x10\n\x08realm_id\x18\x08 \x01(\t\x12[\n\x0f\x63onnection_info\x18\t \x01(\x0b\x32\x42.oak9.tython.gcp.game.GameServicesGameServerClusterXConnectionInfo\x12N\n\x08timeouts\x18\n \x01(\x0b\x32<.oak9.tython.gcp.game.GameServicesGameServerClusterXTimeouts\x12\x37\n\rresource_info\x18\x0b \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"M\n)GameServicesGameServerConfigXFleetConfigs\x12\x12\n\nfleet_spec\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x8b\x01\n5GameServicesGameServerConfigXScalingConfigsXSchedules\x12\x19\n\x11\x63ron_job_duration\x18\x01 \x01(\t\x12\x11\n\tcron_spec\x18\x02 \x01(\t\x12\x10\n\x08\x65nd_time\x18\x03 \x01(\t\x12\x12\n\nstart_time\x18\x04 \x01(\t\"\xcf\x01\n5GameServicesGameServerConfigXScalingConfigsXSelectors\x12g\n\x06labels\x18\x01 \x03(\x0b\x32W.oak9.tython.gcp.game.GameServicesGameServerConfigXScalingConfigsXSelectors.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x9a\x02\n+GameServicesGameServerConfigXScalingConfigs\x12\x1d\n\x15\x66leet_autoscaler_spec\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12^\n\tschedules\x18\x03 \x03(\x0b\x32K.oak9.tython.gcp.game.GameServicesGameServerConfigXScalingConfigsXSchedules\x12^\n\tselectors\x18\x04 \x03(\x0b\x32K.oak9.tython.gcp.game.GameServicesGameServerConfigXScalingConfigsXSelectors\"G\n%GameServicesGameServerConfigXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\"\xd5\x04\n\x1cGameServicesGameServerConfig\x12\x11\n\tconfig_id\x18\x01 \x01(\t\x12\x15\n\rdeployment_id\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\n\n\x02id\x18\x04 \x01(\t\x12N\n\x06labels\x18\x05 \x03(\x0b\x32>.oak9.tython.gcp.game.GameServicesGameServerConfig.LabelsEntry\x12\x10\n\x08location\x18\x06 \x01(\t\x12\x0c\n\x04name\x18\x07 \x01(\t\x12\x0f\n\x07project\x18\x08 \x01(\t\x12V\n\rfleet_configs\x18\t \x03(\x0b\x32?.oak9.tython.gcp.game.GameServicesGameServerConfigXFleetConfigs\x12Z\n\x0fscaling_configs\x18\n \x03(\x0b\x32\x41.oak9.tython.gcp.game.GameServicesGameServerConfigXScalingConfigs\x12M\n\x08timeouts\x18\x0b \x01(\x0b\x32;.oak9.tython.gcp.game.GameServicesGameServerConfigXTimeouts\x12\x37\n\rresource_info\x18\x0c \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"[\n)GameServicesGameServerDeploymentXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\x9a\x03\n GameServicesGameServerDeployment\x12\x15\n\rdeployment_id\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12R\n\x06labels\x18\x04 \x03(\x0b\x32\x42.oak9.tython.gcp.game.GameServicesGameServerDeployment.LabelsEntry\x12\x10\n\x08location\x18\x05 \x01(\t\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x0f\n\x07project\x18\x07 \x01(\t\x12Q\n\x08timeouts\x18\x08 \x01(\x0b\x32?.oak9.tython.gcp.game.GameServicesGameServerDeploymentXTimeouts\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"b\nPGameServicesGameServerDeploymentRolloutXGameServerConfigOverridesXRealmsSelector\x12\x0e\n\x06realms\x18\x01 \x03(\t\"\xdc\x01\nAGameServicesGameServerDeploymentRolloutXGameServerConfigOverrides\x12\x16\n\x0e\x63onfig_version\x18\x01 \x01(\t\x12\x7f\n\x0frealms_selector\x18\x02 \x01(\x0b\x32\x66.oak9.tython.gcp.game.GameServicesGameServerDeploymentRolloutXGameServerConfigOverridesXRealmsSelector\"b\n0GameServicesGameServerDeploymentRolloutXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xa1\x03\n\'GameServicesGameServerDeploymentRollout\x12\"\n\x1a\x64\x65\x66\x61ult_game_server_config\x18\x01 \x01(\t\x12\x15\n\rdeployment_id\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12}\n\x1cgame_server_config_overrides\x18\x06 \x03(\x0b\x32W.oak9.tython.gcp.game.GameServicesGameServerDeploymentRolloutXGameServerConfigOverrides\x12X\n\x08timeouts\x18\x07 \x01(\x0b\x32\x46.oak9.tython.gcp.game.GameServicesGameServerDeploymentRolloutXTimeouts\x12\x37\n\rresource_info\x18\x08 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"L\n\x1aGameServicesRealmXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\x89\x03\n\x11GameServicesRealm\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x43\n\x06labels\x18\x04 \x03(\x0b\x32\x33.oak9.tython.gcp.game.GameServicesRealm.LabelsEntry\x12\x10\n\x08location\x18\x05 \x01(\t\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x0f\n\x07project\x18\x07 \x01(\t\x12\x10\n\x08realm_id\x18\x08 \x01(\t\x12\x11\n\ttime_zone\x18\t \x01(\t\x12\x42\n\x08timeouts\x18\n \x01(\x0b\x32\x30.oak9.tython.gcp.game.GameServicesRealmXTimeouts\x12\x37\n\rresource_info\x18\x0b \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_game_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GAMESERVICESGAMESERVERCLUSTER_LABELSENTRY._options = None
  _GAMESERVICESGAMESERVERCLUSTER_LABELSENTRY._serialized_options = b'8\001'
  _GAMESERVICESGAMESERVERCONFIGXSCALINGCONFIGSXSELECTORS_LABELSENTRY._options = None
  _GAMESERVICESGAMESERVERCONFIGXSCALINGCONFIGSXSELECTORS_LABELSENTRY._serialized_options = b'8\001'
  _GAMESERVICESGAMESERVERCONFIG_LABELSENTRY._options = None
  _GAMESERVICESGAMESERVERCONFIG_LABELSENTRY._serialized_options = b'8\001'
  _GAMESERVICESGAMESERVERDEPLOYMENT_LABELSENTRY._options = None
  _GAMESERVICESGAMESERVERDEPLOYMENT_LABELSENTRY._serialized_options = b'8\001'
  _GAMESERVICESREALM_LABELSENTRY._options = None
  _GAMESERVICESREALM_LABELSENTRY._serialized_options = b'8\001'
  _GAMESERVICESGAMESERVERCLUSTERXCONNECTIONINFOXGKECLUSTERREFERENCE._serialized_start=65
  _GAMESERVICESGAMESERVERCLUSTERXCONNECTIONINFOXGKECLUSTERREFERENCE._serialized_end=148
  _GAMESERVICESGAMESERVERCLUSTERXCONNECTIONINFO._serialized_start=151
  _GAMESERVICESGAMESERVERCLUSTERXCONNECTIONINFO._serialized_end=335
  _GAMESERVICESGAMESERVERCLUSTERXTIMEOUTS._serialized_start=337
  _GAMESERVICESGAMESERVERCLUSTERXTIMEOUTS._serialized_end=425
  _GAMESERVICESGAMESERVERCLUSTER._serialized_start=428
  _GAMESERVICESGAMESERVERCLUSTER._serialized_end=937
  _GAMESERVICESGAMESERVERCLUSTER_LABELSENTRY._serialized_start=892
  _GAMESERVICESGAMESERVERCLUSTER_LABELSENTRY._serialized_end=937
  _GAMESERVICESGAMESERVERCONFIGXFLEETCONFIGS._serialized_start=939
  _GAMESERVICESGAMESERVERCONFIGXFLEETCONFIGS._serialized_end=1016
  _GAMESERVICESGAMESERVERCONFIGXSCALINGCONFIGSXSCHEDULES._serialized_start=1019
  _GAMESERVICESGAMESERVERCONFIGXSCALINGCONFIGSXSCHEDULES._serialized_end=1158
  _GAMESERVICESGAMESERVERCONFIGXSCALINGCONFIGSXSELECTORS._serialized_start=1161
  _GAMESERVICESGAMESERVERCONFIGXSCALINGCONFIGSXSELECTORS._serialized_end=1368
  _GAMESERVICESGAMESERVERCONFIGXSCALINGCONFIGSXSELECTORS_LABELSENTRY._serialized_start=892
  _GAMESERVICESGAMESERVERCONFIGXSCALINGCONFIGSXSELECTORS_LABELSENTRY._serialized_end=937
  _GAMESERVICESGAMESERVERCONFIGXSCALINGCONFIGS._serialized_start=1371
  _GAMESERVICESGAMESERVERCONFIGXSCALINGCONFIGS._serialized_end=1653
  _GAMESERVICESGAMESERVERCONFIGXTIMEOUTS._serialized_start=1655
  _GAMESERVICESGAMESERVERCONFIGXTIMEOUTS._serialized_end=1726
  _GAMESERVICESGAMESERVERCONFIG._serialized_start=1729
  _GAMESERVICESGAMESERVERCONFIG._serialized_end=2326
  _GAMESERVICESGAMESERVERCONFIG_LABELSENTRY._serialized_start=892
  _GAMESERVICESGAMESERVERCONFIG_LABELSENTRY._serialized_end=937
  _GAMESERVICESGAMESERVERDEPLOYMENTXTIMEOUTS._serialized_start=2328
  _GAMESERVICESGAMESERVERDEPLOYMENTXTIMEOUTS._serialized_end=2419
  _GAMESERVICESGAMESERVERDEPLOYMENT._serialized_start=2422
  _GAMESERVICESGAMESERVERDEPLOYMENT._serialized_end=2832
  _GAMESERVICESGAMESERVERDEPLOYMENT_LABELSENTRY._serialized_start=892
  _GAMESERVICESGAMESERVERDEPLOYMENT_LABELSENTRY._serialized_end=937
  _GAMESERVICESGAMESERVERDEPLOYMENTROLLOUTXGAMESERVERCONFIGOVERRIDESXREALMSSELECTOR._serialized_start=2834
  _GAMESERVICESGAMESERVERDEPLOYMENTROLLOUTXGAMESERVERCONFIGOVERRIDESXREALMSSELECTOR._serialized_end=2932
  _GAMESERVICESGAMESERVERDEPLOYMENTROLLOUTXGAMESERVERCONFIGOVERRIDES._serialized_start=2935
  _GAMESERVICESGAMESERVERDEPLOYMENTROLLOUTXGAMESERVERCONFIGOVERRIDES._serialized_end=3155
  _GAMESERVICESGAMESERVERDEPLOYMENTROLLOUTXTIMEOUTS._serialized_start=3157
  _GAMESERVICESGAMESERVERDEPLOYMENTROLLOUTXTIMEOUTS._serialized_end=3255
  _GAMESERVICESGAMESERVERDEPLOYMENTROLLOUT._serialized_start=3258
  _GAMESERVICESGAMESERVERDEPLOYMENTROLLOUT._serialized_end=3675
  _GAMESERVICESREALMXTIMEOUTS._serialized_start=3677
  _GAMESERVICESREALMXTIMEOUTS._serialized_end=3753
  _GAMESERVICESREALM._serialized_start=3756
  _GAMESERVICESREALM._serialized_end=4149
  _GAMESERVICESREALM_LABELSENTRY._serialized_start=892
  _GAMESERVICESREALM_LABELSENTRY._serialized_end=937
# @@protoc_insertion_point(module_scope)
