"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Config(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class ConfigDataEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    CONFIG_DATA_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def config_data(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        config_data: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["config_data", b"config_data", "name", b"name", "resource_info", b"resource_info", "tags", b"tags"]) -> None: ...

global___Config = Config

@typing_extensions.final
class GroundStation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONFIG_FIELD_NUMBER: builtins.int
    DATAFLOW_ENDPOINT_GROUP_FIELD_NUMBER: builtins.int
    MISSION_PROFILE_FIELD_NUMBER: builtins.int
    @property
    def config(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Config]: ...
    @property
    def dataflow_endpoint_group(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DataflowEndpointGroup]: ...
    @property
    def mission_profile(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MissionProfile]: ...
    def __init__(
        self,
        *,
        config: collections.abc.Iterable[global___Config] | None = ...,
        dataflow_endpoint_group: collections.abc.Iterable[global___DataflowEndpointGroup] | None = ...,
        mission_profile: collections.abc.Iterable[global___MissionProfile] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["config", b"config", "dataflow_endpoint_group", b"dataflow_endpoint_group", "mission_profile", b"mission_profile"]) -> None: ...

global___GroundStation = GroundStation

@typing_extensions.final
class DataflowEndpointGroupSecurityDetails(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    SUBNET_IDS_FIELD_NUMBER: builtins.int
    SECURITY_GROUP_IDS_FIELD_NUMBER: builtins.int
    ROLE_ARN_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def subnet_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def security_group_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    role_arn: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        subnet_ids: collections.abc.Iterable[builtins.str] | None = ...,
        security_group_ids: collections.abc.Iterable[builtins.str] | None = ...,
        role_arn: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "role_arn", b"role_arn", "security_group_ids", b"security_group_ids", "subnet_ids", b"subnet_ids"]) -> None: ...

global___DataflowEndpointGroupSecurityDetails = DataflowEndpointGroupSecurityDetails

@typing_extensions.final
class DataflowEndpointGroupSocketAddress(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PORT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    port: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        port: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "port", b"port", "resource_info", b"resource_info"]) -> None: ...

global___DataflowEndpointGroupSocketAddress = DataflowEndpointGroupSocketAddress

@typing_extensions.final
class DataflowEndpointGroupDataflowEndpoint(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ADDRESS_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    MTU_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def address(self) -> global___DataflowEndpointGroupSocketAddress: ...
    status: builtins.str
    mtu: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        address: global___DataflowEndpointGroupSocketAddress | None = ...,
        status: builtins.str = ...,
        mtu: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["address", b"address", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["address", b"address", "mtu", b"mtu", "name", b"name", "resource_info", b"resource_info", "status", b"status"]) -> None: ...

global___DataflowEndpointGroupDataflowEndpoint = DataflowEndpointGroupDataflowEndpoint

@typing_extensions.final
class DataflowEndpointGroupEndpointDetails(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    SECURITY_DETAILS_FIELD_NUMBER: builtins.int
    ENDPOINT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def security_details(self) -> global___DataflowEndpointGroupSecurityDetails: ...
    @property
    def endpoint(self) -> global___DataflowEndpointGroupDataflowEndpoint: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        security_details: global___DataflowEndpointGroupSecurityDetails | None = ...,
        endpoint: global___DataflowEndpointGroupDataflowEndpoint | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["endpoint", b"endpoint", "resource_info", b"resource_info", "security_details", b"security_details"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["endpoint", b"endpoint", "resource_info", b"resource_info", "security_details", b"security_details"]) -> None: ...

global___DataflowEndpointGroupEndpointDetails = DataflowEndpointGroupEndpointDetails

@typing_extensions.final
class DataflowEndpointGroup(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ENDPOINT_DETAILS_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def endpoint_details(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DataflowEndpointGroupEndpointDetails]: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        endpoint_details: collections.abc.Iterable[global___DataflowEndpointGroupEndpointDetails] | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["endpoint_details", b"endpoint_details", "resource_info", b"resource_info", "tags", b"tags"]) -> None: ...

global___DataflowEndpointGroup = DataflowEndpointGroup

@typing_extensions.final
class MissionProfileDataflowEdge(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    DESTINATION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    source: builtins.str
    destination: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        source: builtins.str = ...,
        destination: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["destination", b"destination", "resource_info", b"resource_info", "source", b"source"]) -> None: ...

global___MissionProfileDataflowEdge = MissionProfileDataflowEdge

@typing_extensions.final
class MissionProfile(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    CONTACT_PRE_PASS_DURATION_SECONDS_FIELD_NUMBER: builtins.int
    CONTACT_POST_PASS_DURATION_SECONDS_FIELD_NUMBER: builtins.int
    MINIMUM_VIABLE_CONTACT_DURATION_SECONDS_FIELD_NUMBER: builtins.int
    DATAFLOW_EDGES_FIELD_NUMBER: builtins.int
    TRACKING_CONFIG_ARN_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    contact_pre_pass_duration_seconds: builtins.int
    contact_post_pass_duration_seconds: builtins.int
    minimum_viable_contact_duration_seconds: builtins.int
    @property
    def dataflow_edges(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MissionProfileDataflowEdge]: ...
    tracking_config_arn: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        contact_pre_pass_duration_seconds: builtins.int = ...,
        contact_post_pass_duration_seconds: builtins.int = ...,
        minimum_viable_contact_duration_seconds: builtins.int = ...,
        dataflow_edges: collections.abc.Iterable[global___MissionProfileDataflowEdge] | None = ...,
        tracking_config_arn: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["contact_post_pass_duration_seconds", b"contact_post_pass_duration_seconds", "contact_pre_pass_duration_seconds", b"contact_pre_pass_duration_seconds", "dataflow_edges", b"dataflow_edges", "minimum_viable_contact_duration_seconds", b"minimum_viable_contact_duration_seconds", "name", b"name", "resource_info", b"resource_info", "tags", b"tags", "tracking_config_arn", b"tracking_config_arn"]) -> None: ...

global___MissionProfile = MissionProfile
