"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ApiBodyS3Location(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    BUCKET_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    etag: builtins.str
    bucket: builtins.str
    version: builtins.str
    key: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        etag: builtins.str = ...,
        bucket: builtins.str = ...,
        version: builtins.str = ...,
        key: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bucket", b"bucket", "etag", b"etag", "key", b"key", "resource_info", b"resource_info", "version", b"version"]) -> None: ...

global___ApiBodyS3Location = ApiBodyS3Location

@typing_extensions.final
class ApiCors(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ALLOW_ORIGINS_FIELD_NUMBER: builtins.int
    ALLOW_CREDENTIALS_FIELD_NUMBER: builtins.int
    EXPOSE_HEADERS_FIELD_NUMBER: builtins.int
    ALLOW_HEADERS_FIELD_NUMBER: builtins.int
    MAX_AGE_FIELD_NUMBER: builtins.int
    ALLOW_METHODS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def allow_origins(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    allow_credentials: builtins.bool
    @property
    def expose_headers(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def allow_headers(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    max_age: builtins.int
    @property
    def allow_methods(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        allow_origins: collections.abc.Iterable[builtins.str] | None = ...,
        allow_credentials: builtins.bool = ...,
        expose_headers: collections.abc.Iterable[builtins.str] | None = ...,
        allow_headers: collections.abc.Iterable[builtins.str] | None = ...,
        max_age: builtins.int = ...,
        allow_methods: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["allow_credentials", b"allow_credentials", "allow_headers", b"allow_headers", "allow_methods", b"allow_methods", "allow_origins", b"allow_origins", "expose_headers", b"expose_headers", "max_age", b"max_age", "resource_info", b"resource_info"]) -> None: ...

global___ApiCors = ApiCors

@typing_extensions.final
class Api(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class BodyEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ROUTE_SELECTION_EXPRESSION_FIELD_NUMBER: builtins.int
    BODY_S3_LOCATION_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    BASE_PATH_FIELD_NUMBER: builtins.int
    FAIL_ON_WARNINGS_FIELD_NUMBER: builtins.int
    DISABLE_EXECUTE_API_ENDPOINT_FIELD_NUMBER: builtins.int
    DISABLE_SCHEMA_VALIDATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    TARGET_FIELD_NUMBER: builtins.int
    CREDENTIALS_ARN_FIELD_NUMBER: builtins.int
    CORS_CONFIGURATION_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    PROTOCOL_TYPE_FIELD_NUMBER: builtins.int
    ROUTE_KEY_FIELD_NUMBER: builtins.int
    BODY_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    API_KEY_SELECTION_EXPRESSION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    route_selection_expression: builtins.str
    @property
    def body_s3_location(self) -> global___ApiBodyS3Location: ...
    description: builtins.str
    base_path: builtins.str
    fail_on_warnings: builtins.bool
    disable_execute_api_endpoint: builtins.bool
    disable_schema_validation: builtins.bool
    name: builtins.str
    target: builtins.str
    credentials_arn: builtins.str
    @property
    def cors_configuration(self) -> global___ApiCors: ...
    version: builtins.str
    protocol_type: builtins.str
    route_key: builtins.str
    @property
    def body(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    api_key_selection_expression: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        route_selection_expression: builtins.str = ...,
        body_s3_location: global___ApiBodyS3Location | None = ...,
        description: builtins.str = ...,
        base_path: builtins.str = ...,
        fail_on_warnings: builtins.bool = ...,
        disable_execute_api_endpoint: builtins.bool = ...,
        disable_schema_validation: builtins.bool = ...,
        name: builtins.str = ...,
        target: builtins.str = ...,
        credentials_arn: builtins.str = ...,
        cors_configuration: global___ApiCors | None = ...,
        version: builtins.str = ...,
        protocol_type: builtins.str = ...,
        route_key: builtins.str = ...,
        body: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        api_key_selection_expression: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["body_s3_location", b"body_s3_location", "cors_configuration", b"cors_configuration", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_key_selection_expression", b"api_key_selection_expression", "base_path", b"base_path", "body", b"body", "body_s3_location", b"body_s3_location", "cors_configuration", b"cors_configuration", "credentials_arn", b"credentials_arn", "description", b"description", "disable_execute_api_endpoint", b"disable_execute_api_endpoint", "disable_schema_validation", b"disable_schema_validation", "fail_on_warnings", b"fail_on_warnings", "name", b"name", "protocol_type", b"protocol_type", "resource_info", b"resource_info", "route_key", b"route_key", "route_selection_expression", b"route_selection_expression", "tags", b"tags", "target", b"target", "version", b"version"]) -> None: ...

global___Api = Api

@typing_extensions.final
class ApiGatewayV2(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_FIELD_NUMBER: builtins.int
    API_MAPPING_FIELD_NUMBER: builtins.int
    AUTHORIZER_FIELD_NUMBER: builtins.int
    DEPLOYMENT_FIELD_NUMBER: builtins.int
    DOMAIN_NAME_FIELD_NUMBER: builtins.int
    INTEGRATION_FIELD_NUMBER: builtins.int
    INTEGRATION_RESPONSE_FIELD_NUMBER: builtins.int
    MODEL_FIELD_NUMBER: builtins.int
    ROUTE_FIELD_NUMBER: builtins.int
    ROUTE_RESPONSE_FIELD_NUMBER: builtins.int
    STAGE_FIELD_NUMBER: builtins.int
    @property
    def api(self) -> global___Api: ...
    @property
    def api_mapping(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApiMapping]: ...
    @property
    def authorizer(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Authorizer]: ...
    @property
    def deployment(self) -> global___Deployment: ...
    @property
    def domain_name(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DomainName]: ...
    @property
    def integration(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Integration]: ...
    @property
    def integration_response(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___IntegrationResponse]: ...
    @property
    def model(self) -> global___Model: ...
    @property
    def route(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Route]: ...
    @property
    def route_response(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RouteResponse]: ...
    @property
    def stage(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Stage]: ...
    def __init__(
        self,
        *,
        api: global___Api | None = ...,
        api_mapping: collections.abc.Iterable[global___ApiMapping] | None = ...,
        authorizer: collections.abc.Iterable[global___Authorizer] | None = ...,
        deployment: global___Deployment | None = ...,
        domain_name: collections.abc.Iterable[global___DomainName] | None = ...,
        integration: collections.abc.Iterable[global___Integration] | None = ...,
        integration_response: collections.abc.Iterable[global___IntegrationResponse] | None = ...,
        model: global___Model | None = ...,
        route: collections.abc.Iterable[global___Route] | None = ...,
        route_response: collections.abc.Iterable[global___RouteResponse] | None = ...,
        stage: collections.abc.Iterable[global___Stage] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["api", b"api", "deployment", b"deployment", "model", b"model"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api", b"api", "api_mapping", b"api_mapping", "authorizer", b"authorizer", "deployment", b"deployment", "domain_name", b"domain_name", "integration", b"integration", "integration_response", b"integration_response", "model", b"model", "route", b"route", "route_response", b"route_response", "stage", b"stage"]) -> None: ...

global___ApiGatewayV2 = ApiGatewayV2

@typing_extensions.final
class ApiMapping(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DOMAIN_NAME_FIELD_NUMBER: builtins.int
    STAGE_FIELD_NUMBER: builtins.int
    API_MAPPING_KEY_FIELD_NUMBER: builtins.int
    API_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    domain_name: builtins.str
    stage: builtins.str
    api_mapping_key: builtins.str
    api_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        domain_name: builtins.str = ...,
        stage: builtins.str = ...,
        api_mapping_key: builtins.str = ...,
        api_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_id", b"api_id", "api_mapping_key", b"api_mapping_key", "domain_name", b"domain_name", "resource_info", b"resource_info", "stage", b"stage"]) -> None: ...

global___ApiMapping = ApiMapping

@typing_extensions.final
class AuthorizerJWTConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ISSUER_FIELD_NUMBER: builtins.int
    AUDIENCE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    issuer: builtins.str
    @property
    def audience(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        issuer: builtins.str = ...,
        audience: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["audience", b"audience", "issuer", b"issuer", "resource_info", b"resource_info"]) -> None: ...

global___AuthorizerJWTConfiguration = AuthorizerJWTConfiguration

@typing_extensions.final
class Authorizer(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    IDENTITY_VALIDATION_EXPRESSION_FIELD_NUMBER: builtins.int
    AUTHORIZER_URI_FIELD_NUMBER: builtins.int
    AUTHORIZER_CREDENTIALS_ARN_FIELD_NUMBER: builtins.int
    AUTHORIZER_TYPE_FIELD_NUMBER: builtins.int
    JWT_CONFIGURATION_FIELD_NUMBER: builtins.int
    AUTHORIZER_RESULT_TTL_IN_SECONDS_FIELD_NUMBER: builtins.int
    IDENTITY_SOURCE_FIELD_NUMBER: builtins.int
    AUTHORIZER_PAYLOAD_FORMAT_VERSION_FIELD_NUMBER: builtins.int
    ENABLE_SIMPLE_RESPONSES_FIELD_NUMBER: builtins.int
    API_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    identity_validation_expression: builtins.str
    authorizer_uri: builtins.str
    authorizer_credentials_arn: builtins.str
    authorizer_type: builtins.str
    @property
    def jwt_configuration(self) -> global___AuthorizerJWTConfiguration: ...
    authorizer_result_ttl_in_seconds: builtins.int
    @property
    def identity_source(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    authorizer_payload_format_version: builtins.str
    enable_simple_responses: builtins.bool
    api_id: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        identity_validation_expression: builtins.str = ...,
        authorizer_uri: builtins.str = ...,
        authorizer_credentials_arn: builtins.str = ...,
        authorizer_type: builtins.str = ...,
        jwt_configuration: global___AuthorizerJWTConfiguration | None = ...,
        authorizer_result_ttl_in_seconds: builtins.int = ...,
        identity_source: collections.abc.Iterable[builtins.str] | None = ...,
        authorizer_payload_format_version: builtins.str = ...,
        enable_simple_responses: builtins.bool = ...,
        api_id: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["jwt_configuration", b"jwt_configuration", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_id", b"api_id", "authorizer_credentials_arn", b"authorizer_credentials_arn", "authorizer_payload_format_version", b"authorizer_payload_format_version", "authorizer_result_ttl_in_seconds", b"authorizer_result_ttl_in_seconds", "authorizer_type", b"authorizer_type", "authorizer_uri", b"authorizer_uri", "enable_simple_responses", b"enable_simple_responses", "identity_source", b"identity_source", "identity_validation_expression", b"identity_validation_expression", "jwt_configuration", b"jwt_configuration", "name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___Authorizer = Authorizer

@typing_extensions.final
class Deployment(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    STAGE_NAME_FIELD_NUMBER: builtins.int
    API_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    description: builtins.str
    stage_name: builtins.str
    api_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        description: builtins.str = ...,
        stage_name: builtins.str = ...,
        api_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_id", b"api_id", "description", b"description", "resource_info", b"resource_info", "stage_name", b"stage_name"]) -> None: ...

global___Deployment = Deployment

@typing_extensions.final
class DomainNameMutualTlsAuthentication(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    TRUSTSTORE_VERSION_FIELD_NUMBER: builtins.int
    TRUSTSTORE_URI_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    truststore_version: builtins.str
    truststore_uri: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        truststore_version: builtins.str = ...,
        truststore_uri: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "truststore_uri", b"truststore_uri", "truststore_version", b"truststore_version"]) -> None: ...

global___DomainNameMutualTlsAuthentication = DomainNameMutualTlsAuthentication

@typing_extensions.final
class DomainNameDomainNameConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    SECURITY_POLICY_FIELD_NUMBER: builtins.int
    ENDPOINT_TYPE_FIELD_NUMBER: builtins.int
    CERTIFICATE_NAME_FIELD_NUMBER: builtins.int
    CERTIFICATE_ARN_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    security_policy: builtins.str
    endpoint_type: builtins.str
    certificate_name: builtins.str
    certificate_arn: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        security_policy: builtins.str = ...,
        endpoint_type: builtins.str = ...,
        certificate_name: builtins.str = ...,
        certificate_arn: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["certificate_arn", b"certificate_arn", "certificate_name", b"certificate_name", "endpoint_type", b"endpoint_type", "resource_info", b"resource_info", "security_policy", b"security_policy"]) -> None: ...

global___DomainNameDomainNameConfiguration = DomainNameDomainNameConfiguration

@typing_extensions.final
class DomainName(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    MUTUAL_TLS_AUTHENTICATION_FIELD_NUMBER: builtins.int
    DOMAIN_NAME_FIELD_NUMBER: builtins.int
    DOMAIN_NAME_CONFIGURATIONS_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def mutual_tls_authentication(self) -> global___DomainNameMutualTlsAuthentication: ...
    domain_name: builtins.str
    @property
    def domain_name_configurations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DomainNameDomainNameConfiguration]: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        mutual_tls_authentication: global___DomainNameMutualTlsAuthentication | None = ...,
        domain_name: builtins.str = ...,
        domain_name_configurations: collections.abc.Iterable[global___DomainNameDomainNameConfiguration] | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["mutual_tls_authentication", b"mutual_tls_authentication", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["domain_name", b"domain_name", "domain_name_configurations", b"domain_name_configurations", "mutual_tls_authentication", b"mutual_tls_authentication", "resource_info", b"resource_info", "tags", b"tags"]) -> None: ...

global___DomainName = DomainName

@typing_extensions.final
class IntegrationTlsConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    SERVER_NAME_TO_VERIFY_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    server_name_to_verify: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        server_name_to_verify: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "server_name_to_verify", b"server_name_to_verify"]) -> None: ...

global___IntegrationTlsConfig = IntegrationTlsConfig

@typing_extensions.final
class Integration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class RequestParametersEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class RequestTemplatesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    TEMPLATE_SELECTION_EXPRESSION_FIELD_NUMBER: builtins.int
    CONNECTION_TYPE_FIELD_NUMBER: builtins.int
    INTEGRATION_METHOD_FIELD_NUMBER: builtins.int
    PASSTHROUGH_BEHAVIOR_FIELD_NUMBER: builtins.int
    REQUEST_PARAMETERS_FIELD_NUMBER: builtins.int
    CONNECTION_ID_FIELD_NUMBER: builtins.int
    INTEGRATION_URI_FIELD_NUMBER: builtins.int
    PAYLOAD_FORMAT_VERSION_FIELD_NUMBER: builtins.int
    CREDENTIALS_ARN_FIELD_NUMBER: builtins.int
    REQUEST_TEMPLATES_FIELD_NUMBER: builtins.int
    TIMEOUT_IN_MILLIS_FIELD_NUMBER: builtins.int
    TLS_CONFIG_FIELD_NUMBER: builtins.int
    CONTENT_HANDLING_STRATEGY_FIELD_NUMBER: builtins.int
    INTEGRATION_SUBTYPE_FIELD_NUMBER: builtins.int
    API_ID_FIELD_NUMBER: builtins.int
    INTEGRATION_TYPE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    description: builtins.str
    template_selection_expression: builtins.str
    connection_type: builtins.str
    integration_method: builtins.str
    passthrough_behavior: builtins.str
    @property
    def request_parameters(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    connection_id: builtins.str
    integration_uri: builtins.str
    payload_format_version: builtins.str
    credentials_arn: builtins.str
    @property
    def request_templates(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    timeout_in_millis: builtins.int
    @property
    def tls_config(self) -> global___IntegrationTlsConfig: ...
    content_handling_strategy: builtins.str
    integration_subtype: builtins.str
    api_id: builtins.str
    integration_type: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        description: builtins.str = ...,
        template_selection_expression: builtins.str = ...,
        connection_type: builtins.str = ...,
        integration_method: builtins.str = ...,
        passthrough_behavior: builtins.str = ...,
        request_parameters: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        connection_id: builtins.str = ...,
        integration_uri: builtins.str = ...,
        payload_format_version: builtins.str = ...,
        credentials_arn: builtins.str = ...,
        request_templates: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        timeout_in_millis: builtins.int = ...,
        tls_config: global___IntegrationTlsConfig | None = ...,
        content_handling_strategy: builtins.str = ...,
        integration_subtype: builtins.str = ...,
        api_id: builtins.str = ...,
        integration_type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "tls_config", b"tls_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_id", b"api_id", "connection_id", b"connection_id", "connection_type", b"connection_type", "content_handling_strategy", b"content_handling_strategy", "credentials_arn", b"credentials_arn", "description", b"description", "integration_method", b"integration_method", "integration_subtype", b"integration_subtype", "integration_type", b"integration_type", "integration_uri", b"integration_uri", "passthrough_behavior", b"passthrough_behavior", "payload_format_version", b"payload_format_version", "request_parameters", b"request_parameters", "request_templates", b"request_templates", "resource_info", b"resource_info", "template_selection_expression", b"template_selection_expression", "timeout_in_millis", b"timeout_in_millis", "tls_config", b"tls_config"]) -> None: ...

global___Integration = Integration

@typing_extensions.final
class IntegrationResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class ResponseTemplatesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class ResponseParametersEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    RESPONSE_TEMPLATES_FIELD_NUMBER: builtins.int
    TEMPLATE_SELECTION_EXPRESSION_FIELD_NUMBER: builtins.int
    RESPONSE_PARAMETERS_FIELD_NUMBER: builtins.int
    CONTENT_HANDLING_STRATEGY_FIELD_NUMBER: builtins.int
    INTEGRATION_ID_FIELD_NUMBER: builtins.int
    INTEGRATION_RESPONSE_KEY_FIELD_NUMBER: builtins.int
    API_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def response_templates(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    template_selection_expression: builtins.str
    @property
    def response_parameters(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    content_handling_strategy: builtins.str
    integration_id: builtins.str
    integration_response_key: builtins.str
    api_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        response_templates: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        template_selection_expression: builtins.str = ...,
        response_parameters: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        content_handling_strategy: builtins.str = ...,
        integration_id: builtins.str = ...,
        integration_response_key: builtins.str = ...,
        api_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_id", b"api_id", "content_handling_strategy", b"content_handling_strategy", "integration_id", b"integration_id", "integration_response_key", b"integration_response_key", "resource_info", b"resource_info", "response_parameters", b"response_parameters", "response_templates", b"response_templates", "template_selection_expression", b"template_selection_expression"]) -> None: ...

global___IntegrationResponse = IntegrationResponse

@typing_extensions.final
class Model(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class SchemaEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    CONTENT_TYPE_FIELD_NUMBER: builtins.int
    SCHEMA_FIELD_NUMBER: builtins.int
    API_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    description: builtins.str
    content_type: builtins.str
    @property
    def schema(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    api_id: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        description: builtins.str = ...,
        content_type: builtins.str = ...,
        schema: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        api_id: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_id", b"api_id", "content_type", b"content_type", "description", b"description", "name", b"name", "resource_info", b"resource_info", "schema", b"schema"]) -> None: ...

global___Model = Model

@typing_extensions.final
class Route(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class RequestModelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class RequestParametersEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    TARGET_FIELD_NUMBER: builtins.int
    ROUTE_RESPONSE_SELECTION_EXPRESSION_FIELD_NUMBER: builtins.int
    AUTHORIZER_ID_FIELD_NUMBER: builtins.int
    REQUEST_MODELS_FIELD_NUMBER: builtins.int
    OPERATION_NAME_FIELD_NUMBER: builtins.int
    AUTHORIZATION_SCOPES_FIELD_NUMBER: builtins.int
    API_KEY_REQUIRED_FIELD_NUMBER: builtins.int
    ROUTE_KEY_FIELD_NUMBER: builtins.int
    AUTHORIZATION_TYPE_FIELD_NUMBER: builtins.int
    MODEL_SELECTION_EXPRESSION_FIELD_NUMBER: builtins.int
    API_ID_FIELD_NUMBER: builtins.int
    REQUEST_PARAMETERS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    target: builtins.str
    route_response_selection_expression: builtins.str
    authorizer_id: builtins.str
    @property
    def request_models(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    operation_name: builtins.str
    @property
    def authorization_scopes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    api_key_required: builtins.bool
    route_key: builtins.str
    authorization_type: builtins.str
    model_selection_expression: builtins.str
    api_id: builtins.str
    @property
    def request_parameters(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        target: builtins.str = ...,
        route_response_selection_expression: builtins.str = ...,
        authorizer_id: builtins.str = ...,
        request_models: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        operation_name: builtins.str = ...,
        authorization_scopes: collections.abc.Iterable[builtins.str] | None = ...,
        api_key_required: builtins.bool = ...,
        route_key: builtins.str = ...,
        authorization_type: builtins.str = ...,
        model_selection_expression: builtins.str = ...,
        api_id: builtins.str = ...,
        request_parameters: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_id", b"api_id", "api_key_required", b"api_key_required", "authorization_scopes", b"authorization_scopes", "authorization_type", b"authorization_type", "authorizer_id", b"authorizer_id", "model_selection_expression", b"model_selection_expression", "operation_name", b"operation_name", "request_models", b"request_models", "request_parameters", b"request_parameters", "resource_info", b"resource_info", "route_key", b"route_key", "route_response_selection_expression", b"route_response_selection_expression", "target", b"target"]) -> None: ...

global___Route = Route

@typing_extensions.final
class RouteResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class ResponseParametersEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class ResponseModelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ROUTE_RESPONSE_KEY_FIELD_NUMBER: builtins.int
    RESPONSE_PARAMETERS_FIELD_NUMBER: builtins.int
    ROUTE_ID_FIELD_NUMBER: builtins.int
    MODEL_SELECTION_EXPRESSION_FIELD_NUMBER: builtins.int
    API_ID_FIELD_NUMBER: builtins.int
    RESPONSE_MODELS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    route_response_key: builtins.str
    @property
    def response_parameters(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    route_id: builtins.str
    model_selection_expression: builtins.str
    api_id: builtins.str
    @property
    def response_models(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        route_response_key: builtins.str = ...,
        response_parameters: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        route_id: builtins.str = ...,
        model_selection_expression: builtins.str = ...,
        api_id: builtins.str = ...,
        response_models: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_id", b"api_id", "model_selection_expression", b"model_selection_expression", "resource_info", b"resource_info", "response_models", b"response_models", "response_parameters", b"response_parameters", "route_id", b"route_id", "route_response_key", b"route_response_key"]) -> None: ...

global___RouteResponse = RouteResponse

@typing_extensions.final
class StageAccessLogSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    FORMAT_FIELD_NUMBER: builtins.int
    DESTINATION_ARN_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    format: builtins.str
    destination_arn: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        format: builtins.str = ...,
        destination_arn: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["destination_arn", b"destination_arn", "format", b"format", "resource_info", b"resource_info"]) -> None: ...

global___StageAccessLogSettings = StageAccessLogSettings

@typing_extensions.final
class StageRouteSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    LOGGING_LEVEL_FIELD_NUMBER: builtins.int
    DATA_TRACE_ENABLED_FIELD_NUMBER: builtins.int
    THROTTLING_BURST_LIMIT_FIELD_NUMBER: builtins.int
    DETAILED_METRICS_ENABLED_FIELD_NUMBER: builtins.int
    THROTTLING_RATE_LIMIT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    logging_level: builtins.str
    data_trace_enabled: builtins.bool
    throttling_burst_limit: builtins.int
    detailed_metrics_enabled: builtins.bool
    throttling_rate_limit: builtins.float
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        logging_level: builtins.str = ...,
        data_trace_enabled: builtins.bool = ...,
        throttling_burst_limit: builtins.int = ...,
        detailed_metrics_enabled: builtins.bool = ...,
        throttling_rate_limit: builtins.float = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["data_trace_enabled", b"data_trace_enabled", "detailed_metrics_enabled", b"detailed_metrics_enabled", "logging_level", b"logging_level", "resource_info", b"resource_info", "throttling_burst_limit", b"throttling_burst_limit", "throttling_rate_limit", b"throttling_rate_limit"]) -> None: ...

global___StageRouteSettings = StageRouteSettings

@typing_extensions.final
class Stage(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class RouteSettingsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class StageVariablesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CLIENT_CERTIFICATE_ID_FIELD_NUMBER: builtins.int
    DEPLOYMENT_ID_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ACCESS_LOG_SETTINGS_FIELD_NUMBER: builtins.int
    AUTO_DEPLOY_FIELD_NUMBER: builtins.int
    ROUTE_SETTINGS_FIELD_NUMBER: builtins.int
    STAGE_NAME_FIELD_NUMBER: builtins.int
    STAGE_VARIABLES_FIELD_NUMBER: builtins.int
    API_ID_FIELD_NUMBER: builtins.int
    DEFAULT_ROUTE_SETTINGS_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    client_certificate_id: builtins.str
    deployment_id: builtins.str
    description: builtins.str
    @property
    def access_log_settings(self) -> global___StageAccessLogSettings: ...
    auto_deploy: builtins.bool
    @property
    def route_settings(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    stage_name: builtins.str
    @property
    def stage_variables(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    api_id: builtins.str
    @property
    def default_route_settings(self) -> global___StageRouteSettings: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        client_certificate_id: builtins.str = ...,
        deployment_id: builtins.str = ...,
        description: builtins.str = ...,
        access_log_settings: global___StageAccessLogSettings | None = ...,
        auto_deploy: builtins.bool = ...,
        route_settings: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        stage_name: builtins.str = ...,
        stage_variables: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        api_id: builtins.str = ...,
        default_route_settings: global___StageRouteSettings | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["access_log_settings", b"access_log_settings", "default_route_settings", b"default_route_settings", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["access_log_settings", b"access_log_settings", "api_id", b"api_id", "auto_deploy", b"auto_deploy", "client_certificate_id", b"client_certificate_id", "default_route_settings", b"default_route_settings", "deployment_id", b"deployment_id", "description", b"description", "resource_info", b"resource_info", "route_settings", b"route_settings", "stage_name", b"stage_name", "stage_variables", b"stage_variables", "tags", b"tags"]) -> None: ...

global___Stage = Stage

@typing_extensions.final
class RouteParameterConstraints(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    REQUIRED_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    required: builtins.bool
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        required: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["required", b"required", "resource_info", b"resource_info"]) -> None: ...

global___RouteParameterConstraints = RouteParameterConstraints

@typing_extensions.final
class RouteResponseParameterConstraints(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    REQUIRED_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    required: builtins.bool
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        required: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["required", b"required", "resource_info", b"resource_info"]) -> None: ...

global___RouteResponseParameterConstraints = RouteResponseParameterConstraints
