# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_google_kms_bundle.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2
from oak9.tython.models.gcp import gcp_kms_pb2 as gcp_dot_gcp__kms__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fgcp/gcp_google_kms_bundle.proto\x12!oak9.tython.gcp.google_kms_bundle\x1a\x13shared/shared.proto\x1a\x11gcp/gcp_kms.proto\"\xe3\x05\n\tGoogleKms\x12\x39\n\x0ekms_crypto_key\x18\x01 \x03(\x0b\x32!.oak9.tython.gcp.kms.KmsCryptoKey\x12O\n\x1akms_crypto_key_iam_binding\x18\x02 \x03(\x0b\x32+.oak9.tython.gcp.kms.KmsCryptoKeyIamBinding\x12M\n\x19kms_crypto_key_iam_member\x18\x03 \x03(\x0b\x32*.oak9.tython.gcp.kms.KmsCryptoKeyIamMember\x12M\n\x19kms_crypto_key_iam_policy\x18\x04 \x03(\x0b\x32*.oak9.tython.gcp.kms.KmsCryptoKeyIamPolicy\x12\x35\n\x0ckms_key_ring\x18\x05 \x01(\x0b\x32\x1f.oak9.tython.gcp.kms.KmsKeyRing\x12K\n\x18kms_key_ring_iam_binding\x18\x06 \x03(\x0b\x32).oak9.tython.gcp.kms.KmsKeyRingIamBinding\x12I\n\x17kms_key_ring_iam_member\x18\x07 \x03(\x0b\x32(.oak9.tython.gcp.kms.KmsKeyRingIamMember\x12I\n\x17kms_key_ring_iam_policy\x18\x08 \x03(\x0b\x32(.oak9.tython.gcp.kms.KmsKeyRingIamPolicy\x12I\n\x17kms_key_ring_import_job\x18\t \x03(\x0b\x32(.oak9.tython.gcp.kms.KmsKeyRingImportJob\x12G\n\x15kms_secret_ciphertext\x18\n \x01(\x0b\x32(.oak9.tython.gcp.kms.KmsSecretCiphertextb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_google_kms_bundle_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GOOGLEKMS._serialized_start=111
  _GOOGLEKMS._serialized_end=850
# @@protoc_insertion_point(module_scope)
