# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_cloud9.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14\x61ws/aws_cloud9.proto\x12\x16oak9.tython.aws.cloud9\x1a\x13shared/shared.proto\"\x83\x01\n\x18\x45nvironmentEC2Repository\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0epath_component\x18\x02 \x01(\t\x12\x16\n\x0erepository_url\x18\x03 \x01(\t\"\x9c\x03\n\x0e\x45nvironmentEC2\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x46\n\x0crepositories\x18\x02 \x03(\x0b\x32\x30.oak9.tython.aws.cloud9.EnvironmentEC2Repository\x12\x11\n\towner_arn\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x17\n\x0f\x63onnection_type\x18\x05 \x01(\t\x12#\n\x1b\x61utomatic_stop_time_minutes\x18\x06 \x01(\x05\x12\x11\n\tsubnet_id\x18\x07 \x01(\t\x12\x15\n\rinstance_type\x18\x08 \x01(\t\x12>\n\x04tags\x18\t \x03(\x0b\x32\x30.oak9.tython.aws.cloud9.EnvironmentEC2.TagsEntry\x12\x0c\n\x04name\x18\n \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"J\n\x06\x43loud9\x12@\n\x10\x65nvironment_e_c2\x18\x01 \x03(\x0b\x32&.oak9.tython.aws.cloud9.EnvironmentEC2b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_cloud9_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ENVIRONMENTEC2_TAGSENTRY._options = None
  _ENVIRONMENTEC2_TAGSENTRY._serialized_options = b'8\001'
  _ENVIRONMENTEC2REPOSITORY._serialized_start=70
  _ENVIRONMENTEC2REPOSITORY._serialized_end=201
  _ENVIRONMENTEC2._serialized_start=204
  _ENVIRONMENTEC2._serialized_end=616
  _ENVIRONMENTEC2_TAGSENTRY._serialized_start=573
  _ENVIRONMENTEC2_TAGSENTRY._serialized_end=616
  _CLOUD9._serialized_start=618
  _CLOUD9._serialized_end=692
# @@protoc_insertion_point(module_scope)
