"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Destination(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DESTINATION_NAME_FIELD_NUMBER: builtins.int
    DESTINATION_POLICY_FIELD_NUMBER: builtins.int
    ROLE_ARN_FIELD_NUMBER: builtins.int
    TARGET_ARN_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    destination_name: builtins.str
    destination_policy: builtins.str
    role_arn: builtins.str
    target_arn: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        destination_name: builtins.str = ...,
        destination_policy: builtins.str = ...,
        role_arn: builtins.str = ...,
        target_arn: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["destination_name", b"destination_name", "destination_policy", b"destination_policy", "resource_info", b"resource_info", "role_arn", b"role_arn", "target_arn", b"target_arn"]) -> None: ...

global___Destination = Destination

@typing_extensions.final
class Logs(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESTINATION_FIELD_NUMBER: builtins.int
    LOG_GROUP_FIELD_NUMBER: builtins.int
    LOG_STREAM_FIELD_NUMBER: builtins.int
    METRIC_FILTER_FIELD_NUMBER: builtins.int
    SUBSCRIPTION_FILTER_FIELD_NUMBER: builtins.int
    @property
    def destination(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Destination]: ...
    @property
    def log_group(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___LogGroup]: ...
    @property
    def log_stream(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___LogStream]: ...
    @property
    def metric_filter(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MetricFilter]: ...
    @property
    def subscription_filter(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SubscriptionFilter]: ...
    def __init__(
        self,
        *,
        destination: collections.abc.Iterable[global___Destination] | None = ...,
        log_group: collections.abc.Iterable[global___LogGroup] | None = ...,
        log_stream: collections.abc.Iterable[global___LogStream] | None = ...,
        metric_filter: collections.abc.Iterable[global___MetricFilter] | None = ...,
        subscription_filter: collections.abc.Iterable[global___SubscriptionFilter] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["destination", b"destination", "log_group", b"log_group", "log_stream", b"log_stream", "metric_filter", b"metric_filter", "subscription_filter", b"subscription_filter"]) -> None: ...

global___Logs = Logs

@typing_extensions.final
class LogGroup(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    LOG_GROUP_NAME_FIELD_NUMBER: builtins.int
    RETENTION_IN_DAYS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    log_group_name: builtins.str
    retention_in_days: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        log_group_name: builtins.str = ...,
        retention_in_days: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["log_group_name", b"log_group_name", "resource_info", b"resource_info", "retention_in_days", b"retention_in_days"]) -> None: ...

global___LogGroup = LogGroup

@typing_extensions.final
class LogStream(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    LOG_GROUP_NAME_FIELD_NUMBER: builtins.int
    LOG_STREAM_NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    log_group_name: builtins.str
    log_stream_name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        log_group_name: builtins.str = ...,
        log_stream_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["log_group_name", b"log_group_name", "log_stream_name", b"log_stream_name", "resource_info", b"resource_info"]) -> None: ...

global___LogStream = LogStream

@typing_extensions.final
class MetricFilterMetricTransformation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DEFAULT_VALUE_FIELD_NUMBER: builtins.int
    METRIC_NAME_FIELD_NUMBER: builtins.int
    METRIC_NAMESPACE_FIELD_NUMBER: builtins.int
    METRIC_VALUE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    default_value: builtins.float
    metric_name: builtins.str
    metric_namespace: builtins.str
    metric_value: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        default_value: builtins.float = ...,
        metric_name: builtins.str = ...,
        metric_namespace: builtins.str = ...,
        metric_value: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["default_value", b"default_value", "metric_name", b"metric_name", "metric_namespace", b"metric_namespace", "metric_value", b"metric_value", "resource_info", b"resource_info"]) -> None: ...

global___MetricFilterMetricTransformation = MetricFilterMetricTransformation

@typing_extensions.final
class MetricFilter(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    FILTER_PATTERN_FIELD_NUMBER: builtins.int
    LOG_GROUP_NAME_FIELD_NUMBER: builtins.int
    METRIC_TRANSFORMATIONS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    filter_pattern: builtins.str
    log_group_name: builtins.str
    @property
    def metric_transformations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MetricFilterMetricTransformation]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        filter_pattern: builtins.str = ...,
        log_group_name: builtins.str = ...,
        metric_transformations: collections.abc.Iterable[global___MetricFilterMetricTransformation] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["filter_pattern", b"filter_pattern", "log_group_name", b"log_group_name", "metric_transformations", b"metric_transformations", "resource_info", b"resource_info"]) -> None: ...

global___MetricFilter = MetricFilter

@typing_extensions.final
class SubscriptionFilter(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DESTINATION_ARN_FIELD_NUMBER: builtins.int
    FILTER_PATTERN_FIELD_NUMBER: builtins.int
    LOG_GROUP_NAME_FIELD_NUMBER: builtins.int
    ROLE_ARN_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    destination_arn: builtins.str
    filter_pattern: builtins.str
    log_group_name: builtins.str
    role_arn: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        destination_arn: builtins.str = ...,
        filter_pattern: builtins.str = ...,
        log_group_name: builtins.str = ...,
        role_arn: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["destination_arn", b"destination_arn", "filter_pattern", b"filter_pattern", "log_group_name", b"log_group_name", "resource_info", b"resource_info", "role_arn", b"role_arn"]) -> None: ...

global___SubscriptionFilter = SubscriptionFilter
