"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import kubernetes.kubernetes_io.k8s.api.core.v1_pb2
import kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2
import kubernetes.kubernetes_io.k8s.apimachinery.pkg.runtime_pb2
import kubernetes.kubernetes_io.k8s.apimachinery.pkg.util.intstr_pb2
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ControllerRevision(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    REVISION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    @property
    def data(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.runtime_pb2.RawExtension: ...
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta: ...
    revision: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        data: kubernetes.kubernetes_io.k8s.apimachinery.pkg.runtime_pb2.RawExtension | None = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta | None = ...,
        revision: builtins.int = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["data", b"data", "metadata", b"metadata", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "data", b"data", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info", "revision", b"revision"]) -> None: ...

global___ControllerRevision = ControllerRevision

@typing_extensions.final
class ControllerRevisionList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ControllerRevision]: ...
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        items: collections.abc.Iterable[global___ControllerRevision] | None = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "items", b"items", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info"]) -> None: ...

global___ControllerRevisionList = ControllerRevisionList

@typing_extensions.final
class DaemonSet(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    SPEC_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta: ...
    @property
    def spec(self) -> global___DaemonSetSpec: ...
    @property
    def status(self) -> global___DaemonSetStatus: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta | None = ...,
        spec: global___DaemonSetSpec | None = ...,
        status: global___DaemonSetStatus | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info", "spec", b"spec", "status", b"status"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info", "spec", b"spec", "status", b"status"]) -> None: ...

global___DaemonSet = DaemonSet

@typing_extensions.final
class DaemonSetCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LAST_TRANSITION_TIME_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    REASON_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def last_transition_time(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.Time: ...
    message: builtins.str
    reason: builtins.str
    status: builtins.str
    type: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        last_transition_time: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.Time | None = ...,
        message: builtins.str = ...,
        reason: builtins.str = ...,
        status: builtins.str = ...,
        type: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["last_transition_time", b"last_transition_time", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["last_transition_time", b"last_transition_time", "message", b"message", "reason", b"reason", "resource_info", b"resource_info", "status", b"status", "type", b"type"]) -> None: ...

global___DaemonSetCondition = DaemonSetCondition

@typing_extensions.final
class DaemonSetList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DaemonSet]: ...
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        items: collections.abc.Iterable[global___DaemonSet] | None = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "items", b"items", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info"]) -> None: ...

global___DaemonSetList = DaemonSetList

@typing_extensions.final
class DaemonSetSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MIN_READY_SECONDS_FIELD_NUMBER: builtins.int
    REVISION_HISTORY_LIMIT_FIELD_NUMBER: builtins.int
    SELECTOR_FIELD_NUMBER: builtins.int
    TEMPLATE_FIELD_NUMBER: builtins.int
    UPDATE_STRATEGY_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    min_ready_seconds: builtins.int
    revision_history_limit: builtins.int
    @property
    def selector(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.LabelSelector: ...
    @property
    def template(self) -> kubernetes.kubernetes_io.k8s.api.core.v1_pb2.PodTemplateSpec: ...
    @property
    def update_strategy(self) -> global___DaemonSetUpdateStrategy: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        min_ready_seconds: builtins.int = ...,
        revision_history_limit: builtins.int = ...,
        selector: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.LabelSelector | None = ...,
        template: kubernetes.kubernetes_io.k8s.api.core.v1_pb2.PodTemplateSpec | None = ...,
        update_strategy: global___DaemonSetUpdateStrategy | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "selector", b"selector", "template", b"template", "update_strategy", b"update_strategy"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["min_ready_seconds", b"min_ready_seconds", "resource_info", b"resource_info", "revision_history_limit", b"revision_history_limit", "selector", b"selector", "template", b"template", "update_strategy", b"update_strategy"]) -> None: ...

global___DaemonSetSpec = DaemonSetSpec

@typing_extensions.final
class DaemonSetStatus(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COLLISION_COUNT_FIELD_NUMBER: builtins.int
    CONDITIONS_FIELD_NUMBER: builtins.int
    CURRENT_NUMBER_SCHEDULED_FIELD_NUMBER: builtins.int
    DESIRED_NUMBER_SCHEDULED_FIELD_NUMBER: builtins.int
    NUMBER_AVAILABLE_FIELD_NUMBER: builtins.int
    NUMBER_MISSCHEDULED_FIELD_NUMBER: builtins.int
    NUMBER_READY_FIELD_NUMBER: builtins.int
    NUMBER_UNAVAILABLE_FIELD_NUMBER: builtins.int
    OBSERVED_GENERATION_FIELD_NUMBER: builtins.int
    UPDATED_NUMBER_SCHEDULED_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    collision_count: builtins.int
    @property
    def conditions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DaemonSetCondition]: ...
    current_number_scheduled: builtins.int
    desired_number_scheduled: builtins.int
    number_available: builtins.int
    number_misscheduled: builtins.int
    number_ready: builtins.int
    number_unavailable: builtins.int
    observed_generation: builtins.int
    updated_number_scheduled: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        collision_count: builtins.int = ...,
        conditions: collections.abc.Iterable[global___DaemonSetCondition] | None = ...,
        current_number_scheduled: builtins.int = ...,
        desired_number_scheduled: builtins.int = ...,
        number_available: builtins.int = ...,
        number_misscheduled: builtins.int = ...,
        number_ready: builtins.int = ...,
        number_unavailable: builtins.int = ...,
        observed_generation: builtins.int = ...,
        updated_number_scheduled: builtins.int = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["collision_count", b"collision_count", "conditions", b"conditions", "current_number_scheduled", b"current_number_scheduled", "desired_number_scheduled", b"desired_number_scheduled", "number_available", b"number_available", "number_misscheduled", b"number_misscheduled", "number_ready", b"number_ready", "number_unavailable", b"number_unavailable", "observed_generation", b"observed_generation", "resource_info", b"resource_info", "updated_number_scheduled", b"updated_number_scheduled"]) -> None: ...

global___DaemonSetStatus = DaemonSetStatus

@typing_extensions.final
class DaemonSetUpdateStrategy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ROLLING_UPDATE_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def rolling_update(self) -> global___RollingUpdateDaemonSet: ...
    type: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        rolling_update: global___RollingUpdateDaemonSet | None = ...,
        type: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "rolling_update", b"rolling_update"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "rolling_update", b"rolling_update", "type", b"type"]) -> None: ...

global___DaemonSetUpdateStrategy = DaemonSetUpdateStrategy

@typing_extensions.final
class Deployment(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    SPEC_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta: ...
    @property
    def spec(self) -> global___DeploymentSpec: ...
    @property
    def status(self) -> global___DeploymentStatus: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta | None = ...,
        spec: global___DeploymentSpec | None = ...,
        status: global___DeploymentStatus | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info", "spec", b"spec", "status", b"status"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info", "spec", b"spec", "status", b"status"]) -> None: ...

global___Deployment = Deployment

@typing_extensions.final
class DeploymentCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LAST_TRANSITION_TIME_FIELD_NUMBER: builtins.int
    LAST_UPDATE_TIME_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    REASON_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def last_transition_time(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.Time: ...
    @property
    def last_update_time(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.Time: ...
    message: builtins.str
    reason: builtins.str
    status: builtins.str
    type: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        last_transition_time: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.Time | None = ...,
        last_update_time: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.Time | None = ...,
        message: builtins.str = ...,
        reason: builtins.str = ...,
        status: builtins.str = ...,
        type: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["last_transition_time", b"last_transition_time", "last_update_time", b"last_update_time", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["last_transition_time", b"last_transition_time", "last_update_time", b"last_update_time", "message", b"message", "reason", b"reason", "resource_info", b"resource_info", "status", b"status", "type", b"type"]) -> None: ...

global___DeploymentCondition = DeploymentCondition

@typing_extensions.final
class DeploymentList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Deployment]: ...
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        items: collections.abc.Iterable[global___Deployment] | None = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "items", b"items", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info"]) -> None: ...

global___DeploymentList = DeploymentList

@typing_extensions.final
class DeploymentSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MIN_READY_SECONDS_FIELD_NUMBER: builtins.int
    PAUSED_FIELD_NUMBER: builtins.int
    PROGRESS_DEADLINE_SECONDS_FIELD_NUMBER: builtins.int
    REPLICAS_FIELD_NUMBER: builtins.int
    REVISION_HISTORY_LIMIT_FIELD_NUMBER: builtins.int
    SELECTOR_FIELD_NUMBER: builtins.int
    STRATEGY_FIELD_NUMBER: builtins.int
    TEMPLATE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    min_ready_seconds: builtins.int
    paused: builtins.bool
    progress_deadline_seconds: builtins.int
    replicas: builtins.int
    revision_history_limit: builtins.int
    @property
    def selector(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.LabelSelector: ...
    @property
    def strategy(self) -> global___DeploymentStrategy: ...
    @property
    def template(self) -> kubernetes.kubernetes_io.k8s.api.core.v1_pb2.PodTemplateSpec: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        min_ready_seconds: builtins.int = ...,
        paused: builtins.bool = ...,
        progress_deadline_seconds: builtins.int = ...,
        replicas: builtins.int = ...,
        revision_history_limit: builtins.int = ...,
        selector: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.LabelSelector | None = ...,
        strategy: global___DeploymentStrategy | None = ...,
        template: kubernetes.kubernetes_io.k8s.api.core.v1_pb2.PodTemplateSpec | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "selector", b"selector", "strategy", b"strategy", "template", b"template"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["min_ready_seconds", b"min_ready_seconds", "paused", b"paused", "progress_deadline_seconds", b"progress_deadline_seconds", "replicas", b"replicas", "resource_info", b"resource_info", "revision_history_limit", b"revision_history_limit", "selector", b"selector", "strategy", b"strategy", "template", b"template"]) -> None: ...

global___DeploymentSpec = DeploymentSpec

@typing_extensions.final
class DeploymentStatus(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AVAILABLE_REPLICAS_FIELD_NUMBER: builtins.int
    COLLISION_COUNT_FIELD_NUMBER: builtins.int
    CONDITIONS_FIELD_NUMBER: builtins.int
    OBSERVED_GENERATION_FIELD_NUMBER: builtins.int
    READY_REPLICAS_FIELD_NUMBER: builtins.int
    REPLICAS_FIELD_NUMBER: builtins.int
    UNAVAILABLE_REPLICAS_FIELD_NUMBER: builtins.int
    UPDATED_REPLICAS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    available_replicas: builtins.int
    collision_count: builtins.int
    @property
    def conditions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DeploymentCondition]: ...
    observed_generation: builtins.int
    ready_replicas: builtins.int
    replicas: builtins.int
    unavailable_replicas: builtins.int
    updated_replicas: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        available_replicas: builtins.int = ...,
        collision_count: builtins.int = ...,
        conditions: collections.abc.Iterable[global___DeploymentCondition] | None = ...,
        observed_generation: builtins.int = ...,
        ready_replicas: builtins.int = ...,
        replicas: builtins.int = ...,
        unavailable_replicas: builtins.int = ...,
        updated_replicas: builtins.int = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["available_replicas", b"available_replicas", "collision_count", b"collision_count", "conditions", b"conditions", "observed_generation", b"observed_generation", "ready_replicas", b"ready_replicas", "replicas", b"replicas", "resource_info", b"resource_info", "unavailable_replicas", b"unavailable_replicas", "updated_replicas", b"updated_replicas"]) -> None: ...

global___DeploymentStatus = DeploymentStatus

@typing_extensions.final
class DeploymentStrategy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ROLLING_UPDATE_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def rolling_update(self) -> global___RollingUpdateDeployment: ...
    type: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        rolling_update: global___RollingUpdateDeployment | None = ...,
        type: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "rolling_update", b"rolling_update"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "rolling_update", b"rolling_update", "type", b"type"]) -> None: ...

global___DeploymentStrategy = DeploymentStrategy

@typing_extensions.final
class ReplicaSet(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    SPEC_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta: ...
    @property
    def spec(self) -> global___ReplicaSetSpec: ...
    @property
    def status(self) -> global___ReplicaSetStatus: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta | None = ...,
        spec: global___ReplicaSetSpec | None = ...,
        status: global___ReplicaSetStatus | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info", "spec", b"spec", "status", b"status"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info", "spec", b"spec", "status", b"status"]) -> None: ...

global___ReplicaSet = ReplicaSet

@typing_extensions.final
class ReplicaSetCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LAST_TRANSITION_TIME_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    REASON_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def last_transition_time(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.Time: ...
    message: builtins.str
    reason: builtins.str
    status: builtins.str
    type: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        last_transition_time: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.Time | None = ...,
        message: builtins.str = ...,
        reason: builtins.str = ...,
        status: builtins.str = ...,
        type: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["last_transition_time", b"last_transition_time", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["last_transition_time", b"last_transition_time", "message", b"message", "reason", b"reason", "resource_info", b"resource_info", "status", b"status", "type", b"type"]) -> None: ...

global___ReplicaSetCondition = ReplicaSetCondition

@typing_extensions.final
class ReplicaSetList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ReplicaSet]: ...
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        items: collections.abc.Iterable[global___ReplicaSet] | None = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "items", b"items", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info"]) -> None: ...

global___ReplicaSetList = ReplicaSetList

@typing_extensions.final
class ReplicaSetSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MIN_READY_SECONDS_FIELD_NUMBER: builtins.int
    REPLICAS_FIELD_NUMBER: builtins.int
    SELECTOR_FIELD_NUMBER: builtins.int
    TEMPLATE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    min_ready_seconds: builtins.int
    replicas: builtins.int
    @property
    def selector(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.LabelSelector: ...
    @property
    def template(self) -> kubernetes.kubernetes_io.k8s.api.core.v1_pb2.PodTemplateSpec: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        min_ready_seconds: builtins.int = ...,
        replicas: builtins.int = ...,
        selector: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.LabelSelector | None = ...,
        template: kubernetes.kubernetes_io.k8s.api.core.v1_pb2.PodTemplateSpec | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "selector", b"selector", "template", b"template"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["min_ready_seconds", b"min_ready_seconds", "replicas", b"replicas", "resource_info", b"resource_info", "selector", b"selector", "template", b"template"]) -> None: ...

global___ReplicaSetSpec = ReplicaSetSpec

@typing_extensions.final
class ReplicaSetStatus(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AVAILABLE_REPLICAS_FIELD_NUMBER: builtins.int
    CONDITIONS_FIELD_NUMBER: builtins.int
    FULLY_LABELED_REPLICAS_FIELD_NUMBER: builtins.int
    OBSERVED_GENERATION_FIELD_NUMBER: builtins.int
    READY_REPLICAS_FIELD_NUMBER: builtins.int
    REPLICAS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    available_replicas: builtins.int
    @property
    def conditions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ReplicaSetCondition]: ...
    fully_labeled_replicas: builtins.int
    observed_generation: builtins.int
    ready_replicas: builtins.int
    replicas: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        available_replicas: builtins.int = ...,
        conditions: collections.abc.Iterable[global___ReplicaSetCondition] | None = ...,
        fully_labeled_replicas: builtins.int = ...,
        observed_generation: builtins.int = ...,
        ready_replicas: builtins.int = ...,
        replicas: builtins.int = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["available_replicas", b"available_replicas", "conditions", b"conditions", "fully_labeled_replicas", b"fully_labeled_replicas", "observed_generation", b"observed_generation", "ready_replicas", b"ready_replicas", "replicas", b"replicas", "resource_info", b"resource_info"]) -> None: ...

global___ReplicaSetStatus = ReplicaSetStatus

@typing_extensions.final
class RollingUpdateDaemonSet(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MAX_SURGE_FIELD_NUMBER: builtins.int
    MAX_UNAVAILABLE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def max_surge(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.util.intstr_pb2.IntOrString: ...
    @property
    def max_unavailable(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.util.intstr_pb2.IntOrString: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        max_surge: kubernetes.kubernetes_io.k8s.apimachinery.pkg.util.intstr_pb2.IntOrString | None = ...,
        max_unavailable: kubernetes.kubernetes_io.k8s.apimachinery.pkg.util.intstr_pb2.IntOrString | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["max_surge", b"max_surge", "max_unavailable", b"max_unavailable", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["max_surge", b"max_surge", "max_unavailable", b"max_unavailable", "resource_info", b"resource_info"]) -> None: ...

global___RollingUpdateDaemonSet = RollingUpdateDaemonSet

@typing_extensions.final
class RollingUpdateDeployment(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MAX_SURGE_FIELD_NUMBER: builtins.int
    MAX_UNAVAILABLE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def max_surge(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.util.intstr_pb2.IntOrString: ...
    @property
    def max_unavailable(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.util.intstr_pb2.IntOrString: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        max_surge: kubernetes.kubernetes_io.k8s.apimachinery.pkg.util.intstr_pb2.IntOrString | None = ...,
        max_unavailable: kubernetes.kubernetes_io.k8s.apimachinery.pkg.util.intstr_pb2.IntOrString | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["max_surge", b"max_surge", "max_unavailable", b"max_unavailable", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["max_surge", b"max_surge", "max_unavailable", b"max_unavailable", "resource_info", b"resource_info"]) -> None: ...

global___RollingUpdateDeployment = RollingUpdateDeployment

@typing_extensions.final
class RollingUpdateStatefulSetStrategy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MAX_UNAVAILABLE_FIELD_NUMBER: builtins.int
    PARTITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def max_unavailable(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.util.intstr_pb2.IntOrString: ...
    partition: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        max_unavailable: kubernetes.kubernetes_io.k8s.apimachinery.pkg.util.intstr_pb2.IntOrString | None = ...,
        partition: builtins.int = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["max_unavailable", b"max_unavailable", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["max_unavailable", b"max_unavailable", "partition", b"partition", "resource_info", b"resource_info"]) -> None: ...

global___RollingUpdateStatefulSetStrategy = RollingUpdateStatefulSetStrategy

@typing_extensions.final
class StatefulSet(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    SPEC_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta: ...
    @property
    def spec(self) -> global___StatefulSetSpec: ...
    @property
    def status(self) -> global___StatefulSetStatus: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta | None = ...,
        spec: global___StatefulSetSpec | None = ...,
        status: global___StatefulSetStatus | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info", "spec", b"spec", "status", b"status"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info", "spec", b"spec", "status", b"status"]) -> None: ...

global___StatefulSet = StatefulSet

@typing_extensions.final
class StatefulSetCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LAST_TRANSITION_TIME_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    REASON_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def last_transition_time(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.Time: ...
    message: builtins.str
    reason: builtins.str
    status: builtins.str
    type: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        last_transition_time: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.Time | None = ...,
        message: builtins.str = ...,
        reason: builtins.str = ...,
        status: builtins.str = ...,
        type: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["last_transition_time", b"last_transition_time", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["last_transition_time", b"last_transition_time", "message", b"message", "reason", b"reason", "resource_info", b"resource_info", "status", b"status", "type", b"type"]) -> None: ...

global___StatefulSetCondition = StatefulSetCondition

@typing_extensions.final
class StatefulSetList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___StatefulSet]: ...
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        items: collections.abc.Iterable[global___StatefulSet] | None = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "items", b"items", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info"]) -> None: ...

global___StatefulSetList = StatefulSetList

@typing_extensions.final
class StatefulSetOrdinals(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    START_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    start: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        start: builtins.int = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "start", b"start"]) -> None: ...

global___StatefulSetOrdinals = StatefulSetOrdinals

@typing_extensions.final
class StatefulSetPersistentVolumeClaimRetentionPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    WHEN_DELETED_FIELD_NUMBER: builtins.int
    WHEN_SCALED_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    when_deleted: builtins.str
    when_scaled: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        when_deleted: builtins.str = ...,
        when_scaled: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "when_deleted", b"when_deleted", "when_scaled", b"when_scaled"]) -> None: ...

global___StatefulSetPersistentVolumeClaimRetentionPolicy = StatefulSetPersistentVolumeClaimRetentionPolicy

@typing_extensions.final
class StatefulSetSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MIN_READY_SECONDS_FIELD_NUMBER: builtins.int
    ORDINALS_FIELD_NUMBER: builtins.int
    PERSISTENT_VOLUME_CLAIM_RETENTION_POLICY_FIELD_NUMBER: builtins.int
    POD_MANAGEMENT_POLICY_FIELD_NUMBER: builtins.int
    REPLICAS_FIELD_NUMBER: builtins.int
    REVISION_HISTORY_LIMIT_FIELD_NUMBER: builtins.int
    SELECTOR_FIELD_NUMBER: builtins.int
    SERVICE_NAME_FIELD_NUMBER: builtins.int
    TEMPLATE_FIELD_NUMBER: builtins.int
    UPDATE_STRATEGY_FIELD_NUMBER: builtins.int
    VOLUME_CLAIM_TEMPLATES_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    min_ready_seconds: builtins.int
    @property
    def ordinals(self) -> global___StatefulSetOrdinals: ...
    @property
    def persistent_volume_claim_retention_policy(self) -> global___StatefulSetPersistentVolumeClaimRetentionPolicy: ...
    pod_management_policy: builtins.str
    replicas: builtins.int
    revision_history_limit: builtins.int
    @property
    def selector(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.LabelSelector: ...
    service_name: builtins.str
    @property
    def template(self) -> kubernetes.kubernetes_io.k8s.api.core.v1_pb2.PodTemplateSpec: ...
    @property
    def update_strategy(self) -> global___StatefulSetUpdateStrategy: ...
    @property
    def volume_claim_templates(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[kubernetes.kubernetes_io.k8s.api.core.v1_pb2.PersistentVolumeClaim]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        min_ready_seconds: builtins.int = ...,
        ordinals: global___StatefulSetOrdinals | None = ...,
        persistent_volume_claim_retention_policy: global___StatefulSetPersistentVolumeClaimRetentionPolicy | None = ...,
        pod_management_policy: builtins.str = ...,
        replicas: builtins.int = ...,
        revision_history_limit: builtins.int = ...,
        selector: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.LabelSelector | None = ...,
        service_name: builtins.str = ...,
        template: kubernetes.kubernetes_io.k8s.api.core.v1_pb2.PodTemplateSpec | None = ...,
        update_strategy: global___StatefulSetUpdateStrategy | None = ...,
        volume_claim_templates: collections.abc.Iterable[kubernetes.kubernetes_io.k8s.api.core.v1_pb2.PersistentVolumeClaim] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["ordinals", b"ordinals", "persistent_volume_claim_retention_policy", b"persistent_volume_claim_retention_policy", "resource_info", b"resource_info", "selector", b"selector", "template", b"template", "update_strategy", b"update_strategy"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["min_ready_seconds", b"min_ready_seconds", "ordinals", b"ordinals", "persistent_volume_claim_retention_policy", b"persistent_volume_claim_retention_policy", "pod_management_policy", b"pod_management_policy", "replicas", b"replicas", "resource_info", b"resource_info", "revision_history_limit", b"revision_history_limit", "selector", b"selector", "service_name", b"service_name", "template", b"template", "update_strategy", b"update_strategy", "volume_claim_templates", b"volume_claim_templates"]) -> None: ...

global___StatefulSetSpec = StatefulSetSpec

@typing_extensions.final
class StatefulSetStatus(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AVAILABLE_REPLICAS_FIELD_NUMBER: builtins.int
    COLLISION_COUNT_FIELD_NUMBER: builtins.int
    CONDITIONS_FIELD_NUMBER: builtins.int
    CURRENT_REPLICAS_FIELD_NUMBER: builtins.int
    CURRENT_REVISION_FIELD_NUMBER: builtins.int
    OBSERVED_GENERATION_FIELD_NUMBER: builtins.int
    READY_REPLICAS_FIELD_NUMBER: builtins.int
    REPLICAS_FIELD_NUMBER: builtins.int
    UPDATE_REVISION_FIELD_NUMBER: builtins.int
    UPDATED_REPLICAS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    available_replicas: builtins.int
    collision_count: builtins.int
    @property
    def conditions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___StatefulSetCondition]: ...
    current_replicas: builtins.int
    current_revision: builtins.str
    observed_generation: builtins.int
    ready_replicas: builtins.int
    replicas: builtins.int
    update_revision: builtins.str
    updated_replicas: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        available_replicas: builtins.int = ...,
        collision_count: builtins.int = ...,
        conditions: collections.abc.Iterable[global___StatefulSetCondition] | None = ...,
        current_replicas: builtins.int = ...,
        current_revision: builtins.str = ...,
        observed_generation: builtins.int = ...,
        ready_replicas: builtins.int = ...,
        replicas: builtins.int = ...,
        update_revision: builtins.str = ...,
        updated_replicas: builtins.int = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["available_replicas", b"available_replicas", "collision_count", b"collision_count", "conditions", b"conditions", "current_replicas", b"current_replicas", "current_revision", b"current_revision", "observed_generation", b"observed_generation", "ready_replicas", b"ready_replicas", "replicas", b"replicas", "resource_info", b"resource_info", "update_revision", b"update_revision", "updated_replicas", b"updated_replicas"]) -> None: ...

global___StatefulSetStatus = StatefulSetStatus

@typing_extensions.final
class StatefulSetUpdateStrategy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ROLLING_UPDATE_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def rolling_update(self) -> global___RollingUpdateStatefulSetStrategy: ...
    type: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        rolling_update: global___RollingUpdateStatefulSetStrategy | None = ...,
        type: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "rolling_update", b"rolling_update"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "rolling_update", b"rolling_update", "type", b"type"]) -> None: ...

global___StatefulSetUpdateStrategy = StatefulSetUpdateStrategy
