# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: azure/azure_microsoft_sql_servers.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'azure/azure_microsoft_sql_servers.proto\x12\'oak9.tython.azure.microsoft_sql_servers\x1a\x13shared/shared.proto\"\xf9\x0b\n\x15Microsoft_Sql_Servers\x12\x41\n\x07servers\x18\x01 \x01(\x0b\x32\x30.oak9.tython.azure.microsoft_sql_servers.Servers\x12^\n\x16servers_administrators\x18\x02 \x03(\x0b\x32>.oak9.tython.azure.microsoft_sql_servers.ServersAdministrators\x12\x63\n\x19servers_auditing_settings\x18\x03 \x01(\x0b\x32@.oak9.tython.azure.microsoft_sql_servers.ServersAuditingSettings\x12[\n\x15servers_elastic_pools\x18\x04 \x03(\x0b\x32<.oak9.tython.azure.microsoft_sql_servers.ServersElasticPools\x12i\n\x1cservers_encryption_protector\x18\x05 \x01(\x0b\x32\x43.oak9.tython.azure.microsoft_sql_servers.ServersEncryptionProtector\x12t\n\"servers_extended_auditing_settings\x18\x06 \x01(\x0b\x32H.oak9.tython.azure.microsoft_sql_servers.ServersExtendedAuditingSettings\x12_\n\x17servers_failover_groups\x18\x07 \x03(\x0b\x32>.oak9.tython.azure.microsoft_sql_servers.ServersFailoverGroups\x12]\n\x16servers_firewall_rules\x18\x08 \x03(\x0b\x32=.oak9.tython.azure.microsoft_sql_servers.ServersFirewallRules\x12U\n\x12servers_job_agents\x18\t \x03(\x0b\x32\x39.oak9.tython.azure.microsoft_sql_servers.ServersJobAgents\x12l\n\x1eservers_job_agents_credentials\x18\n \x03(\x0b\x32\x44.oak9.tython.azure.microsoft_sql_servers.ServersJobAgentsCredentials\x12J\n\x0cservers_keys\x18\x0b \x03(\x0b\x32\x34.oak9.tython.azure.microsoft_sql_servers.ServersKeys\x12x\n$servers_private_endpoint_connections\x18\x0c \x03(\x0b\x32J.oak9.tython.azure.microsoft_sql_servers.ServersPrivateEndpointConnections\x12n\n\x1fservers_security_alert_policies\x18\r \x01(\x0b\x32\x45.oak9.tython.azure.microsoft_sql_servers.ServersSecurityAlertPolicies\x12j\n\x1dservers_virtual_network_rules\x18\x0e \x03(\x0b\x32\x43.oak9.tython.azure.microsoft_sql_servers.ServersVirtualNetworkRules\x12s\n!servers_vulnerability_assessments\x18\x0f \x01(\x0b\x32H.oak9.tython.azure.microsoft_sql_servers.ServersVulnerabilityAssessments\"\xc2\x02\n\x1fServersVulnerabilityAssessments\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12q\n\x0frecurring_scans\x18\x03 \x01(\x0b\x32X.oak9.tython.azure.microsoft_sql_servers.VulnerabilityAssessmentRecurringScansProperties\x12\"\n\x1astorage_account_access_key\x18\x04 \x01(\t\x12\x1e\n\x16storage_container_path\x18\x05 \x01(\t\x12!\n\x19storage_container_sas_key\x18\x06 \x01(\t\"x\n/VulnerabilityAssessmentRecurringScansProperties\x12\x0e\n\x06\x65mails\x18\x01 \x03(\t\x12!\n\x19\x65mail_subscription_admins\x18\x02 \x01(\x08\x12\x12\n\nis_enabled\x18\x03 \x01(\x08\"\xb4\x01\n\x1aServersVirtualNetworkRules\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12,\n$ignore_missing_vnet_service_endpoint\x18\x03 \x01(\x08\x12!\n\x19virtual_network_subnet_id\x18\x04 \x01(\t\"t\n\x11ServersSyncAgents\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x18\n\x10sync_database_id\x18\x03 \x01(\t\"\x9a\x02\n\x1cServersSecurityAlertPolicies\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x17\n\x0f\x64isabled_alerts\x18\x03 \x03(\t\x12\x1c\n\x14\x65mail_account_admins\x18\x04 \x01(\x08\x12\x17\n\x0f\x65mail_addresses\x18\x05 \x03(\t\x12\x16\n\x0eretention_days\x18\x06 \x01(\x05\x12\r\n\x05state\x18\x07 \x01(\t\x12\"\n\x1astorage_account_access_key\x18\x08 \x01(\t\x12\x18\n\x10storage_endpoint\x18\t \x01(\t\"\xca\x02\n!ServersPrivateEndpointConnections\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12Z\n\x10private_endpoint\x18\x03 \x01(\x0b\x32@.oak9.tython.azure.microsoft_sql_servers.PrivateEndpointProperty\x12\x81\x01\n%private_link_service_connection_state\x18\x04 \x01(\x0b\x32R.oak9.tython.azure.microsoft_sql_servers.PrivateLinkServiceConnectionStateProperty\"P\n)PrivateLinkServiceConnectionStateProperty\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x0e\n\x06status\x18\x02 \x01(\t\"%\n\x17PrivateEndpointProperty\x12\n\n\x02id\x18\x01 \x01(\t\"e\n\x1cServersOutboundFirewallRules\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\"\xb3\x01\n\x0bServersKeys\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x17\n\x0fserver_key_type\x18\x03 \x01(\t\x12\x0b\n\x03uri\x18\x04 \x01(\t\x12\x12\n\nthumbprint\x18\x05 \x01(\t\x12\x15\n\rcreation_date\x18\x06 \x01(\t\x12\x0c\n\x04kind\x18\x07 \x01(\t\"\xaa\x01\n\x1cServersJobAgentsTargetGroups\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x43\n\x07members\x18\x03 \x03(\x0b\x32\x32.oak9.tython.azure.microsoft_sql_servers.JobTarget\"\xad\x01\n\tJobTarget\x12\x15\n\rdatabase_name\x18\x01 \x01(\t\x12\x19\n\x11\x65lastic_pool_name\x18\x02 \x01(\t\x12\x17\n\x0fmembership_type\x18\x03 \x01(\t\x12\x1a\n\x12refresh_credential\x18\x04 \x01(\t\x12\x13\n\x0bserver_name\x18\x05 \x01(\t\x12\x16\n\x0eshard_map_name\x18\x06 \x01(\t\x12\x0c\n\x04type\x18\x07 \x01(\t\"\x8a\x03\n\x19ServersJobAgentsJobsSteps\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x46\n\x06\x61\x63tion\x18\x03 \x01(\x0b\x32\x36.oak9.tython.azure.microsoft_sql_servers.JobStepAction\x12\x12\n\ncredential\x18\x04 \x01(\t\x12[\n\x11\x65xecution_options\x18\x05 \x01(\x0b\x32@.oak9.tython.azure.microsoft_sql_servers.JobStepExecutionOptions\x12\x46\n\x06output\x18\x06 \x01(\x0b\x32\x36.oak9.tython.azure.microsoft_sql_servers.JobStepOutput\x12\x0f\n\x07step_id\x18\x07 \x01(\x05\x12\x14\n\x0ctarget_group\x18\x08 \x01(\t\"\xbc\x01\n\rJobStepOutput\x12\x12\n\ncredential\x18\x01 \x01(\t\x12\x15\n\rdatabase_name\x18\x02 \x01(\t\x12\x1b\n\x13resource_group_name\x18\x03 \x01(\t\x12\x13\n\x0bschema_name\x18\x04 \x01(\t\x12\x13\n\x0bserver_name\x18\x05 \x01(\t\x12\x17\n\x0fsubscription_id\x18\x06 \x01(\t\x12\x12\n\ntable_name\x18\x07 \x01(\t\x12\x0c\n\x04type\x18\x08 \x01(\t\"\xc5\x01\n\x17JobStepExecutionOptions\x12&\n\x1einitial_retry_interval_seconds\x18\x01 \x01(\x05\x12&\n\x1emaximum_retry_interval_seconds\x18\x02 \x01(\x05\x12\x16\n\x0eretry_attempts\x18\x03 \x01(\x05\x12)\n!retry_interval_backoff_multiplier\x18\x04 \x01(\x01\x12\x17\n\x0ftimeout_seconds\x18\x05 \x01(\x05\"<\n\rJobStepAction\x12\x0e\n\x06source\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\"g\n\x1eServersJobAgentsJobsExecutions\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x9a\x03\n\x14ServersJobAgentsJobs\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x46\n\x08schedule\x18\x04 \x01(\x0b\x32\x34.oak9.tython.azure.microsoft_sql_servers.JobSchedule\x12s\n\"servers_job_agents_jobs_executions\x18\x05 \x03(\x0b\x32G.oak9.tython.azure.microsoft_sql_servers.ServersJobAgentsJobsExecutions\x12i\n\x1dservers_job_agents_jobs_steps\x18\x06 \x03(\x0b\x32\x42.oak9.tython.azure.microsoft_sql_servers.ServersJobAgentsJobsSteps\"d\n\x0bJobSchedule\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x10\n\x08\x65nd_time\x18\x02 \x01(\t\x12\x10\n\x08interval\x18\x03 \x01(\t\x12\x12\n\nstart_time\x18\x04 \x01(\t\x12\x0c\n\x04type\x18\x05 \x01(\t\"\x88\x01\n\x1bServersJobAgentsCredentials\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08password\x18\x03 \x01(\t\x12\x10\n\x08username\x18\x04 \x01(\t\"\x8c\x04\n\x10ServersJobAgents\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08location\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x61tabase_id\x18\x04 \x01(\t\x12\x39\n\x03sku\x18\x05 \x01(\x0b\x32,.oak9.tython.azure.microsoft_sql_servers.Sku\x12Q\n\x04tags\x18\x06 \x03(\x0b\x32\x43.oak9.tython.azure.microsoft_sql_servers.ServersJobAgents.TagsEntry\x12^\n\x17servers_job_agents_jobs\x18\x07 \x03(\x0b\x32=.oak9.tython.azure.microsoft_sql_servers.ServersJobAgentsJobs\x12o\n servers_job_agents_target_groups\x18\x08 \x03(\x0b\x32\x45.oak9.tython.azure.microsoft_sql_servers.ServersJobAgentsTargetGroups\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x97\x01\n\x18ServersIpv6FirewallRules\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x18\n\x10\x65nd_ipv6_address\x18\x03 \x01(\t\x12\x1a\n\x12start_ipv6_address\x18\x04 \x01(\t\"\x8f\x01\n\x14ServersFirewallRules\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x16\n\x0e\x65nd_ip_address\x18\x03 \x01(\t\x12\x18\n\x10start_ip_address\x18\x04 \x01(\t\"\x8f\x04\n\x15ServersFailoverGroups\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x11\n\tdatabases\x18\x03 \x03(\t\x12M\n\x0fpartner_servers\x18\x04 \x03(\x0b\x32\x34.oak9.tython.azure.microsoft_sql_servers.PartnerInfo\x12\x62\n\x12read_only_endpoint\x18\x05 \x01(\x0b\x32\x46.oak9.tython.azure.microsoft_sql_servers.FailoverGroupReadOnlyEndpoint\x12\x64\n\x13read_write_endpoint\x18\x06 \x01(\x0b\x32G.oak9.tython.azure.microsoft_sql_servers.FailoverGroupReadWriteEndpoint\x12V\n\x04tags\x18\x07 \x03(\x0b\x32H.oak9.tython.azure.microsoft_sql_servers.ServersFailoverGroups.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"o\n\x1e\x46\x61iloverGroupReadWriteEndpoint\x12\x17\n\x0f\x66\x61ilover_policy\x18\x01 \x01(\t\x12\x34\n,failover_with_data_loss_grace_period_minutes\x18\x02 \x01(\x05\"8\n\x1d\x46\x61iloverGroupReadOnlyEndpoint\x12\x17\n\x0f\x66\x61ilover_policy\x18\x01 \x01(\t\"\x19\n\x0bPartnerInfo\x12\n\n\x02id\x18\x01 \x01(\t\"\xc1\x03\n\x1fServersExtendedAuditingSettings\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12 \n\x18\x61udit_actions_and_groups\x18\x03 \x03(\t\x12\'\n\x1fis_azure_monitor_target_enabled\x18\x04 \x01(\x08\x12\x1f\n\x17is_devops_audit_enabled\x18\x05 \x01(\x08\x12\'\n\x1fis_storage_secondary_key_in_use\x18\x06 \x01(\x08\x12\x1c\n\x14predicate_expression\x18\x07 \x01(\t\x12\x16\n\x0equeue_delay_ms\x18\x08 \x01(\x05\x12\x16\n\x0eretention_days\x18\t \x01(\x05\x12\r\n\x05state\x18\n \x01(\t\x12\"\n\x1astorage_account_access_key\x18\x0b \x01(\t\x12\'\n\x1fstorage_account_subscription_id\x18\x0c \x01(\t\x12\x18\n\x10storage_endpoint\x18\r \x01(\t\"\xb4\x01\n\x1aServersEncryptionProtector\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x1d\n\x15\x61uto_rotation_enabled\x18\x03 \x01(\x08\x12\x17\n\x0fserver_key_name\x18\x04 \x01(\t\x12\x17\n\x0fserver_key_type\x18\x05 \x01(\t\"\xa9\x04\n\x13ServersElasticPools\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08location\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\'\n\x1fhigh_availability_replica_count\x18\x04 \x01(\x05\x12\x14\n\x0clicense_type\x18\x05 \x01(\t\x12$\n\x1cmaintenance_configuration_id\x18\x06 \x01(\t\x12\x16\n\x0emax_size_bytes\x18\x07 \x01(\x05\x12\x66\n\x15per_database_settings\x18\x08 \x01(\x0b\x32G.oak9.tython.azure.microsoft_sql_servers.ElasticPoolPerDatabaseSettings\x12\x16\n\x0ezone_redundant\x18\t \x01(\x08\x12\x39\n\x03sku\x18\n \x01(\x0b\x32,.oak9.tython.azure.microsoft_sql_servers.Sku\x12T\n\x04tags\x18\x0b \x03(\x0b\x32\x46.oak9.tython.azure.microsoft_sql_servers.ServersElasticPools.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"Q\n\x03Sku\x12\x10\n\x08\x63\x61pacity\x18\x01 \x01(\x05\x12\x0e\n\x06\x66\x61mily\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0c\n\x04size\x18\x04 \x01(\t\x12\x0c\n\x04tier\x18\x05 \x01(\t\"L\n\x1e\x45lasticPoolPerDatabaseSettings\x12\x14\n\x0cmax_capacity\x18\x01 \x01(\x01\x12\x14\n\x0cmin_capacity\x18\x02 \x01(\x01\"Z\n\x11ServersDnsAliases\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x85\x02\n\x1dServersDevOpsAuditingSettings\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\'\n\x1fis_azure_monitor_target_enabled\x18\x03 \x01(\x08\x12\r\n\x05state\x18\x04 \x01(\t\x12\"\n\x1astorage_account_access_key\x18\x05 \x01(\t\x12\'\n\x1fstorage_account_subscription_id\x18\x06 \x01(\t\x12\x18\n\x10storage_endpoint\x18\x07 \x01(\t\"{\n\x19ServersConnectionPolicies\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x17\n\x0f\x63onnection_type\x18\x03 \x01(\t\"\x90\x01\n!ServersAzureADOnlyAuthentications\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12$\n\x1c\x61zure_ad_only_authentication\x18\x03 \x01(\x08\"\x9b\x03\n\x17ServersAuditingSettings\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12 \n\x18\x61udit_actions_and_groups\x18\x03 \x03(\t\x12\'\n\x1fis_azure_monitor_target_enabled\x18\x04 \x01(\x08\x12\x1f\n\x17is_devops_audit_enabled\x18\x05 \x01(\x08\x12\'\n\x1fis_storage_secondary_key_in_use\x18\x06 \x01(\x08\x12\x16\n\x0equeue_delay_ms\x18\x07 \x01(\x05\x12\x16\n\x0eretention_days\x18\x08 \x01(\x05\x12\r\n\x05state\x18\t \x01(\t\x12\"\n\x1astorage_account_access_key\x18\n \x01(\t\x12\'\n\x1fstorage_account_subscription_id\x18\x0b \x01(\t\x12\x18\n\x10storage_endpoint\x18\x0c \x01(\t\"\xcf\x01\n\x15ServersAdministrators\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x1a\n\x12\x61\x64ministrator_type\x18\x03 \x01(\t\x12\r\n\x05login\x18\x04 \x01(\t\x12\x0b\n\x03sid\x18\x05 \x01(\t\x12\x11\n\ttenant_id\x18\x06 \x01(\t\x12$\n\x1c\x61zure_ad_only_authentication\x18\x07 \x01(\t\"\xf7\n\n\x07Servers\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12K\n\x08identity\x18\x02 \x01(\x0b\x32\x39.oak9.tython.azure.microsoft_sql_servers.ResourceIdentity\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x1b\n\x13\x61\x64ministrator_login\x18\x05 \x01(\t\x12$\n\x1c\x61\x64ministrator_login_password\x18\x06 \x01(\t\x12\\\n\x0e\x61\x64ministrators\x18\x07 \x01(\x0b\x32\x44.oak9.tython.azure.microsoft_sql_servers.ServerExternalAdministrator\x12\x1b\n\x13\x66\x65\x64\x65rated_client_id\x18\x08 \x01(\t\x12\x0e\n\x06key_id\x18\t \x01(\t\x12\x1b\n\x13minimal_tls_version\x18\n \x01(\t\x12)\n!primary_user_assigned_identity_id\x18\x0b \x01(\t\x12\x1d\n\x15public_network_access\x18\x0c \x01(\t\x12(\n restrict_outbound_network_access\x18\r \x01(\t\x12\x0f\n\x07version\x18\x0e \x01(\t\x12H\n\x04tags\x18\x0f \x03(\x0b\x32:.oak9.tython.azure.microsoft_sql_servers.Servers.TagsEntry\x12\x66\n\x1bservers_ipv6_firewall_rules\x18\x10 \x03(\x0b\x32\x41.oak9.tython.azure.microsoft_sql_servers.ServersIpv6FirewallRules\x12n\n\x1fservers_outbound_firewall_rules\x18\x11 \x03(\x0b\x32\x45.oak9.tython.azure.microsoft_sql_servers.ServersOutboundFirewallRules\x12y\n%servers_azure_ad_only_authentications\x18\x12 \x03(\x0b\x32J.oak9.tython.azure.microsoft_sql_servers.ServersAzureADOnlyAuthentications\x12g\n\x1bservers_connection_policies\x18\x13 \x03(\x0b\x32\x42.oak9.tython.azure.microsoft_sql_servers.ServersConnectionPolicies\x12q\n!servers_dev_ops_auditing_settings\x18\x14 \x03(\x0b\x32\x46.oak9.tython.azure.microsoft_sql_servers.ServersDevOpsAuditingSettings\x12W\n\x13servers_dns_aliases\x18\x15 \x03(\x0b\x32:.oak9.tython.azure.microsoft_sql_servers.ServersDnsAliases\x12W\n\x13servers_sync_agents\x18\x16 \x03(\x0b\x32:.oak9.tython.azure.microsoft_sql_servers.ServersSyncAgents\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa6\x01\n\x1bServerExternalAdministrator\x12\x1a\n\x12\x61\x64ministrator_type\x18\x01 \x01(\t\x12$\n\x1c\x61zure_ad_only_authentication\x18\x02 \x01(\x08\x12\r\n\x05login\x18\x03 \x01(\t\x12\x16\n\x0eprincipal_type\x18\x04 \x01(\t\x12\x0b\n\x03sid\x18\x05 \x01(\t\x12\x11\n\ttenant_id\x18\x06 \x01(\t\"\xd8\x01\n\x10ResourceIdentity\x12\x0c\n\x04type\x18\x01 \x01(\t\x12w\n\x18user_assigned_identities\x18\x02 \x03(\x0b\x32U.oak9.tython.azure.microsoft_sql_servers.ResourceIdentity.UserAssignedIdentitiesEntry\x1a=\n\x1bUserAssignedIdentitiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'azure.azure_microsoft_sql_servers_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SERVERSJOBAGENTS_TAGSENTRY._options = None
  _SERVERSJOBAGENTS_TAGSENTRY._serialized_options = b'8\001'
  _SERVERSFAILOVERGROUPS_TAGSENTRY._options = None
  _SERVERSFAILOVERGROUPS_TAGSENTRY._serialized_options = b'8\001'
  _SERVERSELASTICPOOLS_TAGSENTRY._options = None
  _SERVERSELASTICPOOLS_TAGSENTRY._serialized_options = b'8\001'
  _SERVERS_TAGSENTRY._options = None
  _SERVERS_TAGSENTRY._serialized_options = b'8\001'
  _RESOURCEIDENTITY_USERASSIGNEDIDENTITIESENTRY._options = None
  _RESOURCEIDENTITY_USERASSIGNEDIDENTITIESENTRY._serialized_options = b'8\001'
  _MICROSOFT_SQL_SERVERS._serialized_start=106
  _MICROSOFT_SQL_SERVERS._serialized_end=1635
  _SERVERSVULNERABILITYASSESSMENTS._serialized_start=1638
  _SERVERSVULNERABILITYASSESSMENTS._serialized_end=1960
  _VULNERABILITYASSESSMENTRECURRINGSCANSPROPERTIES._serialized_start=1962
  _VULNERABILITYASSESSMENTRECURRINGSCANSPROPERTIES._serialized_end=2082
  _SERVERSVIRTUALNETWORKRULES._serialized_start=2085
  _SERVERSVIRTUALNETWORKRULES._serialized_end=2265
  _SERVERSSYNCAGENTS._serialized_start=2267
  _SERVERSSYNCAGENTS._serialized_end=2383
  _SERVERSSECURITYALERTPOLICIES._serialized_start=2386
  _SERVERSSECURITYALERTPOLICIES._serialized_end=2668
  _SERVERSPRIVATEENDPOINTCONNECTIONS._serialized_start=2671
  _SERVERSPRIVATEENDPOINTCONNECTIONS._serialized_end=3001
  _PRIVATELINKSERVICECONNECTIONSTATEPROPERTY._serialized_start=3003
  _PRIVATELINKSERVICECONNECTIONSTATEPROPERTY._serialized_end=3083
  _PRIVATEENDPOINTPROPERTY._serialized_start=3085
  _PRIVATEENDPOINTPROPERTY._serialized_end=3122
  _SERVERSOUTBOUNDFIREWALLRULES._serialized_start=3124
  _SERVERSOUTBOUNDFIREWALLRULES._serialized_end=3225
  _SERVERSKEYS._serialized_start=3228
  _SERVERSKEYS._serialized_end=3407
  _SERVERSJOBAGENTSTARGETGROUPS._serialized_start=3410
  _SERVERSJOBAGENTSTARGETGROUPS._serialized_end=3580
  _JOBTARGET._serialized_start=3583
  _JOBTARGET._serialized_end=3756
  _SERVERSJOBAGENTSJOBSSTEPS._serialized_start=3759
  _SERVERSJOBAGENTSJOBSSTEPS._serialized_end=4153
  _JOBSTEPOUTPUT._serialized_start=4156
  _JOBSTEPOUTPUT._serialized_end=4344
  _JOBSTEPEXECUTIONOPTIONS._serialized_start=4347
  _JOBSTEPEXECUTIONOPTIONS._serialized_end=4544
  _JOBSTEPACTION._serialized_start=4546
  _JOBSTEPACTION._serialized_end=4606
  _SERVERSJOBAGENTSJOBSEXECUTIONS._serialized_start=4608
  _SERVERSJOBAGENTSJOBSEXECUTIONS._serialized_end=4711
  _SERVERSJOBAGENTSJOBS._serialized_start=4714
  _SERVERSJOBAGENTSJOBS._serialized_end=5124
  _JOBSCHEDULE._serialized_start=5126
  _JOBSCHEDULE._serialized_end=5226
  _SERVERSJOBAGENTSCREDENTIALS._serialized_start=5229
  _SERVERSJOBAGENTSCREDENTIALS._serialized_end=5365
  _SERVERSJOBAGENTS._serialized_start=5368
  _SERVERSJOBAGENTS._serialized_end=5892
  _SERVERSJOBAGENTS_TAGSENTRY._serialized_start=5849
  _SERVERSJOBAGENTS_TAGSENTRY._serialized_end=5892
  _SERVERSIPV6FIREWALLRULES._serialized_start=5895
  _SERVERSIPV6FIREWALLRULES._serialized_end=6046
  _SERVERSFIREWALLRULES._serialized_start=6049
  _SERVERSFIREWALLRULES._serialized_end=6192
  _SERVERSFAILOVERGROUPS._serialized_start=6195
  _SERVERSFAILOVERGROUPS._serialized_end=6722
  _SERVERSFAILOVERGROUPS_TAGSENTRY._serialized_start=5849
  _SERVERSFAILOVERGROUPS_TAGSENTRY._serialized_end=5892
  _FAILOVERGROUPREADWRITEENDPOINT._serialized_start=6724
  _FAILOVERGROUPREADWRITEENDPOINT._serialized_end=6835
  _FAILOVERGROUPREADONLYENDPOINT._serialized_start=6837
  _FAILOVERGROUPREADONLYENDPOINT._serialized_end=6893
  _PARTNERINFO._serialized_start=6895
  _PARTNERINFO._serialized_end=6920
  _SERVERSEXTENDEDAUDITINGSETTINGS._serialized_start=6923
  _SERVERSEXTENDEDAUDITINGSETTINGS._serialized_end=7372
  _SERVERSENCRYPTIONPROTECTOR._serialized_start=7375
  _SERVERSENCRYPTIONPROTECTOR._serialized_end=7555
  _SERVERSELASTICPOOLS._serialized_start=7558
  _SERVERSELASTICPOOLS._serialized_end=8111
  _SERVERSELASTICPOOLS_TAGSENTRY._serialized_start=5849
  _SERVERSELASTICPOOLS_TAGSENTRY._serialized_end=5892
  _SKU._serialized_start=8113
  _SKU._serialized_end=8194
  _ELASTICPOOLPERDATABASESETTINGS._serialized_start=8196
  _ELASTICPOOLPERDATABASESETTINGS._serialized_end=8272
  _SERVERSDNSALIASES._serialized_start=8274
  _SERVERSDNSALIASES._serialized_end=8364
  _SERVERSDEVOPSAUDITINGSETTINGS._serialized_start=8367
  _SERVERSDEVOPSAUDITINGSETTINGS._serialized_end=8628
  _SERVERSCONNECTIONPOLICIES._serialized_start=8630
  _SERVERSCONNECTIONPOLICIES._serialized_end=8753
  _SERVERSAZUREADONLYAUTHENTICATIONS._serialized_start=8756
  _SERVERSAZUREADONLYAUTHENTICATIONS._serialized_end=8900
  _SERVERSAUDITINGSETTINGS._serialized_start=8903
  _SERVERSAUDITINGSETTINGS._serialized_end=9314
  _SERVERSADMINISTRATORS._serialized_start=9317
  _SERVERSADMINISTRATORS._serialized_end=9524
  _SERVERS._serialized_start=9527
  _SERVERS._serialized_end=10926
  _SERVERS_TAGSENTRY._serialized_start=5849
  _SERVERS_TAGSENTRY._serialized_end=5892
  _SERVEREXTERNALADMINISTRATOR._serialized_start=10929
  _SERVEREXTERNALADMINISTRATOR._serialized_end=11095
  _RESOURCEIDENTITY._serialized_start=11098
  _RESOURCEIDENTITY._serialized_end=11314
  _RESOURCEIDENTITY_USERASSIGNEDIDENTITIESENTRY._serialized_start=11253
  _RESOURCEIDENTITY_USERASSIGNEDIDENTITIESENTRY._serialized_end=11314
# @@protoc_insertion_point(module_scope)
