# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kubernetes/kubernetes_io.k8s.api.autoscaling.v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2
from oak9.tython.models.kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta import v1_pb2 as kubernetes_dot_kubernetes__io_dot_k8s_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5kubernetes/kubernetes_io.k8s.api.autoscaling.v1.proto\x12\"oak9.tython.k8s.api.autoscaling.v1\x1a\x13shared/shared.proto\x1a@kubernetes/kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1.proto\"\x87\x01\n\x1b\x43rossVersionObjectReference\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x37\n\rresource_info\x18\x04 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xe4\x02\n\x17HorizontalPodAutoscaler\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12K\n\x08metadata\x18\x03 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12M\n\x04spec\x18\x04 \x01(\x0b\x32?.oak9.tython.k8s.api.autoscaling.v1.HorizontalPodAutoscalerSpec\x12Q\n\x06status\x18\x05 \x01(\x0b\x32\x41.oak9.tython.k8s.api.autoscaling.v1.HorizontalPodAutoscalerStatus\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x90\x02\n\x1bHorizontalPodAutoscalerList\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12J\n\x05items\x18\x02 \x03(\x0b\x32;.oak9.tython.k8s.api.autoscaling.v1.HorizontalPodAutoscaler\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12I\n\x08metadata\x18\x04 \x01(\x0b\x32\x37.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ListMeta\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x88\x02\n\x1bHorizontalPodAutoscalerSpec\x12\x14\n\x0cmax_replicas\x18\x01 \x01(\x05\x12\x14\n\x0cmin_replicas\x18\x02 \x01(\x05\x12Y\n\x10scale_target_ref\x18\x03 \x01(\x0b\x32?.oak9.tython.k8s.api.autoscaling.v1.CrossVersionObjectReference\x12)\n!target_cpu_utilization_percentage\x18\x04 \x01(\x05\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xa3\x02\n\x1dHorizontalPodAutoscalerStatus\x12*\n\"current_cpu_utilization_percentage\x18\x01 \x01(\x05\x12\x18\n\x10\x63urrent_replicas\x18\x02 \x01(\x05\x12\x18\n\x10\x64\x65sired_replicas\x18\x03 \x01(\x05\x12L\n\x0flast_scale_time\x18\x04 \x01(\x0b\x32\x33.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.Time\x12\x1b\n\x13observed_generation\x18\x05 \x01(\x05\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xae\x02\n\x05Scale\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12K\n\x08metadata\x18\x03 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12;\n\x04spec\x18\x04 \x01(\x0b\x32-.oak9.tython.k8s.api.autoscaling.v1.ScaleSpec\x12?\n\x06status\x18\x05 \x01(\x0b\x32/.oak9.tython.k8s.api.autoscaling.v1.ScaleStatus\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"V\n\tScaleSpec\x12\x10\n\x08replicas\x18\x01 \x01(\x05\x12\x37\n\rresource_info\x18\x02 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"j\n\x0bScaleStatus\x12\x10\n\x08replicas\x18\x01 \x01(\x05\x12\x10\n\x08selector\x18\x02 \x01(\t\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'kubernetes.kubernetes_io.k8s.api.autoscaling.v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CROSSVERSIONOBJECTREFERENCE._serialized_start=181
  _CROSSVERSIONOBJECTREFERENCE._serialized_end=316
  _HORIZONTALPODAUTOSCALER._serialized_start=319
  _HORIZONTALPODAUTOSCALER._serialized_end=675
  _HORIZONTALPODAUTOSCALERLIST._serialized_start=678
  _HORIZONTALPODAUTOSCALERLIST._serialized_end=950
  _HORIZONTALPODAUTOSCALERSPEC._serialized_start=953
  _HORIZONTALPODAUTOSCALERSPEC._serialized_end=1217
  _HORIZONTALPODAUTOSCALERSTATUS._serialized_start=1220
  _HORIZONTALPODAUTOSCALERSTATUS._serialized_end=1511
  _SCALE._serialized_start=1514
  _SCALE._serialized_end=1816
  _SCALESPEC._serialized_start=1818
  _SCALESPEC._serialized_end=1904
  _SCALESTATUS._serialized_start=1906
  _SCALESTATUS._serialized_end=2012
# @@protoc_insertion_point(module_scope)
