"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ComputeHaVpnGatewayXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete"]) -> None: ...

global___ComputeHaVpnGatewayXTimeouts = ComputeHaVpnGatewayXTimeouts

@typing_extensions.final
class ComputeHaVpnGatewayXVpnInterfaces(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    INTERCONNECT_ATTACHMENT_FIELD_NUMBER: builtins.int
    IP_ADDRESS_FIELD_NUMBER: builtins.int
    id: builtins.float
    interconnect_attachment: builtins.str
    ip_address: builtins.str
    def __init__(
        self,
        *,
        id: builtins.float = ...,
        interconnect_attachment: builtins.str = ...,
        ip_address: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "interconnect_attachment", b"interconnect_attachment", "ip_address", b"ip_address"]) -> None: ...

global___ComputeHaVpnGatewayXVpnInterfaces = ComputeHaVpnGatewayXVpnInterfaces

@typing_extensions.final
class ComputeHaVpnGateway(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    NETWORK_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    SELF_LINK_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    VPN_INTERFACES_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    description: builtins.str
    id: builtins.str
    name: builtins.str
    network: builtins.str
    project: builtins.str
    region: builtins.str
    self_link: builtins.str
    @property
    def timeouts(self) -> global___ComputeHaVpnGatewayXTimeouts: ...
    @property
    def vpn_interfaces(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeHaVpnGatewayXVpnInterfaces]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        network: builtins.str = ...,
        project: builtins.str = ...,
        region: builtins.str = ...,
        self_link: builtins.str = ...,
        timeouts: global___ComputeHaVpnGatewayXTimeouts | None = ...,
        vpn_interfaces: collections.abc.Iterable[global___ComputeHaVpnGatewayXVpnInterfaces] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "id", b"id", "name", b"name", "network", b"network", "project", b"project", "region", b"region", "resource_info", b"resource_info", "self_link", b"self_link", "timeouts", b"timeouts", "vpn_interfaces", b"vpn_interfaces"]) -> None: ...

global___ComputeHaVpnGateway = ComputeHaVpnGateway
