"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import gcp.gcp_pubsub_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class GooglePubsub(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PUBSUB_SCHEMA_FIELD_NUMBER: builtins.int
    PUBSUB_SUBSCRIPTION_FIELD_NUMBER: builtins.int
    PUBSUB_SUBSCRIPTION_IAM_BINDING_FIELD_NUMBER: builtins.int
    PUBSUB_SUBSCRIPTION_IAM_MEMBER_FIELD_NUMBER: builtins.int
    PUBSUB_SUBSCRIPTION_IAM_POLICY_FIELD_NUMBER: builtins.int
    PUBSUB_TOPIC_FIELD_NUMBER: builtins.int
    PUBSUB_TOPIC_IAM_BINDING_FIELD_NUMBER: builtins.int
    PUBSUB_TOPIC_IAM_MEMBER_FIELD_NUMBER: builtins.int
    PUBSUB_TOPIC_IAM_POLICY_FIELD_NUMBER: builtins.int
    @property
    def pubsub_schema(self) -> gcp.gcp_pubsub_pb2.PubsubSchema: ...
    @property
    def pubsub_subscription(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[gcp.gcp_pubsub_pb2.PubsubSubscription]: ...
    @property
    def pubsub_subscription_iam_binding(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[gcp.gcp_pubsub_pb2.PubsubSubscriptionIamBinding]: ...
    @property
    def pubsub_subscription_iam_member(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[gcp.gcp_pubsub_pb2.PubsubSubscriptionIamMember]: ...
    @property
    def pubsub_subscription_iam_policy(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[gcp.gcp_pubsub_pb2.PubsubSubscriptionIamPolicy]: ...
    @property
    def pubsub_topic(self) -> gcp.gcp_pubsub_pb2.PubsubTopic: ...
    @property
    def pubsub_topic_iam_binding(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[gcp.gcp_pubsub_pb2.PubsubTopicIamBinding]: ...
    @property
    def pubsub_topic_iam_member(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[gcp.gcp_pubsub_pb2.PubsubTopicIamMember]: ...
    @property
    def pubsub_topic_iam_policy(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[gcp.gcp_pubsub_pb2.PubsubTopicIamPolicy]: ...
    def __init__(
        self,
        *,
        pubsub_schema: gcp.gcp_pubsub_pb2.PubsubSchema | None = ...,
        pubsub_subscription: collections.abc.Iterable[gcp.gcp_pubsub_pb2.PubsubSubscription] | None = ...,
        pubsub_subscription_iam_binding: collections.abc.Iterable[gcp.gcp_pubsub_pb2.PubsubSubscriptionIamBinding] | None = ...,
        pubsub_subscription_iam_member: collections.abc.Iterable[gcp.gcp_pubsub_pb2.PubsubSubscriptionIamMember] | None = ...,
        pubsub_subscription_iam_policy: collections.abc.Iterable[gcp.gcp_pubsub_pb2.PubsubSubscriptionIamPolicy] | None = ...,
        pubsub_topic: gcp.gcp_pubsub_pb2.PubsubTopic | None = ...,
        pubsub_topic_iam_binding: collections.abc.Iterable[gcp.gcp_pubsub_pb2.PubsubTopicIamBinding] | None = ...,
        pubsub_topic_iam_member: collections.abc.Iterable[gcp.gcp_pubsub_pb2.PubsubTopicIamMember] | None = ...,
        pubsub_topic_iam_policy: collections.abc.Iterable[gcp.gcp_pubsub_pb2.PubsubTopicIamPolicy] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pubsub_schema", b"pubsub_schema", "pubsub_topic", b"pubsub_topic"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["pubsub_schema", b"pubsub_schema", "pubsub_subscription", b"pubsub_subscription", "pubsub_subscription_iam_binding", b"pubsub_subscription_iam_binding", "pubsub_subscription_iam_member", b"pubsub_subscription_iam_member", "pubsub_subscription_iam_policy", b"pubsub_subscription_iam_policy", "pubsub_topic", b"pubsub_topic", "pubsub_topic_iam_binding", b"pubsub_topic_iam_binding", "pubsub_topic_iam_member", b"pubsub_topic_iam_member", "pubsub_topic_iam_policy", b"pubsub_topic_iam_policy"]) -> None: ...

global___GooglePubsub = GooglePubsub
