# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: azure/azure_microsoft_aad.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x61zure/azure_microsoft_aad.proto\x12\x1foak9.tython.azure.microsoft_aad\x1a\x13shared/shared.proto\"Y\n\rMicrosoft_AAD\x12H\n\x0f\x64omain_services\x18\x01 \x03(\x0b\x32/.oak9.tython.azure.microsoft_aad.DomainServices\"\x97\x01\n\x19\x44omainServicesOuContainer\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0c\x61\x63\x63ount_name\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x10\n\x08password\x18\x04 \x01(\t\x12\x0b\n\x03spn\x18\x05 \x01(\t\"\xc2\x06\n\x0e\x44omainServices\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12!\n\x19\x64omain_configuration_type\x18\x05 \x01(\t\x12\x13\n\x0b\x64omain_name\x18\x06 \x01(\t\x12Y\n\x18\x64omain_security_settings\x18\x07 \x01(\x0b\x32\x37.oak9.tython.azure.microsoft_aad.DomainSecuritySettings\x12\x15\n\rfiltered_sync\x18\x08 \x01(\t\x12\x46\n\x0eldaps_settings\x18\t \x01(\x0b\x32..oak9.tython.azure.microsoft_aad.LdapsSettings\x12T\n\x15notification_settings\x18\n \x01(\x0b\x32\x35.oak9.tython.azure.microsoft_aad.NotificationSettings\x12\x41\n\x0creplica_sets\x18\x0b \x03(\x0b\x32+.oak9.tython.azure.microsoft_aad.ReplicaSet\x12Y\n\x18resource_forest_settings\x18\x0c \x01(\x0b\x32\x37.oak9.tython.azure.microsoft_aad.ResourceForestSettings\x12\x0b\n\x03sku\x18\r \x01(\t\x12G\n\x04tags\x18\x0e \x03(\x0b\x32\x39.oak9.tython.azure.microsoft_aad.DomainServices.TagsEntry\x12`\n\x1c\x64omain_services_ou_container\x18\x0f \x03(\x0b\x32:.oak9.tython.azure.microsoft_aad.DomainServicesOuContainer\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"q\n\x16ResourceForestSettings\x12\x17\n\x0fresource_forest\x18\x01 \x01(\t\x12>\n\x08settings\x18\x02 \x03(\x0b\x32,.oak9.tython.azure.microsoft_aad.ForestTrust\"\x8a\x01\n\x0b\x46orestTrust\x12\x15\n\rfriendly_name\x18\x01 \x01(\t\x12\x16\n\x0eremote_dns_ips\x18\x02 \x01(\t\x12\x17\n\x0ftrust_direction\x18\x03 \x01(\t\x12\x1b\n\x13trusted_domain_fqdn\x18\x04 \x01(\t\x12\x16\n\x0etrust_password\x18\x05 \x01(\t\"1\n\nReplicaSet\x12\x10\n\x08location\x18\x01 \x01(\t\x12\x11\n\tsubnet_id\x18\x02 \x01(\t\"m\n\x14NotificationSettings\x12\x1d\n\x15\x61\x64\x64itional_recipients\x18\x01 \x03(\t\x12\x18\n\x10notify_dc_admins\x18\x02 \x01(\t\x12\x1c\n\x14notify_global_admins\x18\x03 \x01(\t\"r\n\rLdapsSettings\x12\x17\n\x0f\x65xternal_access\x18\x01 \x01(\t\x12\r\n\x05ldaps\x18\x02 \x01(\t\x12\x17\n\x0fpfx_certificate\x18\x03 \x01(\t\x12 \n\x18pfx_certificate_password\x18\x04 \x01(\t\"\xd3\x01\n\x16\x44omainSecuritySettings\x12\x19\n\x11kerberos_armoring\x18\x01 \x01(\t\x12\x1f\n\x17kerberos_rc4_encryption\x18\x02 \x01(\t\x12\x0f\n\x07ntlm_v1\x18\x03 \x01(\t\x12\x1f\n\x17sync_kerberos_passwords\x18\x04 \x01(\t\x12\x1b\n\x13sync_ntlm_passwords\x18\x05 \x01(\t\x12\x1e\n\x16sync_on_prem_passwords\x18\x06 \x01(\t\x12\x0e\n\x06tls_v1\x18\x07 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'azure.azure_microsoft_aad_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DOMAINSERVICES_TAGSENTRY._options = None
  _DOMAINSERVICES_TAGSENTRY._serialized_options = b'8\001'
  _MICROSOFT_AAD._serialized_start=89
  _MICROSOFT_AAD._serialized_end=178
  _DOMAINSERVICESOUCONTAINER._serialized_start=181
  _DOMAINSERVICESOUCONTAINER._serialized_end=332
  _DOMAINSERVICES._serialized_start=335
  _DOMAINSERVICES._serialized_end=1169
  _DOMAINSERVICES_TAGSENTRY._serialized_start=1126
  _DOMAINSERVICES_TAGSENTRY._serialized_end=1169
  _RESOURCEFORESTSETTINGS._serialized_start=1171
  _RESOURCEFORESTSETTINGS._serialized_end=1284
  _FORESTTRUST._serialized_start=1287
  _FORESTTRUST._serialized_end=1425
  _REPLICASET._serialized_start=1427
  _REPLICASET._serialized_end=1476
  _NOTIFICATIONSETTINGS._serialized_start=1478
  _NOTIFICATIONSETTINGS._serialized_end=1587
  _LDAPSSETTINGS._serialized_start=1589
  _LDAPSSETTINGS._serialized_end=1703
  _DOMAINSECURITYSETTINGS._serialized_start=1706
  _DOMAINSECURITYSETTINGS._serialized_end=1917
# @@protoc_insertion_point(module_scope)
