"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Microsoft_RecoveryServices_Backup(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VAULTS_BACKUPCONFIG_FIELD_NUMBER: builtins.int
    VAULTS_BACKUP_ENCRYPTION_CONFIGS_FIELD_NUMBER: builtins.int
    VAULTS_BACKUP_FABRICS_BACKUP_PROTECTION_INTENT_FIELD_NUMBER: builtins.int
    VAULTS_BACKUP_FABRICS_PROTECTION_CONTAINERS_FIELD_NUMBER: builtins.int
    VAULTS_BACKUP_POLICIES_FIELD_NUMBER: builtins.int
    VAULTS_BACKUP_RESOURCE_GUARD_PROXIES_FIELD_NUMBER: builtins.int
    VAULTS_BACKUPSTORAGECONFIG_FIELD_NUMBER: builtins.int
    VAULTS_PRIVATE_ENDPOINT_CONNECTIONS_FIELD_NUMBER: builtins.int
    @property
    def vaults_backupconfig(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VaultsBackupconfig]: ...
    @property
    def vaults_backup_encryption_configs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VaultsBackupEncryptionConfigs]: ...
    @property
    def vaults_backup_fabrics_backup_protection_intent(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VaultsBackupFabricsBackupProtectionIntent]: ...
    @property
    def vaults_backup_fabrics_protection_containers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VaultsBackupFabricsProtectionContainers]: ...
    @property
    def vaults_backup_policies(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VaultsBackupPolicies]: ...
    @property
    def vaults_backup_resource_guard_proxies(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VaultsBackupResourceGuardProxies]: ...
    @property
    def vaults_backupstorageconfig(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VaultsBackupstorageconfig]: ...
    @property
    def vaults_private_endpoint_connections(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VaultsPrivateEndpointConnections]: ...
    def __init__(
        self,
        *,
        vaults_backupconfig: collections.abc.Iterable[global___VaultsBackupconfig] | None = ...,
        vaults_backup_encryption_configs: collections.abc.Iterable[global___VaultsBackupEncryptionConfigs] | None = ...,
        vaults_backup_fabrics_backup_protection_intent: collections.abc.Iterable[global___VaultsBackupFabricsBackupProtectionIntent] | None = ...,
        vaults_backup_fabrics_protection_containers: collections.abc.Iterable[global___VaultsBackupFabricsProtectionContainers] | None = ...,
        vaults_backup_policies: collections.abc.Iterable[global___VaultsBackupPolicies] | None = ...,
        vaults_backup_resource_guard_proxies: collections.abc.Iterable[global___VaultsBackupResourceGuardProxies] | None = ...,
        vaults_backupstorageconfig: collections.abc.Iterable[global___VaultsBackupstorageconfig] | None = ...,
        vaults_private_endpoint_connections: collections.abc.Iterable[global___VaultsPrivateEndpointConnections] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["vaults_backup_encryption_configs", b"vaults_backup_encryption_configs", "vaults_backup_fabrics_backup_protection_intent", b"vaults_backup_fabrics_backup_protection_intent", "vaults_backup_fabrics_protection_containers", b"vaults_backup_fabrics_protection_containers", "vaults_backup_policies", b"vaults_backup_policies", "vaults_backup_resource_guard_proxies", b"vaults_backup_resource_guard_proxies", "vaults_backupconfig", b"vaults_backupconfig", "vaults_backupstorageconfig", b"vaults_backupstorageconfig", "vaults_private_endpoint_connections", b"vaults_private_endpoint_connections"]) -> None: ...

global___Microsoft_RecoveryServices_Backup = Microsoft_RecoveryServices_Backup

@typing_extensions.final
class VaultsPrivateEndpointConnections(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    E_TAG_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PRIVATE_ENDPOINT_FIELD_NUMBER: builtins.int
    PRIVATE_LINK_SERVICE_CONNECTION_STATE_FIELD_NUMBER: builtins.int
    PROVISIONING_STATE_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    e_tag: builtins.str
    location: builtins.str
    name: builtins.str
    @property
    def private_endpoint(self) -> global___PrivateEndpoint: ...
    @property
    def private_link_service_connection_state(self) -> global___PrivateLinkServiceConnectionState: ...
    provisioning_state: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        e_tag: builtins.str = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        private_endpoint: global___PrivateEndpoint | None = ...,
        private_link_service_connection_state: global___PrivateLinkServiceConnectionState | None = ...,
        provisioning_state: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["private_endpoint", b"private_endpoint", "private_link_service_connection_state", b"private_link_service_connection_state", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["e_tag", b"e_tag", "location", b"location", "name", b"name", "private_endpoint", b"private_endpoint", "private_link_service_connection_state", b"private_link_service_connection_state", "provisioning_state", b"provisioning_state", "resource_info", b"resource_info", "tags", b"tags"]) -> None: ...

global___VaultsPrivateEndpointConnections = VaultsPrivateEndpointConnections

@typing_extensions.final
class PrivateLinkServiceConnectionState(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACTION_REQUIRED_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    action_required: builtins.str
    description: builtins.str
    status: builtins.str
    def __init__(
        self,
        *,
        action_required: builtins.str = ...,
        description: builtins.str = ...,
        status: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["action_required", b"action_required", "description", b"description", "status", b"status"]) -> None: ...

global___PrivateLinkServiceConnectionState = PrivateLinkServiceConnectionState

@typing_extensions.final
class PrivateEndpoint(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    def __init__(
        self,
        *,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id"]) -> None: ...

global___PrivateEndpoint = PrivateEndpoint

@typing_extensions.final
class VaultsBackupstorageconfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    E_TAG_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    CROSS_REGION_RESTORE_FLAG_FIELD_NUMBER: builtins.int
    DEDUP_STATE_FIELD_NUMBER: builtins.int
    STORAGE_MODEL_TYPE_FIELD_NUMBER: builtins.int
    STORAGE_TYPE_FIELD_NUMBER: builtins.int
    STORAGE_TYPE_STATE_FIELD_NUMBER: builtins.int
    XCOOL_STATE_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    e_tag: builtins.str
    location: builtins.str
    name: builtins.str
    cross_region_restore_flag: builtins.bool
    dedup_state: builtins.str
    storage_model_type: builtins.str
    storage_type: builtins.str
    storage_type_state: builtins.str
    xcool_state: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        e_tag: builtins.str = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        cross_region_restore_flag: builtins.bool = ...,
        dedup_state: builtins.str = ...,
        storage_model_type: builtins.str = ...,
        storage_type: builtins.str = ...,
        storage_type_state: builtins.str = ...,
        xcool_state: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cross_region_restore_flag", b"cross_region_restore_flag", "dedup_state", b"dedup_state", "e_tag", b"e_tag", "location", b"location", "name", b"name", "resource_info", b"resource_info", "storage_model_type", b"storage_model_type", "storage_type", b"storage_type", "storage_type_state", b"storage_type_state", "tags", b"tags", "xcool_state", b"xcool_state"]) -> None: ...

global___VaultsBackupstorageconfig = VaultsBackupstorageconfig

@typing_extensions.final
class VaultsBackupResourceGuardProxies(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___VaultsBackupResourceGuardProxies = VaultsBackupResourceGuardProxies

@typing_extensions.final
class VaultsBackupPolicies(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    E_TAG_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROTECTED_ITEMS_COUNT_FIELD_NUMBER: builtins.int
    RESOURCE_GUARD_OPERATION_REQUESTS_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    e_tag: builtins.str
    location: builtins.str
    name: builtins.str
    protected_items_count: builtins.int
    @property
    def resource_guard_operation_requests(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        e_tag: builtins.str = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        protected_items_count: builtins.int = ...,
        resource_guard_operation_requests: collections.abc.Iterable[builtins.str] | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["e_tag", b"e_tag", "location", b"location", "name", b"name", "protected_items_count", b"protected_items_count", "resource_guard_operation_requests", b"resource_guard_operation_requests", "resource_info", b"resource_info", "tags", b"tags"]) -> None: ...

global___VaultsBackupPolicies = VaultsBackupPolicies

@typing_extensions.final
class VaultsBackupFabricsProtectionContainersProtectedItems(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    E_TAG_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    BACKUP_MANAGEMENT_TYPE_FIELD_NUMBER: builtins.int
    BACKUP_SET_NAME_FIELD_NUMBER: builtins.int
    CONTAINER_NAME_FIELD_NUMBER: builtins.int
    CREATE_MODE_FIELD_NUMBER: builtins.int
    DEFERRED_DELETE_TIME_IN_U_T_C_FIELD_NUMBER: builtins.int
    DEFERRED_DELETE_TIME_REMAINING_FIELD_NUMBER: builtins.int
    IS_ARCHIVE_ENABLED_FIELD_NUMBER: builtins.int
    IS_DEFERRED_DELETE_SCHEDULE_UPCOMING_FIELD_NUMBER: builtins.int
    IS_REHYDRATE_FIELD_NUMBER: builtins.int
    IS_SCHEDULED_FOR_DEFERRED_DELETE_FIELD_NUMBER: builtins.int
    LAST_RECOVERY_POINT_FIELD_NUMBER: builtins.int
    POLICY_ID_FIELD_NUMBER: builtins.int
    POLICY_NAME_FIELD_NUMBER: builtins.int
    RESOURCE_GUARD_OPERATION_REQUESTS_FIELD_NUMBER: builtins.int
    SOURCE_RESOURCE_ID_FIELD_NUMBER: builtins.int
    WORKLOAD_TYPE_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    e_tag: builtins.str
    location: builtins.str
    name: builtins.str
    backup_management_type: builtins.str
    backup_set_name: builtins.str
    container_name: builtins.str
    create_mode: builtins.str
    deferred_delete_time_in_u_t_c: builtins.str
    deferred_delete_time_remaining: builtins.str
    is_archive_enabled: builtins.bool
    is_deferred_delete_schedule_upcoming: builtins.bool
    is_rehydrate: builtins.bool
    is_scheduled_for_deferred_delete: builtins.bool
    last_recovery_point: builtins.str
    policy_id: builtins.str
    policy_name: builtins.str
    @property
    def resource_guard_operation_requests(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    source_resource_id: builtins.str
    workload_type: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        e_tag: builtins.str = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        backup_management_type: builtins.str = ...,
        backup_set_name: builtins.str = ...,
        container_name: builtins.str = ...,
        create_mode: builtins.str = ...,
        deferred_delete_time_in_u_t_c: builtins.str = ...,
        deferred_delete_time_remaining: builtins.str = ...,
        is_archive_enabled: builtins.bool = ...,
        is_deferred_delete_schedule_upcoming: builtins.bool = ...,
        is_rehydrate: builtins.bool = ...,
        is_scheduled_for_deferred_delete: builtins.bool = ...,
        last_recovery_point: builtins.str = ...,
        policy_id: builtins.str = ...,
        policy_name: builtins.str = ...,
        resource_guard_operation_requests: collections.abc.Iterable[builtins.str] | None = ...,
        source_resource_id: builtins.str = ...,
        workload_type: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["backup_management_type", b"backup_management_type", "backup_set_name", b"backup_set_name", "container_name", b"container_name", "create_mode", b"create_mode", "deferred_delete_time_in_u_t_c", b"deferred_delete_time_in_u_t_c", "deferred_delete_time_remaining", b"deferred_delete_time_remaining", "e_tag", b"e_tag", "is_archive_enabled", b"is_archive_enabled", "is_deferred_delete_schedule_upcoming", b"is_deferred_delete_schedule_upcoming", "is_rehydrate", b"is_rehydrate", "is_scheduled_for_deferred_delete", b"is_scheduled_for_deferred_delete", "last_recovery_point", b"last_recovery_point", "location", b"location", "name", b"name", "policy_id", b"policy_id", "policy_name", b"policy_name", "resource_guard_operation_requests", b"resource_guard_operation_requests", "resource_info", b"resource_info", "source_resource_id", b"source_resource_id", "tags", b"tags", "workload_type", b"workload_type"]) -> None: ...

global___VaultsBackupFabricsProtectionContainersProtectedItems = VaultsBackupFabricsProtectionContainersProtectedItems

@typing_extensions.final
class VaultsBackupFabricsProtectionContainers(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    E_TAG_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    BACKUP_MANAGEMENT_TYPE_FIELD_NUMBER: builtins.int
    FRIENDLY_NAME_FIELD_NUMBER: builtins.int
    HEALTH_STATUS_FIELD_NUMBER: builtins.int
    PROTECTABLE_OBJECT_TYPE_FIELD_NUMBER: builtins.int
    REGISTRATION_STATUS_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    VAULTS_BACKUP_FABRICS_PROTECTION_CONTAINERS_PROTECTED_ITEMS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    e_tag: builtins.str
    location: builtins.str
    name: builtins.str
    backup_management_type: builtins.str
    friendly_name: builtins.str
    health_status: builtins.str
    protectable_object_type: builtins.str
    registration_status: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def vaults_backup_fabrics_protection_containers_protected_items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VaultsBackupFabricsProtectionContainersProtectedItems]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        e_tag: builtins.str = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        backup_management_type: builtins.str = ...,
        friendly_name: builtins.str = ...,
        health_status: builtins.str = ...,
        protectable_object_type: builtins.str = ...,
        registration_status: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        vaults_backup_fabrics_protection_containers_protected_items: collections.abc.Iterable[global___VaultsBackupFabricsProtectionContainersProtectedItems] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["backup_management_type", b"backup_management_type", "e_tag", b"e_tag", "friendly_name", b"friendly_name", "health_status", b"health_status", "location", b"location", "name", b"name", "protectable_object_type", b"protectable_object_type", "registration_status", b"registration_status", "resource_info", b"resource_info", "tags", b"tags", "vaults_backup_fabrics_protection_containers_protected_items", b"vaults_backup_fabrics_protection_containers_protected_items"]) -> None: ...

global___VaultsBackupFabricsProtectionContainers = VaultsBackupFabricsProtectionContainers

@typing_extensions.final
class VaultsBackupFabricsBackupProtectionIntent(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    E_TAG_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    BACKUP_MANAGEMENT_TYPE_FIELD_NUMBER: builtins.int
    ITEM_ID_FIELD_NUMBER: builtins.int
    POLICY_ID_FIELD_NUMBER: builtins.int
    PROTECTION_STATE_FIELD_NUMBER: builtins.int
    SOURCE_RESOURCE_ID_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    e_tag: builtins.str
    location: builtins.str
    name: builtins.str
    backup_management_type: builtins.str
    item_id: builtins.str
    policy_id: builtins.str
    protection_state: builtins.str
    source_resource_id: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        e_tag: builtins.str = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        backup_management_type: builtins.str = ...,
        item_id: builtins.str = ...,
        policy_id: builtins.str = ...,
        protection_state: builtins.str = ...,
        source_resource_id: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["backup_management_type", b"backup_management_type", "e_tag", b"e_tag", "item_id", b"item_id", "location", b"location", "name", b"name", "policy_id", b"policy_id", "protection_state", b"protection_state", "resource_info", b"resource_info", "source_resource_id", b"source_resource_id", "tags", b"tags"]) -> None: ...

global___VaultsBackupFabricsBackupProtectionIntent = VaultsBackupFabricsBackupProtectionIntent

@typing_extensions.final
class VaultsBackupEncryptionConfigs(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    E_TAG_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ENCRYPTION_AT_REST_TYPE_FIELD_NUMBER: builtins.int
    INFRASTRUCTURE_ENCRYPTION_STATE_FIELD_NUMBER: builtins.int
    KEY_URI_FIELD_NUMBER: builtins.int
    LAST_UPDATE_STATUS_FIELD_NUMBER: builtins.int
    SUBSCRIPTION_ID_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    e_tag: builtins.str
    location: builtins.str
    name: builtins.str
    encryption_at_rest_type: builtins.str
    infrastructure_encryption_state: builtins.str
    key_uri: builtins.str
    last_update_status: builtins.str
    subscription_id: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        e_tag: builtins.str = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        encryption_at_rest_type: builtins.str = ...,
        infrastructure_encryption_state: builtins.str = ...,
        key_uri: builtins.str = ...,
        last_update_status: builtins.str = ...,
        subscription_id: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["e_tag", b"e_tag", "encryption_at_rest_type", b"encryption_at_rest_type", "infrastructure_encryption_state", b"infrastructure_encryption_state", "key_uri", b"key_uri", "last_update_status", b"last_update_status", "location", b"location", "name", b"name", "resource_info", b"resource_info", "subscription_id", b"subscription_id", "tags", b"tags"]) -> None: ...

global___VaultsBackupEncryptionConfigs = VaultsBackupEncryptionConfigs

@typing_extensions.final
class VaultsBackupconfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    E_TAG_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ENHANCED_SECURITY_STATE_FIELD_NUMBER: builtins.int
    IS_SOFT_DELETE_FEATURE_STATE_EDITABLE_FIELD_NUMBER: builtins.int
    RESOURCE_GUARD_OPERATION_REQUESTS_FIELD_NUMBER: builtins.int
    SOFT_DELETE_FEATURE_STATE_FIELD_NUMBER: builtins.int
    STORAGE_MODEL_TYPE_FIELD_NUMBER: builtins.int
    STORAGE_TYPE_FIELD_NUMBER: builtins.int
    STORAGE_TYPE_STATE_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    e_tag: builtins.str
    location: builtins.str
    name: builtins.str
    enhanced_security_state: builtins.str
    is_soft_delete_feature_state_editable: builtins.bool
    @property
    def resource_guard_operation_requests(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    soft_delete_feature_state: builtins.str
    storage_model_type: builtins.str
    storage_type: builtins.str
    storage_type_state: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        e_tag: builtins.str = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        enhanced_security_state: builtins.str = ...,
        is_soft_delete_feature_state_editable: builtins.bool = ...,
        resource_guard_operation_requests: collections.abc.Iterable[builtins.str] | None = ...,
        soft_delete_feature_state: builtins.str = ...,
        storage_model_type: builtins.str = ...,
        storage_type: builtins.str = ...,
        storage_type_state: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["e_tag", b"e_tag", "enhanced_security_state", b"enhanced_security_state", "is_soft_delete_feature_state_editable", b"is_soft_delete_feature_state_editable", "location", b"location", "name", b"name", "resource_guard_operation_requests", b"resource_guard_operation_requests", "resource_info", b"resource_info", "soft_delete_feature_state", b"soft_delete_feature_state", "storage_model_type", b"storage_model_type", "storage_type", b"storage_type", "storage_type_state", b"storage_type_state", "tags", b"tags"]) -> None: ...

global___VaultsBackupconfig = VaultsBackupconfig
