"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Info(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUILD_DATE_FIELD_NUMBER: builtins.int
    COMPILER_FIELD_NUMBER: builtins.int
    GIT_COMMIT_FIELD_NUMBER: builtins.int
    GIT_TREE_STATE_FIELD_NUMBER: builtins.int
    GIT_VERSION_FIELD_NUMBER: builtins.int
    GO_VERSION_FIELD_NUMBER: builtins.int
    MAJOR_FIELD_NUMBER: builtins.int
    MINOR_FIELD_NUMBER: builtins.int
    PLATFORM_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    build_date: builtins.str
    compiler: builtins.str
    git_commit: builtins.str
    git_tree_state: builtins.str
    git_version: builtins.str
    go_version: builtins.str
    major: builtins.str
    minor: builtins.str
    platform: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        build_date: builtins.str = ...,
        compiler: builtins.str = ...,
        git_commit: builtins.str = ...,
        git_tree_state: builtins.str = ...,
        git_version: builtins.str = ...,
        go_version: builtins.str = ...,
        major: builtins.str = ...,
        minor: builtins.str = ...,
        platform: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["build_date", b"build_date", "compiler", b"compiler", "git_commit", b"git_commit", "git_tree_state", b"git_tree_state", "git_version", b"git_version", "go_version", b"go_version", "major", b"major", "minor", b"minor", "platform", b"platform", "resource_info", b"resource_info"]) -> None: ...

global___Info = Info
