"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Microsoft_Sql_Servers(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERVERS_FIELD_NUMBER: builtins.int
    SERVERS_ADMINISTRATORS_FIELD_NUMBER: builtins.int
    SERVERS_AUDITING_SETTINGS_FIELD_NUMBER: builtins.int
    SERVERS_ELASTIC_POOLS_FIELD_NUMBER: builtins.int
    SERVERS_ENCRYPTION_PROTECTOR_FIELD_NUMBER: builtins.int
    SERVERS_EXTENDED_AUDITING_SETTINGS_FIELD_NUMBER: builtins.int
    SERVERS_FAILOVER_GROUPS_FIELD_NUMBER: builtins.int
    SERVERS_FIREWALL_RULES_FIELD_NUMBER: builtins.int
    SERVERS_JOB_AGENTS_FIELD_NUMBER: builtins.int
    SERVERS_JOB_AGENTS_CREDENTIALS_FIELD_NUMBER: builtins.int
    SERVERS_KEYS_FIELD_NUMBER: builtins.int
    SERVERS_PRIVATE_ENDPOINT_CONNECTIONS_FIELD_NUMBER: builtins.int
    SERVERS_SECURITY_ALERT_POLICIES_FIELD_NUMBER: builtins.int
    SERVERS_VIRTUAL_NETWORK_RULES_FIELD_NUMBER: builtins.int
    SERVERS_VULNERABILITY_ASSESSMENTS_FIELD_NUMBER: builtins.int
    @property
    def servers(self) -> global___Servers: ...
    @property
    def servers_administrators(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServersAdministrators]: ...
    @property
    def servers_auditing_settings(self) -> global___ServersAuditingSettings: ...
    @property
    def servers_elastic_pools(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServersElasticPools]: ...
    @property
    def servers_encryption_protector(self) -> global___ServersEncryptionProtector: ...
    @property
    def servers_extended_auditing_settings(self) -> global___ServersExtendedAuditingSettings: ...
    @property
    def servers_failover_groups(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServersFailoverGroups]: ...
    @property
    def servers_firewall_rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServersFirewallRules]: ...
    @property
    def servers_job_agents(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServersJobAgents]: ...
    @property
    def servers_job_agents_credentials(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServersJobAgentsCredentials]: ...
    @property
    def servers_keys(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServersKeys]: ...
    @property
    def servers_private_endpoint_connections(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServersPrivateEndpointConnections]: ...
    @property
    def servers_security_alert_policies(self) -> global___ServersSecurityAlertPolicies: ...
    @property
    def servers_virtual_network_rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServersVirtualNetworkRules]: ...
    @property
    def servers_vulnerability_assessments(self) -> global___ServersVulnerabilityAssessments: ...
    def __init__(
        self,
        *,
        servers: global___Servers | None = ...,
        servers_administrators: collections.abc.Iterable[global___ServersAdministrators] | None = ...,
        servers_auditing_settings: global___ServersAuditingSettings | None = ...,
        servers_elastic_pools: collections.abc.Iterable[global___ServersElasticPools] | None = ...,
        servers_encryption_protector: global___ServersEncryptionProtector | None = ...,
        servers_extended_auditing_settings: global___ServersExtendedAuditingSettings | None = ...,
        servers_failover_groups: collections.abc.Iterable[global___ServersFailoverGroups] | None = ...,
        servers_firewall_rules: collections.abc.Iterable[global___ServersFirewallRules] | None = ...,
        servers_job_agents: collections.abc.Iterable[global___ServersJobAgents] | None = ...,
        servers_job_agents_credentials: collections.abc.Iterable[global___ServersJobAgentsCredentials] | None = ...,
        servers_keys: collections.abc.Iterable[global___ServersKeys] | None = ...,
        servers_private_endpoint_connections: collections.abc.Iterable[global___ServersPrivateEndpointConnections] | None = ...,
        servers_security_alert_policies: global___ServersSecurityAlertPolicies | None = ...,
        servers_virtual_network_rules: collections.abc.Iterable[global___ServersVirtualNetworkRules] | None = ...,
        servers_vulnerability_assessments: global___ServersVulnerabilityAssessments | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["servers", b"servers", "servers_auditing_settings", b"servers_auditing_settings", "servers_encryption_protector", b"servers_encryption_protector", "servers_extended_auditing_settings", b"servers_extended_auditing_settings", "servers_security_alert_policies", b"servers_security_alert_policies", "servers_vulnerability_assessments", b"servers_vulnerability_assessments"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["servers", b"servers", "servers_administrators", b"servers_administrators", "servers_auditing_settings", b"servers_auditing_settings", "servers_elastic_pools", b"servers_elastic_pools", "servers_encryption_protector", b"servers_encryption_protector", "servers_extended_auditing_settings", b"servers_extended_auditing_settings", "servers_failover_groups", b"servers_failover_groups", "servers_firewall_rules", b"servers_firewall_rules", "servers_job_agents", b"servers_job_agents", "servers_job_agents_credentials", b"servers_job_agents_credentials", "servers_keys", b"servers_keys", "servers_private_endpoint_connections", b"servers_private_endpoint_connections", "servers_security_alert_policies", b"servers_security_alert_policies", "servers_virtual_network_rules", b"servers_virtual_network_rules", "servers_vulnerability_assessments", b"servers_vulnerability_assessments"]) -> None: ...

global___Microsoft_Sql_Servers = Microsoft_Sql_Servers

@typing_extensions.final
class ServersVulnerabilityAssessments(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    RECURRING_SCANS_FIELD_NUMBER: builtins.int
    STORAGE_ACCOUNT_ACCESS_KEY_FIELD_NUMBER: builtins.int
    STORAGE_CONTAINER_PATH_FIELD_NUMBER: builtins.int
    STORAGE_CONTAINER_SAS_KEY_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def recurring_scans(self) -> global___VulnerabilityAssessmentRecurringScansProperties: ...
    storage_account_access_key: builtins.str
    storage_container_path: builtins.str
    storage_container_sas_key: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        recurring_scans: global___VulnerabilityAssessmentRecurringScansProperties | None = ...,
        storage_account_access_key: builtins.str = ...,
        storage_container_path: builtins.str = ...,
        storage_container_sas_key: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["recurring_scans", b"recurring_scans", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "recurring_scans", b"recurring_scans", "resource_info", b"resource_info", "storage_account_access_key", b"storage_account_access_key", "storage_container_path", b"storage_container_path", "storage_container_sas_key", b"storage_container_sas_key"]) -> None: ...

global___ServersVulnerabilityAssessments = ServersVulnerabilityAssessments

@typing_extensions.final
class VulnerabilityAssessmentRecurringScansProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMAILS_FIELD_NUMBER: builtins.int
    EMAIL_SUBSCRIPTION_ADMINS_FIELD_NUMBER: builtins.int
    IS_ENABLED_FIELD_NUMBER: builtins.int
    @property
    def emails(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    email_subscription_admins: builtins.bool
    is_enabled: builtins.bool
    def __init__(
        self,
        *,
        emails: collections.abc.Iterable[builtins.str] | None = ...,
        email_subscription_admins: builtins.bool = ...,
        is_enabled: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["email_subscription_admins", b"email_subscription_admins", "emails", b"emails", "is_enabled", b"is_enabled"]) -> None: ...

global___VulnerabilityAssessmentRecurringScansProperties = VulnerabilityAssessmentRecurringScansProperties

@typing_extensions.final
class ServersVirtualNetworkRules(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    IGNORE_MISSING_VNET_SERVICE_ENDPOINT_FIELD_NUMBER: builtins.int
    VIRTUAL_NETWORK_SUBNET_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    ignore_missing_vnet_service_endpoint: builtins.bool
    virtual_network_subnet_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        ignore_missing_vnet_service_endpoint: builtins.bool = ...,
        virtual_network_subnet_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ignore_missing_vnet_service_endpoint", b"ignore_missing_vnet_service_endpoint", "name", b"name", "resource_info", b"resource_info", "virtual_network_subnet_id", b"virtual_network_subnet_id"]) -> None: ...

global___ServersVirtualNetworkRules = ServersVirtualNetworkRules

@typing_extensions.final
class ServersSyncAgents(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    SYNC_DATABASE_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    sync_database_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        sync_database_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info", "sync_database_id", b"sync_database_id"]) -> None: ...

global___ServersSyncAgents = ServersSyncAgents

@typing_extensions.final
class ServersSecurityAlertPolicies(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DISABLED_ALERTS_FIELD_NUMBER: builtins.int
    EMAIL_ACCOUNT_ADMINS_FIELD_NUMBER: builtins.int
    EMAIL_ADDRESSES_FIELD_NUMBER: builtins.int
    RETENTION_DAYS_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    STORAGE_ACCOUNT_ACCESS_KEY_FIELD_NUMBER: builtins.int
    STORAGE_ENDPOINT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def disabled_alerts(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    email_account_admins: builtins.bool
    @property
    def email_addresses(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    retention_days: builtins.int
    state: builtins.str
    storage_account_access_key: builtins.str
    storage_endpoint: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        disabled_alerts: collections.abc.Iterable[builtins.str] | None = ...,
        email_account_admins: builtins.bool = ...,
        email_addresses: collections.abc.Iterable[builtins.str] | None = ...,
        retention_days: builtins.int = ...,
        state: builtins.str = ...,
        storage_account_access_key: builtins.str = ...,
        storage_endpoint: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["disabled_alerts", b"disabled_alerts", "email_account_admins", b"email_account_admins", "email_addresses", b"email_addresses", "name", b"name", "resource_info", b"resource_info", "retention_days", b"retention_days", "state", b"state", "storage_account_access_key", b"storage_account_access_key", "storage_endpoint", b"storage_endpoint"]) -> None: ...

global___ServersSecurityAlertPolicies = ServersSecurityAlertPolicies

@typing_extensions.final
class ServersPrivateEndpointConnections(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PRIVATE_ENDPOINT_FIELD_NUMBER: builtins.int
    PRIVATE_LINK_SERVICE_CONNECTION_STATE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def private_endpoint(self) -> global___PrivateEndpointProperty: ...
    @property
    def private_link_service_connection_state(self) -> global___PrivateLinkServiceConnectionStateProperty: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        private_endpoint: global___PrivateEndpointProperty | None = ...,
        private_link_service_connection_state: global___PrivateLinkServiceConnectionStateProperty | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["private_endpoint", b"private_endpoint", "private_link_service_connection_state", b"private_link_service_connection_state", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "private_endpoint", b"private_endpoint", "private_link_service_connection_state", b"private_link_service_connection_state", "resource_info", b"resource_info"]) -> None: ...

global___ServersPrivateEndpointConnections = ServersPrivateEndpointConnections

@typing_extensions.final
class PrivateLinkServiceConnectionStateProperty(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    description: builtins.str
    status: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        status: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "status", b"status"]) -> None: ...

global___PrivateLinkServiceConnectionStateProperty = PrivateLinkServiceConnectionStateProperty

@typing_extensions.final
class PrivateEndpointProperty(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    def __init__(
        self,
        *,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id"]) -> None: ...

global___PrivateEndpointProperty = PrivateEndpointProperty

@typing_extensions.final
class ServersOutboundFirewallRules(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___ServersOutboundFirewallRules = ServersOutboundFirewallRules

@typing_extensions.final
class ServersKeys(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    SERVER_KEY_TYPE_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    THUMBPRINT_FIELD_NUMBER: builtins.int
    CREATION_DATE_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    server_key_type: builtins.str
    uri: builtins.str
    thumbprint: builtins.str
    creation_date: builtins.str
    kind: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        server_key_type: builtins.str = ...,
        uri: builtins.str = ...,
        thumbprint: builtins.str = ...,
        creation_date: builtins.str = ...,
        kind: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["creation_date", b"creation_date", "kind", b"kind", "name", b"name", "resource_info", b"resource_info", "server_key_type", b"server_key_type", "thumbprint", b"thumbprint", "uri", b"uri"]) -> None: ...

global___ServersKeys = ServersKeys

@typing_extensions.final
class ServersJobAgentsTargetGroups(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    MEMBERS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def members(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___JobTarget]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        members: collections.abc.Iterable[global___JobTarget] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["members", b"members", "name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___ServersJobAgentsTargetGroups = ServersJobAgentsTargetGroups

@typing_extensions.final
class JobTarget(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATABASE_NAME_FIELD_NUMBER: builtins.int
    ELASTIC_POOL_NAME_FIELD_NUMBER: builtins.int
    MEMBERSHIP_TYPE_FIELD_NUMBER: builtins.int
    REFRESH_CREDENTIAL_FIELD_NUMBER: builtins.int
    SERVER_NAME_FIELD_NUMBER: builtins.int
    SHARD_MAP_NAME_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    database_name: builtins.str
    elastic_pool_name: builtins.str
    membership_type: builtins.str
    refresh_credential: builtins.str
    server_name: builtins.str
    shard_map_name: builtins.str
    type: builtins.str
    def __init__(
        self,
        *,
        database_name: builtins.str = ...,
        elastic_pool_name: builtins.str = ...,
        membership_type: builtins.str = ...,
        refresh_credential: builtins.str = ...,
        server_name: builtins.str = ...,
        shard_map_name: builtins.str = ...,
        type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["database_name", b"database_name", "elastic_pool_name", b"elastic_pool_name", "membership_type", b"membership_type", "refresh_credential", b"refresh_credential", "server_name", b"server_name", "shard_map_name", b"shard_map_name", "type", b"type"]) -> None: ...

global___JobTarget = JobTarget

@typing_extensions.final
class ServersJobAgentsJobsSteps(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ACTION_FIELD_NUMBER: builtins.int
    CREDENTIAL_FIELD_NUMBER: builtins.int
    EXECUTION_OPTIONS_FIELD_NUMBER: builtins.int
    OUTPUT_FIELD_NUMBER: builtins.int
    STEP_ID_FIELD_NUMBER: builtins.int
    TARGET_GROUP_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def action(self) -> global___JobStepAction: ...
    credential: builtins.str
    @property
    def execution_options(self) -> global___JobStepExecutionOptions: ...
    @property
    def output(self) -> global___JobStepOutput: ...
    step_id: builtins.int
    target_group: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        action: global___JobStepAction | None = ...,
        credential: builtins.str = ...,
        execution_options: global___JobStepExecutionOptions | None = ...,
        output: global___JobStepOutput | None = ...,
        step_id: builtins.int = ...,
        target_group: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["action", b"action", "execution_options", b"execution_options", "output", b"output", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["action", b"action", "credential", b"credential", "execution_options", b"execution_options", "name", b"name", "output", b"output", "resource_info", b"resource_info", "step_id", b"step_id", "target_group", b"target_group"]) -> None: ...

global___ServersJobAgentsJobsSteps = ServersJobAgentsJobsSteps

@typing_extensions.final
class JobStepOutput(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREDENTIAL_FIELD_NUMBER: builtins.int
    DATABASE_NAME_FIELD_NUMBER: builtins.int
    RESOURCE_GROUP_NAME_FIELD_NUMBER: builtins.int
    SCHEMA_NAME_FIELD_NUMBER: builtins.int
    SERVER_NAME_FIELD_NUMBER: builtins.int
    SUBSCRIPTION_ID_FIELD_NUMBER: builtins.int
    TABLE_NAME_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    credential: builtins.str
    database_name: builtins.str
    resource_group_name: builtins.str
    schema_name: builtins.str
    server_name: builtins.str
    subscription_id: builtins.str
    table_name: builtins.str
    type: builtins.str
    def __init__(
        self,
        *,
        credential: builtins.str = ...,
        database_name: builtins.str = ...,
        resource_group_name: builtins.str = ...,
        schema_name: builtins.str = ...,
        server_name: builtins.str = ...,
        subscription_id: builtins.str = ...,
        table_name: builtins.str = ...,
        type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["credential", b"credential", "database_name", b"database_name", "resource_group_name", b"resource_group_name", "schema_name", b"schema_name", "server_name", b"server_name", "subscription_id", b"subscription_id", "table_name", b"table_name", "type", b"type"]) -> None: ...

global___JobStepOutput = JobStepOutput

@typing_extensions.final
class JobStepExecutionOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INITIAL_RETRY_INTERVAL_SECONDS_FIELD_NUMBER: builtins.int
    MAXIMUM_RETRY_INTERVAL_SECONDS_FIELD_NUMBER: builtins.int
    RETRY_ATTEMPTS_FIELD_NUMBER: builtins.int
    RETRY_INTERVAL_BACKOFF_MULTIPLIER_FIELD_NUMBER: builtins.int
    TIMEOUT_SECONDS_FIELD_NUMBER: builtins.int
    initial_retry_interval_seconds: builtins.int
    maximum_retry_interval_seconds: builtins.int
    retry_attempts: builtins.int
    retry_interval_backoff_multiplier: builtins.float
    timeout_seconds: builtins.int
    def __init__(
        self,
        *,
        initial_retry_interval_seconds: builtins.int = ...,
        maximum_retry_interval_seconds: builtins.int = ...,
        retry_attempts: builtins.int = ...,
        retry_interval_backoff_multiplier: builtins.float = ...,
        timeout_seconds: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["initial_retry_interval_seconds", b"initial_retry_interval_seconds", "maximum_retry_interval_seconds", b"maximum_retry_interval_seconds", "retry_attempts", b"retry_attempts", "retry_interval_backoff_multiplier", b"retry_interval_backoff_multiplier", "timeout_seconds", b"timeout_seconds"]) -> None: ...

global___JobStepExecutionOptions = JobStepExecutionOptions

@typing_extensions.final
class JobStepAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SOURCE_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    source: builtins.str
    type: builtins.str
    value: builtins.str
    def __init__(
        self,
        *,
        source: builtins.str = ...,
        type: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["source", b"source", "type", b"type", "value", b"value"]) -> None: ...

global___JobStepAction = JobStepAction

@typing_extensions.final
class ServersJobAgentsJobsExecutions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___ServersJobAgentsJobsExecutions = ServersJobAgentsJobsExecutions

@typing_extensions.final
class ServersJobAgentsJobs(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    SCHEDULE_FIELD_NUMBER: builtins.int
    SERVERS_JOB_AGENTS_JOBS_EXECUTIONS_FIELD_NUMBER: builtins.int
    SERVERS_JOB_AGENTS_JOBS_STEPS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    description: builtins.str
    @property
    def schedule(self) -> global___JobSchedule: ...
    @property
    def servers_job_agents_jobs_executions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServersJobAgentsJobsExecutions]: ...
    @property
    def servers_job_agents_jobs_steps(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServersJobAgentsJobsSteps]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        schedule: global___JobSchedule | None = ...,
        servers_job_agents_jobs_executions: collections.abc.Iterable[global___ServersJobAgentsJobsExecutions] | None = ...,
        servers_job_agents_jobs_steps: collections.abc.Iterable[global___ServersJobAgentsJobsSteps] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "schedule", b"schedule"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "name", b"name", "resource_info", b"resource_info", "schedule", b"schedule", "servers_job_agents_jobs_executions", b"servers_job_agents_jobs_executions", "servers_job_agents_jobs_steps", b"servers_job_agents_jobs_steps"]) -> None: ...

global___ServersJobAgentsJobs = ServersJobAgentsJobs

@typing_extensions.final
class JobSchedule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLED_FIELD_NUMBER: builtins.int
    END_TIME_FIELD_NUMBER: builtins.int
    INTERVAL_FIELD_NUMBER: builtins.int
    START_TIME_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    enabled: builtins.bool
    end_time: builtins.str
    interval: builtins.str
    start_time: builtins.str
    type: builtins.str
    def __init__(
        self,
        *,
        enabled: builtins.bool = ...,
        end_time: builtins.str = ...,
        interval: builtins.str = ...,
        start_time: builtins.str = ...,
        type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["enabled", b"enabled", "end_time", b"end_time", "interval", b"interval", "start_time", b"start_time", "type", b"type"]) -> None: ...

global___JobSchedule = JobSchedule

@typing_extensions.final
class ServersJobAgentsCredentials(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PASSWORD_FIELD_NUMBER: builtins.int
    USERNAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    password: builtins.str
    username: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        password: builtins.str = ...,
        username: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "password", b"password", "resource_info", b"resource_info", "username", b"username"]) -> None: ...

global___ServersJobAgentsCredentials = ServersJobAgentsCredentials

@typing_extensions.final
class ServersJobAgents(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DATABASE_ID_FIELD_NUMBER: builtins.int
    SKU_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    SERVERS_JOB_AGENTS_JOBS_FIELD_NUMBER: builtins.int
    SERVERS_JOB_AGENTS_TARGET_GROUPS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    location: builtins.str
    name: builtins.str
    database_id: builtins.str
    @property
    def sku(self) -> global___Sku: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def servers_job_agents_jobs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServersJobAgentsJobs]: ...
    @property
    def servers_job_agents_target_groups(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServersJobAgentsTargetGroups]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        database_id: builtins.str = ...,
        sku: global___Sku | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        servers_job_agents_jobs: collections.abc.Iterable[global___ServersJobAgentsJobs] | None = ...,
        servers_job_agents_target_groups: collections.abc.Iterable[global___ServersJobAgentsTargetGroups] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "sku", b"sku"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["database_id", b"database_id", "location", b"location", "name", b"name", "resource_info", b"resource_info", "servers_job_agents_jobs", b"servers_job_agents_jobs", "servers_job_agents_target_groups", b"servers_job_agents_target_groups", "sku", b"sku", "tags", b"tags"]) -> None: ...

global___ServersJobAgents = ServersJobAgents

@typing_extensions.final
class ServersIpv6FirewallRules(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    END_IPV6_ADDRESS_FIELD_NUMBER: builtins.int
    START_IPV6_ADDRESS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    end_ipv6_address: builtins.str
    start_ipv6_address: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        end_ipv6_address: builtins.str = ...,
        start_ipv6_address: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["end_ipv6_address", b"end_ipv6_address", "name", b"name", "resource_info", b"resource_info", "start_ipv6_address", b"start_ipv6_address"]) -> None: ...

global___ServersIpv6FirewallRules = ServersIpv6FirewallRules

@typing_extensions.final
class ServersFirewallRules(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    END_IP_ADDRESS_FIELD_NUMBER: builtins.int
    START_IP_ADDRESS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    end_ip_address: builtins.str
    start_ip_address: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        end_ip_address: builtins.str = ...,
        start_ip_address: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["end_ip_address", b"end_ip_address", "name", b"name", "resource_info", b"resource_info", "start_ip_address", b"start_ip_address"]) -> None: ...

global___ServersFirewallRules = ServersFirewallRules

@typing_extensions.final
class ServersFailoverGroups(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DATABASES_FIELD_NUMBER: builtins.int
    PARTNER_SERVERS_FIELD_NUMBER: builtins.int
    READ_ONLY_ENDPOINT_FIELD_NUMBER: builtins.int
    READ_WRITE_ENDPOINT_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def databases(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def partner_servers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PartnerInfo]: ...
    @property
    def read_only_endpoint(self) -> global___FailoverGroupReadOnlyEndpoint: ...
    @property
    def read_write_endpoint(self) -> global___FailoverGroupReadWriteEndpoint: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        databases: collections.abc.Iterable[builtins.str] | None = ...,
        partner_servers: collections.abc.Iterable[global___PartnerInfo] | None = ...,
        read_only_endpoint: global___FailoverGroupReadOnlyEndpoint | None = ...,
        read_write_endpoint: global___FailoverGroupReadWriteEndpoint | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["read_only_endpoint", b"read_only_endpoint", "read_write_endpoint", b"read_write_endpoint", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["databases", b"databases", "name", b"name", "partner_servers", b"partner_servers", "read_only_endpoint", b"read_only_endpoint", "read_write_endpoint", b"read_write_endpoint", "resource_info", b"resource_info", "tags", b"tags"]) -> None: ...

global___ServersFailoverGroups = ServersFailoverGroups

@typing_extensions.final
class FailoverGroupReadWriteEndpoint(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FAILOVER_POLICY_FIELD_NUMBER: builtins.int
    FAILOVER_WITH_DATA_LOSS_GRACE_PERIOD_MINUTES_FIELD_NUMBER: builtins.int
    failover_policy: builtins.str
    failover_with_data_loss_grace_period_minutes: builtins.int
    def __init__(
        self,
        *,
        failover_policy: builtins.str = ...,
        failover_with_data_loss_grace_period_minutes: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["failover_policy", b"failover_policy", "failover_with_data_loss_grace_period_minutes", b"failover_with_data_loss_grace_period_minutes"]) -> None: ...

global___FailoverGroupReadWriteEndpoint = FailoverGroupReadWriteEndpoint

@typing_extensions.final
class FailoverGroupReadOnlyEndpoint(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FAILOVER_POLICY_FIELD_NUMBER: builtins.int
    failover_policy: builtins.str
    def __init__(
        self,
        *,
        failover_policy: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["failover_policy", b"failover_policy"]) -> None: ...

global___FailoverGroupReadOnlyEndpoint = FailoverGroupReadOnlyEndpoint

@typing_extensions.final
class PartnerInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    def __init__(
        self,
        *,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id"]) -> None: ...

global___PartnerInfo = PartnerInfo

@typing_extensions.final
class ServersExtendedAuditingSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    AUDIT_ACTIONS_AND_GROUPS_FIELD_NUMBER: builtins.int
    IS_AZURE_MONITOR_TARGET_ENABLED_FIELD_NUMBER: builtins.int
    IS_DEVOPS_AUDIT_ENABLED_FIELD_NUMBER: builtins.int
    IS_STORAGE_SECONDARY_KEY_IN_USE_FIELD_NUMBER: builtins.int
    PREDICATE_EXPRESSION_FIELD_NUMBER: builtins.int
    QUEUE_DELAY_MS_FIELD_NUMBER: builtins.int
    RETENTION_DAYS_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    STORAGE_ACCOUNT_ACCESS_KEY_FIELD_NUMBER: builtins.int
    STORAGE_ACCOUNT_SUBSCRIPTION_ID_FIELD_NUMBER: builtins.int
    STORAGE_ENDPOINT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def audit_actions_and_groups(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    is_azure_monitor_target_enabled: builtins.bool
    is_devops_audit_enabled: builtins.bool
    is_storage_secondary_key_in_use: builtins.bool
    predicate_expression: builtins.str
    queue_delay_ms: builtins.int
    retention_days: builtins.int
    state: builtins.str
    storage_account_access_key: builtins.str
    storage_account_subscription_id: builtins.str
    storage_endpoint: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        audit_actions_and_groups: collections.abc.Iterable[builtins.str] | None = ...,
        is_azure_monitor_target_enabled: builtins.bool = ...,
        is_devops_audit_enabled: builtins.bool = ...,
        is_storage_secondary_key_in_use: builtins.bool = ...,
        predicate_expression: builtins.str = ...,
        queue_delay_ms: builtins.int = ...,
        retention_days: builtins.int = ...,
        state: builtins.str = ...,
        storage_account_access_key: builtins.str = ...,
        storage_account_subscription_id: builtins.str = ...,
        storage_endpoint: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["audit_actions_and_groups", b"audit_actions_and_groups", "is_azure_monitor_target_enabled", b"is_azure_monitor_target_enabled", "is_devops_audit_enabled", b"is_devops_audit_enabled", "is_storage_secondary_key_in_use", b"is_storage_secondary_key_in_use", "name", b"name", "predicate_expression", b"predicate_expression", "queue_delay_ms", b"queue_delay_ms", "resource_info", b"resource_info", "retention_days", b"retention_days", "state", b"state", "storage_account_access_key", b"storage_account_access_key", "storage_account_subscription_id", b"storage_account_subscription_id", "storage_endpoint", b"storage_endpoint"]) -> None: ...

global___ServersExtendedAuditingSettings = ServersExtendedAuditingSettings

@typing_extensions.final
class ServersEncryptionProtector(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    AUTO_ROTATION_ENABLED_FIELD_NUMBER: builtins.int
    SERVER_KEY_NAME_FIELD_NUMBER: builtins.int
    SERVER_KEY_TYPE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    auto_rotation_enabled: builtins.bool
    server_key_name: builtins.str
    server_key_type: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        auto_rotation_enabled: builtins.bool = ...,
        server_key_name: builtins.str = ...,
        server_key_type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auto_rotation_enabled", b"auto_rotation_enabled", "name", b"name", "resource_info", b"resource_info", "server_key_name", b"server_key_name", "server_key_type", b"server_key_type"]) -> None: ...

global___ServersEncryptionProtector = ServersEncryptionProtector

@typing_extensions.final
class ServersElasticPools(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    HIGH_AVAILABILITY_REPLICA_COUNT_FIELD_NUMBER: builtins.int
    LICENSE_TYPE_FIELD_NUMBER: builtins.int
    MAINTENANCE_CONFIGURATION_ID_FIELD_NUMBER: builtins.int
    MAX_SIZE_BYTES_FIELD_NUMBER: builtins.int
    PER_DATABASE_SETTINGS_FIELD_NUMBER: builtins.int
    ZONE_REDUNDANT_FIELD_NUMBER: builtins.int
    SKU_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    location: builtins.str
    name: builtins.str
    high_availability_replica_count: builtins.int
    license_type: builtins.str
    maintenance_configuration_id: builtins.str
    max_size_bytes: builtins.int
    @property
    def per_database_settings(self) -> global___ElasticPoolPerDatabaseSettings: ...
    zone_redundant: builtins.bool
    @property
    def sku(self) -> global___Sku: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        high_availability_replica_count: builtins.int = ...,
        license_type: builtins.str = ...,
        maintenance_configuration_id: builtins.str = ...,
        max_size_bytes: builtins.int = ...,
        per_database_settings: global___ElasticPoolPerDatabaseSettings | None = ...,
        zone_redundant: builtins.bool = ...,
        sku: global___Sku | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["per_database_settings", b"per_database_settings", "resource_info", b"resource_info", "sku", b"sku"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["high_availability_replica_count", b"high_availability_replica_count", "license_type", b"license_type", "location", b"location", "maintenance_configuration_id", b"maintenance_configuration_id", "max_size_bytes", b"max_size_bytes", "name", b"name", "per_database_settings", b"per_database_settings", "resource_info", b"resource_info", "sku", b"sku", "tags", b"tags", "zone_redundant", b"zone_redundant"]) -> None: ...

global___ServersElasticPools = ServersElasticPools

@typing_extensions.final
class Sku(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CAPACITY_FIELD_NUMBER: builtins.int
    FAMILY_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    SIZE_FIELD_NUMBER: builtins.int
    TIER_FIELD_NUMBER: builtins.int
    capacity: builtins.int
    family: builtins.str
    name: builtins.str
    size: builtins.str
    tier: builtins.str
    def __init__(
        self,
        *,
        capacity: builtins.int = ...,
        family: builtins.str = ...,
        name: builtins.str = ...,
        size: builtins.str = ...,
        tier: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["capacity", b"capacity", "family", b"family", "name", b"name", "size", b"size", "tier", b"tier"]) -> None: ...

global___Sku = Sku

@typing_extensions.final
class ElasticPoolPerDatabaseSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MAX_CAPACITY_FIELD_NUMBER: builtins.int
    MIN_CAPACITY_FIELD_NUMBER: builtins.int
    max_capacity: builtins.float
    min_capacity: builtins.float
    def __init__(
        self,
        *,
        max_capacity: builtins.float = ...,
        min_capacity: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["max_capacity", b"max_capacity", "min_capacity", b"min_capacity"]) -> None: ...

global___ElasticPoolPerDatabaseSettings = ElasticPoolPerDatabaseSettings

@typing_extensions.final
class ServersDnsAliases(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___ServersDnsAliases = ServersDnsAliases

@typing_extensions.final
class ServersDevOpsAuditingSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    IS_AZURE_MONITOR_TARGET_ENABLED_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    STORAGE_ACCOUNT_ACCESS_KEY_FIELD_NUMBER: builtins.int
    STORAGE_ACCOUNT_SUBSCRIPTION_ID_FIELD_NUMBER: builtins.int
    STORAGE_ENDPOINT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    is_azure_monitor_target_enabled: builtins.bool
    state: builtins.str
    storage_account_access_key: builtins.str
    storage_account_subscription_id: builtins.str
    storage_endpoint: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        is_azure_monitor_target_enabled: builtins.bool = ...,
        state: builtins.str = ...,
        storage_account_access_key: builtins.str = ...,
        storage_account_subscription_id: builtins.str = ...,
        storage_endpoint: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["is_azure_monitor_target_enabled", b"is_azure_monitor_target_enabled", "name", b"name", "resource_info", b"resource_info", "state", b"state", "storage_account_access_key", b"storage_account_access_key", "storage_account_subscription_id", b"storage_account_subscription_id", "storage_endpoint", b"storage_endpoint"]) -> None: ...

global___ServersDevOpsAuditingSettings = ServersDevOpsAuditingSettings

@typing_extensions.final
class ServersConnectionPolicies(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    CONNECTION_TYPE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    connection_type: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        connection_type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["connection_type", b"connection_type", "name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___ServersConnectionPolicies = ServersConnectionPolicies

@typing_extensions.final
class ServersAzureADOnlyAuthentications(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    AZURE_AD_ONLY_AUTHENTICATION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    azure_ad_only_authentication: builtins.bool
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        azure_ad_only_authentication: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["azure_ad_only_authentication", b"azure_ad_only_authentication", "name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___ServersAzureADOnlyAuthentications = ServersAzureADOnlyAuthentications

@typing_extensions.final
class ServersAuditingSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    AUDIT_ACTIONS_AND_GROUPS_FIELD_NUMBER: builtins.int
    IS_AZURE_MONITOR_TARGET_ENABLED_FIELD_NUMBER: builtins.int
    IS_DEVOPS_AUDIT_ENABLED_FIELD_NUMBER: builtins.int
    IS_STORAGE_SECONDARY_KEY_IN_USE_FIELD_NUMBER: builtins.int
    QUEUE_DELAY_MS_FIELD_NUMBER: builtins.int
    RETENTION_DAYS_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    STORAGE_ACCOUNT_ACCESS_KEY_FIELD_NUMBER: builtins.int
    STORAGE_ACCOUNT_SUBSCRIPTION_ID_FIELD_NUMBER: builtins.int
    STORAGE_ENDPOINT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def audit_actions_and_groups(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    is_azure_monitor_target_enabled: builtins.bool
    is_devops_audit_enabled: builtins.bool
    is_storage_secondary_key_in_use: builtins.bool
    queue_delay_ms: builtins.int
    retention_days: builtins.int
    state: builtins.str
    storage_account_access_key: builtins.str
    storage_account_subscription_id: builtins.str
    storage_endpoint: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        audit_actions_and_groups: collections.abc.Iterable[builtins.str] | None = ...,
        is_azure_monitor_target_enabled: builtins.bool = ...,
        is_devops_audit_enabled: builtins.bool = ...,
        is_storage_secondary_key_in_use: builtins.bool = ...,
        queue_delay_ms: builtins.int = ...,
        retention_days: builtins.int = ...,
        state: builtins.str = ...,
        storage_account_access_key: builtins.str = ...,
        storage_account_subscription_id: builtins.str = ...,
        storage_endpoint: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["audit_actions_and_groups", b"audit_actions_and_groups", "is_azure_monitor_target_enabled", b"is_azure_monitor_target_enabled", "is_devops_audit_enabled", b"is_devops_audit_enabled", "is_storage_secondary_key_in_use", b"is_storage_secondary_key_in_use", "name", b"name", "queue_delay_ms", b"queue_delay_ms", "resource_info", b"resource_info", "retention_days", b"retention_days", "state", b"state", "storage_account_access_key", b"storage_account_access_key", "storage_account_subscription_id", b"storage_account_subscription_id", "storage_endpoint", b"storage_endpoint"]) -> None: ...

global___ServersAuditingSettings = ServersAuditingSettings

@typing_extensions.final
class ServersAdministrators(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ADMINISTRATOR_TYPE_FIELD_NUMBER: builtins.int
    LOGIN_FIELD_NUMBER: builtins.int
    SID_FIELD_NUMBER: builtins.int
    TENANT_ID_FIELD_NUMBER: builtins.int
    AZURE_AD_ONLY_AUTHENTICATION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    administrator_type: builtins.str
    login: builtins.str
    sid: builtins.str
    tenant_id: builtins.str
    azure_ad_only_authentication: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        administrator_type: builtins.str = ...,
        login: builtins.str = ...,
        sid: builtins.str = ...,
        tenant_id: builtins.str = ...,
        azure_ad_only_authentication: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["administrator_type", b"administrator_type", "azure_ad_only_authentication", b"azure_ad_only_authentication", "login", b"login", "name", b"name", "resource_info", b"resource_info", "sid", b"sid", "tenant_id", b"tenant_id"]) -> None: ...

global___ServersAdministrators = ServersAdministrators

@typing_extensions.final
class Servers(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    IDENTITY_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ADMINISTRATOR_LOGIN_FIELD_NUMBER: builtins.int
    ADMINISTRATOR_LOGIN_PASSWORD_FIELD_NUMBER: builtins.int
    ADMINISTRATORS_FIELD_NUMBER: builtins.int
    FEDERATED_CLIENT_ID_FIELD_NUMBER: builtins.int
    KEY_ID_FIELD_NUMBER: builtins.int
    MINIMAL_TLS_VERSION_FIELD_NUMBER: builtins.int
    PRIMARY_USER_ASSIGNED_IDENTITY_ID_FIELD_NUMBER: builtins.int
    PUBLIC_NETWORK_ACCESS_FIELD_NUMBER: builtins.int
    RESTRICT_OUTBOUND_NETWORK_ACCESS_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    SERVERS_IPV6_FIREWALL_RULES_FIELD_NUMBER: builtins.int
    SERVERS_OUTBOUND_FIREWALL_RULES_FIELD_NUMBER: builtins.int
    SERVERS_AZURE_AD_ONLY_AUTHENTICATIONS_FIELD_NUMBER: builtins.int
    SERVERS_CONNECTION_POLICIES_FIELD_NUMBER: builtins.int
    SERVERS_DEV_OPS_AUDITING_SETTINGS_FIELD_NUMBER: builtins.int
    SERVERS_DNS_ALIASES_FIELD_NUMBER: builtins.int
    SERVERS_SYNC_AGENTS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def identity(self) -> global___ResourceIdentity: ...
    location: builtins.str
    name: builtins.str
    administrator_login: builtins.str
    administrator_login_password: builtins.str
    @property
    def administrators(self) -> global___ServerExternalAdministrator: ...
    federated_client_id: builtins.str
    key_id: builtins.str
    minimal_tls_version: builtins.str
    primary_user_assigned_identity_id: builtins.str
    public_network_access: builtins.str
    restrict_outbound_network_access: builtins.str
    version: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def servers_ipv6_firewall_rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServersIpv6FirewallRules]: ...
    @property
    def servers_outbound_firewall_rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServersOutboundFirewallRules]: ...
    @property
    def servers_azure_ad_only_authentications(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServersAzureADOnlyAuthentications]: ...
    @property
    def servers_connection_policies(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServersConnectionPolicies]: ...
    @property
    def servers_dev_ops_auditing_settings(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServersDevOpsAuditingSettings]: ...
    @property
    def servers_dns_aliases(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServersDnsAliases]: ...
    @property
    def servers_sync_agents(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServersSyncAgents]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        identity: global___ResourceIdentity | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        administrator_login: builtins.str = ...,
        administrator_login_password: builtins.str = ...,
        administrators: global___ServerExternalAdministrator | None = ...,
        federated_client_id: builtins.str = ...,
        key_id: builtins.str = ...,
        minimal_tls_version: builtins.str = ...,
        primary_user_assigned_identity_id: builtins.str = ...,
        public_network_access: builtins.str = ...,
        restrict_outbound_network_access: builtins.str = ...,
        version: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        servers_ipv6_firewall_rules: collections.abc.Iterable[global___ServersIpv6FirewallRules] | None = ...,
        servers_outbound_firewall_rules: collections.abc.Iterable[global___ServersOutboundFirewallRules] | None = ...,
        servers_azure_ad_only_authentications: collections.abc.Iterable[global___ServersAzureADOnlyAuthentications] | None = ...,
        servers_connection_policies: collections.abc.Iterable[global___ServersConnectionPolicies] | None = ...,
        servers_dev_ops_auditing_settings: collections.abc.Iterable[global___ServersDevOpsAuditingSettings] | None = ...,
        servers_dns_aliases: collections.abc.Iterable[global___ServersDnsAliases] | None = ...,
        servers_sync_agents: collections.abc.Iterable[global___ServersSyncAgents] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["administrators", b"administrators", "identity", b"identity", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["administrator_login", b"administrator_login", "administrator_login_password", b"administrator_login_password", "administrators", b"administrators", "federated_client_id", b"federated_client_id", "identity", b"identity", "key_id", b"key_id", "location", b"location", "minimal_tls_version", b"minimal_tls_version", "name", b"name", "primary_user_assigned_identity_id", b"primary_user_assigned_identity_id", "public_network_access", b"public_network_access", "resource_info", b"resource_info", "restrict_outbound_network_access", b"restrict_outbound_network_access", "servers_azure_ad_only_authentications", b"servers_azure_ad_only_authentications", "servers_connection_policies", b"servers_connection_policies", "servers_dev_ops_auditing_settings", b"servers_dev_ops_auditing_settings", "servers_dns_aliases", b"servers_dns_aliases", "servers_ipv6_firewall_rules", b"servers_ipv6_firewall_rules", "servers_outbound_firewall_rules", b"servers_outbound_firewall_rules", "servers_sync_agents", b"servers_sync_agents", "tags", b"tags", "version", b"version"]) -> None: ...

global___Servers = Servers

@typing_extensions.final
class ServerExternalAdministrator(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADMINISTRATOR_TYPE_FIELD_NUMBER: builtins.int
    AZURE_AD_ONLY_AUTHENTICATION_FIELD_NUMBER: builtins.int
    LOGIN_FIELD_NUMBER: builtins.int
    PRINCIPAL_TYPE_FIELD_NUMBER: builtins.int
    SID_FIELD_NUMBER: builtins.int
    TENANT_ID_FIELD_NUMBER: builtins.int
    administrator_type: builtins.str
    azure_ad_only_authentication: builtins.bool
    login: builtins.str
    principal_type: builtins.str
    sid: builtins.str
    tenant_id: builtins.str
    def __init__(
        self,
        *,
        administrator_type: builtins.str = ...,
        azure_ad_only_authentication: builtins.bool = ...,
        login: builtins.str = ...,
        principal_type: builtins.str = ...,
        sid: builtins.str = ...,
        tenant_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["administrator_type", b"administrator_type", "azure_ad_only_authentication", b"azure_ad_only_authentication", "login", b"login", "principal_type", b"principal_type", "sid", b"sid", "tenant_id", b"tenant_id"]) -> None: ...

global___ServerExternalAdministrator = ServerExternalAdministrator

@typing_extensions.final
class ResourceIdentity(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class UserAssignedIdentitiesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    TYPE_FIELD_NUMBER: builtins.int
    USER_ASSIGNED_IDENTITIES_FIELD_NUMBER: builtins.int
    type: builtins.str
    @property
    def user_assigned_identities(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        type: builtins.str = ...,
        user_assigned_identities: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["type", b"type", "user_assigned_identities", b"user_assigned_identities"]) -> None: ...

global___ResourceIdentity = ResourceIdentity
