"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ComputeBackendBucketXCdnPolicyXBypassCacheOnRequestHeaders(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HEADER_NAME_FIELD_NUMBER: builtins.int
    header_name: builtins.str
    def __init__(
        self,
        *,
        header_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["header_name", b"header_name"]) -> None: ...

global___ComputeBackendBucketXCdnPolicyXBypassCacheOnRequestHeaders = ComputeBackendBucketXCdnPolicyXBypassCacheOnRequestHeaders

@typing_extensions.final
class ComputeBackendBucketXCdnPolicyXCacheKeyPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INCLUDE_HTTP_HEADERS_FIELD_NUMBER: builtins.int
    QUERY_STRING_WHITELIST_FIELD_NUMBER: builtins.int
    @property
    def include_http_headers(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def query_string_whitelist(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        include_http_headers: collections.abc.Iterable[builtins.str] | None = ...,
        query_string_whitelist: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["include_http_headers", b"include_http_headers", "query_string_whitelist", b"query_string_whitelist"]) -> None: ...

global___ComputeBackendBucketXCdnPolicyXCacheKeyPolicy = ComputeBackendBucketXCdnPolicyXCacheKeyPolicy

@typing_extensions.final
class ComputeBackendBucketXCdnPolicyXNegativeCachingPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CODE_FIELD_NUMBER: builtins.int
    TTL_FIELD_NUMBER: builtins.int
    code: builtins.float
    ttl: builtins.float
    def __init__(
        self,
        *,
        code: builtins.float = ...,
        ttl: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["code", b"code", "ttl", b"ttl"]) -> None: ...

global___ComputeBackendBucketXCdnPolicyXNegativeCachingPolicy = ComputeBackendBucketXCdnPolicyXNegativeCachingPolicy

@typing_extensions.final
class ComputeBackendBucketXCdnPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CACHE_MODE_FIELD_NUMBER: builtins.int
    CLIENT_TTL_FIELD_NUMBER: builtins.int
    DEFAULT_TTL_FIELD_NUMBER: builtins.int
    MAX_TTL_FIELD_NUMBER: builtins.int
    NEGATIVE_CACHING_FIELD_NUMBER: builtins.int
    REQUEST_COALESCING_FIELD_NUMBER: builtins.int
    SERVE_WHILE_STALE_FIELD_NUMBER: builtins.int
    SIGNED_URL_CACHE_MAX_AGE_SEC_FIELD_NUMBER: builtins.int
    BYPASS_CACHE_ON_REQUEST_HEADERS_FIELD_NUMBER: builtins.int
    CACHE_KEY_POLICY_FIELD_NUMBER: builtins.int
    NEGATIVE_CACHING_POLICY_FIELD_NUMBER: builtins.int
    cache_mode: builtins.str
    client_ttl: builtins.float
    default_ttl: builtins.float
    max_ttl: builtins.float
    negative_caching: builtins.bool
    request_coalescing: builtins.bool
    serve_while_stale: builtins.float
    signed_url_cache_max_age_sec: builtins.float
    @property
    def bypass_cache_on_request_headers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeBackendBucketXCdnPolicyXBypassCacheOnRequestHeaders]: ...
    @property
    def cache_key_policy(self) -> global___ComputeBackendBucketXCdnPolicyXCacheKeyPolicy: ...
    @property
    def negative_caching_policy(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeBackendBucketXCdnPolicyXNegativeCachingPolicy]: ...
    def __init__(
        self,
        *,
        cache_mode: builtins.str = ...,
        client_ttl: builtins.float = ...,
        default_ttl: builtins.float = ...,
        max_ttl: builtins.float = ...,
        negative_caching: builtins.bool = ...,
        request_coalescing: builtins.bool = ...,
        serve_while_stale: builtins.float = ...,
        signed_url_cache_max_age_sec: builtins.float = ...,
        bypass_cache_on_request_headers: collections.abc.Iterable[global___ComputeBackendBucketXCdnPolicyXBypassCacheOnRequestHeaders] | None = ...,
        cache_key_policy: global___ComputeBackendBucketXCdnPolicyXCacheKeyPolicy | None = ...,
        negative_caching_policy: collections.abc.Iterable[global___ComputeBackendBucketXCdnPolicyXNegativeCachingPolicy] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cache_key_policy", b"cache_key_policy"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bypass_cache_on_request_headers", b"bypass_cache_on_request_headers", "cache_key_policy", b"cache_key_policy", "cache_mode", b"cache_mode", "client_ttl", b"client_ttl", "default_ttl", b"default_ttl", "max_ttl", b"max_ttl", "negative_caching", b"negative_caching", "negative_caching_policy", b"negative_caching_policy", "request_coalescing", b"request_coalescing", "serve_while_stale", b"serve_while_stale", "signed_url_cache_max_age_sec", b"signed_url_cache_max_age_sec"]) -> None: ...

global___ComputeBackendBucketXCdnPolicy = ComputeBackendBucketXCdnPolicy

@typing_extensions.final
class ComputeBackendBucketXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___ComputeBackendBucketXTimeouts = ComputeBackendBucketXTimeouts

@typing_extensions.final
class ComputeBackendBucket(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUCKET_NAME_FIELD_NUMBER: builtins.int
    CREATION_TIMESTAMP_FIELD_NUMBER: builtins.int
    CUSTOM_RESPONSE_HEADERS_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    EDGE_SECURITY_POLICY_FIELD_NUMBER: builtins.int
    ENABLE_CDN_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    SELF_LINK_FIELD_NUMBER: builtins.int
    CDN_POLICY_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    bucket_name: builtins.str
    creation_timestamp: builtins.str
    @property
    def custom_response_headers(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    description: builtins.str
    edge_security_policy: builtins.str
    enable_cdn: builtins.bool
    id: builtins.str
    name: builtins.str
    project: builtins.str
    self_link: builtins.str
    @property
    def cdn_policy(self) -> global___ComputeBackendBucketXCdnPolicy: ...
    @property
    def timeouts(self) -> global___ComputeBackendBucketXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        bucket_name: builtins.str = ...,
        creation_timestamp: builtins.str = ...,
        custom_response_headers: collections.abc.Iterable[builtins.str] | None = ...,
        description: builtins.str = ...,
        edge_security_policy: builtins.str = ...,
        enable_cdn: builtins.bool = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        self_link: builtins.str = ...,
        cdn_policy: global___ComputeBackendBucketXCdnPolicy | None = ...,
        timeouts: global___ComputeBackendBucketXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cdn_policy", b"cdn_policy", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bucket_name", b"bucket_name", "cdn_policy", b"cdn_policy", "creation_timestamp", b"creation_timestamp", "custom_response_headers", b"custom_response_headers", "description", b"description", "edge_security_policy", b"edge_security_policy", "enable_cdn", b"enable_cdn", "id", b"id", "name", b"name", "project", b"project", "resource_info", b"resource_info", "self_link", b"self_link", "timeouts", b"timeouts"]) -> None: ...

global___ComputeBackendBucket = ComputeBackendBucket

@typing_extensions.final
class ComputeBackendBucketSignedUrlKeyXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete"]) -> None: ...

global___ComputeBackendBucketSignedUrlKeyXTimeouts = ComputeBackendBucketSignedUrlKeyXTimeouts

@typing_extensions.final
class ComputeBackendBucketSignedUrlKey(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BACKEND_BUCKET_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    KEY_VALUE_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    backend_bucket: builtins.str
    id: builtins.str
    key_value: builtins.str
    name: builtins.str
    project: builtins.str
    @property
    def timeouts(self) -> global___ComputeBackendBucketSignedUrlKeyXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        backend_bucket: builtins.str = ...,
        id: builtins.str = ...,
        key_value: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        timeouts: global___ComputeBackendBucketSignedUrlKeyXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["backend_bucket", b"backend_bucket", "id", b"id", "key_value", b"key_value", "name", b"name", "project", b"project", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> None: ...

global___ComputeBackendBucketSignedUrlKey = ComputeBackendBucketSignedUrlKey

@typing_extensions.final
class ComputeBackendServiceXBackend(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BALANCING_MODE_FIELD_NUMBER: builtins.int
    CAPACITY_SCALER_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    GROUP_FIELD_NUMBER: builtins.int
    MAX_CONNECTIONS_FIELD_NUMBER: builtins.int
    MAX_CONNECTIONS_PER_ENDPOINT_FIELD_NUMBER: builtins.int
    MAX_CONNECTIONS_PER_INSTANCE_FIELD_NUMBER: builtins.int
    MAX_RATE_FIELD_NUMBER: builtins.int
    MAX_RATE_PER_ENDPOINT_FIELD_NUMBER: builtins.int
    MAX_RATE_PER_INSTANCE_FIELD_NUMBER: builtins.int
    MAX_UTILIZATION_FIELD_NUMBER: builtins.int
    balancing_mode: builtins.str
    capacity_scaler: builtins.float
    description: builtins.str
    group: builtins.str
    max_connections: builtins.float
    max_connections_per_endpoint: builtins.float
    max_connections_per_instance: builtins.float
    max_rate: builtins.float
    max_rate_per_endpoint: builtins.float
    max_rate_per_instance: builtins.float
    max_utilization: builtins.float
    def __init__(
        self,
        *,
        balancing_mode: builtins.str = ...,
        capacity_scaler: builtins.float = ...,
        description: builtins.str = ...,
        group: builtins.str = ...,
        max_connections: builtins.float = ...,
        max_connections_per_endpoint: builtins.float = ...,
        max_connections_per_instance: builtins.float = ...,
        max_rate: builtins.float = ...,
        max_rate_per_endpoint: builtins.float = ...,
        max_rate_per_instance: builtins.float = ...,
        max_utilization: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["balancing_mode", b"balancing_mode", "capacity_scaler", b"capacity_scaler", "description", b"description", "group", b"group", "max_connections", b"max_connections", "max_connections_per_endpoint", b"max_connections_per_endpoint", "max_connections_per_instance", b"max_connections_per_instance", "max_rate", b"max_rate", "max_rate_per_endpoint", b"max_rate_per_endpoint", "max_rate_per_instance", b"max_rate_per_instance", "max_utilization", b"max_utilization"]) -> None: ...

global___ComputeBackendServiceXBackend = ComputeBackendServiceXBackend

@typing_extensions.final
class ComputeBackendServiceXCdnPolicyXCacheKeyPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INCLUDE_HOST_FIELD_NUMBER: builtins.int
    INCLUDE_NAMED_COOKIES_FIELD_NUMBER: builtins.int
    INCLUDE_PROTOCOL_FIELD_NUMBER: builtins.int
    INCLUDE_QUERY_STRING_FIELD_NUMBER: builtins.int
    QUERY_STRING_BLACKLIST_FIELD_NUMBER: builtins.int
    QUERY_STRING_WHITELIST_FIELD_NUMBER: builtins.int
    include_host: builtins.bool
    @property
    def include_named_cookies(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    include_protocol: builtins.bool
    include_query_string: builtins.bool
    @property
    def query_string_blacklist(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def query_string_whitelist(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        include_host: builtins.bool = ...,
        include_named_cookies: collections.abc.Iterable[builtins.str] | None = ...,
        include_protocol: builtins.bool = ...,
        include_query_string: builtins.bool = ...,
        query_string_blacklist: collections.abc.Iterable[builtins.str] | None = ...,
        query_string_whitelist: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["include_host", b"include_host", "include_named_cookies", b"include_named_cookies", "include_protocol", b"include_protocol", "include_query_string", b"include_query_string", "query_string_blacklist", b"query_string_blacklist", "query_string_whitelist", b"query_string_whitelist"]) -> None: ...

global___ComputeBackendServiceXCdnPolicyXCacheKeyPolicy = ComputeBackendServiceXCdnPolicyXCacheKeyPolicy

@typing_extensions.final
class ComputeBackendServiceXCdnPolicyXNegativeCachingPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CODE_FIELD_NUMBER: builtins.int
    TTL_FIELD_NUMBER: builtins.int
    code: builtins.float
    ttl: builtins.float
    def __init__(
        self,
        *,
        code: builtins.float = ...,
        ttl: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["code", b"code", "ttl", b"ttl"]) -> None: ...

global___ComputeBackendServiceXCdnPolicyXNegativeCachingPolicy = ComputeBackendServiceXCdnPolicyXNegativeCachingPolicy

@typing_extensions.final
class ComputeBackendServiceXCdnPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CACHE_MODE_FIELD_NUMBER: builtins.int
    CLIENT_TTL_FIELD_NUMBER: builtins.int
    DEFAULT_TTL_FIELD_NUMBER: builtins.int
    MAX_TTL_FIELD_NUMBER: builtins.int
    NEGATIVE_CACHING_FIELD_NUMBER: builtins.int
    SERVE_WHILE_STALE_FIELD_NUMBER: builtins.int
    SIGNED_URL_CACHE_MAX_AGE_SEC_FIELD_NUMBER: builtins.int
    CACHE_KEY_POLICY_FIELD_NUMBER: builtins.int
    NEGATIVE_CACHING_POLICY_FIELD_NUMBER: builtins.int
    cache_mode: builtins.str
    client_ttl: builtins.float
    default_ttl: builtins.float
    max_ttl: builtins.float
    negative_caching: builtins.bool
    serve_while_stale: builtins.float
    signed_url_cache_max_age_sec: builtins.float
    @property
    def cache_key_policy(self) -> global___ComputeBackendServiceXCdnPolicyXCacheKeyPolicy: ...
    @property
    def negative_caching_policy(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeBackendServiceXCdnPolicyXNegativeCachingPolicy]: ...
    def __init__(
        self,
        *,
        cache_mode: builtins.str = ...,
        client_ttl: builtins.float = ...,
        default_ttl: builtins.float = ...,
        max_ttl: builtins.float = ...,
        negative_caching: builtins.bool = ...,
        serve_while_stale: builtins.float = ...,
        signed_url_cache_max_age_sec: builtins.float = ...,
        cache_key_policy: global___ComputeBackendServiceXCdnPolicyXCacheKeyPolicy | None = ...,
        negative_caching_policy: collections.abc.Iterable[global___ComputeBackendServiceXCdnPolicyXNegativeCachingPolicy] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cache_key_policy", b"cache_key_policy"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cache_key_policy", b"cache_key_policy", "cache_mode", b"cache_mode", "client_ttl", b"client_ttl", "default_ttl", b"default_ttl", "max_ttl", b"max_ttl", "negative_caching", b"negative_caching", "negative_caching_policy", b"negative_caching_policy", "serve_while_stale", b"serve_while_stale", "signed_url_cache_max_age_sec", b"signed_url_cache_max_age_sec"]) -> None: ...

global___ComputeBackendServiceXCdnPolicy = ComputeBackendServiceXCdnPolicy

@typing_extensions.final
class ComputeBackendServiceXCircuitBreakers(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MAX_CONNECTIONS_FIELD_NUMBER: builtins.int
    MAX_PENDING_REQUESTS_FIELD_NUMBER: builtins.int
    MAX_REQUESTS_FIELD_NUMBER: builtins.int
    MAX_REQUESTS_PER_CONNECTION_FIELD_NUMBER: builtins.int
    MAX_RETRIES_FIELD_NUMBER: builtins.int
    max_connections: builtins.float
    max_pending_requests: builtins.float
    max_requests: builtins.float
    max_requests_per_connection: builtins.float
    max_retries: builtins.float
    def __init__(
        self,
        *,
        max_connections: builtins.float = ...,
        max_pending_requests: builtins.float = ...,
        max_requests: builtins.float = ...,
        max_requests_per_connection: builtins.float = ...,
        max_retries: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["max_connections", b"max_connections", "max_pending_requests", b"max_pending_requests", "max_requests", b"max_requests", "max_requests_per_connection", b"max_requests_per_connection", "max_retries", b"max_retries"]) -> None: ...

global___ComputeBackendServiceXCircuitBreakers = ComputeBackendServiceXCircuitBreakers

@typing_extensions.final
class ComputeBackendServiceXConsistentHashXHttpCookieXTtl(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NANOS_FIELD_NUMBER: builtins.int
    SECONDS_FIELD_NUMBER: builtins.int
    nanos: builtins.float
    seconds: builtins.float
    def __init__(
        self,
        *,
        nanos: builtins.float = ...,
        seconds: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["nanos", b"nanos", "seconds", b"seconds"]) -> None: ...

global___ComputeBackendServiceXConsistentHashXHttpCookieXTtl = ComputeBackendServiceXConsistentHashXHttpCookieXTtl

@typing_extensions.final
class ComputeBackendServiceXConsistentHashXHttpCookie(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    TTL_FIELD_NUMBER: builtins.int
    name: builtins.str
    path: builtins.str
    @property
    def ttl(self) -> global___ComputeBackendServiceXConsistentHashXHttpCookieXTtl: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        path: builtins.str = ...,
        ttl: global___ComputeBackendServiceXConsistentHashXHttpCookieXTtl | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["ttl", b"ttl"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "path", b"path", "ttl", b"ttl"]) -> None: ...

global___ComputeBackendServiceXConsistentHashXHttpCookie = ComputeBackendServiceXConsistentHashXHttpCookie

@typing_extensions.final
class ComputeBackendServiceXConsistentHash(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HTTP_HEADER_NAME_FIELD_NUMBER: builtins.int
    MINIMUM_RING_SIZE_FIELD_NUMBER: builtins.int
    HTTP_COOKIE_FIELD_NUMBER: builtins.int
    http_header_name: builtins.str
    minimum_ring_size: builtins.float
    @property
    def http_cookie(self) -> global___ComputeBackendServiceXConsistentHashXHttpCookie: ...
    def __init__(
        self,
        *,
        http_header_name: builtins.str = ...,
        minimum_ring_size: builtins.float = ...,
        http_cookie: global___ComputeBackendServiceXConsistentHashXHttpCookie | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["http_cookie", b"http_cookie"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["http_cookie", b"http_cookie", "http_header_name", b"http_header_name", "minimum_ring_size", b"minimum_ring_size"]) -> None: ...

global___ComputeBackendServiceXConsistentHash = ComputeBackendServiceXConsistentHash

@typing_extensions.final
class ComputeBackendServiceXIap(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OAUTH2_CLIENT_ID_FIELD_NUMBER: builtins.int
    OAUTH2_CLIENT_SECRET_FIELD_NUMBER: builtins.int
    OAUTH2_CLIENT_SECRET_SHA256_FIELD_NUMBER: builtins.int
    oauth2_client_id: builtins.str
    oauth2_client_secret: builtins.str
    oauth2_client_secret_sha256: builtins.str
    def __init__(
        self,
        *,
        oauth2_client_id: builtins.str = ...,
        oauth2_client_secret: builtins.str = ...,
        oauth2_client_secret_sha256: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["oauth2_client_id", b"oauth2_client_id", "oauth2_client_secret", b"oauth2_client_secret", "oauth2_client_secret_sha256", b"oauth2_client_secret_sha256"]) -> None: ...

global___ComputeBackendServiceXIap = ComputeBackendServiceXIap

@typing_extensions.final
class ComputeBackendServiceXLogConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLE_FIELD_NUMBER: builtins.int
    SAMPLE_RATE_FIELD_NUMBER: builtins.int
    enable: builtins.bool
    sample_rate: builtins.float
    def __init__(
        self,
        *,
        enable: builtins.bool = ...,
        sample_rate: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["enable", b"enable", "sample_rate", b"sample_rate"]) -> None: ...

global___ComputeBackendServiceXLogConfig = ComputeBackendServiceXLogConfig

@typing_extensions.final
class ComputeBackendServiceXOutlierDetectionXBaseEjectionTime(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NANOS_FIELD_NUMBER: builtins.int
    SECONDS_FIELD_NUMBER: builtins.int
    nanos: builtins.float
    seconds: builtins.float
    def __init__(
        self,
        *,
        nanos: builtins.float = ...,
        seconds: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["nanos", b"nanos", "seconds", b"seconds"]) -> None: ...

global___ComputeBackendServiceXOutlierDetectionXBaseEjectionTime = ComputeBackendServiceXOutlierDetectionXBaseEjectionTime

@typing_extensions.final
class ComputeBackendServiceXOutlierDetectionXInterval(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NANOS_FIELD_NUMBER: builtins.int
    SECONDS_FIELD_NUMBER: builtins.int
    nanos: builtins.float
    seconds: builtins.float
    def __init__(
        self,
        *,
        nanos: builtins.float = ...,
        seconds: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["nanos", b"nanos", "seconds", b"seconds"]) -> None: ...

global___ComputeBackendServiceXOutlierDetectionXInterval = ComputeBackendServiceXOutlierDetectionXInterval

@typing_extensions.final
class ComputeBackendServiceXOutlierDetection(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONSECUTIVE_ERRORS_FIELD_NUMBER: builtins.int
    CONSECUTIVE_GATEWAY_FAILURE_FIELD_NUMBER: builtins.int
    ENFORCING_CONSECUTIVE_ERRORS_FIELD_NUMBER: builtins.int
    ENFORCING_CONSECUTIVE_GATEWAY_FAILURE_FIELD_NUMBER: builtins.int
    ENFORCING_SUCCESS_RATE_FIELD_NUMBER: builtins.int
    MAX_EJECTION_PERCENT_FIELD_NUMBER: builtins.int
    SUCCESS_RATE_MINIMUM_HOSTS_FIELD_NUMBER: builtins.int
    SUCCESS_RATE_REQUEST_VOLUME_FIELD_NUMBER: builtins.int
    SUCCESS_RATE_STDEV_FACTOR_FIELD_NUMBER: builtins.int
    BASE_EJECTION_TIME_FIELD_NUMBER: builtins.int
    INTERVAL_FIELD_NUMBER: builtins.int
    consecutive_errors: builtins.float
    consecutive_gateway_failure: builtins.float
    enforcing_consecutive_errors: builtins.float
    enforcing_consecutive_gateway_failure: builtins.float
    enforcing_success_rate: builtins.float
    max_ejection_percent: builtins.float
    success_rate_minimum_hosts: builtins.float
    success_rate_request_volume: builtins.float
    success_rate_stdev_factor: builtins.float
    @property
    def base_ejection_time(self) -> global___ComputeBackendServiceXOutlierDetectionXBaseEjectionTime: ...
    @property
    def interval(self) -> global___ComputeBackendServiceXOutlierDetectionXInterval: ...
    def __init__(
        self,
        *,
        consecutive_errors: builtins.float = ...,
        consecutive_gateway_failure: builtins.float = ...,
        enforcing_consecutive_errors: builtins.float = ...,
        enforcing_consecutive_gateway_failure: builtins.float = ...,
        enforcing_success_rate: builtins.float = ...,
        max_ejection_percent: builtins.float = ...,
        success_rate_minimum_hosts: builtins.float = ...,
        success_rate_request_volume: builtins.float = ...,
        success_rate_stdev_factor: builtins.float = ...,
        base_ejection_time: global___ComputeBackendServiceXOutlierDetectionXBaseEjectionTime | None = ...,
        interval: global___ComputeBackendServiceXOutlierDetectionXInterval | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["base_ejection_time", b"base_ejection_time", "interval", b"interval"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["base_ejection_time", b"base_ejection_time", "consecutive_errors", b"consecutive_errors", "consecutive_gateway_failure", b"consecutive_gateway_failure", "enforcing_consecutive_errors", b"enforcing_consecutive_errors", "enforcing_consecutive_gateway_failure", b"enforcing_consecutive_gateway_failure", "enforcing_success_rate", b"enforcing_success_rate", "interval", b"interval", "max_ejection_percent", b"max_ejection_percent", "success_rate_minimum_hosts", b"success_rate_minimum_hosts", "success_rate_request_volume", b"success_rate_request_volume", "success_rate_stdev_factor", b"success_rate_stdev_factor"]) -> None: ...

global___ComputeBackendServiceXOutlierDetection = ComputeBackendServiceXOutlierDetection

@typing_extensions.final
class ComputeBackendServiceXSecuritySettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLIENT_TLS_POLICY_FIELD_NUMBER: builtins.int
    SUBJECT_ALT_NAMES_FIELD_NUMBER: builtins.int
    client_tls_policy: builtins.str
    @property
    def subject_alt_names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        client_tls_policy: builtins.str = ...,
        subject_alt_names: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["client_tls_policy", b"client_tls_policy", "subject_alt_names", b"subject_alt_names"]) -> None: ...

global___ComputeBackendServiceXSecuritySettings = ComputeBackendServiceXSecuritySettings

@typing_extensions.final
class ComputeBackendServiceXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___ComputeBackendServiceXTimeouts = ComputeBackendServiceXTimeouts

@typing_extensions.final
class ComputeBackendService(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AFFINITY_COOKIE_TTL_SEC_FIELD_NUMBER: builtins.int
    CONNECTION_DRAINING_TIMEOUT_SEC_FIELD_NUMBER: builtins.int
    CREATION_TIMESTAMP_FIELD_NUMBER: builtins.int
    CUSTOM_REQUEST_HEADERS_FIELD_NUMBER: builtins.int
    CUSTOM_RESPONSE_HEADERS_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ENABLE_CDN_FIELD_NUMBER: builtins.int
    FINGERPRINT_FIELD_NUMBER: builtins.int
    HEALTH_CHECKS_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LOAD_BALANCING_SCHEME_FIELD_NUMBER: builtins.int
    LOCALITY_LB_POLICY_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PORT_NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    PROTOCOL_FIELD_NUMBER: builtins.int
    SECURITY_POLICY_FIELD_NUMBER: builtins.int
    SELF_LINK_FIELD_NUMBER: builtins.int
    SESSION_AFFINITY_FIELD_NUMBER: builtins.int
    TIMEOUT_SEC_FIELD_NUMBER: builtins.int
    BACKEND_FIELD_NUMBER: builtins.int
    CDN_POLICY_FIELD_NUMBER: builtins.int
    CIRCUIT_BREAKERS_FIELD_NUMBER: builtins.int
    CONSISTENT_HASH_FIELD_NUMBER: builtins.int
    IAP_FIELD_NUMBER: builtins.int
    LOG_CONFIG_FIELD_NUMBER: builtins.int
    OUTLIER_DETECTION_FIELD_NUMBER: builtins.int
    SECURITY_SETTINGS_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    affinity_cookie_ttl_sec: builtins.float
    connection_draining_timeout_sec: builtins.float
    creation_timestamp: builtins.str
    @property
    def custom_request_headers(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def custom_response_headers(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    description: builtins.str
    enable_cdn: builtins.bool
    fingerprint: builtins.str
    @property
    def health_checks(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    id: builtins.str
    load_balancing_scheme: builtins.str
    locality_lb_policy: builtins.str
    name: builtins.str
    port_name: builtins.str
    project: builtins.str
    protocol: builtins.str
    security_policy: builtins.str
    self_link: builtins.str
    session_affinity: builtins.str
    timeout_sec: builtins.float
    @property
    def backend(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeBackendServiceXBackend]: ...
    @property
    def cdn_policy(self) -> global___ComputeBackendServiceXCdnPolicy: ...
    @property
    def circuit_breakers(self) -> global___ComputeBackendServiceXCircuitBreakers: ...
    @property
    def consistent_hash(self) -> global___ComputeBackendServiceXConsistentHash: ...
    @property
    def iap(self) -> global___ComputeBackendServiceXIap: ...
    @property
    def log_config(self) -> global___ComputeBackendServiceXLogConfig: ...
    @property
    def outlier_detection(self) -> global___ComputeBackendServiceXOutlierDetection: ...
    @property
    def security_settings(self) -> global___ComputeBackendServiceXSecuritySettings: ...
    @property
    def timeouts(self) -> global___ComputeBackendServiceXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        affinity_cookie_ttl_sec: builtins.float = ...,
        connection_draining_timeout_sec: builtins.float = ...,
        creation_timestamp: builtins.str = ...,
        custom_request_headers: collections.abc.Iterable[builtins.str] | None = ...,
        custom_response_headers: collections.abc.Iterable[builtins.str] | None = ...,
        description: builtins.str = ...,
        enable_cdn: builtins.bool = ...,
        fingerprint: builtins.str = ...,
        health_checks: collections.abc.Iterable[builtins.str] | None = ...,
        id: builtins.str = ...,
        load_balancing_scheme: builtins.str = ...,
        locality_lb_policy: builtins.str = ...,
        name: builtins.str = ...,
        port_name: builtins.str = ...,
        project: builtins.str = ...,
        protocol: builtins.str = ...,
        security_policy: builtins.str = ...,
        self_link: builtins.str = ...,
        session_affinity: builtins.str = ...,
        timeout_sec: builtins.float = ...,
        backend: collections.abc.Iterable[global___ComputeBackendServiceXBackend] | None = ...,
        cdn_policy: global___ComputeBackendServiceXCdnPolicy | None = ...,
        circuit_breakers: global___ComputeBackendServiceXCircuitBreakers | None = ...,
        consistent_hash: global___ComputeBackendServiceXConsistentHash | None = ...,
        iap: global___ComputeBackendServiceXIap | None = ...,
        log_config: global___ComputeBackendServiceXLogConfig | None = ...,
        outlier_detection: global___ComputeBackendServiceXOutlierDetection | None = ...,
        security_settings: global___ComputeBackendServiceXSecuritySettings | None = ...,
        timeouts: global___ComputeBackendServiceXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cdn_policy", b"cdn_policy", "circuit_breakers", b"circuit_breakers", "consistent_hash", b"consistent_hash", "iap", b"iap", "log_config", b"log_config", "outlier_detection", b"outlier_detection", "resource_info", b"resource_info", "security_settings", b"security_settings", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["affinity_cookie_ttl_sec", b"affinity_cookie_ttl_sec", "backend", b"backend", "cdn_policy", b"cdn_policy", "circuit_breakers", b"circuit_breakers", "connection_draining_timeout_sec", b"connection_draining_timeout_sec", "consistent_hash", b"consistent_hash", "creation_timestamp", b"creation_timestamp", "custom_request_headers", b"custom_request_headers", "custom_response_headers", b"custom_response_headers", "description", b"description", "enable_cdn", b"enable_cdn", "fingerprint", b"fingerprint", "health_checks", b"health_checks", "iap", b"iap", "id", b"id", "load_balancing_scheme", b"load_balancing_scheme", "locality_lb_policy", b"locality_lb_policy", "log_config", b"log_config", "name", b"name", "outlier_detection", b"outlier_detection", "port_name", b"port_name", "project", b"project", "protocol", b"protocol", "resource_info", b"resource_info", "security_policy", b"security_policy", "security_settings", b"security_settings", "self_link", b"self_link", "session_affinity", b"session_affinity", "timeout_sec", b"timeout_sec", "timeouts", b"timeouts"]) -> None: ...

global___ComputeBackendService = ComputeBackendService

@typing_extensions.final
class ComputeBackendServiceSignedUrlKeyXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete"]) -> None: ...

global___ComputeBackendServiceSignedUrlKeyXTimeouts = ComputeBackendServiceSignedUrlKeyXTimeouts

@typing_extensions.final
class ComputeBackendServiceSignedUrlKey(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BACKEND_SERVICE_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    KEY_VALUE_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    backend_service: builtins.str
    id: builtins.str
    key_value: builtins.str
    name: builtins.str
    project: builtins.str
    @property
    def timeouts(self) -> global___ComputeBackendServiceSignedUrlKeyXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        backend_service: builtins.str = ...,
        id: builtins.str = ...,
        key_value: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        timeouts: global___ComputeBackendServiceSignedUrlKeyXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["backend_service", b"backend_service", "id", b"id", "key_value", b"key_value", "name", b"name", "project", b"project", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> None: ...

global___ComputeBackendServiceSignedUrlKey = ComputeBackendServiceSignedUrlKey
