"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Microsoft_Sql_ManagedInstances(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MANAGED_INSTANCES_DATABASES_FIELD_NUMBER: builtins.int
    @property
    def managed_instances_databases(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ManagedInstancesDatabases]: ...
    def __init__(
        self,
        *,
        managed_instances_databases: collections.abc.Iterable[global___ManagedInstancesDatabases] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["managed_instances_databases", b"managed_instances_databases"]) -> None: ...

global___Microsoft_Sql_ManagedInstances = Microsoft_Sql_ManagedInstances

@typing_extensions.final
class ManagedInstancesVulnerabilityAssessments(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    RECURRING_SCANS_FIELD_NUMBER: builtins.int
    STORAGE_ACCOUNT_ACCESS_KEY_FIELD_NUMBER: builtins.int
    STORAGE_CONTAINER_PATH_FIELD_NUMBER: builtins.int
    STORAGE_CONTAINER_SAS_KEY_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def recurring_scans(self) -> global___VulnerabilityAssessmentRecurringScansProperties: ...
    storage_account_access_key: builtins.str
    storage_container_path: builtins.str
    storage_container_sas_key: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        recurring_scans: global___VulnerabilityAssessmentRecurringScansProperties | None = ...,
        storage_account_access_key: builtins.str = ...,
        storage_container_path: builtins.str = ...,
        storage_container_sas_key: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["recurring_scans", b"recurring_scans", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "recurring_scans", b"recurring_scans", "resource_info", b"resource_info", "storage_account_access_key", b"storage_account_access_key", "storage_container_path", b"storage_container_path", "storage_container_sas_key", b"storage_container_sas_key"]) -> None: ...

global___ManagedInstancesVulnerabilityAssessments = ManagedInstancesVulnerabilityAssessments

@typing_extensions.final
class ManagedInstancesSqlAgent(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    state: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        state: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info", "state", b"state"]) -> None: ...

global___ManagedInstancesSqlAgent = ManagedInstancesSqlAgent

@typing_extensions.final
class ManagedInstancesServerTrustCertificates(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PUBLIC_BLOB_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    public_blob: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        public_blob: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "public_blob", b"public_blob", "resource_info", b"resource_info"]) -> None: ...

global___ManagedInstancesServerTrustCertificates = ManagedInstancesServerTrustCertificates

@typing_extensions.final
class ManagedInstancesSecurityAlertPolicies(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DISABLED_ALERTS_FIELD_NUMBER: builtins.int
    EMAIL_ACCOUNT_ADMINS_FIELD_NUMBER: builtins.int
    EMAIL_ADDRESSES_FIELD_NUMBER: builtins.int
    RETENTION_DAYS_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    STORAGE_ACCOUNT_ACCESS_KEY_FIELD_NUMBER: builtins.int
    STORAGE_ENDPOINT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def disabled_alerts(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    email_account_admins: builtins.bool
    @property
    def email_addresses(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    retention_days: builtins.int
    state: builtins.str
    storage_account_access_key: builtins.str
    storage_endpoint: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        disabled_alerts: collections.abc.Iterable[builtins.str] | None = ...,
        email_account_admins: builtins.bool = ...,
        email_addresses: collections.abc.Iterable[builtins.str] | None = ...,
        retention_days: builtins.int = ...,
        state: builtins.str = ...,
        storage_account_access_key: builtins.str = ...,
        storage_endpoint: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["disabled_alerts", b"disabled_alerts", "email_account_admins", b"email_account_admins", "email_addresses", b"email_addresses", "name", b"name", "resource_info", b"resource_info", "retention_days", b"retention_days", "state", b"state", "storage_account_access_key", b"storage_account_access_key", "storage_endpoint", b"storage_endpoint"]) -> None: ...

global___ManagedInstancesSecurityAlertPolicies = ManagedInstancesSecurityAlertPolicies

@typing_extensions.final
class ManagedInstancesRestorableDroppedDatabasesBackupShortTermRetentionPolicies(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    RETENTION_DAYS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    retention_days: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        retention_days: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info", "retention_days", b"retention_days"]) -> None: ...

global___ManagedInstancesRestorableDroppedDatabasesBackupShortTermRetentionPolicies = ManagedInstancesRestorableDroppedDatabasesBackupShortTermRetentionPolicies

@typing_extensions.final
class ManagedInstancesPrivateEndpointConnections(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PRIVATE_ENDPOINT_FIELD_NUMBER: builtins.int
    PRIVATE_LINK_SERVICE_CONNECTION_STATE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def private_endpoint(self) -> global___ManagedInstancePrivateEndpointProperty: ...
    @property
    def private_link_service_connection_state(self) -> global___ManagedInstancePrivateLinkServiceConnectionStateProperty: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        private_endpoint: global___ManagedInstancePrivateEndpointProperty | None = ...,
        private_link_service_connection_state: global___ManagedInstancePrivateLinkServiceConnectionStateProperty | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["private_endpoint", b"private_endpoint", "private_link_service_connection_state", b"private_link_service_connection_state", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "private_endpoint", b"private_endpoint", "private_link_service_connection_state", b"private_link_service_connection_state", "resource_info", b"resource_info"]) -> None: ...

global___ManagedInstancesPrivateEndpointConnections = ManagedInstancesPrivateEndpointConnections

@typing_extensions.final
class ManagedInstancePrivateLinkServiceConnectionStateProperty(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    description: builtins.str
    status: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        status: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "status", b"status"]) -> None: ...

global___ManagedInstancePrivateLinkServiceConnectionStateProperty = ManagedInstancePrivateLinkServiceConnectionStateProperty

@typing_extensions.final
class ManagedInstancePrivateEndpointProperty(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    def __init__(
        self,
        *,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id"]) -> None: ...

global___ManagedInstancePrivateEndpointProperty = ManagedInstancePrivateEndpointProperty

@typing_extensions.final
class ManagedInstancesKeys(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    SERVER_KEY_TYPE_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    server_key_type: builtins.str
    uri: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        server_key_type: builtins.str = ...,
        uri: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info", "server_key_type", b"server_key_type", "uri", b"uri"]) -> None: ...

global___ManagedInstancesKeys = ManagedInstancesKeys

@typing_extensions.final
class ManagedInstancesEncryptionProtector(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    AUTO_ROTATION_ENABLED_FIELD_NUMBER: builtins.int
    SERVER_KEY_NAME_FIELD_NUMBER: builtins.int
    SERVER_KEY_TYPE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    auto_rotation_enabled: builtins.bool
    server_key_name: builtins.str
    server_key_type: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        auto_rotation_enabled: builtins.bool = ...,
        server_key_name: builtins.str = ...,
        server_key_type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auto_rotation_enabled", b"auto_rotation_enabled", "name", b"name", "resource_info", b"resource_info", "server_key_name", b"server_key_name", "server_key_type", b"server_key_type"]) -> None: ...

global___ManagedInstancesEncryptionProtector = ManagedInstancesEncryptionProtector

@typing_extensions.final
class ManagedInstancesDistributedAvailabilityGroups(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PRIMARY_AVAILABILITY_GROUP_NAME_FIELD_NUMBER: builtins.int
    REPLICATION_MODE_FIELD_NUMBER: builtins.int
    SECONDARY_AVAILABILITY_GROUP_NAME_FIELD_NUMBER: builtins.int
    SOURCE_ENDPOINT_FIELD_NUMBER: builtins.int
    TARGET_DATABASE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    primary_availability_group_name: builtins.str
    replication_mode: builtins.str
    secondary_availability_group_name: builtins.str
    source_endpoint: builtins.str
    target_database: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        primary_availability_group_name: builtins.str = ...,
        replication_mode: builtins.str = ...,
        secondary_availability_group_name: builtins.str = ...,
        source_endpoint: builtins.str = ...,
        target_database: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "primary_availability_group_name", b"primary_availability_group_name", "replication_mode", b"replication_mode", "resource_info", b"resource_info", "secondary_availability_group_name", b"secondary_availability_group_name", "source_endpoint", b"source_endpoint", "target_database", b"target_database"]) -> None: ...

global___ManagedInstancesDistributedAvailabilityGroups = ManagedInstancesDistributedAvailabilityGroups

@typing_extensions.final
class ManagedInstancesDatabasesVulnerabilityAssessmentsRulesBaselines(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    BASELINE_RESULTS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def baseline_results(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DatabaseVulnerabilityAssessmentRuleBaselineItem]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        baseline_results: collections.abc.Iterable[global___DatabaseVulnerabilityAssessmentRuleBaselineItem] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["baseline_results", b"baseline_results", "name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___ManagedInstancesDatabasesVulnerabilityAssessmentsRulesBaselines = ManagedInstancesDatabasesVulnerabilityAssessmentsRulesBaselines

@typing_extensions.final
class DatabaseVulnerabilityAssessmentRuleBaselineItem(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESULT_FIELD_NUMBER: builtins.int
    @property
    def result(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        result: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["result", b"result"]) -> None: ...

global___DatabaseVulnerabilityAssessmentRuleBaselineItem = DatabaseVulnerabilityAssessmentRuleBaselineItem

@typing_extensions.final
class ManagedInstancesDatabasesVulnerabilityAssessments(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    RECURRING_SCANS_FIELD_NUMBER: builtins.int
    STORAGE_ACCOUNT_ACCESS_KEY_FIELD_NUMBER: builtins.int
    STORAGE_CONTAINER_PATH_FIELD_NUMBER: builtins.int
    STORAGE_CONTAINER_SAS_KEY_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def recurring_scans(self) -> global___VulnerabilityAssessmentRecurringScansProperties: ...
    storage_account_access_key: builtins.str
    storage_container_path: builtins.str
    storage_container_sas_key: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        recurring_scans: global___VulnerabilityAssessmentRecurringScansProperties | None = ...,
        storage_account_access_key: builtins.str = ...,
        storage_container_path: builtins.str = ...,
        storage_container_sas_key: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["recurring_scans", b"recurring_scans", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "recurring_scans", b"recurring_scans", "resource_info", b"resource_info", "storage_account_access_key", b"storage_account_access_key", "storage_container_path", b"storage_container_path", "storage_container_sas_key", b"storage_container_sas_key"]) -> None: ...

global___ManagedInstancesDatabasesVulnerabilityAssessments = ManagedInstancesDatabasesVulnerabilityAssessments

@typing_extensions.final
class VulnerabilityAssessmentRecurringScansProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMAILS_FIELD_NUMBER: builtins.int
    EMAIL_SUBSCRIPTION_ADMINS_FIELD_NUMBER: builtins.int
    IS_ENABLED_FIELD_NUMBER: builtins.int
    @property
    def emails(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    email_subscription_admins: builtins.bool
    is_enabled: builtins.bool
    def __init__(
        self,
        *,
        emails: collections.abc.Iterable[builtins.str] | None = ...,
        email_subscription_admins: builtins.bool = ...,
        is_enabled: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["email_subscription_admins", b"email_subscription_admins", "emails", b"emails", "is_enabled", b"is_enabled"]) -> None: ...

global___VulnerabilityAssessmentRecurringScansProperties = VulnerabilityAssessmentRecurringScansProperties

@typing_extensions.final
class ManagedInstancesDatabasesTransparentDataEncryption(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    state: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        state: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info", "state", b"state"]) -> None: ...

global___ManagedInstancesDatabasesTransparentDataEncryption = ManagedInstancesDatabasesTransparentDataEncryption

@typing_extensions.final
class ManagedInstancesDatabasesSecurityAlertPolicies(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DISABLED_ALERTS_FIELD_NUMBER: builtins.int
    EMAIL_ACCOUNT_ADMINS_FIELD_NUMBER: builtins.int
    EMAIL_ADDRESSES_FIELD_NUMBER: builtins.int
    RETENTION_DAYS_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    STORAGE_ACCOUNT_ACCESS_KEY_FIELD_NUMBER: builtins.int
    STORAGE_ENDPOINT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def disabled_alerts(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    email_account_admins: builtins.bool
    @property
    def email_addresses(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    retention_days: builtins.int
    state: builtins.str
    storage_account_access_key: builtins.str
    storage_endpoint: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        disabled_alerts: collections.abc.Iterable[builtins.str] | None = ...,
        email_account_admins: builtins.bool = ...,
        email_addresses: collections.abc.Iterable[builtins.str] | None = ...,
        retention_days: builtins.int = ...,
        state: builtins.str = ...,
        storage_account_access_key: builtins.str = ...,
        storage_endpoint: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["disabled_alerts", b"disabled_alerts", "email_account_admins", b"email_account_admins", "email_addresses", b"email_addresses", "name", b"name", "resource_info", b"resource_info", "retention_days", b"retention_days", "state", b"state", "storage_account_access_key", b"storage_account_access_key", "storage_endpoint", b"storage_endpoint"]) -> None: ...

global___ManagedInstancesDatabasesSecurityAlertPolicies = ManagedInstancesDatabasesSecurityAlertPolicies

@typing_extensions.final
class ManagedInstancesDatabasesSchemasTablesColumnsSensitivityLabels(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    INFORMATION_TYPE_FIELD_NUMBER: builtins.int
    INFORMATION_TYPE_ID_FIELD_NUMBER: builtins.int
    LABEL_ID_FIELD_NUMBER: builtins.int
    LABEL_NAME_FIELD_NUMBER: builtins.int
    RANK_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    information_type: builtins.str
    information_type_id: builtins.str
    label_id: builtins.str
    label_name: builtins.str
    rank: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        information_type: builtins.str = ...,
        information_type_id: builtins.str = ...,
        label_id: builtins.str = ...,
        label_name: builtins.str = ...,
        rank: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["information_type", b"information_type", "information_type_id", b"information_type_id", "label_id", b"label_id", "label_name", b"label_name", "name", b"name", "rank", b"rank", "resource_info", b"resource_info"]) -> None: ...

global___ManagedInstancesDatabasesSchemasTablesColumnsSensitivityLabels = ManagedInstancesDatabasesSchemasTablesColumnsSensitivityLabels

@typing_extensions.final
class ManagedInstancesDatabasesBackupShortTermRetentionPolicies(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    RETENTION_DAYS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    retention_days: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        retention_days: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info", "retention_days", b"retention_days"]) -> None: ...

global___ManagedInstancesDatabasesBackupShortTermRetentionPolicies = ManagedInstancesDatabasesBackupShortTermRetentionPolicies

@typing_extensions.final
class ManagedInstancesDatabasesBackupLongTermRetentionPolicies(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    MONTHLY_RETENTION_FIELD_NUMBER: builtins.int
    WEEKLY_RETENTION_FIELD_NUMBER: builtins.int
    WEEK_OF_YEAR_FIELD_NUMBER: builtins.int
    YEARLY_RETENTION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    monthly_retention: builtins.str
    weekly_retention: builtins.str
    week_of_year: builtins.int
    yearly_retention: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        monthly_retention: builtins.str = ...,
        weekly_retention: builtins.str = ...,
        week_of_year: builtins.int = ...,
        yearly_retention: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["monthly_retention", b"monthly_retention", "name", b"name", "resource_info", b"resource_info", "week_of_year", b"week_of_year", "weekly_retention", b"weekly_retention", "yearly_retention", b"yearly_retention"]) -> None: ...

global___ManagedInstancesDatabasesBackupLongTermRetentionPolicies = ManagedInstancesDatabasesBackupLongTermRetentionPolicies

@typing_extensions.final
class ManagedInstancesDatabases(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    AUTO_COMPLETE_RESTORE_FIELD_NUMBER: builtins.int
    CATALOG_COLLATION_FIELD_NUMBER: builtins.int
    COLLATION_FIELD_NUMBER: builtins.int
    CREATE_MODE_FIELD_NUMBER: builtins.int
    LAST_BACKUP_NAME_FIELD_NUMBER: builtins.int
    LONG_TERM_RETENTION_BACKUP_RESOURCE_ID_FIELD_NUMBER: builtins.int
    RECOVERABLE_DATABASE_ID_FIELD_NUMBER: builtins.int
    RESTORABLE_DROPPED_DATABASE_ID_FIELD_NUMBER: builtins.int
    RESTORE_POINT_IN_TIME_FIELD_NUMBER: builtins.int
    SOURCE_DATABASE_ID_FIELD_NUMBER: builtins.int
    STORAGE_CONTAINER_SAS_TOKEN_FIELD_NUMBER: builtins.int
    STORAGE_CONTAINER_URI_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    MANAGED_INSTANCES_DATABASES_BACKUP_SHORT_TERM_RETENTION_POLICIES_FIELD_NUMBER: builtins.int
    MANAGED_INSTANCES_DATABASES_SECURITY_ALERT_POLICIES_FIELD_NUMBER: builtins.int
    MANAGED_INSTANCES_DATABASES_TRANSPARENT_DATA_ENCRYPTION_FIELD_NUMBER: builtins.int
    MANAGED_INSTANCES_DATABASES_VULNERABILITY_ASSESSMENTS_FIELD_NUMBER: builtins.int
    MANAGED_INSTANCES_DATABASES_BACKUP_LONG_TERM_RETENTION_POLICIES_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    location: builtins.str
    name: builtins.str
    auto_complete_restore: builtins.bool
    catalog_collation: builtins.str
    collation: builtins.str
    create_mode: builtins.str
    last_backup_name: builtins.str
    long_term_retention_backup_resource_id: builtins.str
    recoverable_database_id: builtins.str
    restorable_dropped_database_id: builtins.str
    restore_point_in_time: builtins.str
    source_database_id: builtins.str
    storage_container_sas_token: builtins.str
    storage_container_uri: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def managed_instances_databases_backup_short_term_retention_policies(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ManagedInstancesDatabasesBackupShortTermRetentionPolicies]: ...
    @property
    def managed_instances_databases_security_alert_policies(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ManagedInstancesDatabasesSecurityAlertPolicies]: ...
    @property
    def managed_instances_databases_transparent_data_encryption(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ManagedInstancesDatabasesTransparentDataEncryption]: ...
    @property
    def managed_instances_databases_vulnerability_assessments(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ManagedInstancesDatabasesVulnerabilityAssessments]: ...
    @property
    def managed_instances_databases_backup_long_term_retention_policies(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ManagedInstancesDatabasesBackupLongTermRetentionPolicies]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        auto_complete_restore: builtins.bool = ...,
        catalog_collation: builtins.str = ...,
        collation: builtins.str = ...,
        create_mode: builtins.str = ...,
        last_backup_name: builtins.str = ...,
        long_term_retention_backup_resource_id: builtins.str = ...,
        recoverable_database_id: builtins.str = ...,
        restorable_dropped_database_id: builtins.str = ...,
        restore_point_in_time: builtins.str = ...,
        source_database_id: builtins.str = ...,
        storage_container_sas_token: builtins.str = ...,
        storage_container_uri: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        managed_instances_databases_backup_short_term_retention_policies: collections.abc.Iterable[global___ManagedInstancesDatabasesBackupShortTermRetentionPolicies] | None = ...,
        managed_instances_databases_security_alert_policies: collections.abc.Iterable[global___ManagedInstancesDatabasesSecurityAlertPolicies] | None = ...,
        managed_instances_databases_transparent_data_encryption: collections.abc.Iterable[global___ManagedInstancesDatabasesTransparentDataEncryption] | None = ...,
        managed_instances_databases_vulnerability_assessments: collections.abc.Iterable[global___ManagedInstancesDatabasesVulnerabilityAssessments] | None = ...,
        managed_instances_databases_backup_long_term_retention_policies: collections.abc.Iterable[global___ManagedInstancesDatabasesBackupLongTermRetentionPolicies] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auto_complete_restore", b"auto_complete_restore", "catalog_collation", b"catalog_collation", "collation", b"collation", "create_mode", b"create_mode", "last_backup_name", b"last_backup_name", "location", b"location", "long_term_retention_backup_resource_id", b"long_term_retention_backup_resource_id", "managed_instances_databases_backup_long_term_retention_policies", b"managed_instances_databases_backup_long_term_retention_policies", "managed_instances_databases_backup_short_term_retention_policies", b"managed_instances_databases_backup_short_term_retention_policies", "managed_instances_databases_security_alert_policies", b"managed_instances_databases_security_alert_policies", "managed_instances_databases_transparent_data_encryption", b"managed_instances_databases_transparent_data_encryption", "managed_instances_databases_vulnerability_assessments", b"managed_instances_databases_vulnerability_assessments", "name", b"name", "recoverable_database_id", b"recoverable_database_id", "resource_info", b"resource_info", "restorable_dropped_database_id", b"restorable_dropped_database_id", "restore_point_in_time", b"restore_point_in_time", "source_database_id", b"source_database_id", "storage_container_sas_token", b"storage_container_sas_token", "storage_container_uri", b"storage_container_uri", "tags", b"tags"]) -> None: ...

global___ManagedInstancesDatabases = ManagedInstancesDatabases

@typing_extensions.final
class ManagedInstancesAzureADOnlyAuthentications(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    AZURE_AD_ONLY_AUTHENTICATION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    azure_ad_only_authentication: builtins.bool
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        azure_ad_only_authentication: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["azure_ad_only_authentication", b"azure_ad_only_authentication", "name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___ManagedInstancesAzureADOnlyAuthentications = ManagedInstancesAzureADOnlyAuthentications

@typing_extensions.final
class ManagedInstancesAdministrators(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ADMINISTRATOR_TYPE_FIELD_NUMBER: builtins.int
    LOGIN_FIELD_NUMBER: builtins.int
    SID_FIELD_NUMBER: builtins.int
    TENANT_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    administrator_type: builtins.str
    login: builtins.str
    sid: builtins.str
    tenant_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        administrator_type: builtins.str = ...,
        login: builtins.str = ...,
        sid: builtins.str = ...,
        tenant_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["administrator_type", b"administrator_type", "login", b"login", "name", b"name", "resource_info", b"resource_info", "sid", b"sid", "tenant_id", b"tenant_id"]) -> None: ...

global___ManagedInstancesAdministrators = ManagedInstancesAdministrators

@typing_extensions.final
class ManagedInstances(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    IDENTITY_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ADMINISTRATOR_LOGIN_FIELD_NUMBER: builtins.int
    ADMINISTRATOR_LOGIN_PASSWORD_FIELD_NUMBER: builtins.int
    ADMINISTRATORS_FIELD_NUMBER: builtins.int
    COLLATION_FIELD_NUMBER: builtins.int
    DNS_ZONE_PARTNER_FIELD_NUMBER: builtins.int
    INSTANCE_POOL_ID_FIELD_NUMBER: builtins.int
    KEY_ID_FIELD_NUMBER: builtins.int
    LICENSE_TYPE_FIELD_NUMBER: builtins.int
    MAINTENANCE_CONFIGURATION_ID_FIELD_NUMBER: builtins.int
    MANAGED_INSTANCE_CREATE_MODE_FIELD_NUMBER: builtins.int
    MINIMAL_TLS_VERSION_FIELD_NUMBER: builtins.int
    PRIMARY_USER_ASSIGNED_IDENTITY_ID_FIELD_NUMBER: builtins.int
    PROXY_OVERRIDE_FIELD_NUMBER: builtins.int
    PUBLIC_DATA_ENDPOINT_ENABLED_FIELD_NUMBER: builtins.int
    REQUESTED_BACKUP_STORAGE_REDUNDANCY_FIELD_NUMBER: builtins.int
    RESTORE_POINT_IN_TIME_FIELD_NUMBER: builtins.int
    SERVICE_PRINCIPAL_FIELD_NUMBER: builtins.int
    SOURCE_MANAGED_INSTANCE_ID_FIELD_NUMBER: builtins.int
    STORAGE_SIZE_IN_GB_FIELD_NUMBER: builtins.int
    SUBNET_ID_FIELD_NUMBER: builtins.int
    TIMEZONE_ID_FIELD_NUMBER: builtins.int
    V_CORES_FIELD_NUMBER: builtins.int
    ZONE_REDUNDANT_FIELD_NUMBER: builtins.int
    SKU_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    MANAGED_INSTANCES_DISTRIBUTED_AVAILABILITY_GROUPS_FIELD_NUMBER: builtins.int
    MANAGED_INSTANCES_ADMINISTRATORS_FIELD_NUMBER: builtins.int
    MANAGED_INSTANCES_AZURE_AD_ONLY_AUTHENTICATIONS_FIELD_NUMBER: builtins.int
    MANAGED_INSTANCES_ENCRYPTION_PROTECTOR_FIELD_NUMBER: builtins.int
    MANAGED_INSTANCES_KEYS_FIELD_NUMBER: builtins.int
    MANAGED_INSTANCES_PRIVATE_ENDPOINT_CONNECTIONS_FIELD_NUMBER: builtins.int
    MANAGED_INSTANCES_VULNERABILITY_ASSESSMENTS_FIELD_NUMBER: builtins.int
    MANAGED_INSTANCES_SECURITY_ALERT_POLICIES_FIELD_NUMBER: builtins.int
    MANAGED_INSTANCES_SERVER_TRUST_CERTIFICATES_FIELD_NUMBER: builtins.int
    MANAGED_INSTANCES_SQL_AGENT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def identity(self) -> global___ResourceIdentity: ...
    location: builtins.str
    name: builtins.str
    administrator_login: builtins.str
    administrator_login_password: builtins.str
    @property
    def administrators(self) -> global___ManagedInstanceExternalAdministrator: ...
    collation: builtins.str
    dns_zone_partner: builtins.str
    instance_pool_id: builtins.str
    key_id: builtins.str
    license_type: builtins.str
    maintenance_configuration_id: builtins.str
    managed_instance_create_mode: builtins.str
    minimal_tls_version: builtins.str
    primary_user_assigned_identity_id: builtins.str
    proxy_override: builtins.str
    public_data_endpoint_enabled: builtins.bool
    requested_backup_storage_redundancy: builtins.str
    restore_point_in_time: builtins.str
    @property
    def service_principal(self) -> global___ServicePrincipal: ...
    source_managed_instance_id: builtins.str
    storage_size_in_gb: builtins.int
    subnet_id: builtins.str
    timezone_id: builtins.str
    v_cores: builtins.int
    zone_redundant: builtins.bool
    @property
    def sku(self) -> global___Sku: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def managed_instances_distributed_availability_groups(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ManagedInstancesDistributedAvailabilityGroups]: ...
    @property
    def managed_instances_administrators(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ManagedInstancesAdministrators]: ...
    @property
    def managed_instances_azure_ad_only_authentications(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ManagedInstancesAzureADOnlyAuthentications]: ...
    @property
    def managed_instances_encryption_protector(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ManagedInstancesEncryptionProtector]: ...
    @property
    def managed_instances_keys(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ManagedInstancesKeys]: ...
    @property
    def managed_instances_private_endpoint_connections(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ManagedInstancesPrivateEndpointConnections]: ...
    @property
    def managed_instances_vulnerability_assessments(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ManagedInstancesVulnerabilityAssessments]: ...
    @property
    def managed_instances_security_alert_policies(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ManagedInstancesSecurityAlertPolicies]: ...
    @property
    def managed_instances_server_trust_certificates(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ManagedInstancesServerTrustCertificates]: ...
    @property
    def managed_instances_sql_agent(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ManagedInstancesSqlAgent]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        identity: global___ResourceIdentity | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        administrator_login: builtins.str = ...,
        administrator_login_password: builtins.str = ...,
        administrators: global___ManagedInstanceExternalAdministrator | None = ...,
        collation: builtins.str = ...,
        dns_zone_partner: builtins.str = ...,
        instance_pool_id: builtins.str = ...,
        key_id: builtins.str = ...,
        license_type: builtins.str = ...,
        maintenance_configuration_id: builtins.str = ...,
        managed_instance_create_mode: builtins.str = ...,
        minimal_tls_version: builtins.str = ...,
        primary_user_assigned_identity_id: builtins.str = ...,
        proxy_override: builtins.str = ...,
        public_data_endpoint_enabled: builtins.bool = ...,
        requested_backup_storage_redundancy: builtins.str = ...,
        restore_point_in_time: builtins.str = ...,
        service_principal: global___ServicePrincipal | None = ...,
        source_managed_instance_id: builtins.str = ...,
        storage_size_in_gb: builtins.int = ...,
        subnet_id: builtins.str = ...,
        timezone_id: builtins.str = ...,
        v_cores: builtins.int = ...,
        zone_redundant: builtins.bool = ...,
        sku: global___Sku | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        managed_instances_distributed_availability_groups: collections.abc.Iterable[global___ManagedInstancesDistributedAvailabilityGroups] | None = ...,
        managed_instances_administrators: collections.abc.Iterable[global___ManagedInstancesAdministrators] | None = ...,
        managed_instances_azure_ad_only_authentications: collections.abc.Iterable[global___ManagedInstancesAzureADOnlyAuthentications] | None = ...,
        managed_instances_encryption_protector: collections.abc.Iterable[global___ManagedInstancesEncryptionProtector] | None = ...,
        managed_instances_keys: collections.abc.Iterable[global___ManagedInstancesKeys] | None = ...,
        managed_instances_private_endpoint_connections: collections.abc.Iterable[global___ManagedInstancesPrivateEndpointConnections] | None = ...,
        managed_instances_vulnerability_assessments: collections.abc.Iterable[global___ManagedInstancesVulnerabilityAssessments] | None = ...,
        managed_instances_security_alert_policies: collections.abc.Iterable[global___ManagedInstancesSecurityAlertPolicies] | None = ...,
        managed_instances_server_trust_certificates: collections.abc.Iterable[global___ManagedInstancesServerTrustCertificates] | None = ...,
        managed_instances_sql_agent: collections.abc.Iterable[global___ManagedInstancesSqlAgent] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["administrators", b"administrators", "identity", b"identity", "resource_info", b"resource_info", "service_principal", b"service_principal", "sku", b"sku"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["administrator_login", b"administrator_login", "administrator_login_password", b"administrator_login_password", "administrators", b"administrators", "collation", b"collation", "dns_zone_partner", b"dns_zone_partner", "identity", b"identity", "instance_pool_id", b"instance_pool_id", "key_id", b"key_id", "license_type", b"license_type", "location", b"location", "maintenance_configuration_id", b"maintenance_configuration_id", "managed_instance_create_mode", b"managed_instance_create_mode", "managed_instances_administrators", b"managed_instances_administrators", "managed_instances_azure_ad_only_authentications", b"managed_instances_azure_ad_only_authentications", "managed_instances_distributed_availability_groups", b"managed_instances_distributed_availability_groups", "managed_instances_encryption_protector", b"managed_instances_encryption_protector", "managed_instances_keys", b"managed_instances_keys", "managed_instances_private_endpoint_connections", b"managed_instances_private_endpoint_connections", "managed_instances_security_alert_policies", b"managed_instances_security_alert_policies", "managed_instances_server_trust_certificates", b"managed_instances_server_trust_certificates", "managed_instances_sql_agent", b"managed_instances_sql_agent", "managed_instances_vulnerability_assessments", b"managed_instances_vulnerability_assessments", "minimal_tls_version", b"minimal_tls_version", "name", b"name", "primary_user_assigned_identity_id", b"primary_user_assigned_identity_id", "proxy_override", b"proxy_override", "public_data_endpoint_enabled", b"public_data_endpoint_enabled", "requested_backup_storage_redundancy", b"requested_backup_storage_redundancy", "resource_info", b"resource_info", "restore_point_in_time", b"restore_point_in_time", "service_principal", b"service_principal", "sku", b"sku", "source_managed_instance_id", b"source_managed_instance_id", "storage_size_in_gb", b"storage_size_in_gb", "subnet_id", b"subnet_id", "tags", b"tags", "timezone_id", b"timezone_id", "v_cores", b"v_cores", "zone_redundant", b"zone_redundant"]) -> None: ...

global___ManagedInstances = ManagedInstances

@typing_extensions.final
class Sku(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CAPACITY_FIELD_NUMBER: builtins.int
    FAMILY_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    SIZE_FIELD_NUMBER: builtins.int
    TIER_FIELD_NUMBER: builtins.int
    capacity: builtins.int
    family: builtins.str
    name: builtins.str
    size: builtins.str
    tier: builtins.str
    def __init__(
        self,
        *,
        capacity: builtins.int = ...,
        family: builtins.str = ...,
        name: builtins.str = ...,
        size: builtins.str = ...,
        tier: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["capacity", b"capacity", "family", b"family", "name", b"name", "size", b"size", "tier", b"tier"]) -> None: ...

global___Sku = Sku

@typing_extensions.final
class ServicePrincipal(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    type: builtins.str
    def __init__(
        self,
        *,
        type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["type", b"type"]) -> None: ...

global___ServicePrincipal = ServicePrincipal

@typing_extensions.final
class ManagedInstanceExternalAdministrator(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADMINISTRATOR_TYPE_FIELD_NUMBER: builtins.int
    AZURE_AD_ONLY_AUTHENTICATION_FIELD_NUMBER: builtins.int
    LOGIN_FIELD_NUMBER: builtins.int
    PRINCIPAL_TYPE_FIELD_NUMBER: builtins.int
    SID_FIELD_NUMBER: builtins.int
    TENANT_ID_FIELD_NUMBER: builtins.int
    administrator_type: builtins.str
    azure_ad_only_authentication: builtins.bool
    login: builtins.str
    principal_type: builtins.str
    sid: builtins.str
    tenant_id: builtins.str
    def __init__(
        self,
        *,
        administrator_type: builtins.str = ...,
        azure_ad_only_authentication: builtins.bool = ...,
        login: builtins.str = ...,
        principal_type: builtins.str = ...,
        sid: builtins.str = ...,
        tenant_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["administrator_type", b"administrator_type", "azure_ad_only_authentication", b"azure_ad_only_authentication", "login", b"login", "principal_type", b"principal_type", "sid", b"sid", "tenant_id", b"tenant_id"]) -> None: ...

global___ManagedInstanceExternalAdministrator = ManagedInstanceExternalAdministrator

@typing_extensions.final
class ResourceIdentity(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class UserAssignedIdentitiesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    TYPE_FIELD_NUMBER: builtins.int
    USER_ASSIGNED_IDENTITIES_FIELD_NUMBER: builtins.int
    type: builtins.str
    @property
    def user_assigned_identities(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        type: builtins.str = ...,
        user_assigned_identities: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["type", b"type", "user_assigned_identities", b"user_assigned_identities"]) -> None: ...

global___ResourceIdentity = ResourceIdentity
