"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ComputeSnapshotXSnapshotEncryptionKey(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KMS_KEY_SELF_LINK_FIELD_NUMBER: builtins.int
    KMS_KEY_SERVICE_ACCOUNT_FIELD_NUMBER: builtins.int
    RAW_KEY_FIELD_NUMBER: builtins.int
    SHA256_FIELD_NUMBER: builtins.int
    kms_key_self_link: builtins.str
    kms_key_service_account: builtins.str
    raw_key: builtins.str
    sha256: builtins.str
    def __init__(
        self,
        *,
        kms_key_self_link: builtins.str = ...,
        kms_key_service_account: builtins.str = ...,
        raw_key: builtins.str = ...,
        sha256: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["kms_key_self_link", b"kms_key_self_link", "kms_key_service_account", b"kms_key_service_account", "raw_key", b"raw_key", "sha256", b"sha256"]) -> None: ...

global___ComputeSnapshotXSnapshotEncryptionKey = ComputeSnapshotXSnapshotEncryptionKey

@typing_extensions.final
class ComputeSnapshotXSourceDiskEncryptionKey(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KMS_KEY_SERVICE_ACCOUNT_FIELD_NUMBER: builtins.int
    RAW_KEY_FIELD_NUMBER: builtins.int
    kms_key_service_account: builtins.str
    raw_key: builtins.str
    def __init__(
        self,
        *,
        kms_key_service_account: builtins.str = ...,
        raw_key: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["kms_key_service_account", b"kms_key_service_account", "raw_key", b"raw_key"]) -> None: ...

global___ComputeSnapshotXSourceDiskEncryptionKey = ComputeSnapshotXSourceDiskEncryptionKey

@typing_extensions.final
class ComputeSnapshotXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___ComputeSnapshotXTimeouts = ComputeSnapshotXTimeouts

@typing_extensions.final
class ComputeSnapshot(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    CREATION_TIMESTAMP_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    DISK_SIZE_GB_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LABEL_FINGERPRINT_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    LICENSES_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    SELF_LINK_FIELD_NUMBER: builtins.int
    SNAPSHOT_ID_FIELD_NUMBER: builtins.int
    SOURCE_DISK_FIELD_NUMBER: builtins.int
    STORAGE_BYTES_FIELD_NUMBER: builtins.int
    STORAGE_LOCATIONS_FIELD_NUMBER: builtins.int
    ZONE_FIELD_NUMBER: builtins.int
    SNAPSHOT_ENCRYPTION_KEY_FIELD_NUMBER: builtins.int
    SOURCE_DISK_ENCRYPTION_KEY_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    creation_timestamp: builtins.str
    description: builtins.str
    disk_size_gb: builtins.float
    id: builtins.str
    label_fingerprint: builtins.str
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def licenses(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    name: builtins.str
    project: builtins.str
    self_link: builtins.str
    snapshot_id: builtins.float
    source_disk: builtins.str
    storage_bytes: builtins.float
    @property
    def storage_locations(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    zone: builtins.str
    @property
    def snapshot_encryption_key(self) -> global___ComputeSnapshotXSnapshotEncryptionKey: ...
    @property
    def source_disk_encryption_key(self) -> global___ComputeSnapshotXSourceDiskEncryptionKey: ...
    @property
    def timeouts(self) -> global___ComputeSnapshotXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        creation_timestamp: builtins.str = ...,
        description: builtins.str = ...,
        disk_size_gb: builtins.float = ...,
        id: builtins.str = ...,
        label_fingerprint: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        licenses: collections.abc.Iterable[builtins.str] | None = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        self_link: builtins.str = ...,
        snapshot_id: builtins.float = ...,
        source_disk: builtins.str = ...,
        storage_bytes: builtins.float = ...,
        storage_locations: collections.abc.Iterable[builtins.str] | None = ...,
        zone: builtins.str = ...,
        snapshot_encryption_key: global___ComputeSnapshotXSnapshotEncryptionKey | None = ...,
        source_disk_encryption_key: global___ComputeSnapshotXSourceDiskEncryptionKey | None = ...,
        timeouts: global___ComputeSnapshotXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "snapshot_encryption_key", b"snapshot_encryption_key", "source_disk_encryption_key", b"source_disk_encryption_key", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["creation_timestamp", b"creation_timestamp", "description", b"description", "disk_size_gb", b"disk_size_gb", "id", b"id", "label_fingerprint", b"label_fingerprint", "labels", b"labels", "licenses", b"licenses", "name", b"name", "project", b"project", "resource_info", b"resource_info", "self_link", b"self_link", "snapshot_encryption_key", b"snapshot_encryption_key", "snapshot_id", b"snapshot_id", "source_disk", b"source_disk", "source_disk_encryption_key", b"source_disk_encryption_key", "storage_bytes", b"storage_bytes", "storage_locations", b"storage_locations", "timeouts", b"timeouts", "zone", b"zone"]) -> None: ...

global___ComputeSnapshot = ComputeSnapshot

@typing_extensions.final
class ComputeSnapshotIamBindingXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___ComputeSnapshotIamBindingXCondition = ComputeSnapshotIamBindingXCondition

@typing_extensions.final
class ComputeSnapshotIamBinding(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    MEMBERS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    @property
    def members(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    name: builtins.str
    project: builtins.str
    role: builtins.str
    @property
    def condition(self) -> global___ComputeSnapshotIamBindingXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        members: collections.abc.Iterable[builtins.str] | None = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        role: builtins.str = ...,
        condition: global___ComputeSnapshotIamBindingXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "etag", b"etag", "id", b"id", "members", b"members", "name", b"name", "project", b"project", "resource_info", b"resource_info", "role", b"role"]) -> None: ...

global___ComputeSnapshotIamBinding = ComputeSnapshotIamBinding

@typing_extensions.final
class ComputeSnapshotIamMemberXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___ComputeSnapshotIamMemberXCondition = ComputeSnapshotIamMemberXCondition

@typing_extensions.final
class ComputeSnapshotIamMember(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    MEMBER_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    member: builtins.str
    name: builtins.str
    project: builtins.str
    role: builtins.str
    @property
    def condition(self) -> global___ComputeSnapshotIamMemberXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        member: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        role: builtins.str = ...,
        condition: global___ComputeSnapshotIamMemberXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "etag", b"etag", "id", b"id", "member", b"member", "name", b"name", "project", b"project", "resource_info", b"resource_info", "role", b"role"]) -> None: ...

global___ComputeSnapshotIamMember = ComputeSnapshotIamMember

@typing_extensions.final
class ComputeSnapshotIamPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    POLICY_DATA_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    name: builtins.str
    policy_data: builtins.str
    project: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        policy_data: builtins.str = ...,
        project: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["etag", b"etag", "id", b"id", "name", b"name", "policy_data", b"policy_data", "project", b"project", "resource_info", b"resource_info"]) -> None: ...

global___ComputeSnapshotIamPolicy = ComputeSnapshotIamPolicy
