# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: azure/azure_microsoft_network_routetables.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/azure/azure_microsoft_network_routetables.proto\x12/oak9.tython.azure.microsoft_network_routetables\x1a\x13shared/shared.proto\"\xd4\x01\n\x1dMicrosoft_Network_routeTables\x12R\n\x0croute_tables\x18\x01 \x01(\x0b\x32<.oak9.tython.azure.microsoft_network_routetables.RouteTables\x12_\n\x13route_tables_routes\x18\x02 \x03(\x0b\x32\x42.oak9.tython.azure.microsoft_network_routetables.RouteTablesRoutes\"\xc0\x01\n\x11RouteTablesRoutes\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x16\n\x0e\x61\x64\x64ress_prefix\x18\x03 \x01(\t\x12\x15\n\rnext_hop_type\x18\x04 \x01(\t\x12\x1b\n\x13next_hop_ip_address\x18\x05 \x01(\t\x12\x18\n\x10has_bgp_override\x18\x06 \x01(\x08\"\xd8\x02\n\x0bRouteTables\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12T\n\x04tags\x18\x04 \x03(\x0b\x32\x46.oak9.tython.azure.microsoft_network_routetables.RouteTables.TagsEntry\x12\x46\n\x06routes\x18\x05 \x03(\x0b\x32\x36.oak9.tython.azure.microsoft_network_routetables.Route\x12%\n\x1d\x64isable_bgp_route_propagation\x18\x06 \x01(\x08\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"{\n\x05Route\x12\x16\n\x0e\x61\x64\x64ress_prefix\x18\x01 \x01(\t\x12\x15\n\rnext_hop_type\x18\x02 \x01(\t\x12\x1b\n\x13next_hop_ip_address\x18\x03 \x01(\t\x12\x18\n\x10has_bgp_override\x18\x04 \x01(\x08\x12\x0c\n\x04name\x18\x05 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'azure.azure_microsoft_network_routetables_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ROUTETABLES_TAGSENTRY._options = None
  _ROUTETABLES_TAGSENTRY._serialized_options = b'8\001'
  _MICROSOFT_NETWORK_ROUTETABLES._serialized_start=122
  _MICROSOFT_NETWORK_ROUTETABLES._serialized_end=334
  _ROUTETABLESROUTES._serialized_start=337
  _ROUTETABLESROUTES._serialized_end=529
  _ROUTETABLES._serialized_start=532
  _ROUTETABLES._serialized_end=876
  _ROUTETABLES_TAGSENTRY._serialized_start=833
  _ROUTETABLES_TAGSENTRY._serialized_end=876
  _ROUTE._serialized_start=878
  _ROUTE._serialized_end=1001
# @@protoc_insertion_point(module_scope)
