# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_google_app_engine_bundle.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2
from oak9.tython.models.gcp import gcp_app_pb2 as gcp_dot_gcp__app__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&gcp/gcp_google_app_engine_bundle.proto\x12(oak9.tython.gcp.google_app_engine_bundle\x1a\x13shared/shared.proto\x1a\x11gcp/gcp_app.proto\"\xde\x05\n\x0fGoogleAppEngine\x12I\n\x16\x61pp_engine_application\x18\x01 \x01(\x0b\x32).oak9.tython.gcp.app.AppEngineApplication\x12l\n)app_engine_application_url_dispatch_rules\x18\x02 \x03(\x0b\x32\x39.oak9.tython.gcp.app.AppEngineApplicationUrlDispatchRules\x12N\n\x19\x61pp_engine_domain_mapping\x18\x03 \x03(\x0b\x32+.oak9.tython.gcp.app.AppEngineDomainMapping\x12L\n\x18\x61pp_engine_firewall_rule\x18\x04 \x03(\x0b\x32*.oak9.tython.gcp.app.AppEngineFirewallRule\x12Y\n\x1f\x61pp_engine_flexible_app_version\x18\x05 \x03(\x0b\x32\x30.oak9.tython.gcp.app.AppEngineFlexibleAppVersion\x12\x61\n#app_engine_service_network_settings\x18\x06 \x03(\x0b\x32\x34.oak9.tython.gcp.app.AppEngineServiceNetworkSettings\x12[\n app_engine_service_split_traffic\x18\x07 \x03(\x0b\x32\x31.oak9.tython.gcp.app.AppEngineServiceSplitTraffic\x12Y\n\x1f\x61pp_engine_standard_app_version\x18\x08 \x03(\x0b\x32\x30.oak9.tython.gcp.app.AppEngineStandardAppVersionb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_google_app_engine_bundle_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GOOGLEAPPENGINE._serialized_start=125
  _GOOGLEAPPENGINE._serialized_end=859
# @@protoc_insertion_point(module_scope)
