"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ComputeSubnetworkXLogConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AGGREGATION_INTERVAL_FIELD_NUMBER: builtins.int
    FILTER_EXPR_FIELD_NUMBER: builtins.int
    FLOW_SAMPLING_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    METADATA_FIELDS_FIELD_NUMBER: builtins.int
    aggregation_interval: builtins.str
    filter_expr: builtins.str
    flow_sampling: builtins.float
    metadata: builtins.str
    @property
    def metadata_fields(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        aggregation_interval: builtins.str = ...,
        filter_expr: builtins.str = ...,
        flow_sampling: builtins.float = ...,
        metadata: builtins.str = ...,
        metadata_fields: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["aggregation_interval", b"aggregation_interval", "filter_expr", b"filter_expr", "flow_sampling", b"flow_sampling", "metadata", b"metadata", "metadata_fields", b"metadata_fields"]) -> None: ...

global___ComputeSubnetworkXLogConfig = ComputeSubnetworkXLogConfig

@typing_extensions.final
class ComputeSubnetworkXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___ComputeSubnetworkXTimeouts = ComputeSubnetworkXTimeouts

@typing_extensions.final
class ComputeSubnetwork(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class SecondaryIpRangeEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    CREATION_TIMESTAMP_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXTERNAL_IPV6_PREFIX_FIELD_NUMBER: builtins.int
    FINGERPRINT_FIELD_NUMBER: builtins.int
    GATEWAY_ADDRESS_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    IP_CIDR_RANGE_FIELD_NUMBER: builtins.int
    IPV6_ACCESS_TYPE_FIELD_NUMBER: builtins.int
    IPV6_CIDR_RANGE_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    NETWORK_FIELD_NUMBER: builtins.int
    PRIVATE_IP_GOOGLE_ACCESS_FIELD_NUMBER: builtins.int
    PRIVATE_IPV6_GOOGLE_ACCESS_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    PURPOSE_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    SECONDARY_IP_RANGE_FIELD_NUMBER: builtins.int
    SELF_LINK_FIELD_NUMBER: builtins.int
    STACK_TYPE_FIELD_NUMBER: builtins.int
    LOG_CONFIG_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    creation_timestamp: builtins.str
    description: builtins.str
    external_ipv6_prefix: builtins.str
    fingerprint: builtins.str
    gateway_address: builtins.str
    id: builtins.str
    ip_cidr_range: builtins.str
    ipv6_access_type: builtins.str
    ipv6_cidr_range: builtins.str
    name: builtins.str
    network: builtins.str
    private_ip_google_access: builtins.bool
    private_ipv6_google_access: builtins.str
    project: builtins.str
    purpose: builtins.str
    region: builtins.str
    role: builtins.str
    @property
    def secondary_ip_range(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    self_link: builtins.str
    stack_type: builtins.str
    @property
    def log_config(self) -> global___ComputeSubnetworkXLogConfig: ...
    @property
    def timeouts(self) -> global___ComputeSubnetworkXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        creation_timestamp: builtins.str = ...,
        description: builtins.str = ...,
        external_ipv6_prefix: builtins.str = ...,
        fingerprint: builtins.str = ...,
        gateway_address: builtins.str = ...,
        id: builtins.str = ...,
        ip_cidr_range: builtins.str = ...,
        ipv6_access_type: builtins.str = ...,
        ipv6_cidr_range: builtins.str = ...,
        name: builtins.str = ...,
        network: builtins.str = ...,
        private_ip_google_access: builtins.bool = ...,
        private_ipv6_google_access: builtins.str = ...,
        project: builtins.str = ...,
        purpose: builtins.str = ...,
        region: builtins.str = ...,
        role: builtins.str = ...,
        secondary_ip_range: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        self_link: builtins.str = ...,
        stack_type: builtins.str = ...,
        log_config: global___ComputeSubnetworkXLogConfig | None = ...,
        timeouts: global___ComputeSubnetworkXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["log_config", b"log_config", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["creation_timestamp", b"creation_timestamp", "description", b"description", "external_ipv6_prefix", b"external_ipv6_prefix", "fingerprint", b"fingerprint", "gateway_address", b"gateway_address", "id", b"id", "ip_cidr_range", b"ip_cidr_range", "ipv6_access_type", b"ipv6_access_type", "ipv6_cidr_range", b"ipv6_cidr_range", "log_config", b"log_config", "name", b"name", "network", b"network", "private_ip_google_access", b"private_ip_google_access", "private_ipv6_google_access", b"private_ipv6_google_access", "project", b"project", "purpose", b"purpose", "region", b"region", "resource_info", b"resource_info", "role", b"role", "secondary_ip_range", b"secondary_ip_range", "self_link", b"self_link", "stack_type", b"stack_type", "timeouts", b"timeouts"]) -> None: ...

global___ComputeSubnetwork = ComputeSubnetwork

@typing_extensions.final
class ComputeSubnetworkIamBindingXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___ComputeSubnetworkIamBindingXCondition = ComputeSubnetworkIamBindingXCondition

@typing_extensions.final
class ComputeSubnetworkIamBinding(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    MEMBERS_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    SUBNETWORK_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    @property
    def members(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    project: builtins.str
    region: builtins.str
    role: builtins.str
    subnetwork: builtins.str
    @property
    def condition(self) -> global___ComputeSubnetworkIamBindingXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        members: collections.abc.Iterable[builtins.str] | None = ...,
        project: builtins.str = ...,
        region: builtins.str = ...,
        role: builtins.str = ...,
        subnetwork: builtins.str = ...,
        condition: global___ComputeSubnetworkIamBindingXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "etag", b"etag", "id", b"id", "members", b"members", "project", b"project", "region", b"region", "resource_info", b"resource_info", "role", b"role", "subnetwork", b"subnetwork"]) -> None: ...

global___ComputeSubnetworkIamBinding = ComputeSubnetworkIamBinding

@typing_extensions.final
class ComputeSubnetworkIamMemberXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___ComputeSubnetworkIamMemberXCondition = ComputeSubnetworkIamMemberXCondition

@typing_extensions.final
class ComputeSubnetworkIamMember(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    MEMBER_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    SUBNETWORK_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    member: builtins.str
    project: builtins.str
    region: builtins.str
    role: builtins.str
    subnetwork: builtins.str
    @property
    def condition(self) -> global___ComputeSubnetworkIamMemberXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        member: builtins.str = ...,
        project: builtins.str = ...,
        region: builtins.str = ...,
        role: builtins.str = ...,
        subnetwork: builtins.str = ...,
        condition: global___ComputeSubnetworkIamMemberXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "etag", b"etag", "id", b"id", "member", b"member", "project", b"project", "region", b"region", "resource_info", b"resource_info", "role", b"role", "subnetwork", b"subnetwork"]) -> None: ...

global___ComputeSubnetworkIamMember = ComputeSubnetworkIamMember

@typing_extensions.final
class ComputeSubnetworkIamPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    POLICY_DATA_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    SUBNETWORK_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    policy_data: builtins.str
    project: builtins.str
    region: builtins.str
    subnetwork: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        policy_data: builtins.str = ...,
        project: builtins.str = ...,
        region: builtins.str = ...,
        subnetwork: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["etag", b"etag", "id", b"id", "policy_data", b"policy_data", "project", b"project", "region", b"region", "resource_info", b"resource_info", "subnetwork", b"subnetwork"]) -> None: ...

global___ComputeSubnetworkIamPolicy = ComputeSubnetworkIamPolicy
