# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kubernetes/kubernetes_io.k8s.api.discovery.v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2
from oak9.tython.models.kubernetes.kubernetes_io.k8s.api.core import v1_pb2 as kubernetes_dot_kubernetes__io_dot_k8s_dot_api_dot_core_dot_v1__pb2
from oak9.tython.models.kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta import v1_pb2 as kubernetes_dot_kubernetes__io_dot_k8s_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3kubernetes/kubernetes_io.k8s.api.discovery.v1.proto\x12 oak9.tython.k8s.api.discovery.v1\x1a\x13shared/shared.proto\x1a.kubernetes/kubernetes_io.k8s.api.core.v1.proto\x1a@kubernetes/kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1.proto\"\xf1\x03\n\x08\x45ndpoint\x12\x11\n\taddresses\x18\x01 \x03(\t\x12H\n\nconditions\x18\x02 \x01(\x0b\x32\x34.oak9.tython.k8s.api.discovery.v1.EndpointConditions\x12_\n\x13\x64\x65precated_topology\x18\x03 \x03(\x0b\x32\x42.oak9.tython.k8s.api.discovery.v1.Endpoint.DeprecatedTopologyEntry\x12>\n\x05hints\x18\x04 \x01(\x0b\x32/.oak9.tython.k8s.api.discovery.v1.EndpointHints\x12\x10\n\x08hostname\x18\x05 \x01(\t\x12\x11\n\tnode_name\x18\x06 \x01(\t\x12@\n\ntarget_ref\x18\x07 \x01(\x0b\x32,.oak9.tython.k8s.api.core.v1.ObjectReference\x12\x0c\n\x04zone\x18\x08 \x01(\t\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a\x39\n\x17\x44\x65precatedTopologyEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x82\x01\n\x12\x45ndpointConditions\x12\r\n\x05ready\x18\x01 \x01(\x08\x12\x0f\n\x07serving\x18\x02 \x01(\x08\x12\x13\n\x0bterminating\x18\x03 \x01(\x08\x12\x37\n\rresource_info\x18\x04 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x86\x01\n\rEndpointHints\x12<\n\tfor_zones\x18\x01 \x03(\x0b\x32).oak9.tython.k8s.api.discovery.v1.ForZone\x12\x37\n\rresource_info\x18\x02 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x8b\x01\n\x0c\x45ndpointPort\x12\x14\n\x0c\x61pp_protocol\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04port\x18\x03 \x01(\x05\x12\x10\n\x08protocol\x18\x04 \x01(\t\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xcc\x02\n\rEndpointSlice\x12\x14\n\x0c\x61\x64\x64ress_type\x18\x01 \x01(\t\x12\x13\n\x0b\x61pi_version\x18\x02 \x01(\t\x12=\n\tendpoints\x18\x03 \x03(\x0b\x32*.oak9.tython.k8s.api.discovery.v1.Endpoint\x12\x0c\n\x04kind\x18\x04 \x01(\t\x12K\n\x08metadata\x18\x05 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12=\n\x05ports\x18\x06 \x03(\x0b\x32..oak9.tython.k8s.api.discovery.v1.EndpointPort\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xfa\x01\n\x11\x45ndpointSliceList\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12>\n\x05items\x18\x02 \x03(\x0b\x32/.oak9.tython.k8s.api.discovery.v1.EndpointSlice\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12I\n\x08metadata\x18\x04 \x01(\x0b\x32\x37.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ListMeta\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"P\n\x07\x46orZone\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x37\n\rresource_info\x18\x02 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'kubernetes.kubernetes_io.k8s.api.discovery.v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ENDPOINT_DEPRECATEDTOPOLOGYENTRY._options = None
  _ENDPOINT_DEPRECATEDTOPOLOGYENTRY._serialized_options = b'8\001'
  _ENDPOINT._serialized_start=225
  _ENDPOINT._serialized_end=722
  _ENDPOINT_DEPRECATEDTOPOLOGYENTRY._serialized_start=665
  _ENDPOINT_DEPRECATEDTOPOLOGYENTRY._serialized_end=722
  _ENDPOINTCONDITIONS._serialized_start=725
  _ENDPOINTCONDITIONS._serialized_end=855
  _ENDPOINTHINTS._serialized_start=858
  _ENDPOINTHINTS._serialized_end=992
  _ENDPOINTPORT._serialized_start=995
  _ENDPOINTPORT._serialized_end=1134
  _ENDPOINTSLICE._serialized_start=1137
  _ENDPOINTSLICE._serialized_end=1469
  _ENDPOINTSLICELIST._serialized_start=1472
  _ENDPOINTSLICELIST._serialized_end=1722
  _FORZONE._serialized_start=1724
  _FORZONE._serialized_end=1804
# @@protoc_insertion_point(module_scope)
