# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_google_container_bundle.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2
from oak9.tython.models.gcp import gcp_container_pb2 as gcp_dot_gcp__container__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%gcp/gcp_google_container_bundle.proto\x12\'oak9.tython.gcp.google_container_bundle\x1a\x13shared/shared.proto\x1a\x17gcp/gcp_container.proto\"\xa4\x01\n\x0fGoogleContainer\x12\x46\n\x11\x63ontainer_cluster\x18\x01 \x01(\x0b\x32+.oak9.tython.gcp.container.ContainerCluster\x12I\n\x13\x63ontainer_node_pool\x18\x02 \x03(\x0b\x32,.oak9.tython.gcp.container.ContainerNodePoolb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_google_container_bundle_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GOOGLECONTAINER._serialized_start=129
  _GOOGLECONTAINER._serialized_end=293
# @@protoc_insertion_point(module_scope)
