# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_dialogflow.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18gcp/gcp_dialogflow.proto\x12\x1aoak9.tython.gcp.dialogflow\x1a\x13shared/shared.proto\"J\n\x18\x44ialogflowAgentXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xcf\x03\n\x0f\x44ialogflowAgent\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x12\n\navatar_uri\x18\x02 \x01(\t\x12\x1a\n\x12\x61vatar_uri_backend\x18\x03 \x01(\t\x12 \n\x18\x63lassification_threshold\x18\x04 \x01(\x01\x12\x1d\n\x15\x64\x65\x66\x61ult_language_code\x18\x05 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x06 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x07 \x01(\t\x12\x16\n\x0e\x65nable_logging\x18\x08 \x01(\x08\x12\n\n\x02id\x18\t \x01(\t\x12\x12\n\nmatch_mode\x18\n \x01(\t\x12\x0f\n\x07project\x18\x0b \x01(\t\x12 \n\x18supported_language_codes\x18\x0c \x03(\t\x12\x0c\n\x04tier\x18\r \x01(\t\x12\x11\n\ttime_zone\x18\x0e \x01(\t\x12\x46\n\x08timeouts\x18\x0f \x01(\x0b\x32\x34.oak9.tython.gcp.dialogflow.DialogflowAgentXTimeouts\x12\x37\n\rresource_info\x18\x10 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"J\n&DialogflowCxAgentXSpeechToTextSettings\x12 \n\x18\x65nable_speech_adaptation\x18\x01 \x01(\x08\"L\n\x1a\x44ialogflowCxAgentXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xbf\x04\n\x11\x44ialogflowCxAgent\x12\x12\n\navatar_uri\x18\x01 \x01(\t\x12\x1d\n\x15\x64\x65\x66\x61ult_language_code\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x04 \x01(\t\x12\x1f\n\x17\x65nable_spell_correction\x18\x05 \x01(\x08\x12\"\n\x1a\x65nable_stackdriver_logging\x18\x06 \x01(\x08\x12\n\n\x02id\x18\x07 \x01(\t\x12\x10\n\x08location\x18\x08 \x01(\t\x12\x0c\n\x04name\x18\t \x01(\t\x12\x0f\n\x07project\x18\n \x01(\t\x12\x19\n\x11security_settings\x18\x0b \x01(\t\x12\x12\n\nstart_flow\x18\x0c \x01(\t\x12 \n\x18supported_language_codes\x18\r \x03(\t\x12\x11\n\ttime_zone\x18\x0e \x01(\t\x12\x63\n\x17speech_to_text_settings\x18\x0f \x01(\x0b\x32\x42.oak9.tython.gcp.dialogflow.DialogflowCxAgentXSpeechToTextSettings\x12H\n\x08timeouts\x18\x10 \x01(\x0b\x32\x36.oak9.tython.gcp.dialogflow.DialogflowCxAgentXTimeouts\x12\x37\n\rresource_info\x18\x11 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"B\n\x1f\x44ialogflowCxEntityTypeXEntities\x12\x10\n\x08synonyms\x18\x01 \x03(\t\x12\r\n\x05value\x18\x02 \x01(\t\"7\n&DialogflowCxEntityTypeXExcludedPhrases\x12\r\n\x05value\x18\x01 \x01(\t\"Q\n\x1f\x44ialogflowCxEntityTypeXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\x80\x04\n\x16\x44ialogflowCxEntityType\x12\x1b\n\x13\x61uto_expansion_mode\x18\x01 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x02 \x01(\t\x12\x1f\n\x17\x65nable_fuzzy_extraction\x18\x03 \x01(\x08\x12\n\n\x02id\x18\x04 \x01(\t\x12\x0c\n\x04kind\x18\x05 \x01(\t\x12\x15\n\rlanguage_code\x18\x06 \x01(\t\x12\x0c\n\x04name\x18\x07 \x01(\t\x12\x0e\n\x06parent\x18\x08 \x01(\t\x12\x0e\n\x06redact\x18\t \x01(\x08\x12M\n\x08\x65ntities\x18\n \x03(\x0b\x32;.oak9.tython.gcp.dialogflow.DialogflowCxEntityTypeXEntities\x12\\\n\x10\x65xcluded_phrases\x18\x0b \x03(\x0b\x32\x42.oak9.tython.gcp.dialogflow.DialogflowCxEntityTypeXExcludedPhrases\x12M\n\x08timeouts\x18\x0c \x01(\x0b\x32;.oak9.tython.gcp.dialogflow.DialogflowCxEntityTypeXTimeouts\x12\x37\n\rresource_info\x18\r \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"R\n DialogflowCxEnvironmentXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"9\n&DialogflowCxEnvironmentXVersionConfigs\x12\x0f\n\x07version\x18\x01 \x01(\t\"\xe9\x02\n\x17\x44ialogflowCxEnvironment\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0e\n\x06parent\x18\x05 \x01(\t\x12\x13\n\x0bupdate_time\x18\x06 \x01(\t\x12N\n\x08timeouts\x18\x07 \x01(\x0b\x32<.oak9.tython.gcp.dialogflow.DialogflowCxEnvironmentXTimeouts\x12[\n\x0fversion_configs\x18\x08 \x03(\x0b\x32\x42.oak9.tython.gcp.dialogflow.DialogflowCxEnvironmentXVersionConfigs\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"t\n?DialogflowCxFlowXEventHandlersXTriggerFulfillmentXMessagesXText\x12#\n\x1b\x61llow_playback_interruption\x18\x01 \x01(\x08\x12\x0c\n\x04text\x18\x02 \x03(\t\"\xa7\x01\n:DialogflowCxFlowXEventHandlersXTriggerFulfillmentXMessages\x12i\n\x04text\x18\x01 \x01(\x0b\x32[.oak9.tython.gcp.dialogflow.DialogflowCxFlowXEventHandlersXTriggerFulfillmentXMessagesXText\"\xdd\x01\n1DialogflowCxFlowXEventHandlersXTriggerFulfillment\x12 \n\x18return_partial_responses\x18\x01 \x01(\x08\x12\x0b\n\x03tag\x18\x02 \x01(\t\x12\x0f\n\x07webhook\x18\x03 \x01(\t\x12h\n\x08messages\x18\x04 \x03(\x0b\x32V.oak9.tython.gcp.dialogflow.DialogflowCxFlowXEventHandlersXTriggerFulfillmentXMessages\"\xd3\x01\n\x1e\x44ialogflowCxFlowXEventHandlers\x12\r\n\x05\x65vent\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0btarget_flow\x18\x03 \x01(\t\x12\x13\n\x0btarget_page\x18\x04 \x01(\t\x12j\n\x13trigger_fulfillment\x18\x05 \x01(\x0b\x32M.oak9.tython.gcp.dialogflow.DialogflowCxFlowXEventHandlersXTriggerFulfillment\"q\n\x1c\x44ialogflowCxFlowXNluSettings\x12 \n\x18\x63lassification_threshold\x18\x01 \x01(\x01\x12\x1b\n\x13model_training_mode\x18\x02 \x01(\t\x12\x12\n\nmodel_type\x18\x03 \x01(\t\"K\n\x19\x44ialogflowCxFlowXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"w\nBDialogflowCxFlowXTransitionRoutesXTriggerFulfillmentXMessagesXText\x12#\n\x1b\x61llow_playback_interruption\x18\x01 \x01(\x08\x12\x0c\n\x04text\x18\x02 \x03(\t\"\xad\x01\n=DialogflowCxFlowXTransitionRoutesXTriggerFulfillmentXMessages\x12l\n\x04text\x18\x01 \x01(\x0b\x32^.oak9.tython.gcp.dialogflow.DialogflowCxFlowXTransitionRoutesXTriggerFulfillmentXMessagesXText\"\xe3\x01\n4DialogflowCxFlowXTransitionRoutesXTriggerFulfillment\x12 \n\x18return_partial_responses\x18\x01 \x01(\x08\x12\x0b\n\x03tag\x18\x02 \x01(\t\x12\x0f\n\x07webhook\x18\x03 \x01(\t\x12k\n\x08messages\x18\x04 \x03(\x0b\x32Y.oak9.tython.gcp.dialogflow.DialogflowCxFlowXTransitionRoutesXTriggerFulfillmentXMessages\"\xed\x01\n!DialogflowCxFlowXTransitionRoutes\x12\x11\n\tcondition\x18\x01 \x01(\t\x12\x0e\n\x06intent\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0btarget_flow\x18\x04 \x01(\t\x12\x13\n\x0btarget_page\x18\x05 \x01(\t\x12m\n\x13trigger_fulfillment\x18\x06 \x01(\x0b\x32P.oak9.tython.gcp.dialogflow.DialogflowCxFlowXTransitionRoutesXTriggerFulfillment\"\x9f\x04\n\x10\x44ialogflowCxFlow\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x15\n\rlanguage_code\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x0e\n\x06parent\x18\x06 \x01(\t\x12\x1f\n\x17transition_route_groups\x18\x07 \x03(\t\x12R\n\x0e\x65vent_handlers\x18\x08 \x03(\x0b\x32:.oak9.tython.gcp.dialogflow.DialogflowCxFlowXEventHandlers\x12N\n\x0cnlu_settings\x18\t \x01(\x0b\x32\x38.oak9.tython.gcp.dialogflow.DialogflowCxFlowXNluSettings\x12G\n\x08timeouts\x18\n \x01(\x0b\x32\x35.oak9.tython.gcp.dialogflow.DialogflowCxFlowXTimeouts\x12X\n\x11transition_routes\x18\x0b \x03(\x0b\x32=.oak9.tython.gcp.dialogflow.DialogflowCxFlowXTransitionRoutes\x12\x37\n\rresource_info\x18\x0c \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"a\n\x1d\x44ialogflowCxIntentXParameters\x12\x13\n\x0b\x65ntity_type\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0f\n\x07is_list\x18\x03 \x01(\x08\x12\x0e\n\x06redact\x18\x04 \x01(\x08\"M\n\x1b\x44ialogflowCxIntentXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"N\n(DialogflowCxIntentXTrainingPhrasesXParts\x12\x14\n\x0cparameter_id\x18\x01 \x01(\t\x12\x0c\n\x04text\x18\x02 \x01(\t\"\x9b\x01\n\"DialogflowCxIntentXTrainingPhrases\x12\n\n\x02id\x18\x01 \x01(\t\x12\x14\n\x0crepeat_count\x18\x02 \x01(\x01\x12S\n\x05parts\x18\x03 \x03(\x0b\x32\x44.oak9.tython.gcp.dialogflow.DialogflowCxIntentXTrainingPhrasesXParts\"\xcf\x04\n\x12\x44ialogflowCxIntent\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x13\n\x0bis_fallback\x18\x04 \x01(\x08\x12J\n\x06labels\x18\x05 \x03(\x0b\x32:.oak9.tython.gcp.dialogflow.DialogflowCxIntent.LabelsEntry\x12\x15\n\rlanguage_code\x18\x06 \x01(\t\x12\x0c\n\x04name\x18\x07 \x01(\t\x12\x0e\n\x06parent\x18\x08 \x01(\t\x12\x10\n\x08priority\x18\t \x01(\x01\x12M\n\nparameters\x18\n \x03(\x0b\x32\x39.oak9.tython.gcp.dialogflow.DialogflowCxIntentXParameters\x12I\n\x08timeouts\x18\x0b \x01(\x0b\x32\x37.oak9.tython.gcp.dialogflow.DialogflowCxIntentXTimeouts\x12X\n\x10training_phrases\x18\x0c \x03(\x0b\x32>.oak9.tython.gcp.dialogflow.DialogflowCxIntentXTrainingPhrases\x12\x37\n\rresource_info\x18\r \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"d\n/DialogflowCxPageXEntryFulfillmentXMessagesXText\x12#\n\x1b\x61llow_playback_interruption\x18\x01 \x01(\x08\x12\x0c\n\x04text\x18\x02 \x03(\t\"\x87\x01\n*DialogflowCxPageXEntryFulfillmentXMessages\x12Y\n\x04text\x18\x01 \x01(\x0b\x32K.oak9.tython.gcp.dialogflow.DialogflowCxPageXEntryFulfillmentXMessagesXText\"\xbd\x01\n!DialogflowCxPageXEntryFulfillment\x12 \n\x18return_partial_responses\x18\x01 \x01(\x08\x12\x0b\n\x03tag\x18\x02 \x01(\t\x12\x0f\n\x07webhook\x18\x03 \x01(\t\x12X\n\x08messages\x18\x04 \x03(\x0b\x32\x46.oak9.tython.gcp.dialogflow.DialogflowCxPageXEntryFulfillmentXMessages\"t\n?DialogflowCxPageXEventHandlersXTriggerFulfillmentXMessagesXText\x12#\n\x1b\x61llow_playback_interruption\x18\x01 \x01(\x08\x12\x0c\n\x04text\x18\x02 \x03(\t\"\xa7\x01\n:DialogflowCxPageXEventHandlersXTriggerFulfillmentXMessages\x12i\n\x04text\x18\x01 \x01(\x0b\x32[.oak9.tython.gcp.dialogflow.DialogflowCxPageXEventHandlersXTriggerFulfillmentXMessagesXText\"\xdd\x01\n1DialogflowCxPageXEventHandlersXTriggerFulfillment\x12 \n\x18return_partial_responses\x18\x01 \x01(\x08\x12\x0b\n\x03tag\x18\x02 \x01(\t\x12\x0f\n\x07webhook\x18\x03 \x01(\t\x12h\n\x08messages\x18\x04 \x03(\x0b\x32V.oak9.tython.gcp.dialogflow.DialogflowCxPageXEventHandlersXTriggerFulfillmentXMessages\"\xd3\x01\n\x1e\x44ialogflowCxPageXEventHandlers\x12\r\n\x05\x65vent\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0btarget_flow\x18\x03 \x01(\t\x12\x13\n\x0btarget_page\x18\x04 \x01(\t\x12j\n\x13trigger_fulfillment\x18\x05 \x01(\x0b\x32M.oak9.tython.gcp.dialogflow.DialogflowCxPageXEventHandlersXTriggerFulfillment\"\x89\x01\nTDialogflowCxPageXFormXParametersXFillBehaviorXInitialPromptFulfillmentXMessagesXText\x12#\n\x1b\x61llow_playback_interruption\x18\x01 \x01(\x08\x12\x0c\n\x04text\x18\x02 \x03(\t\"\xd1\x01\nODialogflowCxPageXFormXParametersXFillBehaviorXInitialPromptFulfillmentXMessages\x12~\n\x04text\x18\x01 \x01(\x0b\x32p.oak9.tython.gcp.dialogflow.DialogflowCxPageXFormXParametersXFillBehaviorXInitialPromptFulfillmentXMessagesXText\"\x87\x02\nFDialogflowCxPageXFormXParametersXFillBehaviorXInitialPromptFulfillment\x12 \n\x18return_partial_responses\x18\x01 \x01(\x08\x12\x0b\n\x03tag\x18\x02 \x01(\t\x12\x0f\n\x07webhook\x18\x03 \x01(\t\x12}\n\x08messages\x18\x04 \x03(\x0b\x32k.oak9.tython.gcp.dialogflow.DialogflowCxPageXFormXParametersXFillBehaviorXInitialPromptFulfillmentXMessages\"\xb8\x01\n-DialogflowCxPageXFormXParametersXFillBehavior\x12\x86\x01\n\x1ainitial_prompt_fulfillment\x18\x01 \x01(\x0b\x32\x62.oak9.tython.gcp.dialogflow.DialogflowCxPageXFormXParametersXFillBehaviorXInitialPromptFulfillment\"\xe2\x01\n DialogflowCxPageXFormXParameters\x12\x14\n\x0c\x64isplay_name\x18\x01 \x01(\t\x12\x13\n\x0b\x65ntity_type\x18\x02 \x01(\t\x12\x0f\n\x07is_list\x18\x03 \x01(\x08\x12\x0e\n\x06redact\x18\x04 \x01(\x08\x12\x10\n\x08required\x18\x05 \x01(\x08\x12`\n\rfill_behavior\x18\x06 \x01(\x0b\x32I.oak9.tython.gcp.dialogflow.DialogflowCxPageXFormXParametersXFillBehavior\"i\n\x15\x44ialogflowCxPageXForm\x12P\n\nparameters\x18\x01 \x03(\x0b\x32<.oak9.tython.gcp.dialogflow.DialogflowCxPageXFormXParameters\"K\n\x19\x44ialogflowCxPageXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"w\nBDialogflowCxPageXTransitionRoutesXTriggerFulfillmentXMessagesXText\x12#\n\x1b\x61llow_playback_interruption\x18\x01 \x01(\x08\x12\x0c\n\x04text\x18\x02 \x03(\t\"\xad\x01\n=DialogflowCxPageXTransitionRoutesXTriggerFulfillmentXMessages\x12l\n\x04text\x18\x01 \x01(\x0b\x32^.oak9.tython.gcp.dialogflow.DialogflowCxPageXTransitionRoutesXTriggerFulfillmentXMessagesXText\"\xe3\x01\n4DialogflowCxPageXTransitionRoutesXTriggerFulfillment\x12 \n\x18return_partial_responses\x18\x01 \x01(\x08\x12\x0b\n\x03tag\x18\x02 \x01(\t\x12\x0f\n\x07webhook\x18\x03 \x01(\t\x12k\n\x08messages\x18\x04 \x03(\x0b\x32Y.oak9.tython.gcp.dialogflow.DialogflowCxPageXTransitionRoutesXTriggerFulfillmentXMessages\"\xed\x01\n!DialogflowCxPageXTransitionRoutes\x12\x11\n\tcondition\x18\x01 \x01(\t\x12\x0e\n\x06intent\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0btarget_flow\x18\x04 \x01(\t\x12\x13\n\x0btarget_page\x18\x05 \x01(\t\x12m\n\x13trigger_fulfillment\x18\x06 \x01(\x0b\x32P.oak9.tython.gcp.dialogflow.DialogflowCxPageXTransitionRoutesXTriggerFulfillment\"\xd5\x04\n\x10\x44ialogflowCxPage\x12\x14\n\x0c\x64isplay_name\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x15\n\rlanguage_code\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0e\n\x06parent\x18\x05 \x01(\t\x12\x1f\n\x17transition_route_groups\x18\x06 \x03(\t\x12X\n\x11\x65ntry_fulfillment\x18\x07 \x01(\x0b\x32=.oak9.tython.gcp.dialogflow.DialogflowCxPageXEntryFulfillment\x12R\n\x0e\x65vent_handlers\x18\x08 \x03(\x0b\x32:.oak9.tython.gcp.dialogflow.DialogflowCxPageXEventHandlers\x12?\n\x04\x66orm\x18\t \x01(\x0b\x32\x31.oak9.tython.gcp.dialogflow.DialogflowCxPageXForm\x12G\n\x08timeouts\x18\n \x01(\x0b\x32\x35.oak9.tython.gcp.dialogflow.DialogflowCxPageXTimeouts\x12X\n\x11transition_routes\x18\x0b \x03(\x0b\x32=.oak9.tython.gcp.dialogflow.DialogflowCxPageXTransitionRoutes\x12\x37\n\rresource_info\x18\x0c \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"N\n\x1c\x44ialogflowCxVersionXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\x9f\x03\n\x13\x44ialogflowCxVersion\x12\x13\n\x0b\x63reate_time\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x03 \x01(\t\x12\n\n\x02id\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12V\n\x0cnlu_settings\x18\x06 \x03(\x0b\x32@.oak9.tython.gcp.dialogflow.DialogflowCxVersion.NluSettingsEntry\x12\x0e\n\x06parent\x18\x07 \x01(\t\x12\r\n\x05state\x18\x08 \x01(\t\x12J\n\x08timeouts\x18\t \x01(\x0b\x32\x38.oak9.tython.gcp.dialogflow.DialogflowCxVersionXTimeouts\x12\x37\n\rresource_info\x18\n \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a\x32\n\x10NluSettingsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"@\n\x1d\x44ialogflowEntityTypeXEntities\x12\x10\n\x08synonyms\x18\x01 \x03(\t\x12\r\n\x05value\x18\x02 \x01(\t\"O\n\x1d\x44ialogflowEntityTypeXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xd9\x02\n\x14\x44ialogflowEntityType\x12\x14\n\x0c\x64isplay_name\x18\x01 \x01(\t\x12\x1f\n\x17\x65nable_fuzzy_extraction\x18\x02 \x01(\x08\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0c\n\x04kind\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x0f\n\x07project\x18\x06 \x01(\t\x12K\n\x08\x65ntities\x18\x07 \x03(\x0b\x32\x39.oak9.tython.gcp.dialogflow.DialogflowEntityTypeXEntities\x12K\n\x08timeouts\x18\x08 \x01(\x0b\x32\x39.oak9.tython.gcp.dialogflow.DialogflowEntityTypeXTimeouts\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\".\n\x1e\x44ialogflowFulfillmentXFeatures\x12\x0c\n\x04type\x18\x01 \x01(\t\"\x83\x02\n\'DialogflowFulfillmentXGenericWebService\x12\x10\n\x08password\x18\x01 \x01(\t\x12p\n\x0frequest_headers\x18\x02 \x03(\x0b\x32W.oak9.tython.gcp.dialogflow.DialogflowFulfillmentXGenericWebService.RequestHeadersEntry\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\x10\n\x08username\x18\x04 \x01(\t\x1a\x35\n\x13RequestHeadersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"P\n\x1e\x44ialogflowFulfillmentXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xa0\x03\n\x15\x44ialogflowFulfillment\x12\x14\n\x0c\x64isplay_name\x18\x01 \x01(\t\x12\x0f\n\x07\x65nabled\x18\x02 \x01(\x08\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12L\n\x08\x66\x65\x61tures\x18\x06 \x03(\x0b\x32:.oak9.tython.gcp.dialogflow.DialogflowFulfillmentXFeatures\x12`\n\x13generic_web_service\x18\x07 \x01(\x0b\x32\x43.oak9.tython.gcp.dialogflow.DialogflowFulfillmentXGenericWebService\x12L\n\x08timeouts\x18\x08 \x01(\x0b\x32:.oak9.tython.gcp.dialogflow.DialogflowFulfillmentXTimeouts\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"K\n\x19\x44ialogflowIntentXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\x88\x05\n\x10\x44ialogflowIntent\x12\x0e\n\x06\x61\x63tion\x18\x01 \x01(\t\x12\"\n\x1a\x64\x65\x66\x61ult_response_platforms\x18\x02 \x03(\t\x12\x14\n\x0c\x64isplay_name\x18\x03 \x01(\t\x12\x0e\n\x06\x65vents\x18\x04 \x03(\t\x12\x62\n\x14\x66ollowup_intent_info\x18\x05 \x03(\x0b\x32\x44.oak9.tython.gcp.dialogflow.DialogflowIntent.FollowupIntentInfoEntry\x12\n\n\x02id\x18\x06 \x01(\t\x12\x1b\n\x13input_context_names\x18\x07 \x03(\t\x12\x13\n\x0bis_fallback\x18\x08 \x01(\x08\x12\x13\n\x0bml_disabled\x18\t \x01(\x08\x12\x0c\n\x04name\x18\n \x01(\t\x12#\n\x1bparent_followup_intent_name\x18\x0b \x01(\t\x12\x10\n\x08priority\x18\x0c \x01(\x01\x12\x0f\n\x07project\x18\r \x01(\t\x12\x16\n\x0ereset_contexts\x18\x0e \x01(\x08\x12!\n\x19root_followup_intent_name\x18\x0f \x01(\t\x12\x15\n\rwebhook_state\x18\x10 \x01(\t\x12G\n\x08timeouts\x18\x11 \x01(\x0b\x32\x35.oak9.tython.gcp.dialogflow.DialogflowIntentXTimeouts\x12\x37\n\rresource_info\x18\x12 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a\x39\n\x17\x46ollowupIntentInfoEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_dialogflow_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DIALOGFLOWCXINTENT_LABELSENTRY._options = None
  _DIALOGFLOWCXINTENT_LABELSENTRY._serialized_options = b'8\001'
  _DIALOGFLOWCXVERSION_NLUSETTINGSENTRY._options = None
  _DIALOGFLOWCXVERSION_NLUSETTINGSENTRY._serialized_options = b'8\001'
  _DIALOGFLOWFULFILLMENTXGENERICWEBSERVICE_REQUESTHEADERSENTRY._options = None
  _DIALOGFLOWFULFILLMENTXGENERICWEBSERVICE_REQUESTHEADERSENTRY._serialized_options = b'8\001'
  _DIALOGFLOWINTENT_FOLLOWUPINTENTINFOENTRY._options = None
  _DIALOGFLOWINTENT_FOLLOWUPINTENTINFOENTRY._serialized_options = b'8\001'
  _DIALOGFLOWAGENTXTIMEOUTS._serialized_start=77
  _DIALOGFLOWAGENTXTIMEOUTS._serialized_end=151
  _DIALOGFLOWAGENT._serialized_start=154
  _DIALOGFLOWAGENT._serialized_end=617
  _DIALOGFLOWCXAGENTXSPEECHTOTEXTSETTINGS._serialized_start=619
  _DIALOGFLOWCXAGENTXSPEECHTOTEXTSETTINGS._serialized_end=693
  _DIALOGFLOWCXAGENTXTIMEOUTS._serialized_start=695
  _DIALOGFLOWCXAGENTXTIMEOUTS._serialized_end=771
  _DIALOGFLOWCXAGENT._serialized_start=774
  _DIALOGFLOWCXAGENT._serialized_end=1349
  _DIALOGFLOWCXENTITYTYPEXENTITIES._serialized_start=1351
  _DIALOGFLOWCXENTITYTYPEXENTITIES._serialized_end=1417
  _DIALOGFLOWCXENTITYTYPEXEXCLUDEDPHRASES._serialized_start=1419
  _DIALOGFLOWCXENTITYTYPEXEXCLUDEDPHRASES._serialized_end=1474
  _DIALOGFLOWCXENTITYTYPEXTIMEOUTS._serialized_start=1476
  _DIALOGFLOWCXENTITYTYPEXTIMEOUTS._serialized_end=1557
  _DIALOGFLOWCXENTITYTYPE._serialized_start=1560
  _DIALOGFLOWCXENTITYTYPE._serialized_end=2072
  _DIALOGFLOWCXENVIRONMENTXTIMEOUTS._serialized_start=2074
  _DIALOGFLOWCXENVIRONMENTXTIMEOUTS._serialized_end=2156
  _DIALOGFLOWCXENVIRONMENTXVERSIONCONFIGS._serialized_start=2158
  _DIALOGFLOWCXENVIRONMENTXVERSIONCONFIGS._serialized_end=2215
  _DIALOGFLOWCXENVIRONMENT._serialized_start=2218
  _DIALOGFLOWCXENVIRONMENT._serialized_end=2579
  _DIALOGFLOWCXFLOWXEVENTHANDLERSXTRIGGERFULFILLMENTXMESSAGESXTEXT._serialized_start=2581
  _DIALOGFLOWCXFLOWXEVENTHANDLERSXTRIGGERFULFILLMENTXMESSAGESXTEXT._serialized_end=2697
  _DIALOGFLOWCXFLOWXEVENTHANDLERSXTRIGGERFULFILLMENTXMESSAGES._serialized_start=2700
  _DIALOGFLOWCXFLOWXEVENTHANDLERSXTRIGGERFULFILLMENTXMESSAGES._serialized_end=2867
  _DIALOGFLOWCXFLOWXEVENTHANDLERSXTRIGGERFULFILLMENT._serialized_start=2870
  _DIALOGFLOWCXFLOWXEVENTHANDLERSXTRIGGERFULFILLMENT._serialized_end=3091
  _DIALOGFLOWCXFLOWXEVENTHANDLERS._serialized_start=3094
  _DIALOGFLOWCXFLOWXEVENTHANDLERS._serialized_end=3305
  _DIALOGFLOWCXFLOWXNLUSETTINGS._serialized_start=3307
  _DIALOGFLOWCXFLOWXNLUSETTINGS._serialized_end=3420
  _DIALOGFLOWCXFLOWXTIMEOUTS._serialized_start=3422
  _DIALOGFLOWCXFLOWXTIMEOUTS._serialized_end=3497
  _DIALOGFLOWCXFLOWXTRANSITIONROUTESXTRIGGERFULFILLMENTXMESSAGESXTEXT._serialized_start=3499
  _DIALOGFLOWCXFLOWXTRANSITIONROUTESXTRIGGERFULFILLMENTXMESSAGESXTEXT._serialized_end=3618
  _DIALOGFLOWCXFLOWXTRANSITIONROUTESXTRIGGERFULFILLMENTXMESSAGES._serialized_start=3621
  _DIALOGFLOWCXFLOWXTRANSITIONROUTESXTRIGGERFULFILLMENTXMESSAGES._serialized_end=3794
  _DIALOGFLOWCXFLOWXTRANSITIONROUTESXTRIGGERFULFILLMENT._serialized_start=3797
  _DIALOGFLOWCXFLOWXTRANSITIONROUTESXTRIGGERFULFILLMENT._serialized_end=4024
  _DIALOGFLOWCXFLOWXTRANSITIONROUTES._serialized_start=4027
  _DIALOGFLOWCXFLOWXTRANSITIONROUTES._serialized_end=4264
  _DIALOGFLOWCXFLOW._serialized_start=4267
  _DIALOGFLOWCXFLOW._serialized_end=4810
  _DIALOGFLOWCXINTENTXPARAMETERS._serialized_start=4812
  _DIALOGFLOWCXINTENTXPARAMETERS._serialized_end=4909
  _DIALOGFLOWCXINTENTXTIMEOUTS._serialized_start=4911
  _DIALOGFLOWCXINTENTXTIMEOUTS._serialized_end=4988
  _DIALOGFLOWCXINTENTXTRAININGPHRASESXPARTS._serialized_start=4990
  _DIALOGFLOWCXINTENTXTRAININGPHRASESXPARTS._serialized_end=5068
  _DIALOGFLOWCXINTENTXTRAININGPHRASES._serialized_start=5071
  _DIALOGFLOWCXINTENTXTRAININGPHRASES._serialized_end=5226
  _DIALOGFLOWCXINTENT._serialized_start=5229
  _DIALOGFLOWCXINTENT._serialized_end=5820
  _DIALOGFLOWCXINTENT_LABELSENTRY._serialized_start=5775
  _DIALOGFLOWCXINTENT_LABELSENTRY._serialized_end=5820
  _DIALOGFLOWCXPAGEXENTRYFULFILLMENTXMESSAGESXTEXT._serialized_start=5822
  _DIALOGFLOWCXPAGEXENTRYFULFILLMENTXMESSAGESXTEXT._serialized_end=5922
  _DIALOGFLOWCXPAGEXENTRYFULFILLMENTXMESSAGES._serialized_start=5925
  _DIALOGFLOWCXPAGEXENTRYFULFILLMENTXMESSAGES._serialized_end=6060
  _DIALOGFLOWCXPAGEXENTRYFULFILLMENT._serialized_start=6063
  _DIALOGFLOWCXPAGEXENTRYFULFILLMENT._serialized_end=6252
  _DIALOGFLOWCXPAGEXEVENTHANDLERSXTRIGGERFULFILLMENTXMESSAGESXTEXT._serialized_start=6254
  _DIALOGFLOWCXPAGEXEVENTHANDLERSXTRIGGERFULFILLMENTXMESSAGESXTEXT._serialized_end=6370
  _DIALOGFLOWCXPAGEXEVENTHANDLERSXTRIGGERFULFILLMENTXMESSAGES._serialized_start=6373
  _DIALOGFLOWCXPAGEXEVENTHANDLERSXTRIGGERFULFILLMENTXMESSAGES._serialized_end=6540
  _DIALOGFLOWCXPAGEXEVENTHANDLERSXTRIGGERFULFILLMENT._serialized_start=6543
  _DIALOGFLOWCXPAGEXEVENTHANDLERSXTRIGGERFULFILLMENT._serialized_end=6764
  _DIALOGFLOWCXPAGEXEVENTHANDLERS._serialized_start=6767
  _DIALOGFLOWCXPAGEXEVENTHANDLERS._serialized_end=6978
  _DIALOGFLOWCXPAGEXFORMXPARAMETERSXFILLBEHAVIORXINITIALPROMPTFULFILLMENTXMESSAGESXTEXT._serialized_start=6981
  _DIALOGFLOWCXPAGEXFORMXPARAMETERSXFILLBEHAVIORXINITIALPROMPTFULFILLMENTXMESSAGESXTEXT._serialized_end=7118
  _DIALOGFLOWCXPAGEXFORMXPARAMETERSXFILLBEHAVIORXINITIALPROMPTFULFILLMENTXMESSAGES._serialized_start=7121
  _DIALOGFLOWCXPAGEXFORMXPARAMETERSXFILLBEHAVIORXINITIALPROMPTFULFILLMENTXMESSAGES._serialized_end=7330
  _DIALOGFLOWCXPAGEXFORMXPARAMETERSXFILLBEHAVIORXINITIALPROMPTFULFILLMENT._serialized_start=7333
  _DIALOGFLOWCXPAGEXFORMXPARAMETERSXFILLBEHAVIORXINITIALPROMPTFULFILLMENT._serialized_end=7596
  _DIALOGFLOWCXPAGEXFORMXPARAMETERSXFILLBEHAVIOR._serialized_start=7599
  _DIALOGFLOWCXPAGEXFORMXPARAMETERSXFILLBEHAVIOR._serialized_end=7783
  _DIALOGFLOWCXPAGEXFORMXPARAMETERS._serialized_start=7786
  _DIALOGFLOWCXPAGEXFORMXPARAMETERS._serialized_end=8012
  _DIALOGFLOWCXPAGEXFORM._serialized_start=8014
  _DIALOGFLOWCXPAGEXFORM._serialized_end=8119
  _DIALOGFLOWCXPAGEXTIMEOUTS._serialized_start=8121
  _DIALOGFLOWCXPAGEXTIMEOUTS._serialized_end=8196
  _DIALOGFLOWCXPAGEXTRANSITIONROUTESXTRIGGERFULFILLMENTXMESSAGESXTEXT._serialized_start=8198
  _DIALOGFLOWCXPAGEXTRANSITIONROUTESXTRIGGERFULFILLMENTXMESSAGESXTEXT._serialized_end=8317
  _DIALOGFLOWCXPAGEXTRANSITIONROUTESXTRIGGERFULFILLMENTXMESSAGES._serialized_start=8320
  _DIALOGFLOWCXPAGEXTRANSITIONROUTESXTRIGGERFULFILLMENTXMESSAGES._serialized_end=8493
  _DIALOGFLOWCXPAGEXTRANSITIONROUTESXTRIGGERFULFILLMENT._serialized_start=8496
  _DIALOGFLOWCXPAGEXTRANSITIONROUTESXTRIGGERFULFILLMENT._serialized_end=8723
  _DIALOGFLOWCXPAGEXTRANSITIONROUTES._serialized_start=8726
  _DIALOGFLOWCXPAGEXTRANSITIONROUTES._serialized_end=8963
  _DIALOGFLOWCXPAGE._serialized_start=8966
  _DIALOGFLOWCXPAGE._serialized_end=9563
  _DIALOGFLOWCXVERSIONXTIMEOUTS._serialized_start=9565
  _DIALOGFLOWCXVERSIONXTIMEOUTS._serialized_end=9643
  _DIALOGFLOWCXVERSION._serialized_start=9646
  _DIALOGFLOWCXVERSION._serialized_end=10061
  _DIALOGFLOWCXVERSION_NLUSETTINGSENTRY._serialized_start=10011
  _DIALOGFLOWCXVERSION_NLUSETTINGSENTRY._serialized_end=10061
  _DIALOGFLOWENTITYTYPEXENTITIES._serialized_start=10063
  _DIALOGFLOWENTITYTYPEXENTITIES._serialized_end=10127
  _DIALOGFLOWENTITYTYPEXTIMEOUTS._serialized_start=10129
  _DIALOGFLOWENTITYTYPEXTIMEOUTS._serialized_end=10208
  _DIALOGFLOWENTITYTYPE._serialized_start=10211
  _DIALOGFLOWENTITYTYPE._serialized_end=10556
  _DIALOGFLOWFULFILLMENTXFEATURES._serialized_start=10558
  _DIALOGFLOWFULFILLMENTXFEATURES._serialized_end=10604
  _DIALOGFLOWFULFILLMENTXGENERICWEBSERVICE._serialized_start=10607
  _DIALOGFLOWFULFILLMENTXGENERICWEBSERVICE._serialized_end=10866
  _DIALOGFLOWFULFILLMENTXGENERICWEBSERVICE_REQUESTHEADERSENTRY._serialized_start=10813
  _DIALOGFLOWFULFILLMENTXGENERICWEBSERVICE_REQUESTHEADERSENTRY._serialized_end=10866
  _DIALOGFLOWFULFILLMENTXTIMEOUTS._serialized_start=10868
  _DIALOGFLOWFULFILLMENTXTIMEOUTS._serialized_end=10948
  _DIALOGFLOWFULFILLMENT._serialized_start=10951
  _DIALOGFLOWFULFILLMENT._serialized_end=11367
  _DIALOGFLOWINTENTXTIMEOUTS._serialized_start=11369
  _DIALOGFLOWINTENTXTIMEOUTS._serialized_end=11444
  _DIALOGFLOWINTENT._serialized_start=11447
  _DIALOGFLOWINTENT._serialized_end=12095
  _DIALOGFLOWINTENT_FOLLOWUPINTENTINFOENTRY._serialized_start=12038
  _DIALOGFLOWINTENT_FOLLOWUPINTENTINFOENTRY._serialized_end=12095
# @@protoc_insertion_point(module_scope)
