# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_assured.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15gcp/gcp_assured.proto\x12\x17oak9.tython.gcp.assured\x1a\x13shared/shared.proto\"[\n$AssuredWorkloadsWorkloadXKmsSettings\x12\x1a\n\x12next_rotation_time\x18\x01 \x01(\t\x12\x17\n\x0frotation_period\x18\x02 \x01(\t\"W\n)AssuredWorkloadsWorkloadXResourceSettings\x12\x13\n\x0bresource_id\x18\x01 \x01(\t\x12\x15\n\rresource_type\x18\x02 \x01(\t\"S\n!AssuredWorkloadsWorkloadXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xa1\x06\n\x18\x41ssuredWorkloadsWorkload\x12\x17\n\x0f\x62illing_account\x18\x01 \x01(\t\x12\x19\n\x11\x63ompliance_regime\x18\x02 \x01(\t\x12\x13\n\x0b\x63reate_time\x18\x03 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x04 \x01(\t\x12\n\n\x02id\x18\x05 \x01(\t\x12M\n\x06labels\x18\x06 \x03(\x0b\x32=.oak9.tython.gcp.assured.AssuredWorkloadsWorkload.LabelsEntry\x12\x10\n\x08location\x18\x07 \x01(\t\x12\x0c\n\x04name\x18\x08 \x01(\t\x12\x14\n\x0corganization\x18\t \x01(\t\x12$\n\x1cprovisioned_resources_parent\x18\n \x01(\t\x12S\n\tresources\x18\x0b \x03(\x0b\x32@.oak9.tython.gcp.assured.AssuredWorkloadsWorkload.ResourcesEntry\x12S\n\x0ckms_settings\x18\x0c \x01(\x0b\x32=.oak9.tython.gcp.assured.AssuredWorkloadsWorkloadXKmsSettings\x12]\n\x11resource_settings\x18\r \x03(\x0b\x32\x42.oak9.tython.gcp.assured.AssuredWorkloadsWorkloadXResourceSettings\x12L\n\x08timeouts\x18\x0e \x01(\x0b\x32:.oak9.tython.gcp.assured.AssuredWorkloadsWorkloadXTimeouts\x12\x37\n\rresource_info\x18\x0f \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x30\n\x0eResourcesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_assured_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ASSUREDWORKLOADSWORKLOAD_LABELSENTRY._options = None
  _ASSUREDWORKLOADSWORKLOAD_LABELSENTRY._serialized_options = b'8\001'
  _ASSUREDWORKLOADSWORKLOAD_RESOURCESENTRY._options = None
  _ASSUREDWORKLOADSWORKLOAD_RESOURCESENTRY._serialized_options = b'8\001'
  _ASSUREDWORKLOADSWORKLOADXKMSSETTINGS._serialized_start=71
  _ASSUREDWORKLOADSWORKLOADXKMSSETTINGS._serialized_end=162
  _ASSUREDWORKLOADSWORKLOADXRESOURCESETTINGS._serialized_start=164
  _ASSUREDWORKLOADSWORKLOADXRESOURCESETTINGS._serialized_end=251
  _ASSUREDWORKLOADSWORKLOADXTIMEOUTS._serialized_start=253
  _ASSUREDWORKLOADSWORKLOADXTIMEOUTS._serialized_end=336
  _ASSUREDWORKLOADSWORKLOAD._serialized_start=339
  _ASSUREDWORKLOADSWORKLOAD._serialized_end=1140
  _ASSUREDWORKLOADSWORKLOAD_LABELSENTRY._serialized_start=1045
  _ASSUREDWORKLOADSWORKLOAD_LABELSENTRY._serialized_end=1090
  _ASSUREDWORKLOADSWORKLOAD_RESOURCESENTRY._serialized_start=1092
  _ASSUREDWORKLOADSWORKLOAD_RESOURCESENTRY._serialized_end=1140
# @@protoc_insertion_point(module_scope)
