# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: azure/azure_microsoft_network_frontdoor_networkexperimentprofiles.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nGazure/azure_microsoft_network_frontdoor_networkexperimentprofiles.proto\x12Goak9.tython.azure.microsoft_network_frontdoor_networkexperimentprofiles\x1a\x13shared/shared.proto\"\xc1\x01\n5Microsoft_Network_FrontDoor_NetworkExperimentProfiles\x12\x87\x01\n\x1bnetwork_experiment_profiles\x18\x01 \x03(\x0b\x32\x62.oak9.tython.azure.microsoft_network_frontdoor_networkexperimentprofiles.NetworkExperimentProfiles\"\xc6\x04\n$NetworkExperimentProfilesExperiments\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08location\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x15\n\renabled_state\x18\x05 \x01(\t\x12\x65\n\nendpoint_a\x18\x06 \x01(\x0b\x32Q.oak9.tython.azure.microsoft_network_frontdoor_networkexperimentprofiles.Endpoint\x12\x65\n\nendpoint_b\x18\x07 \x01(\x0b\x32Q.oak9.tython.azure.microsoft_network_frontdoor_networkexperimentprofiles.Endpoint\x12\x16\n\x0eresource_state\x18\x08 \x01(\t\x12\x85\x01\n\x04tags\x18\t \x03(\x0b\x32w.oak9.tython.azure.microsoft_network_frontdoor_networkexperimentprofiles.NetworkExperimentProfilesExperiments.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"*\n\x08\x45ndpoint\x12\x10\n\x08\x65ndpoint\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\xfc\x03\n\x19NetworkExperimentProfiles\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x15\n\renabled_state\x18\x05 \x01(\t\x12\x16\n\x0eresource_state\x18\x06 \x01(\t\x12z\n\x04tags\x18\x07 \x03(\x0b\x32l.oak9.tython.azure.microsoft_network_frontdoor_networkexperimentprofiles.NetworkExperimentProfiles.TagsEntry\x12\x9f\x01\n(network_experiment_profiles__experiments\x18\x08 \x03(\x0b\x32m.oak9.tython.azure.microsoft_network_frontdoor_networkexperimentprofiles.NetworkExperimentProfilesExperiments\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'azure.azure_microsoft_network_frontdoor_networkexperimentprofiles_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _NETWORKEXPERIMENTPROFILESEXPERIMENTS_TAGSENTRY._options = None
  _NETWORKEXPERIMENTPROFILESEXPERIMENTS_TAGSENTRY._serialized_options = b'8\001'
  _NETWORKEXPERIMENTPROFILES_TAGSENTRY._options = None
  _NETWORKEXPERIMENTPROFILES_TAGSENTRY._serialized_options = b'8\001'
  _MICROSOFT_NETWORK_FRONTDOOR_NETWORKEXPERIMENTPROFILES._serialized_start=170
  _MICROSOFT_NETWORK_FRONTDOOR_NETWORKEXPERIMENTPROFILES._serialized_end=363
  _NETWORKEXPERIMENTPROFILESEXPERIMENTS._serialized_start=366
  _NETWORKEXPERIMENTPROFILESEXPERIMENTS._serialized_end=948
  _NETWORKEXPERIMENTPROFILESEXPERIMENTS_TAGSENTRY._serialized_start=905
  _NETWORKEXPERIMENTPROFILESEXPERIMENTS_TAGSENTRY._serialized_end=948
  _ENDPOINT._serialized_start=950
  _ENDPOINT._serialized_end=992
  _NETWORKEXPERIMENTPROFILES._serialized_start=995
  _NETWORKEXPERIMENTPROFILES._serialized_end=1503
  _NETWORKEXPERIMENTPROFILES_TAGSENTRY._serialized_start=905
  _NETWORKEXPERIMENTPROFILES_TAGSENTRY._serialized_end=948
# @@protoc_insertion_point(module_scope)
